/* CommandManager.c generated by valac 0.40.4, the Vala compiler
 * generated from CommandManager.vala, do not modify */

/* Copyright 2016 Software Freedom Conservancy Inc.
 *
 * This software is licensed under the GNU LGPL (version 2.1 or later).
 * See the COPYING file in this distribution.
 */


#include <glib.h>
#include <glib-object.h>
#include <stdlib.h>
#include <string.h>
#include <gee.h>
#include <gobject/gvaluecollector.h>


#define TYPE_COMMAND_DESCRIPTION (command_description_get_type ())
#define COMMAND_DESCRIPTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_COMMAND_DESCRIPTION, CommandDescription))
#define IS_COMMAND_DESCRIPTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_COMMAND_DESCRIPTION))
#define COMMAND_DESCRIPTION_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), TYPE_COMMAND_DESCRIPTION, CommandDescriptionIface))

typedef struct _CommandDescription CommandDescription;
typedef struct _CommandDescriptionIface CommandDescriptionIface;

#define TYPE_COMMAND (command_get_type ())
#define COMMAND(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_COMMAND, Command))
#define COMMAND_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_COMMAND, CommandClass))
#define IS_COMMAND(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_COMMAND))
#define IS_COMMAND_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_COMMAND))
#define COMMAND_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_COMMAND, CommandClass))

typedef struct _Command Command;
typedef struct _CommandClass CommandClass;
typedef struct _CommandPrivate CommandPrivate;

#define TYPE_COMMAND_MANAGER (command_manager_get_type ())
#define COMMAND_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_COMMAND_MANAGER, CommandManager))
#define COMMAND_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_COMMAND_MANAGER, CommandManagerClass))
#define IS_COMMAND_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_COMMAND_MANAGER))
#define IS_COMMAND_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_COMMAND_MANAGER))
#define COMMAND_MANAGER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_COMMAND_MANAGER, CommandManagerClass))

typedef struct _CommandManager CommandManager;
typedef struct _CommandManagerClass CommandManagerClass;
enum  {
	COMMAND_0_PROPERTY,
	COMMAND_NUM_PROPERTIES
};
static GParamSpec* command_properties[COMMAND_NUM_PROPERTIES];
#define _g_free0(var) (var = (g_free (var), NULL))
typedef struct _CommandManagerPrivate CommandManagerPrivate;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
typedef struct _ParamSpecCommandManager ParamSpecCommandManager;
enum  {
	COMMAND_MANAGER_ALTERED_SIGNAL,
	COMMAND_MANAGER_NUM_SIGNALS
};
static guint command_manager_signals[COMMAND_MANAGER_NUM_SIGNALS] = {0};
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);
#define _vala_return_if_fail(expr, msg) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return; }
#define _vala_return_val_if_fail(expr, msg, val) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return val; }
#define _vala_warn_if_fail(expr, msg) if G_LIKELY (expr) ; else g_warn_message (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _CommandDescriptionIface {
	GTypeInterface parent_iface;
	gchar* (*get_name) (CommandDescription* self);
	gchar* (*get_explanation) (CommandDescription* self);
};

struct _Command {
	GObject parent_instance;
	CommandPrivate * priv;
};

struct _CommandClass {
	GObjectClass parent_class;
	void (*prepare) (Command* self);
	void (*execute) (Command* self);
	void (*undo) (Command* self);
	void (*redo) (Command* self);
	gboolean (*compress) (Command* self, Command* command);
	gchar* (*get_name) (Command* self);
	gchar* (*get_explanation) (Command* self);
};

struct _CommandPrivate {
	gchar* name;
	gchar* explanation;
	CommandManager* manager;
};

struct _CommandManager {
	GTypeInstance parent_instance;
	volatile int ref_count;
	CommandManagerPrivate * priv;
};

struct _CommandManagerClass {
	GTypeClass parent_class;
	void (*finalize) (CommandManager *self);
};

struct _CommandManagerPrivate {
	gint depth;
	GeeArrayList* undo_stack;
	GeeArrayList* redo_stack;
};

struct _ParamSpecCommandManager {
	GParamSpec parent_instance;
};


static gpointer command_parent_class = NULL;
static CommandDescriptionIface * command_command_description_parent_iface = NULL;
static gpointer command_manager_parent_class = NULL;

GType command_description_get_type (void) G_GNUC_CONST;
gchar* command_description_get_name (CommandDescription* self);
gchar* command_description_get_explanation (CommandDescription* self);
GType command_get_type (void) G_GNUC_CONST;
gpointer command_manager_ref (gpointer instance);
void command_manager_unref (gpointer instance);
GParamSpec* param_spec_command_manager (const gchar* name,
                                        const gchar* nick,
                                        const gchar* blurb,
                                        GType object_type,
                                        GParamFlags flags);
void value_set_command_manager (GValue* value,
                                gpointer v_object);
void value_take_command_manager (GValue* value,
                                 gpointer v_object);
gpointer value_get_command_manager (const GValue* value);
GType command_manager_get_type (void) G_GNUC_CONST;
#define COMMAND_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_COMMAND, CommandPrivate))
Command* command_construct (GType object_type,
                            const gchar* name,
                            const gchar* explanation);
void command_prepare (Command* self);
static void command_real_prepare (Command* self);
void command_execute (Command* self);
static void command_real_execute (Command* self);
void command_undo (Command* self);
static void command_real_undo (Command* self);
void command_redo (Command* self);
static void command_real_redo (Command* self);
gboolean command_compress (Command* self,
                           Command* command);
static gboolean command_real_compress (Command* self,
                                Command* command);
gchar* command_get_name (Command* self);
static gchar* command_real_get_name (Command* self);
gchar* command_get_explanation (Command* self);
static gchar* command_real_get_explanation (Command* self);
CommandManager* command_get_command_manager (Command* self);
void command_internal_set_command_manager (Command* self,
                                           CommandManager* manager);
static void command_finalize (GObject * obj);
#define COMMAND_MANAGER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_COMMAND_MANAGER, CommandManagerPrivate))
#define COMMAND_MANAGER_DEFAULT_DEPTH 20
CommandManager* command_manager_new (gint depth);
CommandManager* command_manager_construct (GType object_type,
                                           gint depth);
void command_manager_reset (CommandManager* self);
void command_manager_execute (CommandManager* self,
                              Command* command);
static Command* command_manager_top (CommandManager* self,
                              GeeArrayList* stack);
static void command_manager_push (CommandManager* self,
                           GeeArrayList* stack,
                           Command* command);
gboolean command_manager_can_undo (CommandManager* self);
gboolean command_manager_can_redo (CommandManager* self);
CommandDescription* command_manager_get_undo_description (CommandManager* self);
gboolean command_manager_undo (CommandManager* self);
static Command* command_manager_pop (CommandManager* self,
                              GeeArrayList* stack);
CommandDescription* command_manager_get_redo_description (CommandManager* self);
gboolean command_manager_redo (CommandManager* self);
static void g_cclosure_user_marshal_VOID__BOOLEAN_BOOLEAN (GClosure * closure,
                                                    GValue * return_value,
                                                    guint n_param_values,
                                                    const GValue * param_values,
                                                    gpointer invocation_hint,
                                                    gpointer marshal_data);
static void command_manager_finalize (CommandManager * obj);


gchar*
command_description_get_name (CommandDescription* self)
{
#line 8 "/home/jens/Source/shotwell/src/CommandManager.vala"
	g_return_val_if_fail (IS_COMMAND_DESCRIPTION (self), NULL);
#line 8 "/home/jens/Source/shotwell/src/CommandManager.vala"
	return COMMAND_DESCRIPTION_GET_INTERFACE (self)->get_name (self);
#line 199 "CommandManager.c"
}


gchar*
command_description_get_explanation (CommandDescription* self)
{
#line 10 "/home/jens/Source/shotwell/src/CommandManager.vala"
	g_return_val_if_fail (IS_COMMAND_DESCRIPTION (self), NULL);
#line 10 "/home/jens/Source/shotwell/src/CommandManager.vala"
	return COMMAND_DESCRIPTION_GET_INTERFACE (self)->get_explanation (self);
#line 210 "CommandManager.c"
}


static void
command_description_base_init (CommandDescriptionIface * iface)
{
#line 7 "/home/jens/Source/shotwell/src/CommandManager.vala"
	static gboolean initialized = FALSE;
#line 7 "/home/jens/Source/shotwell/src/CommandManager.vala"
	if (!initialized) {
#line 7 "/home/jens/Source/shotwell/src/CommandManager.vala"
		initialized = TRUE;
#line 223 "CommandManager.c"
	}
}


GType
command_description_get_type (void)
{
	static volatile gsize command_description_type_id__volatile = 0;
	if (g_once_init_enter (&command_description_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (CommandDescriptionIface), (GBaseInitFunc) command_description_base_init, (GBaseFinalizeFunc) NULL, (GClassInitFunc) NULL, (GClassFinalizeFunc) NULL, NULL, 0, 0, (GInstanceInitFunc) NULL, NULL };
		GType command_description_type_id;
		command_description_type_id = g_type_register_static (G_TYPE_INTERFACE, "CommandDescription", &g_define_type_info, 0);
		g_type_interface_add_prerequisite (command_description_type_id, G_TYPE_OBJECT);
		g_once_init_leave (&command_description_type_id__volatile, command_description_type_id);
	}
	return command_description_type_id__volatile;
}


Command*
command_construct (GType object_type,
                   const gchar* name,
                   const gchar* explanation)
{
	Command * self = NULL;
	gchar* _tmp0_;
	gchar* _tmp1_;
#line 32 "/home/jens/Source/shotwell/src/CommandManager.vala"
	g_return_val_if_fail (name != NULL, NULL);
#line 32 "/home/jens/Source/shotwell/src/CommandManager.vala"
	g_return_val_if_fail (explanation != NULL, NULL);
#line 32 "/home/jens/Source/shotwell/src/CommandManager.vala"
	self = (Command*) g_object_new (object_type, NULL);
#line 33 "/home/jens/Source/shotwell/src/CommandManager.vala"
	_tmp0_ = g_strdup (name);
#line 33 "/home/jens/Source/shotwell/src/CommandManager.vala"
	_g_free0 (self->priv->name);
#line 33 "/home/jens/Source/shotwell/src/CommandManager.vala"
	self->priv->name = _tmp0_;
#line 34 "/home/jens/Source/shotwell/src/CommandManager.vala"
	_tmp1_ = g_strdup (explanation);
#line 34 "/home/jens/Source/shotwell/src/CommandManager.vala"
	_g_free0 (self->priv->explanation);
#line 34 "/home/jens/Source/shotwell/src/CommandManager.vala"
	self->priv->explanation = _tmp1_;
#line 32 "/home/jens/Source/shotwell/src/CommandManager.vala"
	return self;
#line 271 "CommandManager.c"
}


static void
command_real_prepare (Command* self)
{
}


void
command_prepare (Command* self)
{
#line 43 "/home/jens/Source/shotwell/src/CommandManager.vala"
	g_return_if_fail (IS_COMMAND (self));
#line 43 "/home/jens/Source/shotwell/src/CommandManager.vala"
	COMMAND_GET_CLASS (self)->prepare (self);
#line 288 "CommandManager.c"
}


static void
command_real_execute (Command* self)
{
#line 46 "/home/jens/Source/shotwell/src/CommandManager.vala"
	g_critical ("Type `%s' does not implement abstract method `command_execute'", g_type_name (G_TYPE_FROM_INSTANCE (self)));
#line 46 "/home/jens/Source/shotwell/src/CommandManager.vala"
	return;
#line 299 "CommandManager.c"
}


void
command_execute (Command* self)
{
#line 46 "/home/jens/Source/shotwell/src/CommandManager.vala"
	g_return_if_fail (IS_COMMAND (self));
#line 46 "/home/jens/Source/shotwell/src/CommandManager.vala"
	COMMAND_GET_CLASS (self)->execute (self);
#line 310 "CommandManager.c"
}


static void
command_real_undo (Command* self)
{
#line 48 "/home/jens/Source/shotwell/src/CommandManager.vala"
	g_critical ("Type `%s' does not implement abstract method `command_undo'", g_type_name (G_TYPE_FROM_INSTANCE (self)));
#line 48 "/home/jens/Source/shotwell/src/CommandManager.vala"
	return;
#line 321 "CommandManager.c"
}


void
command_undo (Command* self)
{
#line 48 "/home/jens/Source/shotwell/src/CommandManager.vala"
	g_return_if_fail (IS_COMMAND (self));
#line 48 "/home/jens/Source/shotwell/src/CommandManager.vala"
	COMMAND_GET_CLASS (self)->undo (self);
#line 332 "CommandManager.c"
}


static void
command_real_redo (Command* self)
{
#line 51 "/home/jens/Source/shotwell/src/CommandManager.vala"
	command_execute (self);
#line 341 "CommandManager.c"
}


void
command_redo (Command* self)
{
#line 50 "/home/jens/Source/shotwell/src/CommandManager.vala"
	g_return_if_fail (IS_COMMAND (self));
#line 50 "/home/jens/Source/shotwell/src/CommandManager.vala"
	COMMAND_GET_CLASS (self)->redo (self);
#line 352 "CommandManager.c"
}


static gboolean
command_real_compress (Command* self,
                       Command* command)
{
	gboolean result = FALSE;
#line 56 "/home/jens/Source/shotwell/src/CommandManager.vala"
	g_return_val_if_fail (IS_COMMAND (command), FALSE);
#line 57 "/home/jens/Source/shotwell/src/CommandManager.vala"
	result = FALSE;
#line 57 "/home/jens/Source/shotwell/src/CommandManager.vala"
	return result;
#line 367 "CommandManager.c"
}


gboolean
command_compress (Command* self,
                  Command* command)
{
#line 56 "/home/jens/Source/shotwell/src/CommandManager.vala"
	g_return_val_if_fail (IS_COMMAND (self), FALSE);
#line 56 "/home/jens/Source/shotwell/src/CommandManager.vala"
	return COMMAND_GET_CLASS (self)->compress (self, command);
#line 379 "CommandManager.c"
}


static gchar*
command_real_get_name (Command* self)
{
	gchar* result = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 61 "/home/jens/Source/shotwell/src/CommandManager.vala"
	_tmp0_ = self->priv->name;
#line 61 "/home/jens/Source/shotwell/src/CommandManager.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 61 "/home/jens/Source/shotwell/src/CommandManager.vala"
	result = _tmp1_;
#line 61 "/home/jens/Source/shotwell/src/CommandManager.vala"
	return result;
#line 397 "CommandManager.c"
}


gchar*
command_get_name (Command* self)
{
#line 60 "/home/jens/Source/shotwell/src/CommandManager.vala"
	g_return_val_if_fail (IS_COMMAND (self), NULL);
#line 60 "/home/jens/Source/shotwell/src/CommandManager.vala"
	return COMMAND_GET_CLASS (self)->get_name (self);
#line 408 "CommandManager.c"
}


static gchar*
command_real_get_explanation (Command* self)
{
	gchar* result = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 65 "/home/jens/Source/shotwell/src/CommandManager.vala"
	_tmp0_ = self->priv->explanation;
#line 65 "/home/jens/Source/shotwell/src/CommandManager.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 65 "/home/jens/Source/shotwell/src/CommandManager.vala"
	result = _tmp1_;
#line 65 "/home/jens/Source/shotwell/src/CommandManager.vala"
	return result;
#line 426 "CommandManager.c"
}


gchar*
command_get_explanation (Command* self)
{
#line 64 "/home/jens/Source/shotwell/src/CommandManager.vala"
	g_return_val_if_fail (IS_COMMAND (self), NULL);
#line 64 "/home/jens/Source/shotwell/src/CommandManager.vala"
	return COMMAND_GET_CLASS (self)->get_explanation (self);
#line 437 "CommandManager.c"
}


static gpointer
_command_manager_ref0 (gpointer self)
{
#line 69 "/home/jens/Source/shotwell/src/CommandManager.vala"
	return self ? command_manager_ref (self) : NULL;
#line 446 "CommandManager.c"
}


CommandManager*
command_get_command_manager (Command* self)
{
	CommandManager* result = NULL;
	CommandManager* _tmp0_;
	CommandManager* _tmp1_;
#line 68 "/home/jens/Source/shotwell/src/CommandManager.vala"
	g_return_val_if_fail (IS_COMMAND (self), NULL);
#line 69 "/home/jens/Source/shotwell/src/CommandManager.vala"
	_tmp0_ = self->priv->manager;
#line 69 "/home/jens/Source/shotwell/src/CommandManager.vala"
	_tmp1_ = _command_manager_ref0 (_tmp0_);
#line 69 "/home/jens/Source/shotwell/src/CommandManager.vala"
	result = _tmp1_;
#line 69 "/home/jens/Source/shotwell/src/CommandManager.vala"
	return result;
#line 466 "CommandManager.c"
}


void
command_internal_set_command_manager (Command* self,
                                      CommandManager* manager)
{
	CommandManager* _tmp0_;
#line 73 "/home/jens/Source/shotwell/src/CommandManager.vala"
	g_return_if_fail (IS_COMMAND (self));
#line 73 "/home/jens/Source/shotwell/src/CommandManager.vala"
	g_return_if_fail (IS_COMMAND_MANAGER (manager));
#line 74 "/home/jens/Source/shotwell/src/CommandManager.vala"
	_tmp0_ = self->priv->manager;
#line 74 "/home/jens/Source/shotwell/src/CommandManager.vala"
	_vala_assert (_tmp0_ == NULL, "this.manager == null");
#line 76 "/home/jens/Source/shotwell/src/CommandManager.vala"
	self->priv->manager = manager;
#line 485 "CommandManager.c"
}


static void
command_class_init (CommandClass * klass)
{
#line 27 "/home/jens/Source/shotwell/src/CommandManager.vala"
	command_parent_class = g_type_class_peek_parent (klass);
#line 27 "/home/jens/Source/shotwell/src/CommandManager.vala"
	g_type_class_add_private (klass, sizeof (CommandPrivate));
#line 27 "/home/jens/Source/shotwell/src/CommandManager.vala"
	((CommandClass *) klass)->prepare = (void (*) (Command *)) command_real_prepare;
#line 27 "/home/jens/Source/shotwell/src/CommandManager.vala"
	((CommandClass *) klass)->execute = (void (*) (Command *)) command_real_execute;
#line 27 "/home/jens/Source/shotwell/src/CommandManager.vala"
	((CommandClass *) klass)->undo = (void (*) (Command *)) command_real_undo;
#line 27 "/home/jens/Source/shotwell/src/CommandManager.vala"
	((CommandClass *) klass)->redo = (void (*) (Command *)) command_real_redo;
#line 27 "/home/jens/Source/shotwell/src/CommandManager.vala"
	((CommandClass *) klass)->compress = (gboolean (*) (Command *, Command*)) command_real_compress;
#line 27 "/home/jens/Source/shotwell/src/CommandManager.vala"
	((CommandClass *) klass)->get_name = (gchar* (*) (Command *)) command_real_get_name;
#line 27 "/home/jens/Source/shotwell/src/CommandManager.vala"
	((CommandClass *) klass)->get_explanation = (gchar* (*) (Command *)) command_real_get_explanation;
#line 27 "/home/jens/Source/shotwell/src/CommandManager.vala"
	G_OBJECT_CLASS (klass)->finalize = command_finalize;
#line 512 "CommandManager.c"
}


static void
command_command_description_interface_init (CommandDescriptionIface * iface)
{
#line 27 "/home/jens/Source/shotwell/src/CommandManager.vala"
	command_command_description_parent_iface = g_type_interface_peek_parent (iface);
#line 27 "/home/jens/Source/shotwell/src/CommandManager.vala"
	iface->get_name = (gchar* (*) (CommandDescription *)) command_get_name;
#line 27 "/home/jens/Source/shotwell/src/CommandManager.vala"
	iface->get_explanation = (gchar* (*) (CommandDescription *)) command_get_explanation;
#line 525 "CommandManager.c"
}


static void
command_instance_init (Command * self)
{
#line 27 "/home/jens/Source/shotwell/src/CommandManager.vala"
	self->priv = COMMAND_GET_PRIVATE (self);
#line 30 "/home/jens/Source/shotwell/src/CommandManager.vala"
	self->priv->manager = NULL;
#line 536 "CommandManager.c"
}


static void
command_finalize (GObject * obj)
{
	Command * self;
#line 27 "/home/jens/Source/shotwell/src/CommandManager.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_COMMAND, Command);
#line 28 "/home/jens/Source/shotwell/src/CommandManager.vala"
	_g_free0 (self->priv->name);
#line 29 "/home/jens/Source/shotwell/src/CommandManager.vala"
	_g_free0 (self->priv->explanation);
#line 27 "/home/jens/Source/shotwell/src/CommandManager.vala"
	G_OBJECT_CLASS (command_parent_class)->finalize (obj);
#line 552 "CommandManager.c"
}


GType
command_get_type (void)
{
	static volatile gsize command_type_id__volatile = 0;
	if (g_once_init_enter (&command_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (CommandClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) command_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (Command), 0, (GInstanceInitFunc) command_instance_init, NULL };
		static const GInterfaceInfo command_description_info = { (GInterfaceInitFunc) command_command_description_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType command_type_id;
		command_type_id = g_type_register_static (G_TYPE_OBJECT, "Command", &g_define_type_info, G_TYPE_FLAG_ABSTRACT);
		g_type_add_interface_static (command_type_id, TYPE_COMMAND_DESCRIPTION, &command_description_info);
		g_once_init_leave (&command_type_id__volatile, command_type_id);
	}
	return command_type_id__volatile;
}


CommandManager*
command_manager_construct (GType object_type,
                           gint depth)
{
	CommandManager* self = NULL;
#line 89 "/home/jens/Source/shotwell/src/CommandManager.vala"
	self = (CommandManager*) g_type_create_instance (object_type);
#line 90 "/home/jens/Source/shotwell/src/CommandManager.vala"
	_vala_assert (depth > 0, "depth > 0");
#line 92 "/home/jens/Source/shotwell/src/CommandManager.vala"
	self->priv->depth = depth;
#line 89 "/home/jens/Source/shotwell/src/CommandManager.vala"
	return self;
#line 585 "CommandManager.c"
}


CommandManager*
command_manager_new (gint depth)
{
#line 89 "/home/jens/Source/shotwell/src/CommandManager.vala"
	return command_manager_construct (TYPE_COMMAND_MANAGER, depth);
#line 594 "CommandManager.c"
}


void
command_manager_reset (CommandManager* self)
{
	GeeArrayList* _tmp0_;
	GeeArrayList* _tmp1_;
#line 95 "/home/jens/Source/shotwell/src/CommandManager.vala"
	g_return_if_fail (IS_COMMAND_MANAGER (self));
#line 96 "/home/jens/Source/shotwell/src/CommandManager.vala"
	_tmp0_ = self->priv->undo_stack;
#line 96 "/home/jens/Source/shotwell/src/CommandManager.vala"
	gee_abstract_collection_clear (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection));
#line 97 "/home/jens/Source/shotwell/src/CommandManager.vala"
	_tmp1_ = self->priv->redo_stack;
#line 97 "/home/jens/Source/shotwell/src/CommandManager.vala"
	gee_abstract_collection_clear (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection));
#line 99 "/home/jens/Source/shotwell/src/CommandManager.vala"
	g_signal_emit (self, command_manager_signals[COMMAND_MANAGER_ALTERED_SIGNAL], 0, FALSE, FALSE);
#line 615 "CommandManager.c"
}


void
command_manager_execute (CommandManager* self,
                         Command* command)
{
	GeeArrayList* _tmp0_;
	Command* top_command = NULL;
	GeeArrayList* _tmp1_;
	Command* _tmp2_;
	Command* _tmp3_;
	GeeArrayList* _tmp5_;
#line 102 "/home/jens/Source/shotwell/src/CommandManager.vala"
	g_return_if_fail (IS_COMMAND_MANAGER (self));
#line 102 "/home/jens/Source/shotwell/src/CommandManager.vala"
	g_return_if_fail (IS_COMMAND (command));
#line 104 "/home/jens/Source/shotwell/src/CommandManager.vala"
	command_internal_set_command_manager (command, self);
#line 107 "/home/jens/Source/shotwell/src/CommandManager.vala"
	_tmp0_ = self->priv->redo_stack;
#line 107 "/home/jens/Source/shotwell/src/CommandManager.vala"
	gee_abstract_collection_clear (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection));
#line 110 "/home/jens/Source/shotwell/src/CommandManager.vala"
	_tmp1_ = self->priv->undo_stack;
#line 110 "/home/jens/Source/shotwell/src/CommandManager.vala"
	_tmp2_ = command_manager_top (self, _tmp1_);
#line 110 "/home/jens/Source/shotwell/src/CommandManager.vala"
	top_command = _tmp2_;
#line 111 "/home/jens/Source/shotwell/src/CommandManager.vala"
	_tmp3_ = top_command;
#line 111 "/home/jens/Source/shotwell/src/CommandManager.vala"
	if (_tmp3_ != NULL) {
#line 649 "CommandManager.c"
		Command* _tmp4_;
#line 112 "/home/jens/Source/shotwell/src/CommandManager.vala"
		_tmp4_ = top_command;
#line 112 "/home/jens/Source/shotwell/src/CommandManager.vala"
		if (command_compress (_tmp4_, command)) {
#line 113 "/home/jens/Source/shotwell/src/CommandManager.vala"
			_g_object_unref0 (top_command);
#line 113 "/home/jens/Source/shotwell/src/CommandManager.vala"
			return;
#line 659 "CommandManager.c"
		}
	}
#line 117 "/home/jens/Source/shotwell/src/CommandManager.vala"
	_tmp5_ = self->priv->undo_stack;
#line 117 "/home/jens/Source/shotwell/src/CommandManager.vala"
	command_manager_push (self, _tmp5_, command);
#line 119 "/home/jens/Source/shotwell/src/CommandManager.vala"
	command_prepare (command);
#line 120 "/home/jens/Source/shotwell/src/CommandManager.vala"
	command_execute (command);
#line 123 "/home/jens/Source/shotwell/src/CommandManager.vala"
	g_signal_emit (self, command_manager_signals[COMMAND_MANAGER_ALTERED_SIGNAL], 0, command_manager_can_undo (self), command_manager_can_redo (self));
#line 102 "/home/jens/Source/shotwell/src/CommandManager.vala"
	_g_object_unref0 (top_command);
#line 674 "CommandManager.c"
}


gboolean
command_manager_can_undo (CommandManager* self)
{
	gboolean result = FALSE;
	GeeArrayList* _tmp0_;
	gint _tmp1_;
	gint _tmp2_;
#line 126 "/home/jens/Source/shotwell/src/CommandManager.vala"
	g_return_val_if_fail (IS_COMMAND_MANAGER (self), FALSE);
#line 127 "/home/jens/Source/shotwell/src/CommandManager.vala"
	_tmp0_ = self->priv->undo_stack;
#line 127 "/home/jens/Source/shotwell/src/CommandManager.vala"
	_tmp1_ = gee_abstract_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection));
#line 127 "/home/jens/Source/shotwell/src/CommandManager.vala"
	_tmp2_ = _tmp1_;
#line 127 "/home/jens/Source/shotwell/src/CommandManager.vala"
	result = _tmp2_ > 0;
#line 127 "/home/jens/Source/shotwell/src/CommandManager.vala"
	return result;
#line 697 "CommandManager.c"
}


CommandDescription*
command_manager_get_undo_description (CommandManager* self)
{
	CommandDescription* result = NULL;
	GeeArrayList* _tmp0_;
	Command* _tmp1_;
#line 130 "/home/jens/Source/shotwell/src/CommandManager.vala"
	g_return_val_if_fail (IS_COMMAND_MANAGER (self), NULL);
#line 131 "/home/jens/Source/shotwell/src/CommandManager.vala"
	_tmp0_ = self->priv->undo_stack;
#line 131 "/home/jens/Source/shotwell/src/CommandManager.vala"
	_tmp1_ = command_manager_top (self, _tmp0_);
#line 131 "/home/jens/Source/shotwell/src/CommandManager.vala"
	result = G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, TYPE_COMMAND_DESCRIPTION, CommandDescription);
#line 131 "/home/jens/Source/shotwell/src/CommandManager.vala"
	return result;
#line 717 "CommandManager.c"
}


gboolean
command_manager_undo (CommandManager* self)
{
	gboolean result = FALSE;
	Command* command = NULL;
	GeeArrayList* _tmp0_;
	Command* _tmp1_;
	Command* _tmp2_;
	GeeArrayList* _tmp3_;
	Command* _tmp4_;
	Command* _tmp5_;
	Command* _tmp6_;
#line 134 "/home/jens/Source/shotwell/src/CommandManager.vala"
	g_return_val_if_fail (IS_COMMAND_MANAGER (self), FALSE);
#line 135 "/home/jens/Source/shotwell/src/CommandManager.vala"
	_tmp0_ = self->priv->undo_stack;
#line 135 "/home/jens/Source/shotwell/src/CommandManager.vala"
	_tmp1_ = command_manager_pop (self, _tmp0_);
#line 135 "/home/jens/Source/shotwell/src/CommandManager.vala"
	command = _tmp1_;
#line 136 "/home/jens/Source/shotwell/src/CommandManager.vala"
	_tmp2_ = command;
#line 136 "/home/jens/Source/shotwell/src/CommandManager.vala"
	if (_tmp2_ == NULL) {
#line 137 "/home/jens/Source/shotwell/src/CommandManager.vala"
		result = FALSE;
#line 137 "/home/jens/Source/shotwell/src/CommandManager.vala"
		_g_object_unref0 (command);
#line 137 "/home/jens/Source/shotwell/src/CommandManager.vala"
		return result;
#line 751 "CommandManager.c"
	}
#line 140 "/home/jens/Source/shotwell/src/CommandManager.vala"
	_tmp3_ = self->priv->redo_stack;
#line 140 "/home/jens/Source/shotwell/src/CommandManager.vala"
	_tmp4_ = command;
#line 140 "/home/jens/Source/shotwell/src/CommandManager.vala"
	command_manager_push (self, _tmp3_, _tmp4_);
#line 143 "/home/jens/Source/shotwell/src/CommandManager.vala"
	_tmp5_ = command;
#line 143 "/home/jens/Source/shotwell/src/CommandManager.vala"
	command_prepare (_tmp5_);
#line 144 "/home/jens/Source/shotwell/src/CommandManager.vala"
	_tmp6_ = command;
#line 144 "/home/jens/Source/shotwell/src/CommandManager.vala"
	command_undo (_tmp6_);
#line 147 "/home/jens/Source/shotwell/src/CommandManager.vala"
	g_signal_emit (self, command_manager_signals[COMMAND_MANAGER_ALTERED_SIGNAL], 0, command_manager_can_undo (self), command_manager_can_redo (self));
#line 149 "/home/jens/Source/shotwell/src/CommandManager.vala"
	result = TRUE;
#line 149 "/home/jens/Source/shotwell/src/CommandManager.vala"
	_g_object_unref0 (command);
#line 149 "/home/jens/Source/shotwell/src/CommandManager.vala"
	return result;
#line 775 "CommandManager.c"
}


gboolean
command_manager_can_redo (CommandManager* self)
{
	gboolean result = FALSE;
	GeeArrayList* _tmp0_;
	gint _tmp1_;
	gint _tmp2_;
#line 152 "/home/jens/Source/shotwell/src/CommandManager.vala"
	g_return_val_if_fail (IS_COMMAND_MANAGER (self), FALSE);
#line 153 "/home/jens/Source/shotwell/src/CommandManager.vala"
	_tmp0_ = self->priv->redo_stack;
#line 153 "/home/jens/Source/shotwell/src/CommandManager.vala"
	_tmp1_ = gee_abstract_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection));
#line 153 "/home/jens/Source/shotwell/src/CommandManager.vala"
	_tmp2_ = _tmp1_;
#line 153 "/home/jens/Source/shotwell/src/CommandManager.vala"
	result = _tmp2_ > 0;
#line 153 "/home/jens/Source/shotwell/src/CommandManager.vala"
	return result;
#line 798 "CommandManager.c"
}


CommandDescription*
command_manager_get_redo_description (CommandManager* self)
{
	CommandDescription* result = NULL;
	GeeArrayList* _tmp0_;
	Command* _tmp1_;
#line 156 "/home/jens/Source/shotwell/src/CommandManager.vala"
	g_return_val_if_fail (IS_COMMAND_MANAGER (self), NULL);
#line 157 "/home/jens/Source/shotwell/src/CommandManager.vala"
	_tmp0_ = self->priv->redo_stack;
#line 157 "/home/jens/Source/shotwell/src/CommandManager.vala"
	_tmp1_ = command_manager_top (self, _tmp0_);
#line 157 "/home/jens/Source/shotwell/src/CommandManager.vala"
	result = G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, TYPE_COMMAND_DESCRIPTION, CommandDescription);
#line 157 "/home/jens/Source/shotwell/src/CommandManager.vala"
	return result;
#line 818 "CommandManager.c"
}


gboolean
command_manager_redo (CommandManager* self)
{
	gboolean result = FALSE;
	Command* command = NULL;
	GeeArrayList* _tmp0_;
	Command* _tmp1_;
	Command* _tmp2_;
	GeeArrayList* _tmp3_;
	Command* _tmp4_;
	Command* _tmp5_;
	Command* _tmp6_;
#line 160 "/home/jens/Source/shotwell/src/CommandManager.vala"
	g_return_val_if_fail (IS_COMMAND_MANAGER (self), FALSE);
#line 161 "/home/jens/Source/shotwell/src/CommandManager.vala"
	_tmp0_ = self->priv->redo_stack;
#line 161 "/home/jens/Source/shotwell/src/CommandManager.vala"
	_tmp1_ = command_manager_pop (self, _tmp0_);
#line 161 "/home/jens/Source/shotwell/src/CommandManager.vala"
	command = _tmp1_;
#line 162 "/home/jens/Source/shotwell/src/CommandManager.vala"
	_tmp2_ = command;
#line 162 "/home/jens/Source/shotwell/src/CommandManager.vala"
	if (_tmp2_ == NULL) {
#line 163 "/home/jens/Source/shotwell/src/CommandManager.vala"
		result = FALSE;
#line 163 "/home/jens/Source/shotwell/src/CommandManager.vala"
		_g_object_unref0 (command);
#line 163 "/home/jens/Source/shotwell/src/CommandManager.vala"
		return result;
#line 852 "CommandManager.c"
	}
#line 166 "/home/jens/Source/shotwell/src/CommandManager.vala"
	_tmp3_ = self->priv->undo_stack;
#line 166 "/home/jens/Source/shotwell/src/CommandManager.vala"
	_tmp4_ = command;
#line 166 "/home/jens/Source/shotwell/src/CommandManager.vala"
	command_manager_push (self, _tmp3_, _tmp4_);
#line 169 "/home/jens/Source/shotwell/src/CommandManager.vala"
	_tmp5_ = command;
#line 169 "/home/jens/Source/shotwell/src/CommandManager.vala"
	command_prepare (_tmp5_);
#line 170 "/home/jens/Source/shotwell/src/CommandManager.vala"
	_tmp6_ = command;
#line 170 "/home/jens/Source/shotwell/src/CommandManager.vala"
	command_redo (_tmp6_);
#line 173 "/home/jens/Source/shotwell/src/CommandManager.vala"
	g_signal_emit (self, command_manager_signals[COMMAND_MANAGER_ALTERED_SIGNAL], 0, command_manager_can_undo (self), command_manager_can_redo (self));
#line 175 "/home/jens/Source/shotwell/src/CommandManager.vala"
	result = TRUE;
#line 175 "/home/jens/Source/shotwell/src/CommandManager.vala"
	_g_object_unref0 (command);
#line 175 "/home/jens/Source/shotwell/src/CommandManager.vala"
	return result;
#line 876 "CommandManager.c"
}


static Command*
command_manager_top (CommandManager* self,
                     GeeArrayList* stack)
{
	Command* result = NULL;
	Command* _tmp0_ = NULL;
	gint _tmp1_;
	gint _tmp2_;
#line 178 "/home/jens/Source/shotwell/src/CommandManager.vala"
	g_return_val_if_fail (IS_COMMAND_MANAGER (self), NULL);
#line 178 "/home/jens/Source/shotwell/src/CommandManager.vala"
	g_return_val_if_fail (GEE_IS_ARRAY_LIST (stack), NULL);
#line 179 "/home/jens/Source/shotwell/src/CommandManager.vala"
	_tmp1_ = gee_abstract_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (stack, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection));
#line 179 "/home/jens/Source/shotwell/src/CommandManager.vala"
	_tmp2_ = _tmp1_;
#line 179 "/home/jens/Source/shotwell/src/CommandManager.vala"
	if (_tmp2_ > 0) {
#line 898 "CommandManager.c"
		gint _tmp3_;
		gint _tmp4_;
		gpointer _tmp5_;
#line 179 "/home/jens/Source/shotwell/src/CommandManager.vala"
		_tmp3_ = gee_abstract_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (stack, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection));
#line 179 "/home/jens/Source/shotwell/src/CommandManager.vala"
		_tmp4_ = _tmp3_;
#line 179 "/home/jens/Source/shotwell/src/CommandManager.vala"
		_tmp5_ = gee_abstract_list_get (G_TYPE_CHECK_INSTANCE_CAST (stack, GEE_TYPE_ABSTRACT_LIST, GeeAbstractList), _tmp4_ - 1);
#line 179 "/home/jens/Source/shotwell/src/CommandManager.vala"
		_g_object_unref0 (_tmp0_);
#line 179 "/home/jens/Source/shotwell/src/CommandManager.vala"
		_tmp0_ = (Command*) _tmp5_;
#line 912 "CommandManager.c"
	} else {
#line 179 "/home/jens/Source/shotwell/src/CommandManager.vala"
		_g_object_unref0 (_tmp0_);
#line 179 "/home/jens/Source/shotwell/src/CommandManager.vala"
		_tmp0_ = NULL;
#line 918 "CommandManager.c"
	}
#line 179 "/home/jens/Source/shotwell/src/CommandManager.vala"
	result = _tmp0_;
#line 179 "/home/jens/Source/shotwell/src/CommandManager.vala"
	return result;
#line 924 "CommandManager.c"
}


static void
command_manager_push (CommandManager* self,
                      GeeArrayList* stack,
                      Command* command)
{
#line 182 "/home/jens/Source/shotwell/src/CommandManager.vala"
	g_return_if_fail (IS_COMMAND_MANAGER (self));
#line 182 "/home/jens/Source/shotwell/src/CommandManager.vala"
	g_return_if_fail (GEE_IS_ARRAY_LIST (stack));
#line 182 "/home/jens/Source/shotwell/src/CommandManager.vala"
	g_return_if_fail (IS_COMMAND (command));
#line 183 "/home/jens/Source/shotwell/src/CommandManager.vala"
	gee_abstract_collection_add (G_TYPE_CHECK_INSTANCE_CAST (stack, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection), command);
#line 186 "/home/jens/Source/shotwell/src/CommandManager.vala"
	while (TRUE) {
#line 943 "CommandManager.c"
		gint _tmp0_;
		gint _tmp1_;
		gint _tmp2_;
		gpointer _tmp3_;
		Command* _tmp4_;
#line 186 "/home/jens/Source/shotwell/src/CommandManager.vala"
		_tmp0_ = gee_abstract_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (stack, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection));
#line 186 "/home/jens/Source/shotwell/src/CommandManager.vala"
		_tmp1_ = _tmp0_;
#line 186 "/home/jens/Source/shotwell/src/CommandManager.vala"
		_tmp2_ = self->priv->depth;
#line 186 "/home/jens/Source/shotwell/src/CommandManager.vala"
		if (!(_tmp1_ >= _tmp2_)) {
#line 186 "/home/jens/Source/shotwell/src/CommandManager.vala"
			break;
#line 959 "CommandManager.c"
		}
#line 187 "/home/jens/Source/shotwell/src/CommandManager.vala"
		_tmp3_ = gee_abstract_list_remove_at (G_TYPE_CHECK_INSTANCE_CAST (stack, GEE_TYPE_ABSTRACT_LIST, GeeAbstractList), 0);
#line 187 "/home/jens/Source/shotwell/src/CommandManager.vala"
		_tmp4_ = (Command*) _tmp3_;
#line 187 "/home/jens/Source/shotwell/src/CommandManager.vala"
		_g_object_unref0 (_tmp4_);
#line 967 "CommandManager.c"
	}
}


static Command*
command_manager_pop (CommandManager* self,
                     GeeArrayList* stack)
{
	Command* result = NULL;
	gint _tmp0_;
	gint _tmp1_;
	Command* command = NULL;
	gint _tmp2_;
	gint _tmp3_;
	gpointer _tmp4_;
	gboolean removed = FALSE;
	Command* _tmp5_;
	gboolean _tmp6_;
#line 190 "/home/jens/Source/shotwell/src/CommandManager.vala"
	g_return_val_if_fail (IS_COMMAND_MANAGER (self), NULL);
#line 190 "/home/jens/Source/shotwell/src/CommandManager.vala"
	g_return_val_if_fail (GEE_IS_ARRAY_LIST (stack), NULL);
#line 191 "/home/jens/Source/shotwell/src/CommandManager.vala"
	_tmp0_ = gee_abstract_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (stack, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection));
#line 191 "/home/jens/Source/shotwell/src/CommandManager.vala"
	_tmp1_ = _tmp0_;
#line 191 "/home/jens/Source/shotwell/src/CommandManager.vala"
	if (_tmp1_ <= 0) {
#line 192 "/home/jens/Source/shotwell/src/CommandManager.vala"
		result = NULL;
#line 192 "/home/jens/Source/shotwell/src/CommandManager.vala"
		return result;
#line 1000 "CommandManager.c"
	}
#line 194 "/home/jens/Source/shotwell/src/CommandManager.vala"
	_tmp2_ = gee_abstract_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (stack, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection));
#line 194 "/home/jens/Source/shotwell/src/CommandManager.vala"
	_tmp3_ = _tmp2_;
#line 194 "/home/jens/Source/shotwell/src/CommandManager.vala"
	_tmp4_ = gee_abstract_list_get (G_TYPE_CHECK_INSTANCE_CAST (stack, GEE_TYPE_ABSTRACT_LIST, GeeAbstractList), _tmp3_ - 1);
#line 194 "/home/jens/Source/shotwell/src/CommandManager.vala"
	command = (Command*) _tmp4_;
#line 195 "/home/jens/Source/shotwell/src/CommandManager.vala"
	_tmp5_ = command;
#line 195 "/home/jens/Source/shotwell/src/CommandManager.vala"
	removed = gee_abstract_collection_remove (G_TYPE_CHECK_INSTANCE_CAST (stack, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection), _tmp5_);
#line 196 "/home/jens/Source/shotwell/src/CommandManager.vala"
	_tmp6_ = removed;
#line 196 "/home/jens/Source/shotwell/src/CommandManager.vala"
	_vala_assert (_tmp6_, "removed");
#line 198 "/home/jens/Source/shotwell/src/CommandManager.vala"
	result = command;
#line 198 "/home/jens/Source/shotwell/src/CommandManager.vala"
	return result;
#line 1022 "CommandManager.c"
}


static void
g_cclosure_user_marshal_VOID__BOOLEAN_BOOLEAN (GClosure * closure,
                                               GValue * return_value,
                                               guint n_param_values,
                                               const GValue * param_values,
                                               gpointer invocation_hint,
                                               gpointer marshal_data)
{
	typedef void (*GMarshalFunc_VOID__BOOLEAN_BOOLEAN) (gpointer data1, gboolean arg_1, gboolean arg_2, gpointer data2);
	register GMarshalFunc_VOID__BOOLEAN_BOOLEAN callback;
	register GCClosure * cc;
	register gpointer data1;
	register gpointer data2;
	cc = (GCClosure *) closure;
#line 80 "/home/jens/Source/shotwell/src/CommandManager.vala"
	g_return_if_fail (n_param_values == 3);
#line 80 "/home/jens/Source/shotwell/src/CommandManager.vala"
	if (G_CCLOSURE_SWAP_DATA (closure)) {
#line 80 "/home/jens/Source/shotwell/src/CommandManager.vala"
		data1 = closure->data;
#line 80 "/home/jens/Source/shotwell/src/CommandManager.vala"
		data2 = param_values->data[0].v_pointer;
#line 1048 "CommandManager.c"
	} else {
#line 80 "/home/jens/Source/shotwell/src/CommandManager.vala"
		data1 = param_values->data[0].v_pointer;
#line 80 "/home/jens/Source/shotwell/src/CommandManager.vala"
		data2 = closure->data;
#line 1054 "CommandManager.c"
	}
#line 80 "/home/jens/Source/shotwell/src/CommandManager.vala"
	callback = (GMarshalFunc_VOID__BOOLEAN_BOOLEAN) (marshal_data ? marshal_data : cc->callback);
#line 80 "/home/jens/Source/shotwell/src/CommandManager.vala"
	callback (data1, g_value_get_boolean (param_values + 1), g_value_get_boolean (param_values + 2), data2);
#line 1060 "CommandManager.c"
}


static void
value_command_manager_init (GValue* value)
{
#line 80 "/home/jens/Source/shotwell/src/CommandManager.vala"
	value->data[0].v_pointer = NULL;
#line 1069 "CommandManager.c"
}


static void
value_command_manager_free_value (GValue* value)
{
#line 80 "/home/jens/Source/shotwell/src/CommandManager.vala"
	if (value->data[0].v_pointer) {
#line 80 "/home/jens/Source/shotwell/src/CommandManager.vala"
		command_manager_unref (value->data[0].v_pointer);
#line 1080 "CommandManager.c"
	}
}


static void
value_command_manager_copy_value (const GValue* src_value,
                                  GValue* dest_value)
{
#line 80 "/home/jens/Source/shotwell/src/CommandManager.vala"
	if (src_value->data[0].v_pointer) {
#line 80 "/home/jens/Source/shotwell/src/CommandManager.vala"
		dest_value->data[0].v_pointer = command_manager_ref (src_value->data[0].v_pointer);
#line 1093 "CommandManager.c"
	} else {
#line 80 "/home/jens/Source/shotwell/src/CommandManager.vala"
		dest_value->data[0].v_pointer = NULL;
#line 1097 "CommandManager.c"
	}
}


static gpointer
value_command_manager_peek_pointer (const GValue* value)
{
#line 80 "/home/jens/Source/shotwell/src/CommandManager.vala"
	return value->data[0].v_pointer;
#line 1107 "CommandManager.c"
}


static gchar*
value_command_manager_collect_value (GValue* value,
                                     guint n_collect_values,
                                     GTypeCValue* collect_values,
                                     guint collect_flags)
{
#line 80 "/home/jens/Source/shotwell/src/CommandManager.vala"
	if (collect_values[0].v_pointer) {
#line 1119 "CommandManager.c"
		CommandManager * object;
		object = collect_values[0].v_pointer;
#line 80 "/home/jens/Source/shotwell/src/CommandManager.vala"
		if (object->parent_instance.g_class == NULL) {
#line 80 "/home/jens/Source/shotwell/src/CommandManager.vala"
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 1126 "CommandManager.c"
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
#line 80 "/home/jens/Source/shotwell/src/CommandManager.vala"
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 1130 "CommandManager.c"
		}
#line 80 "/home/jens/Source/shotwell/src/CommandManager.vala"
		value->data[0].v_pointer = command_manager_ref (object);
#line 1134 "CommandManager.c"
	} else {
#line 80 "/home/jens/Source/shotwell/src/CommandManager.vala"
		value->data[0].v_pointer = NULL;
#line 1138 "CommandManager.c"
	}
#line 80 "/home/jens/Source/shotwell/src/CommandManager.vala"
	return NULL;
#line 1142 "CommandManager.c"
}


static gchar*
value_command_manager_lcopy_value (const GValue* value,
                                   guint n_collect_values,
                                   GTypeCValue* collect_values,
                                   guint collect_flags)
{
	CommandManager ** object_p;
	object_p = collect_values[0].v_pointer;
#line 80 "/home/jens/Source/shotwell/src/CommandManager.vala"
	if (!object_p) {
#line 80 "/home/jens/Source/shotwell/src/CommandManager.vala"
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
#line 1158 "CommandManager.c"
	}
#line 80 "/home/jens/Source/shotwell/src/CommandManager.vala"
	if (!value->data[0].v_pointer) {
#line 80 "/home/jens/Source/shotwell/src/CommandManager.vala"
		*object_p = NULL;
#line 1164 "CommandManager.c"
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
#line 80 "/home/jens/Source/shotwell/src/CommandManager.vala"
		*object_p = value->data[0].v_pointer;
#line 1168 "CommandManager.c"
	} else {
#line 80 "/home/jens/Source/shotwell/src/CommandManager.vala"
		*object_p = command_manager_ref (value->data[0].v_pointer);
#line 1172 "CommandManager.c"
	}
#line 80 "/home/jens/Source/shotwell/src/CommandManager.vala"
	return NULL;
#line 1176 "CommandManager.c"
}


GParamSpec*
param_spec_command_manager (const gchar* name,
                            const gchar* nick,
                            const gchar* blurb,
                            GType object_type,
                            GParamFlags flags)
{
	ParamSpecCommandManager* spec;
#line 80 "/home/jens/Source/shotwell/src/CommandManager.vala"
	g_return_val_if_fail (g_type_is_a (object_type, TYPE_COMMAND_MANAGER), NULL);
#line 80 "/home/jens/Source/shotwell/src/CommandManager.vala"
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
#line 80 "/home/jens/Source/shotwell/src/CommandManager.vala"
	G_PARAM_SPEC (spec)->value_type = object_type;
#line 80 "/home/jens/Source/shotwell/src/CommandManager.vala"
	return G_PARAM_SPEC (spec);
#line 1196 "CommandManager.c"
}


gpointer
value_get_command_manager (const GValue* value)
{
#line 80 "/home/jens/Source/shotwell/src/CommandManager.vala"
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, TYPE_COMMAND_MANAGER), NULL);
#line 80 "/home/jens/Source/shotwell/src/CommandManager.vala"
	return value->data[0].v_pointer;
#line 1207 "CommandManager.c"
}


void
value_set_command_manager (GValue* value,
                           gpointer v_object)
{
	CommandManager * old;
#line 80 "/home/jens/Source/shotwell/src/CommandManager.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, TYPE_COMMAND_MANAGER));
#line 80 "/home/jens/Source/shotwell/src/CommandManager.vala"
	old = value->data[0].v_pointer;
#line 80 "/home/jens/Source/shotwell/src/CommandManager.vala"
	if (v_object) {
#line 80 "/home/jens/Source/shotwell/src/CommandManager.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, TYPE_COMMAND_MANAGER));
#line 80 "/home/jens/Source/shotwell/src/CommandManager.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 80 "/home/jens/Source/shotwell/src/CommandManager.vala"
		value->data[0].v_pointer = v_object;
#line 80 "/home/jens/Source/shotwell/src/CommandManager.vala"
		command_manager_ref (value->data[0].v_pointer);
#line 1230 "CommandManager.c"
	} else {
#line 80 "/home/jens/Source/shotwell/src/CommandManager.vala"
		value->data[0].v_pointer = NULL;
#line 1234 "CommandManager.c"
	}
#line 80 "/home/jens/Source/shotwell/src/CommandManager.vala"
	if (old) {
#line 80 "/home/jens/Source/shotwell/src/CommandManager.vala"
		command_manager_unref (old);
#line 1240 "CommandManager.c"
	}
}


void
value_take_command_manager (GValue* value,
                            gpointer v_object)
{
	CommandManager * old;
#line 80 "/home/jens/Source/shotwell/src/CommandManager.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, TYPE_COMMAND_MANAGER));
#line 80 "/home/jens/Source/shotwell/src/CommandManager.vala"
	old = value->data[0].v_pointer;
#line 80 "/home/jens/Source/shotwell/src/CommandManager.vala"
	if (v_object) {
#line 80 "/home/jens/Source/shotwell/src/CommandManager.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, TYPE_COMMAND_MANAGER));
#line 80 "/home/jens/Source/shotwell/src/CommandManager.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 80 "/home/jens/Source/shotwell/src/CommandManager.vala"
		value->data[0].v_pointer = v_object;
#line 1262 "CommandManager.c"
	} else {
#line 80 "/home/jens/Source/shotwell/src/CommandManager.vala"
		value->data[0].v_pointer = NULL;
#line 1266 "CommandManager.c"
	}
#line 80 "/home/jens/Source/shotwell/src/CommandManager.vala"
	if (old) {
#line 80 "/home/jens/Source/shotwell/src/CommandManager.vala"
		command_manager_unref (old);
#line 1272 "CommandManager.c"
	}
}


static void
command_manager_class_init (CommandManagerClass * klass)
{
#line 80 "/home/jens/Source/shotwell/src/CommandManager.vala"
	command_manager_parent_class = g_type_class_peek_parent (klass);
#line 80 "/home/jens/Source/shotwell/src/CommandManager.vala"
	((CommandManagerClass *) klass)->finalize = command_manager_finalize;
#line 80 "/home/jens/Source/shotwell/src/CommandManager.vala"
	g_type_class_add_private (klass, sizeof (CommandManagerPrivate));
#line 80 "/home/jens/Source/shotwell/src/CommandManager.vala"
	command_manager_signals[COMMAND_MANAGER_ALTERED_SIGNAL] = g_signal_new ("altered", TYPE_COMMAND_MANAGER, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_user_marshal_VOID__BOOLEAN_BOOLEAN, G_TYPE_NONE, 2, G_TYPE_BOOLEAN, G_TYPE_BOOLEAN);
#line 1288 "CommandManager.c"
}


static void
command_manager_instance_init (CommandManager * self)
{
	GeeArrayList* _tmp0_;
	GeeArrayList* _tmp1_;
#line 80 "/home/jens/Source/shotwell/src/CommandManager.vala"
	self->priv = COMMAND_MANAGER_GET_PRIVATE (self);
#line 84 "/home/jens/Source/shotwell/src/CommandManager.vala"
	_tmp0_ = gee_array_list_new (TYPE_COMMAND, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, NULL, NULL, NULL);
#line 84 "/home/jens/Source/shotwell/src/CommandManager.vala"
	self->priv->undo_stack = _tmp0_;
#line 85 "/home/jens/Source/shotwell/src/CommandManager.vala"
	_tmp1_ = gee_array_list_new (TYPE_COMMAND, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, NULL, NULL, NULL);
#line 85 "/home/jens/Source/shotwell/src/CommandManager.vala"
	self->priv->redo_stack = _tmp1_;
#line 80 "/home/jens/Source/shotwell/src/CommandManager.vala"
	self->ref_count = 1;
#line 1309 "CommandManager.c"
}


static void
command_manager_finalize (CommandManager * obj)
{
	CommandManager * self;
#line 80 "/home/jens/Source/shotwell/src/CommandManager.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_COMMAND_MANAGER, CommandManager);
#line 80 "/home/jens/Source/shotwell/src/CommandManager.vala"
	g_signal_handlers_destroy (self);
#line 84 "/home/jens/Source/shotwell/src/CommandManager.vala"
	_g_object_unref0 (self->priv->undo_stack);
#line 85 "/home/jens/Source/shotwell/src/CommandManager.vala"
	_g_object_unref0 (self->priv->redo_stack);
#line 1325 "CommandManager.c"
}


GType
command_manager_get_type (void)
{
	static volatile gsize command_manager_type_id__volatile = 0;
	if (g_once_init_enter (&command_manager_type_id__volatile)) {
		static const GTypeValueTable g_define_type_value_table = { value_command_manager_init, value_command_manager_free_value, value_command_manager_copy_value, value_command_manager_peek_pointer, "p", value_command_manager_collect_value, "p", value_command_manager_lcopy_value };
		static const GTypeInfo g_define_type_info = { sizeof (CommandManagerClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) command_manager_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (CommandManager), 0, (GInstanceInitFunc) command_manager_instance_init, &g_define_type_value_table };
		static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
		GType command_manager_type_id;
		command_manager_type_id = g_type_register_fundamental (g_type_fundamental_next (), "CommandManager", &g_define_type_info, &g_define_type_fundamental_info, 0);
		g_once_init_leave (&command_manager_type_id__volatile, command_manager_type_id);
	}
	return command_manager_type_id__volatile;
}


gpointer
command_manager_ref (gpointer instance)
{
	CommandManager * self;
	self = instance;
#line 80 "/home/jens/Source/shotwell/src/CommandManager.vala"
	g_atomic_int_inc (&self->ref_count);
#line 80 "/home/jens/Source/shotwell/src/CommandManager.vala"
	return instance;
#line 1354 "CommandManager.c"
}


void
command_manager_unref (gpointer instance)
{
	CommandManager * self;
	self = instance;
#line 80 "/home/jens/Source/shotwell/src/CommandManager.vala"
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
#line 80 "/home/jens/Source/shotwell/src/CommandManager.vala"
		COMMAND_MANAGER_GET_CLASS (self)->finalize (self);
#line 80 "/home/jens/Source/shotwell/src/CommandManager.vala"
		g_type_free_instance ((GTypeInstance *) self);
#line 1369 "CommandManager.c"
	}
}



