/* ManifestWidget.c generated by valac 0.40.4, the Vala compiler
 * generated from ManifestWidget.vala, do not modify */

/* Copyright 2016 Software Freedom Conservancy Inc.
 *
 * This software is licensed under the GNU Lesser General Public License
 * (version 2.1 or later).  See the COPYING file in this distribution.
 */


#include <glib.h>
#include <glib-object.h>
#include <gtk/gtk.h>
#include <stdlib.h>
#include <string.h>
#include "shotwell-plugin-dev-1.0.h"
#include <gdk-pixbuf/gdk-pixbuf.h>
#include <gdk/gdk.h>
#include <gee.h>
#include <gio/gio.h>


#define PLUGINS_TYPE_MANIFEST_WIDGET_MEDIATOR (plugins_manifest_widget_mediator_get_type ())
#define PLUGINS_MANIFEST_WIDGET_MEDIATOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PLUGINS_TYPE_MANIFEST_WIDGET_MEDIATOR, PluginsManifestWidgetMediator))
#define PLUGINS_MANIFEST_WIDGET_MEDIATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PLUGINS_TYPE_MANIFEST_WIDGET_MEDIATOR, PluginsManifestWidgetMediatorClass))
#define PLUGINS_IS_MANIFEST_WIDGET_MEDIATOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PLUGINS_TYPE_MANIFEST_WIDGET_MEDIATOR))
#define PLUGINS_IS_MANIFEST_WIDGET_MEDIATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PLUGINS_TYPE_MANIFEST_WIDGET_MEDIATOR))
#define PLUGINS_MANIFEST_WIDGET_MEDIATOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PLUGINS_TYPE_MANIFEST_WIDGET_MEDIATOR, PluginsManifestWidgetMediatorClass))

typedef struct _PluginsManifestWidgetMediator PluginsManifestWidgetMediator;
typedef struct _PluginsManifestWidgetMediatorClass PluginsManifestWidgetMediatorClass;
typedef struct _PluginsManifestWidgetMediatorPrivate PluginsManifestWidgetMediatorPrivate;

#define PLUGINS_TYPE_MANIFEST_LIST_VIEW (plugins_manifest_list_view_get_type ())
#define PLUGINS_MANIFEST_LIST_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PLUGINS_TYPE_MANIFEST_LIST_VIEW, PluginsManifestListView))
#define PLUGINS_MANIFEST_LIST_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PLUGINS_TYPE_MANIFEST_LIST_VIEW, PluginsManifestListViewClass))
#define PLUGINS_IS_MANIFEST_LIST_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PLUGINS_TYPE_MANIFEST_LIST_VIEW))
#define PLUGINS_IS_MANIFEST_LIST_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PLUGINS_TYPE_MANIFEST_LIST_VIEW))
#define PLUGINS_MANIFEST_LIST_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PLUGINS_TYPE_MANIFEST_LIST_VIEW, PluginsManifestListViewClass))

typedef struct _PluginsManifestListView PluginsManifestListView;
typedef struct _PluginsManifestListViewClass PluginsManifestListViewClass;
enum  {
	PLUGINS_MANIFEST_WIDGET_MEDIATOR_0_PROPERTY,
	PLUGINS_MANIFEST_WIDGET_MEDIATOR_NUM_PROPERTIES
};
static GParamSpec* plugins_manifest_widget_mediator_properties[PLUGINS_MANIFEST_WIDGET_MEDIATOR_NUM_PROPERTIES];
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
typedef struct _PluginsManifestListViewPrivate PluginsManifestListViewPrivate;
enum  {
	PLUGINS_MANIFEST_LIST_VIEW_0_PROPERTY,
	PLUGINS_MANIFEST_LIST_VIEW_NUM_PROPERTIES
};
static GParamSpec* plugins_manifest_list_view_properties[PLUGINS_MANIFEST_LIST_VIEW_NUM_PROPERTIES];

#define PLUGINS_MANIFEST_LIST_VIEW_TYPE_COLUMN (plugins_manifest_list_view_column_get_type ())

#define PLUGINS_TYPE_EXTENSION_POINT (plugins_extension_point_get_type ())
#define PLUGINS_EXTENSION_POINT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PLUGINS_TYPE_EXTENSION_POINT, PluginsExtensionPoint))
#define PLUGINS_EXTENSION_POINT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PLUGINS_TYPE_EXTENSION_POINT, PluginsExtensionPointClass))
#define PLUGINS_IS_EXTENSION_POINT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PLUGINS_TYPE_EXTENSION_POINT))
#define PLUGINS_IS_EXTENSION_POINT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PLUGINS_TYPE_EXTENSION_POINT))
#define PLUGINS_EXTENSION_POINT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PLUGINS_TYPE_EXTENSION_POINT, PluginsExtensionPointClass))

typedef struct _PluginsExtensionPoint PluginsExtensionPoint;
typedef struct _PluginsExtensionPointClass PluginsExtensionPointClass;
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
#define _gtk_icon_info_free0(var) ((var == NULL) ? NULL : (var = (gtk_icon_info_free (var), NULL)))
#define _plugins_extension_point_unref0(var) ((var == NULL) ? NULL : (var = (plugins_extension_point_unref (var), NULL)))
#define __vala_GtkTreePath_free0(var) ((var == NULL) ? NULL : (var = (_vala_GtkTreePath_free (var), NULL)))
#define __g_list_free___vala_GtkTreePath_free0_0(var) ((var == NULL) ? NULL : (var = (_g_list_free___vala_GtkTreePath_free0_ (var), NULL)))

struct _PluginsManifestWidgetMediator {
	GtkBox parent_instance;
	PluginsManifestWidgetMediatorPrivate * priv;
};

struct _PluginsManifestWidgetMediatorClass {
	GtkBoxClass parent_class;
};

struct _PluginsManifestWidgetMediatorPrivate {
	GtkButton* about_button;
	GtkScrolledWindow* list_bin;
	PluginsManifestListView* list;
};

struct _PluginsManifestListView {
	GtkTreeView parent_instance;
	PluginsManifestListViewPrivate * priv;
};

struct _PluginsManifestListViewClass {
	GtkTreeViewClass parent_class;
};

struct _PluginsManifestListViewPrivate {
	GtkTreeStore* store;
};

typedef enum  {
	PLUGINS_MANIFEST_LIST_VIEW_COLUMN_ENABLED,
	PLUGINS_MANIFEST_LIST_VIEW_COLUMN_CAN_ENABLE,
	PLUGINS_MANIFEST_LIST_VIEW_COLUMN_ICON,
	PLUGINS_MANIFEST_LIST_VIEW_COLUMN_NAME,
	PLUGINS_MANIFEST_LIST_VIEW_COLUMN_ID,
	PLUGINS_MANIFEST_LIST_VIEW_COLUMN_N_COLUMNS
} PluginsManifestListViewColumn;


static gpointer plugins_manifest_widget_mediator_parent_class = NULL;
static gpointer plugins_manifest_list_view_parent_class = NULL;

GType plugins_manifest_widget_mediator_get_type (void) G_GNUC_CONST;
GType plugins_manifest_list_view_get_type (void) G_GNUC_CONST;
#define PLUGINS_MANIFEST_WIDGET_MEDIATOR_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PLUGINS_TYPE_MANIFEST_WIDGET_MEDIATOR, PluginsManifestWidgetMediatorPrivate))
PluginsManifestListView* plugins_manifest_list_view_new (void);
PluginsManifestListView* plugins_manifest_list_view_construct (GType object_type);
PluginsManifestWidgetMediator* plugins_manifest_widget_mediator_new (void);
PluginsManifestWidgetMediator* plugins_manifest_widget_mediator_construct (GType object_type);
static void plugins_manifest_widget_mediator_on_about (PluginsManifestWidgetMediator* self);
static void _plugins_manifest_widget_mediator_on_about_gtk_button_clicked (GtkButton* _sender,
                                                                    gpointer self);
static void plugins_manifest_widget_mediator_on_selection_changed (PluginsManifestWidgetMediator* self);
static void _plugins_manifest_widget_mediator_on_selection_changed_gtk_tree_selection_changed (GtkTreeSelection* _sender,
                                                                                        gpointer self);
static void plugins_manifest_widget_mediator_set_about_button_sensitivity (PluginsManifestWidgetMediator* self);
gchar** plugins_manifest_list_view_get_selected_ids (PluginsManifestListView* self,
                                                     int* result_length1);
gboolean plugins_get_pluggable_info (const gchar* id,
                                     SpitPluggableInfo* info);
gboolean is_string_empty (const gchar* s);
static void _vala_array_add52 (gchar** * array,
                        int* length,
                        int* size,
                        gchar* value);
GdkPixbuf* resources_get_icon (const gchar* name,
                               gint scale);
#define RESOURCES_ICON_GENERIC_PLUGIN "generic-plugin.png"
#define RESOURCES_DEFAULT_ICON_SCALE 24
gchar* plugins_get_pluggable_name (const gchar* id);
static void plugins_manifest_widget_mediator_finalize (GObject * obj);
#define PLUGINS_MANIFEST_LIST_VIEW_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PLUGINS_TYPE_MANIFEST_LIST_VIEW, PluginsManifestListViewPrivate))
static GType plugins_manifest_list_view_column_get_type (void) G_GNUC_CONST G_GNUC_UNUSED;
#define PLUGINS_MANIFEST_LIST_VIEW_ICON_SIZE 24
#define PLUGINS_MANIFEST_LIST_VIEW_ICON_X_PADDING 6
#define PLUGINS_MANIFEST_LIST_VIEW_ICON_Y_PADDING 2
GtkIconTheme* resources_get_icon_theme_engine (void);
gpointer plugins_extension_point_ref (gpointer instance);
void plugins_extension_point_unref (gpointer instance);
GParamSpec* plugins_param_spec_extension_point (const gchar* name,
                                                const gchar* nick,
                                                const gchar* blurb,
                                                GType object_type,
                                                GParamFlags flags);
void plugins_value_set_extension_point (GValue* value,
                                        gpointer v_object);
void plugins_value_take_extension_point (GValue* value,
                                         gpointer v_object);
gpointer plugins_value_get_extension_point (const GValue* value);
GType plugins_extension_point_get_type (void) G_GNUC_CONST;
GeeCollection* plugins_get_extension_points (GCompareDataFunc compare_func,
                                             void* compare_func_target,
                                             GDestroyNotify compare_func_target_destroy_notify);
gint plugins_compare_extension_point_names (void* a,
                                            void* b);
static gint _plugins_compare_extension_point_names_gcompare_data_func (gconstpointer a,
                                                                gconstpointer b,
                                                                gpointer self);
const gchar* plugins_extension_point_get_icon_name (PluginsExtensionPoint* self);
const gchar* plugins_extension_point_get_name (PluginsExtensionPoint* self);
GeeCollection* plugins_get_pluggables_for_type (GType type,
                                                GCompareDataFunc compare_func,
                                                void* compare_func_target,
                                                GDestroyNotify compare_func_target_destroy_notify,
                                                gboolean include_disabled);
GType plugins_extension_point_get_pluggable_type (PluginsExtensionPoint* self);
gint plugins_compare_pluggable_names (void* a,
                                      void* b);
static gint _plugins_compare_pluggable_names_gcompare_data_func (gconstpointer a,
                                                          gconstpointer b,
                                                          gpointer self);
gboolean plugins_get_pluggable_enabled (const gchar* id,
                                        gboolean* enabled);
static GtkTreePath* _vala_GtkTreePath_copy (GtkTreePath* self);
static gchar* plugins_manifest_list_view_get_id_at_path (PluginsManifestListView* self,
                                                  GtkTreePath* path,
                                                  GtkTreeIter* iter);
static void _vala_array_add53 (gchar** * array,
                        int* length,
                        int* size,
                        gchar* value);
static void _vala_GtkTreePath_free (GtkTreePath* self);
static void __vala_GtkTreePath_free0_ (gpointer var);
static inline void _g_list_free___vala_GtkTreePath_free0_ (GList* self);
static gboolean plugins_manifest_list_view_real_button_press_event (GtkWidget* base,
                                                             GdkEventButton* event);
void plugins_set_pluggable_enabled (const gchar* id,
                                    gboolean enabled);
static void plugins_manifest_list_view_finalize (GObject * obj);
static void _vala_array_destroy (gpointer array,
                          gint array_length,
                          GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array,
                       gint array_length,
                       GDestroyNotify destroy_func);
static gint _vala_array_length (gpointer array);


static void
_plugins_manifest_widget_mediator_on_about_gtk_button_clicked (GtkButton* _sender,
                                                               gpointer self)
{
#line 25 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	plugins_manifest_widget_mediator_on_about ((PluginsManifestWidgetMediator*) self);
#line 218 "ManifestWidget.c"
}


static void
_plugins_manifest_widget_mediator_on_selection_changed_gtk_tree_selection_changed (GtkTreeSelection* _sender,
                                                                                   gpointer self)
{
#line 26 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	plugins_manifest_widget_mediator_on_selection_changed ((PluginsManifestWidgetMediator*) self);
#line 228 "ManifestWidget.c"
}


PluginsManifestWidgetMediator*
plugins_manifest_widget_mediator_construct (GType object_type)
{
	PluginsManifestWidgetMediator * self = NULL;
	GtkScrolledWindow* _tmp0_;
	PluginsManifestListView* _tmp1_;
	GtkButton* _tmp2_;
	PluginsManifestListView* _tmp3_;
	GtkTreeSelection* _tmp4_;
#line 21 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	self = (PluginsManifestWidgetMediator*) g_object_new (object_type, NULL);
#line 23 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_tmp0_ = self->priv->list_bin;
#line 23 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_tmp1_ = self->priv->list;
#line 23 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	gtk_container_add (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, gtk_container_get_type (), GtkContainer), G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, gtk_widget_get_type (), GtkWidget));
#line 25 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_tmp2_ = self->priv->about_button;
#line 25 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	g_signal_connect_object (_tmp2_, "clicked", (GCallback) _plugins_manifest_widget_mediator_on_about_gtk_button_clicked, self, 0);
#line 26 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_tmp3_ = self->priv->list;
#line 26 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_tmp4_ = gtk_tree_view_get_selection (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, gtk_tree_view_get_type (), GtkTreeView));
#line 26 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	g_signal_connect_object (_tmp4_, "changed", (GCallback) _plugins_manifest_widget_mediator_on_selection_changed_gtk_tree_selection_changed, self, 0);
#line 28 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	plugins_manifest_widget_mediator_set_about_button_sensitivity (self);
#line 20 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	return self;
#line 263 "ManifestWidget.c"
}


PluginsManifestWidgetMediator*
plugins_manifest_widget_mediator_new (void)
{
#line 20 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	return plugins_manifest_widget_mediator_construct (PLUGINS_TYPE_MANIFEST_WIDGET_MEDIATOR);
#line 272 "ManifestWidget.c"
}


static gchar*
string_strip (const gchar* self)
{
	gchar* result = NULL;
	gchar* _result_ = NULL;
	gchar* _tmp0_;
	const gchar* _tmp1_;
#line 1248 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, NULL);
#line 1249 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	_tmp0_ = g_strdup (self);
#line 1249 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	_result_ = _tmp0_;
#line 1250 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	_tmp1_ = _result_;
#line 1250 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	g_strstrip (_tmp1_);
#line 1251 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	result = _result_;
#line 1251 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	return result;
#line 297 "ManifestWidget.c"
}


static void
_vala_array_add52 (gchar** * array,
                   int* length,
                   int* size,
                   gchar* value)
{
#line 56 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	if ((*length) == (*size)) {
#line 56 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 56 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
		*array = g_renew (gchar*, *array, (*size) + 1);
#line 313 "ManifestWidget.c"
	}
#line 56 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	(*array)[(*length)++] = value;
#line 56 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	(*array)[*length] = NULL;
#line 319 "ManifestWidget.c"
}


static gpointer
_g_object_ref0 (gpointer self)
{
#line 67 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	return self ? g_object_ref (self) : NULL;
#line 328 "ManifestWidget.c"
}


static void
plugins_manifest_widget_mediator_on_about (PluginsManifestWidgetMediator* self)
{
	gchar** ids = NULL;
	PluginsManifestListView* _tmp0_;
	gint _tmp1_;
	gchar** _tmp2_;
	gint ids_length1;
	gint _ids_size_;
	gchar** _tmp3_;
	gint _tmp3__length1;
	gchar* id = NULL;
	gchar** _tmp4_;
	gint _tmp4__length1;
	const gchar* _tmp5_;
	gchar* _tmp6_;
	SpitPluggableInfo info = {0};
	const gchar* _tmp7_;
	gboolean _tmp8_;
	gchar** authors = NULL;
	gint authors_length1;
	gint _authors_size_;
	SpitPluggableInfo _tmp10_;
	const gchar* _tmp11_;
	GtkAboutDialog* about_dialog = NULL;
	GtkAboutDialog* _tmp30_;
	GtkAboutDialog* _tmp31_;
	gchar** _tmp32_;
	gint _tmp32__length1;
	GtkAboutDialog* _tmp33_;
	SpitPluggableInfo _tmp34_;
	const gchar* _tmp35_;
	GtkAboutDialog* _tmp36_;
	SpitPluggableInfo _tmp37_;
	const gchar* _tmp38_;
	GtkAboutDialog* _tmp39_;
	SpitPluggableInfo _tmp40_;
	const gchar* _tmp41_;
	GtkAboutDialog* _tmp42_;
	SpitPluggableInfo _tmp43_;
	gboolean _tmp44_;
	GdkPixbuf* _tmp45_ = NULL;
	gboolean _tmp46_ = FALSE;
	SpitPluggableInfo _tmp47_;
	GdkPixbuf** _tmp48_;
	gint _tmp48__length1;
	GtkAboutDialog* _tmp56_;
	GtkAboutDialog* _tmp57_;
	const gchar* _tmp58_;
	gchar* _tmp59_;
	gchar* _tmp60_;
	GtkAboutDialog* _tmp61_;
	SpitPluggableInfo _tmp62_;
	const gchar* _tmp63_;
	GtkAboutDialog* _tmp64_;
	SpitPluggableInfo _tmp65_;
	const gchar* _tmp66_;
	GtkAboutDialog* _tmp67_;
	SpitPluggableInfo _tmp68_;
	const gchar* _tmp69_;
	GtkAboutDialog* _tmp70_;
	SpitPluggableInfo _tmp71_;
	const gchar* _tmp72_;
	GtkAboutDialog* _tmp73_;
	GtkAboutDialog* _tmp74_;
#line 31 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	g_return_if_fail (PLUGINS_IS_MANIFEST_WIDGET_MEDIATOR (self));
#line 32 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_tmp0_ = self->priv->list;
#line 32 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_tmp2_ = plugins_manifest_list_view_get_selected_ids (_tmp0_, &_tmp1_);
#line 32 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	ids = _tmp2_;
#line 32 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	ids_length1 = _tmp1_;
#line 32 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_ids_size_ = ids_length1;
#line 33 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_tmp3_ = ids;
#line 33 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_tmp3__length1 = ids_length1;
#line 33 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	if (_tmp3__length1 == 0) {
#line 34 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
		ids = (_vala_array_free (ids, ids_length1, (GDestroyNotify) g_free), NULL);
#line 34 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
		return;
#line 419 "ManifestWidget.c"
	}
#line 36 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_tmp4_ = ids;
#line 36 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_tmp4__length1 = ids_length1;
#line 36 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_tmp5_ = _tmp4_[0];
#line 36 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_tmp6_ = g_strdup (_tmp5_);
#line 36 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	id = _tmp6_;
#line 38 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	memset (&info, 0, sizeof (SpitPluggableInfo));
#line 39 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_tmp7_ = id;
#line 39 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_tmp8_ = plugins_get_pluggable_info (_tmp7_, &info);
#line 39 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	if (!_tmp8_) {
#line 439 "ManifestWidget.c"
		const gchar* _tmp9_;
#line 40 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
		_tmp9_ = id;
#line 40 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
		g_warning ("ManifestWidget.vala:40: Unable to retrieve information for plugin %s", _tmp9_);
#line 42 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
		spit_pluggable_info_destroy (&info);
#line 42 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
		_g_free0 (id);
#line 42 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
		ids = (_vala_array_free (ids, ids_length1, (GDestroyNotify) g_free), NULL);
#line 42 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
		return;
#line 453 "ManifestWidget.c"
	}
#line 47 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	authors = NULL;
#line 47 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	authors_length1 = 0;
#line 47 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_authors_size_ = authors_length1;
#line 48 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_tmp10_ = info;
#line 48 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_tmp11_ = _tmp10_.authors;
#line 48 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	if (_tmp11_ != NULL) {
#line 467 "ManifestWidget.c"
		gchar** split = NULL;
		SpitPluggableInfo _tmp12_;
		const gchar* _tmp13_;
		gchar** _tmp14_;
		gchar** _tmp15_;
		gint split_length1;
		gint _split_size_;
#line 49 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
		_tmp12_ = info;
#line 49 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
		_tmp13_ = _tmp12_.authors;
#line 49 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
		_tmp15_ = _tmp14_ = g_strsplit (_tmp13_, ",", 0);
#line 49 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
		split = _tmp15_;
#line 49 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
		split_length1 = _vala_array_length (_tmp14_);
#line 49 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
		_split_size_ = split_length1;
#line 487 "ManifestWidget.c"
		{
			gint ctr = 0;
#line 50 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
			ctr = 0;
#line 492 "ManifestWidget.c"
			{
				gboolean _tmp16_ = FALSE;
#line 50 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
				_tmp16_ = TRUE;
#line 50 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
				while (TRUE) {
#line 499 "ManifestWidget.c"
					gint _tmp18_;
					gchar** _tmp19_;
					gint _tmp19__length1;
					gchar* stripped = NULL;
					gchar** _tmp20_;
					gint _tmp20__length1;
					gint _tmp21_;
					const gchar* _tmp22_;
					gchar* _tmp23_;
					const gchar* _tmp24_;
#line 50 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
					if (!_tmp16_) {
#line 512 "ManifestWidget.c"
						gint _tmp17_;
#line 50 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
						_tmp17_ = ctr;
#line 50 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
						ctr = _tmp17_ + 1;
#line 518 "ManifestWidget.c"
					}
#line 50 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
					_tmp16_ = FALSE;
#line 50 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
					_tmp18_ = ctr;
#line 50 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
					_tmp19_ = split;
#line 50 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
					_tmp19__length1 = split_length1;
#line 50 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
					if (!(_tmp18_ < _tmp19__length1)) {
#line 50 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
						break;
#line 532 "ManifestWidget.c"
					}
#line 51 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
					_tmp20_ = split;
#line 51 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
					_tmp20__length1 = split_length1;
#line 51 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
					_tmp21_ = ctr;
#line 51 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
					_tmp22_ = _tmp20_[_tmp21_];
#line 51 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
					_tmp23_ = string_strip (_tmp22_);
#line 51 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
					stripped = _tmp23_;
#line 52 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
					_tmp24_ = stripped;
#line 52 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
					if (!is_string_empty (_tmp24_)) {
#line 550 "ManifestWidget.c"
						gchar** _tmp25_;
						gint _tmp25__length1;
						gchar** _tmp27_;
						gint _tmp27__length1;
						const gchar* _tmp28_;
						gchar* _tmp29_;
#line 53 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
						_tmp25_ = authors;
#line 53 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
						_tmp25__length1 = authors_length1;
#line 53 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
						if (_tmp25_ == NULL) {
#line 563 "ManifestWidget.c"
							gchar** _tmp26_;
#line 54 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
							_tmp26_ = g_new0 (gchar*, 0 + 1);
#line 54 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
							authors = (_vala_array_free (authors, authors_length1, (GDestroyNotify) g_free), NULL);
#line 54 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
							authors = _tmp26_;
#line 54 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
							authors_length1 = 0;
#line 54 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
							_authors_size_ = authors_length1;
#line 575 "ManifestWidget.c"
						}
#line 56 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
						_tmp27_ = authors;
#line 56 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
						_tmp27__length1 = authors_length1;
#line 56 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
						_tmp28_ = stripped;
#line 56 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
						_tmp29_ = g_strdup (_tmp28_);
#line 56 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
						_vala_array_add52 (&authors, &authors_length1, &_authors_size_, _tmp29_);
#line 587 "ManifestWidget.c"
					}
#line 50 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
					_g_free0 (stripped);
#line 591 "ManifestWidget.c"
				}
			}
		}
#line 48 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
		split = (_vala_array_free (split, split_length1, (GDestroyNotify) g_free), NULL);
#line 597 "ManifestWidget.c"
	}
#line 61 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_tmp30_ = (GtkAboutDialog*) gtk_about_dialog_new ();
#line 61 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	g_object_ref_sink (_tmp30_);
#line 61 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	about_dialog = _tmp30_;
#line 62 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_tmp31_ = about_dialog;
#line 62 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_tmp32_ = authors;
#line 62 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_tmp32__length1 = authors_length1;
#line 62 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	gtk_about_dialog_set_authors (_tmp31_, _tmp32_);
#line 63 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_tmp33_ = about_dialog;
#line 63 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_tmp34_ = info;
#line 63 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_tmp35_ = _tmp34_.brief_description;
#line 63 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	gtk_about_dialog_set_comments (_tmp33_, _tmp35_);
#line 64 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_tmp36_ = about_dialog;
#line 64 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_tmp37_ = info;
#line 64 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_tmp38_ = _tmp37_.copyright;
#line 64 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	gtk_about_dialog_set_copyright (_tmp36_, _tmp38_);
#line 65 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_tmp39_ = about_dialog;
#line 65 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_tmp40_ = info;
#line 65 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_tmp41_ = _tmp40_.license;
#line 65 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	gtk_about_dialog_set_license (_tmp39_, _tmp41_);
#line 66 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_tmp42_ = about_dialog;
#line 66 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_tmp43_ = info;
#line 66 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_tmp44_ = _tmp43_.is_license_wordwrapped;
#line 66 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	gtk_about_dialog_set_wrap_license (_tmp42_, _tmp44_);
#line 67 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_tmp47_ = info;
#line 67 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_tmp48_ = _tmp47_.icons;
#line 67 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_tmp48__length1 = _tmp47_.icons_length1;
#line 67 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	if (_tmp48_ != NULL) {
#line 653 "ManifestWidget.c"
		SpitPluggableInfo _tmp49_;
		GdkPixbuf** _tmp50_;
		gint _tmp50__length1;
#line 67 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
		_tmp49_ = info;
#line 67 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
		_tmp50_ = _tmp49_.icons;
#line 67 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
		_tmp50__length1 = _tmp49_.icons_length1;
#line 67 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
		_tmp46_ = _tmp50__length1 > 0;
#line 665 "ManifestWidget.c"
	} else {
#line 67 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
		_tmp46_ = FALSE;
#line 669 "ManifestWidget.c"
	}
#line 67 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	if (_tmp46_) {
#line 673 "ManifestWidget.c"
		SpitPluggableInfo _tmp51_;
		GdkPixbuf** _tmp52_;
		gint _tmp52__length1;
		GdkPixbuf* _tmp53_;
		GdkPixbuf* _tmp54_;
#line 67 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
		_tmp51_ = info;
#line 67 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
		_tmp52_ = _tmp51_.icons;
#line 67 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
		_tmp52__length1 = _tmp51_.icons_length1;
#line 67 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
		_tmp53_ = _tmp52_[0];
#line 67 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
		_tmp54_ = _g_object_ref0 (_tmp53_);
#line 67 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
		_g_object_unref0 (_tmp45_);
#line 67 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
		_tmp45_ = _tmp54_;
#line 693 "ManifestWidget.c"
	} else {
		GdkPixbuf* _tmp55_;
#line 68 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
		_tmp55_ = resources_get_icon (RESOURCES_ICON_GENERIC_PLUGIN, RESOURCES_DEFAULT_ICON_SCALE);
#line 68 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
		_g_object_unref0 (_tmp45_);
#line 68 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
		_tmp45_ = _tmp55_;
#line 702 "ManifestWidget.c"
	}
#line 67 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_tmp56_ = about_dialog;
#line 67 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	gtk_about_dialog_set_logo (_tmp56_, _tmp45_);
#line 69 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_tmp57_ = about_dialog;
#line 69 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_tmp58_ = id;
#line 69 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_tmp59_ = plugins_get_pluggable_name (_tmp58_);
#line 69 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_tmp60_ = _tmp59_;
#line 69 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	gtk_about_dialog_set_program_name (_tmp57_, _tmp60_);
#line 69 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_g_free0 (_tmp60_);
#line 70 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_tmp61_ = about_dialog;
#line 70 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_tmp62_ = info;
#line 70 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_tmp63_ = _tmp62_.translators;
#line 70 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	gtk_about_dialog_set_translator_credits (_tmp61_, _tmp63_);
#line 71 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_tmp64_ = about_dialog;
#line 71 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_tmp65_ = info;
#line 71 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_tmp66_ = _tmp65_.version;
#line 71 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	gtk_about_dialog_set_version (_tmp64_, _tmp66_);
#line 72 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_tmp67_ = about_dialog;
#line 72 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_tmp68_ = info;
#line 72 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_tmp69_ = _tmp68_.website_url;
#line 72 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	gtk_about_dialog_set_website (_tmp67_, _tmp69_);
#line 73 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_tmp70_ = about_dialog;
#line 73 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_tmp71_ = info;
#line 73 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_tmp72_ = _tmp71_.website_name;
#line 73 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	gtk_about_dialog_set_website_label (_tmp70_, _tmp72_);
#line 75 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_tmp73_ = about_dialog;
#line 75 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	gtk_dialog_run (G_TYPE_CHECK_INSTANCE_CAST (_tmp73_, gtk_dialog_get_type (), GtkDialog));
#line 77 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_tmp74_ = about_dialog;
#line 77 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	gtk_widget_destroy (G_TYPE_CHECK_INSTANCE_CAST (_tmp74_, gtk_widget_get_type (), GtkWidget));
#line 31 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_g_object_unref0 (_tmp45_);
#line 31 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_g_object_unref0 (about_dialog);
#line 31 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	authors = (_vala_array_free (authors, authors_length1, (GDestroyNotify) g_free), NULL);
#line 31 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	spit_pluggable_info_destroy (&info);
#line 31 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_g_free0 (id);
#line 31 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	ids = (_vala_array_free (ids, ids_length1, (GDestroyNotify) g_free), NULL);
#line 772 "ManifestWidget.c"
}


static void
plugins_manifest_widget_mediator_on_selection_changed (PluginsManifestWidgetMediator* self)
{
#line 80 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	g_return_if_fail (PLUGINS_IS_MANIFEST_WIDGET_MEDIATOR (self));
#line 81 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	plugins_manifest_widget_mediator_set_about_button_sensitivity (self);
#line 783 "ManifestWidget.c"
}


static void
plugins_manifest_widget_mediator_set_about_button_sensitivity (PluginsManifestWidgetMediator* self)
{
	gchar** ids = NULL;
	PluginsManifestListView* _tmp0_;
	gint _tmp1_;
	gchar** _tmp2_;
	gint ids_length1;
	gint _ids_size_;
	GtkButton* _tmp3_;
#line 84 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	g_return_if_fail (PLUGINS_IS_MANIFEST_WIDGET_MEDIATOR (self));
#line 89 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_tmp0_ = self->priv->list;
#line 89 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_tmp2_ = plugins_manifest_list_view_get_selected_ids (_tmp0_, &_tmp1_);
#line 89 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	ids = _tmp2_;
#line 89 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	ids_length1 = _tmp1_;
#line 89 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_ids_size_ = ids_length1;
#line 90 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_tmp3_ = self->priv->about_button;
#line 90 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, gtk_widget_get_type (), GtkWidget), ids_length1 == 1);
#line 84 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	ids = (_vala_array_free (ids, ids_length1, (GDestroyNotify) g_free), NULL);
#line 815 "ManifestWidget.c"
}


static void
plugins_manifest_widget_mediator_class_init (PluginsManifestWidgetMediatorClass * klass)
{
	gint PluginsManifestWidgetMediator_private_offset;
#line 11 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	plugins_manifest_widget_mediator_parent_class = g_type_class_peek_parent (klass);
#line 11 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	g_type_class_add_private (klass, sizeof (PluginsManifestWidgetMediatorPrivate));
#line 11 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	G_OBJECT_CLASS (klass)->finalize = plugins_manifest_widget_mediator_finalize;
#line 11 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	PluginsManifestWidgetMediator_private_offset = g_type_class_get_instance_private_offset (klass);
#line 11 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	gtk_widget_class_set_template_from_resource (GTK_WIDGET_CLASS (klass), "/org/gnome/Shotwell/ui/manifest_widget.ui");
#line 11 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "about_button", FALSE, PluginsManifestWidgetMediator_private_offset + G_STRUCT_OFFSET (PluginsManifestWidgetMediatorPrivate, about_button));
#line 11 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "list_bin", FALSE, PluginsManifestWidgetMediator_private_offset + G_STRUCT_OFFSET (PluginsManifestWidgetMediatorPrivate, list_bin));
#line 837 "ManifestWidget.c"
}


static void
plugins_manifest_widget_mediator_instance_init (PluginsManifestWidgetMediator * self)
{
	PluginsManifestListView* _tmp0_;
#line 11 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	self->priv = PLUGINS_MANIFEST_WIDGET_MEDIATOR_GET_PRIVATE (self);
#line 18 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_tmp0_ = plugins_manifest_list_view_new ();
#line 18 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	g_object_ref_sink (_tmp0_);
#line 18 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	self->priv->list = _tmp0_;
#line 11 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	gtk_widget_init_template (GTK_WIDGET (self));
#line 855 "ManifestWidget.c"
}


static void
plugins_manifest_widget_mediator_finalize (GObject * obj)
{
	PluginsManifestWidgetMediator * self;
#line 11 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PLUGINS_TYPE_MANIFEST_WIDGET_MEDIATOR, PluginsManifestWidgetMediator);
#line 13 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_g_object_unref0 (self->priv->about_button);
#line 16 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_g_object_unref0 (self->priv->list_bin);
#line 18 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_g_object_unref0 (self->priv->list);
#line 11 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	G_OBJECT_CLASS (plugins_manifest_widget_mediator_parent_class)->finalize (obj);
#line 873 "ManifestWidget.c"
}


GType
plugins_manifest_widget_mediator_get_type (void)
{
	static volatile gsize plugins_manifest_widget_mediator_type_id__volatile = 0;
	if (g_once_init_enter (&plugins_manifest_widget_mediator_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PluginsManifestWidgetMediatorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) plugins_manifest_widget_mediator_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PluginsManifestWidgetMediator), 0, (GInstanceInitFunc) plugins_manifest_widget_mediator_instance_init, NULL };
		GType plugins_manifest_widget_mediator_type_id;
		plugins_manifest_widget_mediator_type_id = g_type_register_static (gtk_box_get_type (), "PluginsManifestWidgetMediator", &g_define_type_info, 0);
		g_once_init_leave (&plugins_manifest_widget_mediator_type_id__volatile, plugins_manifest_widget_mediator_type_id);
	}
	return plugins_manifest_widget_mediator_type_id__volatile;
}


static GType
plugins_manifest_list_view_column_get_type (void)
{
	static volatile gsize plugins_manifest_list_view_column_type_id__volatile = 0;
	if (g_once_init_enter (&plugins_manifest_list_view_column_type_id__volatile)) {
		static const GEnumValue values[] = {{PLUGINS_MANIFEST_LIST_VIEW_COLUMN_ENABLED, "PLUGINS_MANIFEST_LIST_VIEW_COLUMN_ENABLED", "enabled"}, {PLUGINS_MANIFEST_LIST_VIEW_COLUMN_CAN_ENABLE, "PLUGINS_MANIFEST_LIST_VIEW_COLUMN_CAN_ENABLE", "can-enable"}, {PLUGINS_MANIFEST_LIST_VIEW_COLUMN_ICON, "PLUGINS_MANIFEST_LIST_VIEW_COLUMN_ICON", "icon"}, {PLUGINS_MANIFEST_LIST_VIEW_COLUMN_NAME, "PLUGINS_MANIFEST_LIST_VIEW_COLUMN_NAME", "name"}, {PLUGINS_MANIFEST_LIST_VIEW_COLUMN_ID, "PLUGINS_MANIFEST_LIST_VIEW_COLUMN_ID", "id"}, {PLUGINS_MANIFEST_LIST_VIEW_COLUMN_N_COLUMNS, "PLUGINS_MANIFEST_LIST_VIEW_COLUMN_N_COLUMNS", "n-columns"}, {0, NULL, NULL}};
		GType plugins_manifest_list_view_column_type_id;
		plugins_manifest_list_view_column_type_id = g_enum_register_static ("PluginsManifestListViewColumn", values);
		g_once_init_leave (&plugins_manifest_list_view_column_type_id__volatile, plugins_manifest_list_view_column_type_id);
	}
	return plugins_manifest_list_view_column_type_id__volatile;
}


static gint
_plugins_compare_extension_point_names_gcompare_data_func (gconstpointer a,
                                                           gconstpointer b,
                                                           gpointer self)
{
	gint result;
	result = plugins_compare_extension_point_names (a, b);
#line 155 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	return result;
#line 914 "ManifestWidget.c"
}


static gint
_plugins_compare_pluggable_names_gcompare_data_func (gconstpointer a,
                                                     gconstpointer b,
                                                     gpointer self)
{
	gint result;
	result = plugins_compare_pluggable_names (a, b);
#line 175 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	return result;
#line 927 "ManifestWidget.c"
}


PluginsManifestListView*
plugins_manifest_list_view_construct (GType object_type)
{
	PluginsManifestListView * self = NULL;
	GtkTreeStore* _tmp0_;
	GtkCellRendererToggle* checkbox_renderer = NULL;
	GtkCellRendererToggle* _tmp1_;
	GtkCellRendererToggle* _tmp2_;
	GtkCellRendererToggle* _tmp3_;
	GtkCellRendererPixbuf* icon_renderer = NULL;
	GtkCellRendererPixbuf* _tmp4_;
	GtkCellRendererPixbuf* _tmp5_;
	GtkCellRendererPixbuf* _tmp6_;
	GtkCellRendererPixbuf* _tmp7_;
	GtkCellRendererText* text_renderer = NULL;
	GtkCellRendererText* _tmp8_;
	GtkTreeViewColumn* column = NULL;
	GtkTreeViewColumn* _tmp9_;
	GtkTreeViewColumn* _tmp10_;
	GtkTreeViewColumn* _tmp11_;
	GtkCellRendererToggle* _tmp12_;
	GtkTreeViewColumn* _tmp13_;
	GtkCellRendererPixbuf* _tmp14_;
	GtkTreeViewColumn* _tmp15_;
	GtkCellRendererText* _tmp16_;
	GtkTreeViewColumn* _tmp17_;
	GtkCellRendererToggle* _tmp18_;
	GtkTreeViewColumn* _tmp19_;
	GtkCellRendererToggle* _tmp20_;
	GtkTreeViewColumn* _tmp21_;
	GtkCellRendererPixbuf* _tmp22_;
	GtkTreeViewColumn* _tmp23_;
	GtkCellRendererText* _tmp24_;
	GtkTreeViewColumn* _tmp25_;
	GtkTreeSelection* _tmp26_;
	GtkIconTheme* icon_theme = NULL;
	GtkIconTheme* _tmp27_;
	GError * _inner_error_ = NULL;
#line 116 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	self = (PluginsManifestListView*) g_object_new (object_type, NULL);
#line 117 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_tmp0_ = self->priv->store;
#line 117 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	gtk_tree_view_set_model (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_view_get_type (), GtkTreeView), G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, gtk_tree_model_get_type (), GtkTreeModel));
#line 119 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_tmp1_ = (GtkCellRendererToggle*) gtk_cell_renderer_toggle_new ();
#line 119 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	g_object_ref_sink (_tmp1_);
#line 119 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	checkbox_renderer = _tmp1_;
#line 120 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_tmp2_ = checkbox_renderer;
#line 120 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	gtk_cell_renderer_toggle_set_radio (_tmp2_, FALSE);
#line 121 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_tmp3_ = checkbox_renderer;
#line 121 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	gtk_cell_renderer_toggle_set_activatable (_tmp3_, TRUE);
#line 123 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_tmp4_ = (GtkCellRendererPixbuf*) gtk_cell_renderer_pixbuf_new ();
#line 123 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	g_object_ref_sink (_tmp4_);
#line 123 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	icon_renderer = _tmp4_;
#line 124 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_tmp5_ = icon_renderer;
#line 124 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	g_object_set (_tmp5_, "stock-size", (guint) GTK_ICON_SIZE_MENU, NULL);
#line 125 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_tmp6_ = icon_renderer;
#line 125 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	g_object_set (G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, gtk_cell_renderer_get_type (), GtkCellRenderer), "xpad", (guint) PLUGINS_MANIFEST_LIST_VIEW_ICON_X_PADDING, NULL);
#line 126 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_tmp7_ = icon_renderer;
#line 126 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	g_object_set (G_TYPE_CHECK_INSTANCE_CAST (_tmp7_, gtk_cell_renderer_get_type (), GtkCellRenderer), "ypad", (guint) PLUGINS_MANIFEST_LIST_VIEW_ICON_Y_PADDING, NULL);
#line 128 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_tmp8_ = (GtkCellRendererText*) gtk_cell_renderer_text_new ();
#line 128 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	g_object_ref_sink (_tmp8_);
#line 128 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	text_renderer = _tmp8_;
#line 130 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_tmp9_ = gtk_tree_view_column_new ();
#line 130 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	g_object_ref_sink (_tmp9_);
#line 130 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	column = _tmp9_;
#line 131 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_tmp10_ = column;
#line 131 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	gtk_tree_view_column_set_sizing (_tmp10_, GTK_TREE_VIEW_COLUMN_AUTOSIZE);
#line 132 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_tmp11_ = column;
#line 132 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_tmp12_ = checkbox_renderer;
#line 132 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	gtk_cell_layout_pack_start (G_TYPE_CHECK_INSTANCE_CAST (_tmp11_, gtk_cell_layout_get_type (), GtkCellLayout), G_TYPE_CHECK_INSTANCE_CAST (_tmp12_, gtk_cell_renderer_get_type (), GtkCellRenderer), FALSE);
#line 133 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_tmp13_ = column;
#line 133 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_tmp14_ = icon_renderer;
#line 133 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	gtk_cell_layout_pack_start (G_TYPE_CHECK_INSTANCE_CAST (_tmp13_, gtk_cell_layout_get_type (), GtkCellLayout), G_TYPE_CHECK_INSTANCE_CAST (_tmp14_, gtk_cell_renderer_get_type (), GtkCellRenderer), FALSE);
#line 134 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_tmp15_ = column;
#line 134 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_tmp16_ = text_renderer;
#line 134 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	gtk_cell_layout_pack_end (G_TYPE_CHECK_INSTANCE_CAST (_tmp15_, gtk_cell_layout_get_type (), GtkCellLayout), G_TYPE_CHECK_INSTANCE_CAST (_tmp16_, gtk_cell_renderer_get_type (), GtkCellRenderer), TRUE);
#line 136 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_tmp17_ = column;
#line 136 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_tmp18_ = checkbox_renderer;
#line 136 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	gtk_cell_layout_add_attribute (G_TYPE_CHECK_INSTANCE_CAST (_tmp17_, gtk_cell_layout_get_type (), GtkCellLayout), G_TYPE_CHECK_INSTANCE_CAST (_tmp18_, gtk_cell_renderer_get_type (), GtkCellRenderer), "active", (gint) PLUGINS_MANIFEST_LIST_VIEW_COLUMN_ENABLED);
#line 137 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_tmp19_ = column;
#line 137 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_tmp20_ = checkbox_renderer;
#line 137 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	gtk_cell_layout_add_attribute (G_TYPE_CHECK_INSTANCE_CAST (_tmp19_, gtk_cell_layout_get_type (), GtkCellLayout), G_TYPE_CHECK_INSTANCE_CAST (_tmp20_, gtk_cell_renderer_get_type (), GtkCellRenderer), "visible", (gint) PLUGINS_MANIFEST_LIST_VIEW_COLUMN_CAN_ENABLE);
#line 138 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_tmp21_ = column;
#line 138 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_tmp22_ = icon_renderer;
#line 138 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	gtk_cell_layout_add_attribute (G_TYPE_CHECK_INSTANCE_CAST (_tmp21_, gtk_cell_layout_get_type (), GtkCellLayout), G_TYPE_CHECK_INSTANCE_CAST (_tmp22_, gtk_cell_renderer_get_type (), GtkCellRenderer), "pixbuf", (gint) PLUGINS_MANIFEST_LIST_VIEW_COLUMN_ICON);
#line 139 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_tmp23_ = column;
#line 139 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_tmp24_ = text_renderer;
#line 139 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	gtk_cell_layout_add_attribute (G_TYPE_CHECK_INSTANCE_CAST (_tmp23_, gtk_cell_layout_get_type (), GtkCellLayout), G_TYPE_CHECK_INSTANCE_CAST (_tmp24_, gtk_cell_renderer_get_type (), GtkCellRenderer), "text", (gint) PLUGINS_MANIFEST_LIST_VIEW_COLUMN_NAME);
#line 141 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_tmp25_ = column;
#line 141 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	gtk_tree_view_append_column (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_view_get_type (), GtkTreeView), _tmp25_);
#line 143 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	gtk_tree_view_set_headers_visible (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_view_get_type (), GtkTreeView), FALSE);
#line 144 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	gtk_tree_view_set_enable_search (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_view_get_type (), GtkTreeView), FALSE);
#line 145 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	gtk_tree_view_set_show_expanders (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_view_get_type (), GtkTreeView), TRUE);
#line 146 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	gtk_tree_view_set_reorderable (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_view_get_type (), GtkTreeView), FALSE);
#line 147 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	gtk_tree_view_set_enable_tree_lines (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_view_get_type (), GtkTreeView), FALSE);
#line 148 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	gtk_tree_view_set_grid_lines (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_view_get_type (), GtkTreeView), GTK_TREE_VIEW_GRID_LINES_NONE);
#line 149 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_tmp26_ = gtk_tree_view_get_selection (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_view_get_type (), GtkTreeView));
#line 149 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	gtk_tree_selection_set_mode (_tmp26_, GTK_SELECTION_BROWSE);
#line 151 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_tmp27_ = resources_get_icon_theme_engine ();
#line 151 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	icon_theme = _tmp27_;
#line 1089 "ManifestWidget.c"
	{
		GeeIterator* _extension_point_it = NULL;
		GeeCollection* _tmp28_;
		GeeCollection* _tmp29_;
		GeeIterator* _tmp30_;
		GeeIterator* _tmp31_;
#line 155 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
		_tmp28_ = plugins_get_extension_points (_plugins_compare_extension_point_names_gcompare_data_func, NULL, NULL);
#line 155 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
		_tmp29_ = _tmp28_;
#line 155 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
		_tmp30_ = gee_iterable_iterator (G_TYPE_CHECK_INSTANCE_CAST (_tmp29_, GEE_TYPE_ITERABLE, GeeIterable));
#line 155 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
		_tmp31_ = _tmp30_;
#line 155 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
		_g_object_unref0 (_tmp29_);
#line 155 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
		_extension_point_it = _tmp31_;
#line 155 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
		while (TRUE) {
#line 1110 "ManifestWidget.c"
			GeeIterator* _tmp32_;
			PluginsExtensionPoint* extension_point = NULL;
			GeeIterator* _tmp33_;
			gpointer _tmp34_;
			GtkTreeIter category_iter = {0};
			GtkTreeStore* _tmp35_;
			GtkTreeIter _tmp36_ = {0};
			GdkPixbuf* icon = NULL;
			PluginsExtensionPoint* _tmp37_;
			const gchar* _tmp38_;
			const gchar* _tmp39_;
			GtkTreeStore* _tmp58_;
			GtkTreeIter _tmp59_;
			PluginsExtensionPoint* _tmp60_;
			const gchar* _tmp61_;
			const gchar* _tmp62_;
			GdkPixbuf* _tmp63_;
			GeeCollection* pluggables = NULL;
			PluginsExtensionPoint* _tmp64_;
			GType _tmp65_;
			GType _tmp66_;
			GeeCollection* _tmp67_;
#line 155 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
			_tmp32_ = _extension_point_it;
#line 155 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
			if (!gee_iterator_next (_tmp32_)) {
#line 155 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
				break;
#line 1139 "ManifestWidget.c"
			}
#line 155 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
			_tmp33_ = _extension_point_it;
#line 155 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
			_tmp34_ = gee_iterator_get (_tmp33_);
#line 155 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
			extension_point = (PluginsExtensionPoint*) _tmp34_;
#line 157 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
			_tmp35_ = self->priv->store;
#line 157 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
			gtk_tree_store_append (_tmp35_, &_tmp36_, NULL);
#line 157 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
			category_iter = _tmp36_;
#line 159 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
			icon = NULL;
#line 160 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
			_tmp37_ = extension_point;
#line 160 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
			_tmp38_ = plugins_extension_point_get_icon_name (_tmp37_);
#line 160 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
			_tmp39_ = _tmp38_;
#line 160 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
			if (_tmp39_ != NULL) {
#line 1163 "ManifestWidget.c"
				GtkIconInfo* icon_info = NULL;
				GtkIconTheme* _tmp40_;
				PluginsExtensionPoint* _tmp41_;
				const gchar* _tmp42_;
				const gchar* _tmp43_;
				GThemedIcon* _tmp44_;
				GThemedIcon* _tmp45_;
				GtkIconInfo* _tmp46_;
				GtkIconInfo* _tmp47_;
				GtkIconInfo* _tmp48_;
#line 161 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
				_tmp40_ = icon_theme;
#line 161 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
				_tmp41_ = extension_point;
#line 161 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
				_tmp42_ = plugins_extension_point_get_icon_name (_tmp41_);
#line 161 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
				_tmp43_ = _tmp42_;
#line 161 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
				_tmp44_ = (GThemedIcon*) g_themed_icon_new (_tmp43_);
#line 161 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
				_tmp45_ = _tmp44_;
#line 161 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
				_tmp46_ = gtk_icon_theme_lookup_by_gicon (_tmp40_, G_TYPE_CHECK_INSTANCE_CAST (_tmp45_, g_icon_get_type (), GIcon), PLUGINS_MANIFEST_LIST_VIEW_ICON_SIZE, 0);
#line 161 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
				_tmp47_ = _tmp46_;
#line 161 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
				_g_object_unref0 (_tmp45_);
#line 161 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
				icon_info = _tmp47_;
#line 163 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
				_tmp48_ = icon_info;
#line 163 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
				if (_tmp48_ != NULL) {
#line 1198 "ManifestWidget.c"
					{
						GdkPixbuf* _tmp49_ = NULL;
						GtkIconInfo* _tmp50_;
						GdkPixbuf* _tmp51_;
						GdkPixbuf* _tmp52_;
#line 165 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
						_tmp50_ = icon_info;
#line 165 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
						_tmp51_ = gtk_icon_info_load_icon (_tmp50_, &_inner_error_);
#line 165 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
						_tmp49_ = _tmp51_;
#line 165 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
						if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1212 "ManifestWidget.c"
							goto __catch41_g_error;
						}
#line 165 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
						_tmp52_ = _tmp49_;
#line 165 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
						_tmp49_ = NULL;
#line 165 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
						_g_object_unref0 (icon);
#line 165 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
						icon = _tmp52_;
#line 164 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
						_g_object_unref0 (_tmp49_);
#line 1225 "ManifestWidget.c"
					}
					goto __finally41;
					__catch41_g_error:
					{
						GError* err = NULL;
						PluginsExtensionPoint* _tmp53_;
						const gchar* _tmp54_;
						const gchar* _tmp55_;
						GError* _tmp56_;
						const gchar* _tmp57_;
#line 164 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
						err = _inner_error_;
#line 164 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
						_inner_error_ = NULL;
#line 167 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
						_tmp53_ = extension_point;
#line 167 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
						_tmp54_ = plugins_extension_point_get_icon_name (_tmp53_);
#line 167 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
						_tmp55_ = _tmp54_;
#line 167 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
						_tmp56_ = err;
#line 167 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
						_tmp57_ = _tmp56_->message;
#line 167 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
						g_warning ("ManifestWidget.vala:167: Unable to load icon %s: %s", _tmp55_, _tmp57_);
#line 164 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
						_g_error_free0 (err);
#line 1254 "ManifestWidget.c"
					}
					__finally41:
#line 164 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
					if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 164 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
						_gtk_icon_info_free0 (icon_info);
#line 164 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
						_g_object_unref0 (icon);
#line 164 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
						_plugins_extension_point_unref0 (extension_point);
#line 164 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
						_g_object_unref0 (_extension_point_it);
#line 164 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
						_g_object_unref0 (icon_theme);
#line 164 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
						_g_object_unref0 (column);
#line 164 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
						_g_object_unref0 (text_renderer);
#line 164 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
						_g_object_unref0 (icon_renderer);
#line 164 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
						_g_object_unref0 (checkbox_renderer);
#line 164 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
						g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 164 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
						g_clear_error (&_inner_error_);
#line 164 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
						return NULL;
#line 1283 "ManifestWidget.c"
					}
				}
#line 160 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
				_gtk_icon_info_free0 (icon_info);
#line 1288 "ManifestWidget.c"
			}
#line 172 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
			_tmp58_ = self->priv->store;
#line 172 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
			_tmp59_ = category_iter;
#line 172 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
			_tmp60_ = extension_point;
#line 172 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
			_tmp61_ = plugins_extension_point_get_name (_tmp60_);
#line 172 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
			_tmp62_ = _tmp61_;
#line 172 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
			_tmp63_ = icon;
#line 172 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
			gtk_tree_store_set (_tmp58_, &_tmp59_, PLUGINS_MANIFEST_LIST_VIEW_COLUMN_NAME, _tmp62_, PLUGINS_MANIFEST_LIST_VIEW_COLUMN_CAN_ENABLE, FALSE, PLUGINS_MANIFEST_LIST_VIEW_COLUMN_ICON, _tmp63_, -1);
#line 175 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
			_tmp64_ = extension_point;
#line 175 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
			_tmp65_ = plugins_extension_point_get_pluggable_type (_tmp64_);
#line 175 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
			_tmp66_ = _tmp65_;
#line 175 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
			_tmp67_ = plugins_get_pluggables_for_type (_tmp66_, _plugins_compare_pluggable_names_gcompare_data_func, NULL, NULL, TRUE);
#line 175 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
			pluggables = _tmp67_;
#line 1314 "ManifestWidget.c"
			{
				GeeIterator* _pluggable_it = NULL;
				GeeCollection* _tmp68_;
				GeeIterator* _tmp69_;
#line 177 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
				_tmp68_ = pluggables;
#line 177 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
				_tmp69_ = gee_iterable_iterator (G_TYPE_CHECK_INSTANCE_CAST (_tmp68_, GEE_TYPE_ITERABLE, GeeIterable));
#line 177 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
				_pluggable_it = _tmp69_;
#line 177 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
				while (TRUE) {
#line 1327 "ManifestWidget.c"
					GeeIterator* _tmp70_;
					SpitPluggable* pluggable = NULL;
					GeeIterator* _tmp71_;
					gpointer _tmp72_;
					gboolean enabled = FALSE;
					SpitPluggable* _tmp73_;
					const gchar* _tmp74_;
					gboolean _tmp75_ = FALSE;
					gboolean _tmp76_;
					SpitPluggableInfo info = {0};
					SpitPluggable* _tmp77_;
					GdkPixbuf* _tmp78_ = NULL;
					gboolean _tmp79_ = FALSE;
					SpitPluggableInfo _tmp80_;
					GdkPixbuf** _tmp81_;
					gint _tmp81__length1;
					GdkPixbuf* _tmp89_;
					GtkTreeIter plugin_iter = {0};
					GtkTreeStore* _tmp90_;
					GtkTreeIter _tmp91_;
					GtkTreeIter _tmp92_ = {0};
					GtkTreeStore* _tmp93_;
					GtkTreeIter _tmp94_;
					gboolean _tmp95_;
					SpitPluggable* _tmp96_;
					const gchar* _tmp97_;
					SpitPluggable* _tmp98_;
					const gchar* _tmp99_;
					GdkPixbuf* _tmp100_;
#line 177 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
					_tmp70_ = _pluggable_it;
#line 177 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
					if (!gee_iterator_next (_tmp70_)) {
#line 177 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
						break;
#line 1363 "ManifestWidget.c"
					}
#line 177 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
					_tmp71_ = _pluggable_it;
#line 177 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
					_tmp72_ = gee_iterator_get (_tmp71_);
#line 177 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
					pluggable = (SpitPluggable*) _tmp72_;
#line 179 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
					_tmp73_ = pluggable;
#line 179 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
					_tmp74_ = spit_pluggable_get_id (_tmp73_);
#line 179 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
					_tmp76_ = plugins_get_pluggable_enabled (_tmp74_, &_tmp75_);
#line 179 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
					enabled = _tmp75_;
#line 179 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
					if (!_tmp76_) {
#line 180 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
						_g_object_unref0 (pluggable);
#line 180 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
						continue;
#line 1385 "ManifestWidget.c"
					}
#line 182 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
					memset (&info, 0, sizeof (SpitPluggableInfo));
#line 183 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
					_tmp77_ = pluggable;
#line 183 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
					spit_pluggable_get_info (_tmp77_, &info);
#line 185 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
					_tmp80_ = info;
#line 185 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
					_tmp81_ = _tmp80_.icons;
#line 185 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
					_tmp81__length1 = _tmp80_.icons_length1;
#line 185 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
					if (_tmp81_ != NULL) {
#line 1401 "ManifestWidget.c"
						SpitPluggableInfo _tmp82_;
						GdkPixbuf** _tmp83_;
						gint _tmp83__length1;
#line 185 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
						_tmp82_ = info;
#line 185 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
						_tmp83_ = _tmp82_.icons;
#line 185 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
						_tmp83__length1 = _tmp82_.icons_length1;
#line 185 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
						_tmp79_ = _tmp83__length1 > 0;
#line 1413 "ManifestWidget.c"
					} else {
#line 185 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
						_tmp79_ = FALSE;
#line 1417 "ManifestWidget.c"
					}
#line 185 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
					if (_tmp79_) {
#line 1421 "ManifestWidget.c"
						SpitPluggableInfo _tmp84_;
						GdkPixbuf** _tmp85_;
						gint _tmp85__length1;
						GdkPixbuf* _tmp86_;
						GdkPixbuf* _tmp87_;
#line 186 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
						_tmp84_ = info;
#line 186 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
						_tmp85_ = _tmp84_.icons;
#line 186 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
						_tmp85__length1 = _tmp84_.icons_length1;
#line 186 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
						_tmp86_ = _tmp85_[0];
#line 186 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
						_tmp87_ = _g_object_ref0 (_tmp86_);
#line 186 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
						_g_object_unref0 (_tmp78_);
#line 186 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
						_tmp78_ = _tmp87_;
#line 1441 "ManifestWidget.c"
					} else {
						GdkPixbuf* _tmp88_;
#line 187 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
						_tmp88_ = resources_get_icon (RESOURCES_ICON_GENERIC_PLUGIN, PLUGINS_MANIFEST_LIST_VIEW_ICON_SIZE);
#line 187 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
						_g_object_unref0 (_tmp78_);
#line 187 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
						_tmp78_ = _tmp88_;
#line 1450 "ManifestWidget.c"
					}
#line 185 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
					_tmp89_ = _g_object_ref0 (_tmp78_);
#line 185 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
					_g_object_unref0 (icon);
#line 185 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
					icon = _tmp89_;
#line 190 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
					_tmp90_ = self->priv->store;
#line 190 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
					_tmp91_ = category_iter;
#line 190 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
					gtk_tree_store_append (_tmp90_, &_tmp92_, &_tmp91_);
#line 190 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
					plugin_iter = _tmp92_;
#line 192 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
					_tmp93_ = self->priv->store;
#line 192 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
					_tmp94_ = plugin_iter;
#line 192 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
					_tmp95_ = enabled;
#line 192 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
					_tmp96_ = pluggable;
#line 192 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
					_tmp97_ = spit_pluggable_get_pluggable_name (_tmp96_);
#line 192 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
					_tmp98_ = pluggable;
#line 192 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
					_tmp99_ = spit_pluggable_get_id (_tmp98_);
#line 192 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
					_tmp100_ = icon;
#line 192 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
					gtk_tree_store_set (_tmp93_, &_tmp94_, PLUGINS_MANIFEST_LIST_VIEW_COLUMN_ENABLED, _tmp95_, PLUGINS_MANIFEST_LIST_VIEW_COLUMN_NAME, _tmp97_, PLUGINS_MANIFEST_LIST_VIEW_COLUMN_ID, _tmp99_, PLUGINS_MANIFEST_LIST_VIEW_COLUMN_CAN_ENABLE, TRUE, PLUGINS_MANIFEST_LIST_VIEW_COLUMN_ICON, _tmp100_, -1);
#line 177 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
					_g_object_unref0 (_tmp78_);
#line 177 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
					spit_pluggable_info_destroy (&info);
#line 177 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
					_g_object_unref0 (pluggable);
#line 1490 "ManifestWidget.c"
				}
#line 177 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
				_g_object_unref0 (_pluggable_it);
#line 1494 "ManifestWidget.c"
			}
#line 155 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
			_g_object_unref0 (pluggables);
#line 155 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
			_g_object_unref0 (icon);
#line 155 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
			_plugins_extension_point_unref0 (extension_point);
#line 1502 "ManifestWidget.c"
		}
#line 155 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
		_g_object_unref0 (_extension_point_it);
#line 1506 "ManifestWidget.c"
	}
#line 197 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	gtk_tree_view_expand_all (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_view_get_type (), GtkTreeView));
#line 116 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_g_object_unref0 (icon_theme);
#line 116 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_g_object_unref0 (column);
#line 116 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_g_object_unref0 (text_renderer);
#line 116 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_g_object_unref0 (icon_renderer);
#line 116 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_g_object_unref0 (checkbox_renderer);
#line 116 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	return self;
#line 1522 "ManifestWidget.c"
}


PluginsManifestListView*
plugins_manifest_list_view_new (void)
{
#line 116 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	return plugins_manifest_list_view_construct (PLUGINS_TYPE_MANIFEST_LIST_VIEW);
#line 1531 "ManifestWidget.c"
}


static GtkTreePath*
_vala_GtkTreePath_copy (GtkTreePath* self)
{
#line 204 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	return g_boxed_copy (gtk_tree_path_get_type (), self);
#line 1540 "ManifestWidget.c"
}


static gpointer
__vala_GtkTreePath_copy0 (gpointer self)
{
#line 204 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	return self ? _vala_GtkTreePath_copy (self) : NULL;
#line 1549 "ManifestWidget.c"
}


static void
_vala_array_add53 (gchar** * array,
                   int* length,
                   int* size,
                   gchar* value)
{
#line 208 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	if ((*length) == (*size)) {
#line 208 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 208 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
		*array = g_renew (gchar*, *array, (*size) + 1);
#line 1565 "ManifestWidget.c"
	}
#line 208 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	(*array)[(*length)++] = value;
#line 208 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	(*array)[*length] = NULL;
#line 1571 "ManifestWidget.c"
}


static void
_vala_GtkTreePath_free (GtkTreePath* self)
{
#line 204 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	g_boxed_free (gtk_tree_path_get_type (), self);
#line 1580 "ManifestWidget.c"
}


static void
__vala_GtkTreePath_free0_ (gpointer var)
{
#line 211 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	(var == NULL) ? NULL : (var = (_vala_GtkTreePath_free (var), NULL));
#line 1589 "ManifestWidget.c"
}


static inline void
_g_list_free___vala_GtkTreePath_free0_ (GList* self)
{
#line 211 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	g_list_free_full (self, (GDestroyNotify) __vala_GtkTreePath_free0_);
#line 1598 "ManifestWidget.c"
}


gchar**
plugins_manifest_list_view_get_selected_ids (PluginsManifestListView* self,
                                             int* result_length1)
{
	gchar** result = NULL;
	gchar** ids = NULL;
	gchar** _tmp0_;
	gint ids_length1;
	gint _ids_size_;
	GList* selected = NULL;
	GtkTreeSelection* _tmp1_;
	GList* _tmp2_;
	GList* _tmp3_;
	gchar** _tmp12_;
	gint _tmp12__length1;
#line 200 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	g_return_val_if_fail (PLUGINS_IS_MANIFEST_LIST_VIEW (self), NULL);
#line 201 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_tmp0_ = g_new0 (gchar*, 0 + 1);
#line 201 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	ids = _tmp0_;
#line 201 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	ids_length1 = 0;
#line 201 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_ids_size_ = ids_length1;
#line 203 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_tmp1_ = gtk_tree_view_get_selection (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_view_get_type (), GtkTreeView));
#line 203 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_tmp2_ = gtk_tree_selection_get_selected_rows (_tmp1_, NULL);
#line 203 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	selected = _tmp2_;
#line 204 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_tmp3_ = selected;
#line 1635 "ManifestWidget.c"
	{
		GList* path_collection = NULL;
		GList* path_it = NULL;
#line 204 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
		path_collection = _tmp3_;
#line 204 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
		for (path_it = path_collection; path_it != NULL; path_it = path_it->next) {
#line 1643 "ManifestWidget.c"
			GtkTreePath* _tmp4_;
			GtkTreePath* path = NULL;
#line 204 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
			_tmp4_ = __vala_GtkTreePath_copy0 ((GtkTreePath*) path_it->data);
#line 204 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
			path = _tmp4_;
#line 1650 "ManifestWidget.c"
			{
				GtkTreeIter iter = {0};
				gchar* id = NULL;
				GtkTreePath* _tmp5_;
				GtkTreeIter _tmp6_ = {0};
				gchar* _tmp7_;
				const gchar* _tmp8_;
#line 206 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
				_tmp5_ = path;
#line 206 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
				_tmp7_ = plugins_manifest_list_view_get_id_at_path (self, _tmp5_, &_tmp6_);
#line 206 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
				iter = _tmp6_;
#line 206 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
				id = _tmp7_;
#line 207 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
				_tmp8_ = id;
#line 207 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
				if (_tmp8_ != NULL) {
#line 1670 "ManifestWidget.c"
					gchar** _tmp9_;
					gint _tmp9__length1;
					const gchar* _tmp10_;
					gchar* _tmp11_;
#line 208 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
					_tmp9_ = ids;
#line 208 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
					_tmp9__length1 = ids_length1;
#line 208 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
					_tmp10_ = id;
#line 208 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
					_tmp11_ = g_strdup (_tmp10_);
#line 208 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
					_vala_array_add53 (&ids, &ids_length1, &_ids_size_, _tmp11_);
#line 1685 "ManifestWidget.c"
				}
#line 204 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
				_g_free0 (id);
#line 204 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
				__vala_GtkTreePath_free0 (path);
#line 1691 "ManifestWidget.c"
			}
		}
	}
#line 211 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_tmp12_ = ids;
#line 211 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_tmp12__length1 = ids_length1;
#line 211 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	if (result_length1) {
#line 211 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
		*result_length1 = _tmp12__length1;
#line 1703 "ManifestWidget.c"
	}
#line 211 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	result = _tmp12_;
#line 211 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	__g_list_free___vala_GtkTreePath_free0_0 (selected);
#line 211 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	return result;
#line 1711 "ManifestWidget.c"
}


static gchar*
plugins_manifest_list_view_get_id_at_path (PluginsManifestListView* self,
                                           GtkTreePath* path,
                                           GtkTreeIter* iter)
{
	GtkTreeIter _vala_iter = {0};
	gchar* result = NULL;
	GtkTreeStore* _tmp0_;
	GtkTreeIter _tmp1_ = {0};
	gboolean _tmp2_;
	const gchar* id = NULL;
	GtkTreeStore* _tmp3_;
	GtkTreeIter _tmp4_;
	const gchar* _tmp5_;
	gchar* _tmp6_;
#line 214 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	g_return_val_if_fail (PLUGINS_IS_MANIFEST_LIST_VIEW (self), NULL);
#line 214 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	g_return_val_if_fail (path != NULL, NULL);
#line 215 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_tmp0_ = self->priv->store;
#line 215 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_tmp2_ = gtk_tree_model_get_iter (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, gtk_tree_model_get_type (), GtkTreeModel), &_tmp1_, path);
#line 215 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_vala_iter = _tmp1_;
#line 215 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	if (!_tmp2_) {
#line 216 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
		result = NULL;
#line 216 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
		if (iter) {
#line 216 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
			*iter = _vala_iter;
#line 1748 "ManifestWidget.c"
		}
#line 216 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
		return result;
#line 1752 "ManifestWidget.c"
	}
#line 219 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_tmp3_ = self->priv->store;
#line 219 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_tmp4_ = _vala_iter;
#line 219 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	gtk_tree_model_get (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, gtk_tree_model_get_type (), GtkTreeModel), &_tmp4_, PLUGINS_MANIFEST_LIST_VIEW_COLUMN_ID, &id, -1);
#line 221 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_tmp5_ = id;
#line 221 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_tmp6_ = g_strdup (_tmp5_);
#line 221 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	result = _tmp6_;
#line 221 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	if (iter) {
#line 221 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
		*iter = _vala_iter;
#line 1770 "ManifestWidget.c"
	}
#line 221 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	return result;
#line 1774 "ManifestWidget.c"
}


static gboolean
plugins_manifest_list_view_real_button_press_event (GtkWidget* base,
                                                    GdkEventButton* event)
{
	PluginsManifestListView * self;
	gboolean result = FALSE;
	GtkTreePath* path = NULL;
	GtkTreeViewColumn* col = NULL;
	gint cellx = 0;
	gint celly = 0;
	gdouble _tmp0_;
	gdouble _tmp1_;
	GtkTreePath* _tmp2_ = NULL;
	GtkTreeViewColumn* _tmp3_ = NULL;
	gint _tmp4_ = 0;
	gint _tmp5_ = 0;
	gboolean _tmp6_;
	GtkTreeViewColumn* _tmp7_;
	gboolean _tmp8_ = FALSE;
	gint _tmp9_;
	GtkTreeIter iter = {0};
	gchar* id = NULL;
	GtkTreePath* _tmp11_;
	GtkTreeIter _tmp12_ = {0};
	gchar* _tmp13_;
	const gchar* _tmp14_;
	gboolean enabled = FALSE;
	const gchar* _tmp15_;
	gboolean _tmp16_ = FALSE;
	gboolean _tmp17_;
	gboolean _tmp18_;
	const gchar* _tmp19_;
	gboolean _tmp20_;
	GtkTreeStore* _tmp21_;
	GtkTreeIter _tmp22_;
	gboolean _tmp23_;
#line 232 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PLUGINS_TYPE_MANIFEST_LIST_VIEW, PluginsManifestListView);
#line 232 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 237 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_tmp0_ = event->x;
#line 237 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_tmp1_ = event->y;
#line 237 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_tmp6_ = gtk_tree_view_get_path_at_pos (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_view_get_type (), GtkTreeView), (gint) _tmp0_, (gint) _tmp1_, &_tmp2_, &_tmp3_, &_tmp4_, &_tmp5_);
#line 237 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	__vala_GtkTreePath_free0 (path);
#line 237 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	path = _tmp2_;
#line 237 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_g_object_unref0 (col);
#line 237 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_tmp7_ = _g_object_ref0 (_tmp3_);
#line 237 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	col = _tmp7_;
#line 237 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	cellx = _tmp4_;
#line 237 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	celly = _tmp5_;
#line 237 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	if (!_tmp6_) {
#line 239 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
		result = GTK_WIDGET_CLASS (plugins_manifest_list_view_parent_class)->button_press_event (G_TYPE_CHECK_INSTANCE_CAST (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_view_get_type (), GtkTreeView), gtk_widget_get_type (), GtkWidget), event);
#line 239 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
		_g_object_unref0 (col);
#line 239 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
		__vala_GtkTreePath_free0 (path);
#line 239 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
		return result;
#line 1848 "ManifestWidget.c"
	}
#line 244 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_tmp9_ = cellx;
#line 244 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	if (_tmp9_ < (PLUGINS_MANIFEST_LIST_VIEW_ICON_SIZE + PLUGINS_MANIFEST_LIST_VIEW_ICON_X_PADDING)) {
#line 244 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
		_tmp8_ = TRUE;
#line 1856 "ManifestWidget.c"
	} else {
		gint _tmp10_;
#line 244 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
		_tmp10_ = cellx;
#line 244 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
		_tmp8_ = _tmp10_ > (2 * (PLUGINS_MANIFEST_LIST_VIEW_ICON_X_PADDING + PLUGINS_MANIFEST_LIST_VIEW_ICON_SIZE));
#line 1863 "ManifestWidget.c"
	}
#line 244 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	if (_tmp8_) {
#line 245 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
		result = GTK_WIDGET_CLASS (plugins_manifest_list_view_parent_class)->button_press_event (G_TYPE_CHECK_INSTANCE_CAST (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_view_get_type (), GtkTreeView), gtk_widget_get_type (), GtkWidget), event);
#line 245 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
		_g_object_unref0 (col);
#line 245 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
		__vala_GtkTreePath_free0 (path);
#line 245 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
		return result;
#line 1875 "ManifestWidget.c"
	}
#line 248 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_tmp11_ = path;
#line 248 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_tmp13_ = plugins_manifest_list_view_get_id_at_path (self, _tmp11_, &_tmp12_);
#line 248 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	iter = _tmp12_;
#line 248 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	id = _tmp13_;
#line 249 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_tmp14_ = id;
#line 249 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	if (_tmp14_ == NULL) {
#line 250 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
		result = GTK_WIDGET_CLASS (plugins_manifest_list_view_parent_class)->button_press_event (G_TYPE_CHECK_INSTANCE_CAST (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_view_get_type (), GtkTreeView), gtk_widget_get_type (), GtkWidget), event);
#line 250 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
		_g_free0 (id);
#line 250 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
		_g_object_unref0 (col);
#line 250 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
		__vala_GtkTreePath_free0 (path);
#line 250 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
		return result;
#line 1899 "ManifestWidget.c"
	}
#line 253 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_tmp15_ = id;
#line 253 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_tmp17_ = plugins_get_pluggable_enabled (_tmp15_, &_tmp16_);
#line 253 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	enabled = _tmp16_;
#line 253 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	if (!_tmp17_) {
#line 254 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
		result = GTK_WIDGET_CLASS (plugins_manifest_list_view_parent_class)->button_press_event (G_TYPE_CHECK_INSTANCE_CAST (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_view_get_type (), GtkTreeView), gtk_widget_get_type (), GtkWidget), event);
#line 254 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
		_g_free0 (id);
#line 254 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
		_g_object_unref0 (col);
#line 254 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
		__vala_GtkTreePath_free0 (path);
#line 254 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
		return result;
#line 1919 "ManifestWidget.c"
	}
#line 257 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_tmp18_ = enabled;
#line 257 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	enabled = !_tmp18_;
#line 258 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_tmp19_ = id;
#line 258 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_tmp20_ = enabled;
#line 258 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	plugins_set_pluggable_enabled (_tmp19_, _tmp20_);
#line 260 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_tmp21_ = self->priv->store;
#line 260 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_tmp22_ = iter;
#line 260 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_tmp23_ = enabled;
#line 260 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	gtk_tree_store_set (_tmp21_, &_tmp22_, PLUGINS_MANIFEST_LIST_VIEW_COLUMN_ENABLED, _tmp23_, -1);
#line 262 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	result = TRUE;
#line 262 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_g_free0 (id);
#line 262 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_g_object_unref0 (col);
#line 262 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	__vala_GtkTreePath_free0 (path);
#line 262 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	return result;
#line 1949 "ManifestWidget.c"
}


static void
plugins_manifest_list_view_class_init (PluginsManifestListViewClass * klass)
{
#line 94 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	plugins_manifest_list_view_parent_class = g_type_class_peek_parent (klass);
#line 94 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	g_type_class_add_private (klass, sizeof (PluginsManifestListViewPrivate));
#line 94 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	((GtkWidgetClass *) klass)->button_press_event = (gboolean (*) (GtkWidget *, GdkEventButton*)) plugins_manifest_list_view_real_button_press_event;
#line 94 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	G_OBJECT_CLASS (klass)->finalize = plugins_manifest_list_view_finalize;
#line 1964 "ManifestWidget.c"
}


static void
plugins_manifest_list_view_instance_init (PluginsManifestListView * self)
{
	GtkTreeStore* _tmp0_;
#line 94 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	self->priv = PLUGINS_MANIFEST_LIST_VIEW_GET_PRIVATE (self);
#line 108 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_tmp0_ = gtk_tree_store_new ((gint) PLUGINS_MANIFEST_LIST_VIEW_COLUMN_N_COLUMNS, G_TYPE_BOOLEAN, G_TYPE_BOOLEAN, gdk_pixbuf_get_type (), G_TYPE_STRING, G_TYPE_STRING);
#line 108 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	self->priv->store = _tmp0_;
#line 1978 "ManifestWidget.c"
}


static void
plugins_manifest_list_view_finalize (GObject * obj)
{
	PluginsManifestListView * self;
#line 94 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PLUGINS_TYPE_MANIFEST_LIST_VIEW, PluginsManifestListView);
#line 108 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	_g_object_unref0 (self->priv->store);
#line 94 "/home/jens/Source/shotwell/src/plugins/ManifestWidget.vala"
	G_OBJECT_CLASS (plugins_manifest_list_view_parent_class)->finalize (obj);
#line 1992 "ManifestWidget.c"
}


GType
plugins_manifest_list_view_get_type (void)
{
	static volatile gsize plugins_manifest_list_view_type_id__volatile = 0;
	if (g_once_init_enter (&plugins_manifest_list_view_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PluginsManifestListViewClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) plugins_manifest_list_view_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PluginsManifestListView), 0, (GInstanceInitFunc) plugins_manifest_list_view_instance_init, NULL };
		GType plugins_manifest_list_view_type_id;
		plugins_manifest_list_view_type_id = g_type_register_static (gtk_tree_view_get_type (), "PluginsManifestListView", &g_define_type_info, 0);
		g_once_init_leave (&plugins_manifest_list_view_type_id__volatile, plugins_manifest_list_view_type_id);
	}
	return plugins_manifest_list_view_type_id__volatile;
}


static void
_vala_array_destroy (gpointer array,
                     gint array_length,
                     GDestroyNotify destroy_func)
{
	if ((array != NULL) && (destroy_func != NULL)) {
		int i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}


static void
_vala_array_free (gpointer array,
                  gint array_length,
                  GDestroyNotify destroy_func)
{
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}


static gint
_vala_array_length (gpointer array)
{
	int length;
	length = 0;
	if (array) {
		while (((gpointer*) array)[length]) {
			length++;
		}
	}
	return length;
}



