/* Copyright 2016 Software Freedom Conservancy Inc.
 *
 * This software is licensed under the GNU Lesser General Public License
 * (version 2.1 or later).  See the COPYING file in this distribution.
 *
 * Auto-generated file.  Do not modify!
 */

namespace Direct {

public void app_init() throws Error {
    Direct.init_entry();
}

public void app_terminate() {
    Direct.terminate_entry();
}

}
