/* StripesEffect.c generated by valac 0.40.4, the Vala compiler
 * generated from StripesEffect.vala, do not modify */

/* Copyright 2013 Jens Bav
 * Copyright 2016 Software Freedom Conservancy Inc.
 *
 * This software is licensed under the GNU Lesser General Public License
 * (version 2.1 or later).  See the COPYING file in this distribution.
 */


#include <glib.h>
#include <glib-object.h>
#include <shotwell-plugin-dev-1.0.h>
#include <stdlib.h>
#include <string.h>
#include <gio/gio.h>
#include <glib/gi18n-lib.h>
#include <cairo.h>
#include <float.h>
#include <math.h>
#include <gdk/gdk.h>


#define TYPE_SHOTWELL_TRANSITION_DESCRIPTOR (shotwell_transition_descriptor_get_type ())
#define SHOTWELL_TRANSITION_DESCRIPTOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SHOTWELL_TRANSITION_DESCRIPTOR, ShotwellTransitionDescriptor))
#define SHOTWELL_TRANSITION_DESCRIPTOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SHOTWELL_TRANSITION_DESCRIPTOR, ShotwellTransitionDescriptorClass))
#define IS_SHOTWELL_TRANSITION_DESCRIPTOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SHOTWELL_TRANSITION_DESCRIPTOR))
#define IS_SHOTWELL_TRANSITION_DESCRIPTOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SHOTWELL_TRANSITION_DESCRIPTOR))
#define SHOTWELL_TRANSITION_DESCRIPTOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SHOTWELL_TRANSITION_DESCRIPTOR, ShotwellTransitionDescriptorClass))

typedef struct _ShotwellTransitionDescriptor ShotwellTransitionDescriptor;
typedef struct _ShotwellTransitionDescriptorClass ShotwellTransitionDescriptorClass;
typedef struct _ShotwellTransitionDescriptorPrivate ShotwellTransitionDescriptorPrivate;

#define TYPE_STRIPES_EFFECT_DESCRIPTOR (stripes_effect_descriptor_get_type ())
#define STRIPES_EFFECT_DESCRIPTOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_STRIPES_EFFECT_DESCRIPTOR, StripesEffectDescriptor))
#define STRIPES_EFFECT_DESCRIPTOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_STRIPES_EFFECT_DESCRIPTOR, StripesEffectDescriptorClass))
#define IS_STRIPES_EFFECT_DESCRIPTOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_STRIPES_EFFECT_DESCRIPTOR))
#define IS_STRIPES_EFFECT_DESCRIPTOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_STRIPES_EFFECT_DESCRIPTOR))
#define STRIPES_EFFECT_DESCRIPTOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_STRIPES_EFFECT_DESCRIPTOR, StripesEffectDescriptorClass))

typedef struct _StripesEffectDescriptor StripesEffectDescriptor;
typedef struct _StripesEffectDescriptorClass StripesEffectDescriptorClass;
typedef struct _StripesEffectDescriptorPrivate StripesEffectDescriptorPrivate;
enum  {
	STRIPES_EFFECT_DESCRIPTOR_0_PROPERTY,
	STRIPES_EFFECT_DESCRIPTOR_NUM_PROPERTIES
};
static GParamSpec* stripes_effect_descriptor_properties[STRIPES_EFFECT_DESCRIPTOR_NUM_PROPERTIES];

#define TYPE_STRIPES_EFFECT (stripes_effect_get_type ())
#define STRIPES_EFFECT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_STRIPES_EFFECT, StripesEffect))
#define STRIPES_EFFECT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_STRIPES_EFFECT, StripesEffectClass))
#define IS_STRIPES_EFFECT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_STRIPES_EFFECT))
#define IS_STRIPES_EFFECT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_STRIPES_EFFECT))
#define STRIPES_EFFECT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_STRIPES_EFFECT, StripesEffectClass))

typedef struct _StripesEffect StripesEffect;
typedef struct _StripesEffectClass StripesEffectClass;
typedef struct _StripesEffectPrivate StripesEffectPrivate;
enum  {
	STRIPES_EFFECT_0_PROPERTY,
	STRIPES_EFFECT_NUM_PROPERTIES
};
static GParamSpec* stripes_effect_properties[STRIPES_EFFECT_NUM_PROPERTIES];

struct _ShotwellTransitionDescriptor {
	GObject parent_instance;
	ShotwellTransitionDescriptorPrivate * priv;
};

struct _ShotwellTransitionDescriptorClass {
	GObjectClass parent_class;
	const gchar* (*get_id) (ShotwellTransitionDescriptor* self);
	const gchar* (*get_pluggable_name) (ShotwellTransitionDescriptor* self);
	SpitTransitionsEffect* (*create) (ShotwellTransitionDescriptor* self, SpitHostInterface* host);
};

struct _StripesEffectDescriptor {
	ShotwellTransitionDescriptor parent_instance;
	StripesEffectDescriptorPrivate * priv;
};

struct _StripesEffectDescriptorClass {
	ShotwellTransitionDescriptorClass parent_class;
};

struct _StripesEffect {
	GObject parent_instance;
	StripesEffectPrivate * priv;
};

struct _StripesEffectClass {
	GObjectClass parent_class;
};

struct _StripesEffectPrivate {
	gint stripe_count;
};


static gpointer stripes_effect_descriptor_parent_class = NULL;
static gpointer stripes_effect_parent_class = NULL;
static SpitTransitionsEffectIface * stripes_effect_spit_transitions_effect_parent_iface = NULL;

GType shotwell_transition_descriptor_get_type (void) G_GNUC_CONST;
GType stripes_effect_descriptor_get_type (void) G_GNUC_CONST;
StripesEffectDescriptor* stripes_effect_descriptor_new (GFile* resource_directory);
StripesEffectDescriptor* stripes_effect_descriptor_construct (GType object_type,
                                                              GFile* resource_directory);
ShotwellTransitionDescriptor* shotwell_transition_descriptor_construct (GType object_type,
                                                                        GFile* resource_directory);
static const gchar* stripes_effect_descriptor_real_get_id (ShotwellTransitionDescriptor* base);
static const gchar* stripes_effect_descriptor_real_get_pluggable_name (ShotwellTransitionDescriptor* base);
static SpitTransitionsEffect* stripes_effect_descriptor_real_create (ShotwellTransitionDescriptor* base,
                                                              SpitHostInterface* host);
StripesEffect* stripes_effect_new (void);
StripesEffect* stripes_effect_construct (GType object_type);
GType stripes_effect_get_type (void) G_GNUC_CONST;
#define STRIPES_EFFECT_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_STRIPES_EFFECT, StripesEffectPrivate))
#define STRIPES_EFFECT_DESIRED_FPS 25
#define STRIPES_EFFECT_MIN_FPS 10
#define STRIPES_EFFECT_STRIPE_HEIGHT 100
static void stripes_effect_real_get_fps (SpitTransitionsEffect* base,
                                  gint* desired_fps,
                                  gint* min_fps);
static void stripes_effect_real_start (SpitTransitionsEffect* base,
                                SpitTransitionsVisuals* visuals,
                                SpitTransitionsMotion* motion);
static gboolean stripes_effect_real_needs_clear_background (SpitTransitionsEffect* base);
static void stripes_effect_real_paint (SpitTransitionsEffect* base,
                                SpitTransitionsVisuals* visuals,
                                SpitTransitionsMotion* motion,
                                cairo_t* ctx,
                                gint width,
                                gint height,
                                gint frame_number);
static void stripes_effect_real_advance (SpitTransitionsEffect* base,
                                  SpitTransitionsVisuals* visuals,
                                  SpitTransitionsMotion* motion,
                                  gint frame_number);
static void stripes_effect_real_cancel (SpitTransitionsEffect* base);
static void stripes_effect_finalize (GObject * obj);


StripesEffectDescriptor*
stripes_effect_descriptor_construct (GType object_type,
                                     GFile* resource_directory)
{
	StripesEffectDescriptor * self = NULL;
#line 11 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
	g_return_val_if_fail (G_IS_FILE (resource_directory), NULL);
#line 12 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
	self = (StripesEffectDescriptor*) shotwell_transition_descriptor_construct (object_type, resource_directory);
#line 11 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
	return self;
#line 159 "StripesEffect.c"
}


StripesEffectDescriptor*
stripes_effect_descriptor_new (GFile* resource_directory)
{
#line 11 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
	return stripes_effect_descriptor_construct (TYPE_STRIPES_EFFECT_DESCRIPTOR, resource_directory);
#line 168 "StripesEffect.c"
}


static const gchar*
stripes_effect_descriptor_real_get_id (ShotwellTransitionDescriptor* base)
{
	StripesEffectDescriptor * self;
	const gchar* result = NULL;
#line 15 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_STRIPES_EFFECT_DESCRIPTOR, StripesEffectDescriptor);
#line 16 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
	result = "org.yorba.shotwell.transitions.stripes";
#line 16 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
	return result;
#line 183 "StripesEffect.c"
}


static const gchar*
stripes_effect_descriptor_real_get_pluggable_name (ShotwellTransitionDescriptor* base)
{
	StripesEffectDescriptor * self;
	const gchar* result = NULL;
#line 19 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_STRIPES_EFFECT_DESCRIPTOR, StripesEffectDescriptor);
#line 20 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
	result = _ ("Stripes");
#line 20 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
	return result;
#line 198 "StripesEffect.c"
}


static SpitTransitionsEffect*
stripes_effect_descriptor_real_create (ShotwellTransitionDescriptor* base,
                                       SpitHostInterface* host)
{
	StripesEffectDescriptor * self;
	SpitTransitionsEffect* result = NULL;
	StripesEffect* _tmp0_;
#line 23 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_STRIPES_EFFECT_DESCRIPTOR, StripesEffectDescriptor);
#line 23 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
	g_return_val_if_fail (SPIT_IS_HOST_INTERFACE (host), NULL);
#line 24 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
	_tmp0_ = stripes_effect_new ();
#line 24 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
	result = G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_TRANSITIONS_TYPE_EFFECT, SpitTransitionsEffect);
#line 24 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
	return result;
#line 219 "StripesEffect.c"
}


static void
stripes_effect_descriptor_class_init (StripesEffectDescriptorClass * klass)
{
#line 10 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
	stripes_effect_descriptor_parent_class = g_type_class_peek_parent (klass);
#line 10 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
	((ShotwellTransitionDescriptorClass *) klass)->get_id = (const gchar* (*) (ShotwellTransitionDescriptor *)) stripes_effect_descriptor_real_get_id;
#line 10 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
	((ShotwellTransitionDescriptorClass *) klass)->get_pluggable_name = (const gchar* (*) (ShotwellTransitionDescriptor *)) stripes_effect_descriptor_real_get_pluggable_name;
#line 10 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
	((ShotwellTransitionDescriptorClass *) klass)->create = (SpitTransitionsEffect* (*) (ShotwellTransitionDescriptor *, SpitHostInterface*)) stripes_effect_descriptor_real_create;
#line 234 "StripesEffect.c"
}


static void
stripes_effect_descriptor_instance_init (StripesEffectDescriptor * self)
{
}


GType
stripes_effect_descriptor_get_type (void)
{
	static volatile gsize stripes_effect_descriptor_type_id__volatile = 0;
	if (g_once_init_enter (&stripes_effect_descriptor_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (StripesEffectDescriptorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) stripes_effect_descriptor_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (StripesEffectDescriptor), 0, (GInstanceInitFunc) stripes_effect_descriptor_instance_init, NULL };
		GType stripes_effect_descriptor_type_id;
		stripes_effect_descriptor_type_id = g_type_register_static (TYPE_SHOTWELL_TRANSITION_DESCRIPTOR, "StripesEffectDescriptor", &g_define_type_info, 0);
		g_once_init_leave (&stripes_effect_descriptor_type_id__volatile, stripes_effect_descriptor_type_id);
	}
	return stripes_effect_descriptor_type_id__volatile;
}


StripesEffect*
stripes_effect_construct (GType object_type)
{
	StripesEffect * self = NULL;
#line 34 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
	self = (StripesEffect*) g_object_new (object_type, NULL);
#line 34 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
	return self;
#line 266 "StripesEffect.c"
}


StripesEffect*
stripes_effect_new (void)
{
#line 34 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
	return stripes_effect_construct (TYPE_STRIPES_EFFECT);
#line 275 "StripesEffect.c"
}


static void
stripes_effect_real_get_fps (SpitTransitionsEffect* base,
                             gint* desired_fps,
                             gint* min_fps)
{
	StripesEffect * self;
	gint _vala_desired_fps = 0;
	gint _vala_min_fps = 0;
#line 37 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_STRIPES_EFFECT, StripesEffect);
#line 38 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
	_vala_desired_fps = STRIPES_EFFECT_DESIRED_FPS;
#line 39 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
	_vala_min_fps = STRIPES_EFFECT_MIN_FPS;
#line 37 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
	if (desired_fps) {
#line 37 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
		*desired_fps = _vala_desired_fps;
#line 297 "StripesEffect.c"
	}
#line 37 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
	if (min_fps) {
#line 37 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
		*min_fps = _vala_min_fps;
#line 303 "StripesEffect.c"
	}
}


static void
stripes_effect_real_start (SpitTransitionsEffect* base,
                           SpitTransitionsVisuals* visuals,
                           SpitTransitionsMotion* motion)
{
	StripesEffect * self;
	GdkRectangle _tmp0_ = {0};
	GdkRectangle _tmp1_;
	gint _tmp2_;
#line 42 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_STRIPES_EFFECT, StripesEffect);
#line 42 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
	g_return_if_fail (SPIT_TRANSITIONS_IS_VISUALS (visuals));
#line 42 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
	g_return_if_fail (SPIT_TRANSITIONS_IS_MOTION (motion));
#line 43 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
	spit_transitions_visuals_get_to_pos (visuals, &_tmp0_);
#line 43 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
	_tmp1_ = _tmp0_;
#line 43 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
	_tmp2_ = _tmp1_.height;
#line 43 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
	self->priv->stripe_count = (_tmp2_ / STRIPES_EFFECT_STRIPE_HEIGHT) + 1;
#line 331 "StripesEffect.c"
}


static gboolean
stripes_effect_real_needs_clear_background (SpitTransitionsEffect* base)
{
	StripesEffect * self;
	gboolean result = FALSE;
#line 46 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_STRIPES_EFFECT, StripesEffect);
#line 47 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
	result = TRUE;
#line 47 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
	return result;
#line 346 "StripesEffect.c"
}


static void
stripes_effect_real_paint (SpitTransitionsEffect* base,
                           SpitTransitionsVisuals* visuals,
                           SpitTransitionsMotion* motion,
                           cairo_t* ctx,
                           gint width,
                           gint height,
                           gint frame_number)
{
	StripesEffect * self;
	gdouble alpha = 0.0;
	GdkPixbuf* _tmp0_;
	GdkPixbuf* _tmp1_;
	GdkPixbuf* _tmp11_;
	GdkPixbuf* _tmp12_;
#line 50 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_STRIPES_EFFECT, StripesEffect);
#line 50 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
	g_return_if_fail (SPIT_TRANSITIONS_IS_VISUALS (visuals));
#line 50 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
	g_return_if_fail (SPIT_TRANSITIONS_IS_MOTION (motion));
#line 50 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
	g_return_if_fail (ctx != NULL);
#line 52 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
	alpha = spit_transitions_motion_get_alpha (motion, frame_number);
#line 53 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
	_tmp0_ = spit_transitions_visuals_get_from_pixbuf (visuals);
#line 53 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
	_tmp1_ = _tmp0_;
#line 53 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
	if (_tmp1_ != NULL) {
#line 381 "StripesEffect.c"
		GdkPixbuf* _tmp2_;
		GdkPixbuf* _tmp3_;
		GdkRectangle _tmp4_ = {0};
		GdkRectangle _tmp5_;
		gint _tmp6_;
		GdkRectangle _tmp7_ = {0};
		GdkRectangle _tmp8_;
		gint _tmp9_;
		gdouble _tmp10_;
#line 54 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
		_tmp2_ = spit_transitions_visuals_get_from_pixbuf (visuals);
#line 54 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
		_tmp3_ = _tmp2_;
#line 54 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
		spit_transitions_visuals_get_from_pos (visuals, &_tmp4_);
#line 54 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
		_tmp5_ = _tmp4_;
#line 54 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
		_tmp6_ = _tmp5_.x;
#line 54 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
		spit_transitions_visuals_get_from_pos (visuals, &_tmp7_);
#line 54 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
		_tmp8_ = _tmp7_;
#line 54 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
		_tmp9_ = _tmp8_.y;
#line 54 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
		gdk_cairo_set_source_pixbuf (ctx, _tmp3_, (gdouble) _tmp6_, (gdouble) _tmp9_);
#line 56 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
		_tmp10_ = alpha;
#line 56 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
		cairo_paint_with_alpha (ctx, 1 - fmin ((gdouble) 1, _tmp10_ * 2));
#line 413 "StripesEffect.c"
	}
#line 59 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
	_tmp11_ = spit_transitions_visuals_get_to_pixbuf (visuals);
#line 59 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
	_tmp12_ = _tmp11_;
#line 59 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
	if (_tmp12_ != NULL) {
#line 421 "StripesEffect.c"
		GdkPixbuf* _tmp13_;
		GdkPixbuf* _tmp14_;
		GdkRectangle _tmp15_ = {0};
		GdkRectangle _tmp16_;
		gint _tmp17_;
		GdkRectangle _tmp18_ = {0};
		GdkRectangle _tmp19_;
		gint _tmp20_;
		gint x = 0;
		GdkRectangle _tmp21_ = {0};
		GdkRectangle _tmp22_;
		gint _tmp23_;
		gint y = 0;
		GdkRectangle _tmp24_ = {0};
		GdkRectangle _tmp25_;
		gint _tmp26_;
		gdouble _tmp55_;
#line 60 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
		_tmp13_ = spit_transitions_visuals_get_to_pixbuf (visuals);
#line 60 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
		_tmp14_ = _tmp13_;
#line 60 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
		spit_transitions_visuals_get_to_pos (visuals, &_tmp15_);
#line 60 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
		_tmp16_ = _tmp15_;
#line 60 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
		_tmp17_ = _tmp16_.x;
#line 60 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
		spit_transitions_visuals_get_to_pos (visuals, &_tmp18_);
#line 60 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
		_tmp19_ = _tmp18_;
#line 60 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
		_tmp20_ = _tmp19_.y;
#line 60 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
		gdk_cairo_set_source_pixbuf (ctx, _tmp14_, (gdouble) _tmp17_, (gdouble) _tmp20_);
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
		spit_transitions_visuals_get_to_pos (visuals, &_tmp21_);
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
		_tmp22_ = _tmp21_;
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
		_tmp23_ = _tmp22_.x;
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
		x = _tmp23_;
#line 62 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
		spit_transitions_visuals_get_to_pos (visuals, &_tmp24_);
#line 62 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
		_tmp25_ = _tmp24_;
#line 62 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
		_tmp26_ = _tmp25_.y;
#line 62 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
		y = _tmp26_;
#line 473 "StripesEffect.c"
		{
			gint i = 0;
#line 63 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
			i = 0;
#line 478 "StripesEffect.c"
			{
				gboolean _tmp27_ = FALSE;
#line 63 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
				_tmp27_ = TRUE;
#line 63 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
				while (TRUE) {
#line 485 "StripesEffect.c"
					gint _tmp29_;
					gint _tmp30_;
					gint _tmp31_;
					SpitTransitionsDirection _tmp32_;
					SpitTransitionsDirection _tmp33_;
#line 63 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
					if (!_tmp27_) {
#line 493 "StripesEffect.c"
						gint _tmp28_;
#line 63 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
						_tmp28_ = i;
#line 63 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
						i = _tmp28_ + 1;
#line 499 "StripesEffect.c"
					}
#line 63 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
					_tmp27_ = FALSE;
#line 63 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
					_tmp29_ = i;
#line 63 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
					_tmp30_ = self->priv->stripe_count;
#line 63 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
					if (!(_tmp29_ <= _tmp30_)) {
#line 63 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
						break;
#line 511 "StripesEffect.c"
					}
#line 64 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
					_tmp31_ = i;
#line 64 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
					_tmp32_ = spit_transitions_motion_get_direction (motion);
#line 64 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
					_tmp33_ = _tmp32_;
#line 64 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
					if ((_tmp31_ % 2) == ((gint) _tmp33_)) {
#line 521 "StripesEffect.c"
						gint _tmp34_;
						GdkRectangle _tmp35_ = {0};
						GdkRectangle _tmp36_;
						gint _tmp37_;
						gdouble _tmp38_;
						GdkRectangle _tmp39_ = {0};
						GdkRectangle _tmp40_;
						gint _tmp41_;
						gint _tmp42_;
						gint _tmp43_;
						gint _tmp44_;
						GdkRectangle _tmp45_ = {0};
						GdkRectangle _tmp46_;
						gint _tmp47_;
#line 65 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
						_tmp34_ = x;
#line 65 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
						spit_transitions_visuals_get_to_pos (visuals, &_tmp35_);
#line 65 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
						_tmp36_ = _tmp35_;
#line 65 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
						_tmp37_ = _tmp36_.width;
#line 65 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
						_tmp38_ = alpha;
#line 65 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
						spit_transitions_visuals_get_to_pos (visuals, &_tmp39_);
#line 65 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
						_tmp40_ = _tmp39_;
#line 65 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
						_tmp41_ = _tmp40_.width;
#line 65 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
						_tmp42_ = y;
#line 65 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
						_tmp43_ = i;
#line 65 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
						_tmp44_ = x;
#line 65 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
						spit_transitions_visuals_get_to_pos (visuals, &_tmp45_);
#line 65 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
						_tmp46_ = _tmp45_;
#line 65 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
						_tmp47_ = _tmp46_.width;
#line 65 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
						cairo_rectangle (ctx, (_tmp34_ + _tmp37_) - (_tmp38_ * _tmp41_), (gdouble) (_tmp42_ + (_tmp43_ * STRIPES_EFFECT_STRIPE_HEIGHT)), (gdouble) (_tmp44_ + _tmp47_), (gdouble) STRIPES_EFFECT_STRIPE_HEIGHT);
#line 566 "StripesEffect.c"
					} else {
						gint _tmp48_;
						gint _tmp49_;
						gint _tmp50_;
						GdkRectangle _tmp51_ = {0};
						GdkRectangle _tmp52_;
						gint _tmp53_;
						gdouble _tmp54_;
#line 68 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
						_tmp48_ = x;
#line 68 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
						_tmp49_ = y;
#line 68 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
						_tmp50_ = i;
#line 68 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
						spit_transitions_visuals_get_to_pos (visuals, &_tmp51_);
#line 68 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
						_tmp52_ = _tmp51_;
#line 68 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
						_tmp53_ = _tmp52_.width;
#line 68 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
						_tmp54_ = alpha;
#line 68 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
						cairo_rectangle (ctx, (gdouble) _tmp48_, (gdouble) (_tmp49_ + (STRIPES_EFFECT_STRIPE_HEIGHT * _tmp50_)), _tmp53_ * _tmp54_, (gdouble) STRIPES_EFFECT_STRIPE_HEIGHT);
#line 591 "StripesEffect.c"
					}
				}
			}
		}
#line 73 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
		cairo_clip (ctx);
#line 74 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
		_tmp55_ = alpha;
#line 74 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
		cairo_paint_with_alpha (ctx, _tmp55_);
#line 602 "StripesEffect.c"
	}
}


static void
stripes_effect_real_advance (SpitTransitionsEffect* base,
                             SpitTransitionsVisuals* visuals,
                             SpitTransitionsMotion* motion,
                             gint frame_number)
{
	StripesEffect * self;
#line 78 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_STRIPES_EFFECT, StripesEffect);
#line 78 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
	g_return_if_fail (SPIT_TRANSITIONS_IS_VISUALS (visuals));
#line 78 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
	g_return_if_fail (SPIT_TRANSITIONS_IS_MOTION (motion));
#line 620 "StripesEffect.c"
}


static void
stripes_effect_real_cancel (SpitTransitionsEffect* base)
{
	StripesEffect * self;
#line 81 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_STRIPES_EFFECT, StripesEffect);
#line 630 "StripesEffect.c"
}


static void
stripes_effect_class_init (StripesEffectClass * klass)
{
#line 28 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
	stripes_effect_parent_class = g_type_class_peek_parent (klass);
#line 28 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
	g_type_class_add_private (klass, sizeof (StripesEffectPrivate));
#line 28 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
	G_OBJECT_CLASS (klass)->finalize = stripes_effect_finalize;
#line 643 "StripesEffect.c"
}


static void
stripes_effect_spit_transitions_effect_interface_init (SpitTransitionsEffectIface * iface)
{
#line 28 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
	stripes_effect_spit_transitions_effect_parent_iface = g_type_interface_peek_parent (iface);
#line 28 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
	iface->get_fps = (void (*) (SpitTransitionsEffect *, gint*, gint*)) stripes_effect_real_get_fps;
#line 28 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
	iface->start = (void (*) (SpitTransitionsEffect *, SpitTransitionsVisuals*, SpitTransitionsMotion*)) stripes_effect_real_start;
#line 28 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
	iface->needs_clear_background = (gboolean (*) (SpitTransitionsEffect *)) stripes_effect_real_needs_clear_background;
#line 28 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
	iface->paint = (void (*) (SpitTransitionsEffect *, SpitTransitionsVisuals*, SpitTransitionsMotion*, cairo_t*, gint, gint, gint)) stripes_effect_real_paint;
#line 28 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
	iface->advance = (void (*) (SpitTransitionsEffect *, SpitTransitionsVisuals*, SpitTransitionsMotion*, gint)) stripes_effect_real_advance;
#line 28 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
	iface->cancel = (void (*) (SpitTransitionsEffect *)) stripes_effect_real_cancel;
#line 664 "StripesEffect.c"
}


static void
stripes_effect_instance_init (StripesEffect * self)
{
#line 28 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
	self->priv = STRIPES_EFFECT_GET_PRIVATE (self);
#line 673 "StripesEffect.c"
}


static void
stripes_effect_finalize (GObject * obj)
{
	StripesEffect * self;
#line 28 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_STRIPES_EFFECT, StripesEffect);
#line 28 "/home/jens/Source/shotwell/plugins/shotwell-transitions/StripesEffect.vala"
	G_OBJECT_CLASS (stripes_effect_parent_class)->finalize (obj);
#line 685 "StripesEffect.c"
}


GType
stripes_effect_get_type (void)
{
	static volatile gsize stripes_effect_type_id__volatile = 0;
	if (g_once_init_enter (&stripes_effect_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (StripesEffectClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) stripes_effect_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (StripesEffect), 0, (GInstanceInitFunc) stripes_effect_instance_init, NULL };
		static const GInterfaceInfo spit_transitions_effect_info = { (GInterfaceInitFunc) stripes_effect_spit_transitions_effect_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType stripes_effect_type_id;
		stripes_effect_type_id = g_type_register_static (G_TYPE_OBJECT, "StripesEffect", &g_define_type_info, 0);
		g_type_add_interface_static (stripes_effect_type_id, SPIT_TRANSITIONS_TYPE_EFFECT, &spit_transitions_effect_info);
		g_once_init_leave (&stripes_effect_type_id__volatile, stripes_effect_type_id);
	}
	return stripes_effect_type_id__volatile;
}



