/* shotwell-transitions.c generated by valac 0.40.4, the Vala compiler
 * generated from shotwell-transitions.vala, do not modify */

/* Copyright 2016 Software Freedom Conservancy Inc.
 *
 * This software is licensed under the GNU Lesser General Public License
 * (version 2.1 or later).  See the COPYING file in this distribution.
 */


#include <glib.h>
#include <glib-object.h>
#include <shotwell-plugin-dev-1.0.h>
#include <gio/gio.h>
#include <stdlib.h>
#include <string.h>
#include <glib/gi18n-lib.h>
#include <gdk-pixbuf/gdk-pixbuf.h>
#include "shotwell-plugin-common.h"


#define TYPE_SHOTWELL_TRANSITIONS (shotwell_transitions_get_type ())
#define SHOTWELL_TRANSITIONS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SHOTWELL_TRANSITIONS, ShotwellTransitions))
#define SHOTWELL_TRANSITIONS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SHOTWELL_TRANSITIONS, ShotwellTransitionsClass))
#define IS_SHOTWELL_TRANSITIONS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SHOTWELL_TRANSITIONS))
#define IS_SHOTWELL_TRANSITIONS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SHOTWELL_TRANSITIONS))
#define SHOTWELL_TRANSITIONS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SHOTWELL_TRANSITIONS, ShotwellTransitionsClass))

typedef struct _ShotwellTransitions ShotwellTransitions;
typedef struct _ShotwellTransitionsClass ShotwellTransitionsClass;
typedef struct _ShotwellTransitionsPrivate ShotwellTransitionsPrivate;
enum  {
	SHOTWELL_TRANSITIONS_0_PROPERTY,
	SHOTWELL_TRANSITIONS_NUM_PROPERTIES
};
static GParamSpec* shotwell_transitions_properties[SHOTWELL_TRANSITIONS_NUM_PROPERTIES];

#define TYPE_SHOTWELL_TRANSITION_DESCRIPTOR (shotwell_transition_descriptor_get_type ())
#define SHOTWELL_TRANSITION_DESCRIPTOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SHOTWELL_TRANSITION_DESCRIPTOR, ShotwellTransitionDescriptor))
#define SHOTWELL_TRANSITION_DESCRIPTOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SHOTWELL_TRANSITION_DESCRIPTOR, ShotwellTransitionDescriptorClass))
#define IS_SHOTWELL_TRANSITION_DESCRIPTOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SHOTWELL_TRANSITION_DESCRIPTOR))
#define IS_SHOTWELL_TRANSITION_DESCRIPTOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SHOTWELL_TRANSITION_DESCRIPTOR))
#define SHOTWELL_TRANSITION_DESCRIPTOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SHOTWELL_TRANSITION_DESCRIPTOR, ShotwellTransitionDescriptorClass))

typedef struct _ShotwellTransitionDescriptor ShotwellTransitionDescriptor;
typedef struct _ShotwellTransitionDescriptorClass ShotwellTransitionDescriptorClass;

#define TYPE_FADE_EFFECT_DESCRIPTOR (fade_effect_descriptor_get_type ())
#define FADE_EFFECT_DESCRIPTOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_FADE_EFFECT_DESCRIPTOR, FadeEffectDescriptor))
#define FADE_EFFECT_DESCRIPTOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_FADE_EFFECT_DESCRIPTOR, FadeEffectDescriptorClass))
#define IS_FADE_EFFECT_DESCRIPTOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_FADE_EFFECT_DESCRIPTOR))
#define IS_FADE_EFFECT_DESCRIPTOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_FADE_EFFECT_DESCRIPTOR))
#define FADE_EFFECT_DESCRIPTOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_FADE_EFFECT_DESCRIPTOR, FadeEffectDescriptorClass))

typedef struct _FadeEffectDescriptor FadeEffectDescriptor;
typedef struct _FadeEffectDescriptorClass FadeEffectDescriptorClass;

#define TYPE_SLIDE_EFFECT_DESCRIPTOR (slide_effect_descriptor_get_type ())
#define SLIDE_EFFECT_DESCRIPTOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SLIDE_EFFECT_DESCRIPTOR, SlideEffectDescriptor))
#define SLIDE_EFFECT_DESCRIPTOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SLIDE_EFFECT_DESCRIPTOR, SlideEffectDescriptorClass))
#define IS_SLIDE_EFFECT_DESCRIPTOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SLIDE_EFFECT_DESCRIPTOR))
#define IS_SLIDE_EFFECT_DESCRIPTOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SLIDE_EFFECT_DESCRIPTOR))
#define SLIDE_EFFECT_DESCRIPTOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SLIDE_EFFECT_DESCRIPTOR, SlideEffectDescriptorClass))

typedef struct _SlideEffectDescriptor SlideEffectDescriptor;
typedef struct _SlideEffectDescriptorClass SlideEffectDescriptorClass;

#define TYPE_CRUMBLE_EFFECT_DESCRIPTOR (crumble_effect_descriptor_get_type ())
#define CRUMBLE_EFFECT_DESCRIPTOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_CRUMBLE_EFFECT_DESCRIPTOR, CrumbleEffectDescriptor))
#define CRUMBLE_EFFECT_DESCRIPTOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_CRUMBLE_EFFECT_DESCRIPTOR, CrumbleEffectDescriptorClass))
#define IS_CRUMBLE_EFFECT_DESCRIPTOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_CRUMBLE_EFFECT_DESCRIPTOR))
#define IS_CRUMBLE_EFFECT_DESCRIPTOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_CRUMBLE_EFFECT_DESCRIPTOR))
#define CRUMBLE_EFFECT_DESCRIPTOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_CRUMBLE_EFFECT_DESCRIPTOR, CrumbleEffectDescriptorClass))

typedef struct _CrumbleEffectDescriptor CrumbleEffectDescriptor;
typedef struct _CrumbleEffectDescriptorClass CrumbleEffectDescriptorClass;

#define TYPE_BLINDS_EFFECT_DESCRIPTOR (blinds_effect_descriptor_get_type ())
#define BLINDS_EFFECT_DESCRIPTOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_BLINDS_EFFECT_DESCRIPTOR, BlindsEffectDescriptor))
#define BLINDS_EFFECT_DESCRIPTOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_BLINDS_EFFECT_DESCRIPTOR, BlindsEffectDescriptorClass))
#define IS_BLINDS_EFFECT_DESCRIPTOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_BLINDS_EFFECT_DESCRIPTOR))
#define IS_BLINDS_EFFECT_DESCRIPTOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_BLINDS_EFFECT_DESCRIPTOR))
#define BLINDS_EFFECT_DESCRIPTOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_BLINDS_EFFECT_DESCRIPTOR, BlindsEffectDescriptorClass))

typedef struct _BlindsEffectDescriptor BlindsEffectDescriptor;
typedef struct _BlindsEffectDescriptorClass BlindsEffectDescriptorClass;

#define TYPE_CIRCLE_EFFECT_DESCRIPTOR (circle_effect_descriptor_get_type ())
#define CIRCLE_EFFECT_DESCRIPTOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_CIRCLE_EFFECT_DESCRIPTOR, CircleEffectDescriptor))
#define CIRCLE_EFFECT_DESCRIPTOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_CIRCLE_EFFECT_DESCRIPTOR, CircleEffectDescriptorClass))
#define IS_CIRCLE_EFFECT_DESCRIPTOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_CIRCLE_EFFECT_DESCRIPTOR))
#define IS_CIRCLE_EFFECT_DESCRIPTOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_CIRCLE_EFFECT_DESCRIPTOR))
#define CIRCLE_EFFECT_DESCRIPTOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_CIRCLE_EFFECT_DESCRIPTOR, CircleEffectDescriptorClass))

typedef struct _CircleEffectDescriptor CircleEffectDescriptor;
typedef struct _CircleEffectDescriptorClass CircleEffectDescriptorClass;

#define TYPE_CIRCLES_EFFECT_DESCRIPTOR (circles_effect_descriptor_get_type ())
#define CIRCLES_EFFECT_DESCRIPTOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_CIRCLES_EFFECT_DESCRIPTOR, CirclesEffectDescriptor))
#define CIRCLES_EFFECT_DESCRIPTOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_CIRCLES_EFFECT_DESCRIPTOR, CirclesEffectDescriptorClass))
#define IS_CIRCLES_EFFECT_DESCRIPTOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_CIRCLES_EFFECT_DESCRIPTOR))
#define IS_CIRCLES_EFFECT_DESCRIPTOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_CIRCLES_EFFECT_DESCRIPTOR))
#define CIRCLES_EFFECT_DESCRIPTOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_CIRCLES_EFFECT_DESCRIPTOR, CirclesEffectDescriptorClass))

typedef struct _CirclesEffectDescriptor CirclesEffectDescriptor;
typedef struct _CirclesEffectDescriptorClass CirclesEffectDescriptorClass;

#define TYPE_CLOCK_EFFECT_DESCRIPTOR (clock_effect_descriptor_get_type ())
#define CLOCK_EFFECT_DESCRIPTOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_CLOCK_EFFECT_DESCRIPTOR, ClockEffectDescriptor))
#define CLOCK_EFFECT_DESCRIPTOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_CLOCK_EFFECT_DESCRIPTOR, ClockEffectDescriptorClass))
#define IS_CLOCK_EFFECT_DESCRIPTOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_CLOCK_EFFECT_DESCRIPTOR))
#define IS_CLOCK_EFFECT_DESCRIPTOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_CLOCK_EFFECT_DESCRIPTOR))
#define CLOCK_EFFECT_DESCRIPTOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_CLOCK_EFFECT_DESCRIPTOR, ClockEffectDescriptorClass))

typedef struct _ClockEffectDescriptor ClockEffectDescriptor;
typedef struct _ClockEffectDescriptorClass ClockEffectDescriptorClass;

#define TYPE_SQUARES_EFFECT_DESCRIPTOR (squares_effect_descriptor_get_type ())
#define SQUARES_EFFECT_DESCRIPTOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SQUARES_EFFECT_DESCRIPTOR, SquaresEffectDescriptor))
#define SQUARES_EFFECT_DESCRIPTOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SQUARES_EFFECT_DESCRIPTOR, SquaresEffectDescriptorClass))
#define IS_SQUARES_EFFECT_DESCRIPTOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SQUARES_EFFECT_DESCRIPTOR))
#define IS_SQUARES_EFFECT_DESCRIPTOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SQUARES_EFFECT_DESCRIPTOR))
#define SQUARES_EFFECT_DESCRIPTOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SQUARES_EFFECT_DESCRIPTOR, SquaresEffectDescriptorClass))

typedef struct _SquaresEffectDescriptor SquaresEffectDescriptor;
typedef struct _SquaresEffectDescriptorClass SquaresEffectDescriptorClass;

#define TYPE_CHESS_EFFECT_DESCRIPTOR (chess_effect_descriptor_get_type ())
#define CHESS_EFFECT_DESCRIPTOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_CHESS_EFFECT_DESCRIPTOR, ChessEffectDescriptor))
#define CHESS_EFFECT_DESCRIPTOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_CHESS_EFFECT_DESCRIPTOR, ChessEffectDescriptorClass))
#define IS_CHESS_EFFECT_DESCRIPTOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_CHESS_EFFECT_DESCRIPTOR))
#define IS_CHESS_EFFECT_DESCRIPTOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_CHESS_EFFECT_DESCRIPTOR))
#define CHESS_EFFECT_DESCRIPTOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_CHESS_EFFECT_DESCRIPTOR, ChessEffectDescriptorClass))

typedef struct _ChessEffectDescriptor ChessEffectDescriptor;
typedef struct _ChessEffectDescriptorClass ChessEffectDescriptorClass;

#define TYPE_STRIPES_EFFECT_DESCRIPTOR (stripes_effect_descriptor_get_type ())
#define STRIPES_EFFECT_DESCRIPTOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_STRIPES_EFFECT_DESCRIPTOR, StripesEffectDescriptor))
#define STRIPES_EFFECT_DESCRIPTOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_STRIPES_EFFECT_DESCRIPTOR, StripesEffectDescriptorClass))
#define IS_STRIPES_EFFECT_DESCRIPTOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_STRIPES_EFFECT_DESCRIPTOR))
#define IS_STRIPES_EFFECT_DESCRIPTOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_STRIPES_EFFECT_DESCRIPTOR))
#define STRIPES_EFFECT_DESCRIPTOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_STRIPES_EFFECT_DESCRIPTOR, StripesEffectDescriptorClass))

typedef struct _StripesEffectDescriptor StripesEffectDescriptor;
typedef struct _StripesEffectDescriptorClass StripesEffectDescriptorClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
typedef struct _ShotwellTransitionDescriptorPrivate ShotwellTransitionDescriptorPrivate;
enum  {
	SHOTWELL_TRANSITION_DESCRIPTOR_0_PROPERTY,
	SHOTWELL_TRANSITION_DESCRIPTOR_NUM_PROPERTIES
};
static GParamSpec* shotwell_transition_descriptor_properties[SHOTWELL_TRANSITION_DESCRIPTOR_NUM_PROPERTIES];
#define _g_free0(var) (var = (g_free (var), NULL))

struct _ShotwellTransitions {
	GObject parent_instance;
	ShotwellTransitionsPrivate * priv;
};

struct _ShotwellTransitionsClass {
	GObjectClass parent_class;
};

struct _ShotwellTransitionsPrivate {
	SpitPluggable** pluggables;
	gint pluggables_length1;
	gint _pluggables_size_;
};

struct _ShotwellTransitionDescriptor {
	GObject parent_instance;
	ShotwellTransitionDescriptorPrivate * priv;
};

struct _ShotwellTransitionDescriptorClass {
	GObjectClass parent_class;
	const gchar* (*get_id) (ShotwellTransitionDescriptor* self);
	const gchar* (*get_pluggable_name) (ShotwellTransitionDescriptor* self);
	SpitTransitionsEffect* (*create) (ShotwellTransitionDescriptor* self, SpitHostInterface* host);
};


static gpointer shotwell_transitions_parent_class = NULL;
static SpitModuleIface * shotwell_transitions_spit_module_parent_iface = NULL;
static gpointer shotwell_transition_descriptor_parent_class = NULL;
static GdkPixbuf** shotwell_transition_descriptor_icon_pixbuf_set;
static gint shotwell_transition_descriptor_icon_pixbuf_set_length1;
static GdkPixbuf** shotwell_transition_descriptor_icon_pixbuf_set = NULL;
static gint shotwell_transition_descriptor_icon_pixbuf_set_length1 = 0;
static gint _shotwell_transition_descriptor_icon_pixbuf_set_size_ = 0;
static SpitPluggableIface * shotwell_transition_descriptor_spit_pluggable_parent_iface = NULL;
static SpitTransitionsDescriptorIface * shotwell_transition_descriptor_spit_transitions_descriptor_parent_iface = NULL;

GType shotwell_transitions_get_type (void) G_GNUC_CONST;
#define SHOTWELL_TRANSITIONS_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_SHOTWELL_TRANSITIONS, ShotwellTransitionsPrivate))
ShotwellTransitions* shotwell_transitions_new (GFile* module_file);
ShotwellTransitions* shotwell_transitions_construct (GType object_type,
                                                     GFile* module_file);
FadeEffectDescriptor* fade_effect_descriptor_new (GFile* resource_directory);
FadeEffectDescriptor* fade_effect_descriptor_construct (GType object_type,
                                                        GFile* resource_directory);
GType shotwell_transition_descriptor_get_type (void) G_GNUC_CONST;
GType fade_effect_descriptor_get_type (void) G_GNUC_CONST;
static void _vala_array_add1 (SpitPluggable** * array,
                       int* length,
                       int* size,
                       SpitPluggable* value);
SlideEffectDescriptor* slide_effect_descriptor_new (GFile* resource_directory);
SlideEffectDescriptor* slide_effect_descriptor_construct (GType object_type,
                                                          GFile* resource_directory);
GType slide_effect_descriptor_get_type (void) G_GNUC_CONST;
static void _vala_array_add2 (SpitPluggable** * array,
                       int* length,
                       int* size,
                       SpitPluggable* value);
CrumbleEffectDescriptor* crumble_effect_descriptor_new (GFile* resource_directory);
CrumbleEffectDescriptor* crumble_effect_descriptor_construct (GType object_type,
                                                              GFile* resource_directory);
GType crumble_effect_descriptor_get_type (void) G_GNUC_CONST;
static void _vala_array_add3 (SpitPluggable** * array,
                       int* length,
                       int* size,
                       SpitPluggable* value);
BlindsEffectDescriptor* blinds_effect_descriptor_new (GFile* resource_directory);
BlindsEffectDescriptor* blinds_effect_descriptor_construct (GType object_type,
                                                            GFile* resource_directory);
GType blinds_effect_descriptor_get_type (void) G_GNUC_CONST;
static void _vala_array_add4 (SpitPluggable** * array,
                       int* length,
                       int* size,
                       SpitPluggable* value);
CircleEffectDescriptor* circle_effect_descriptor_new (GFile* resource_directory);
CircleEffectDescriptor* circle_effect_descriptor_construct (GType object_type,
                                                            GFile* resource_directory);
GType circle_effect_descriptor_get_type (void) G_GNUC_CONST;
static void _vala_array_add5 (SpitPluggable** * array,
                       int* length,
                       int* size,
                       SpitPluggable* value);
CirclesEffectDescriptor* circles_effect_descriptor_new (GFile* resource_directory);
CirclesEffectDescriptor* circles_effect_descriptor_construct (GType object_type,
                                                              GFile* resource_directory);
GType circles_effect_descriptor_get_type (void) G_GNUC_CONST;
static void _vala_array_add6 (SpitPluggable** * array,
                       int* length,
                       int* size,
                       SpitPluggable* value);
ClockEffectDescriptor* clock_effect_descriptor_new (GFile* resource_directory);
ClockEffectDescriptor* clock_effect_descriptor_construct (GType object_type,
                                                          GFile* resource_directory);
GType clock_effect_descriptor_get_type (void) G_GNUC_CONST;
static void _vala_array_add7 (SpitPluggable** * array,
                       int* length,
                       int* size,
                       SpitPluggable* value);
SquaresEffectDescriptor* squares_effect_descriptor_new (GFile* resource_directory);
SquaresEffectDescriptor* squares_effect_descriptor_construct (GType object_type,
                                                              GFile* resource_directory);
GType squares_effect_descriptor_get_type (void) G_GNUC_CONST;
static void _vala_array_add8 (SpitPluggable** * array,
                       int* length,
                       int* size,
                       SpitPluggable* value);
ChessEffectDescriptor* chess_effect_descriptor_new (GFile* resource_directory);
ChessEffectDescriptor* chess_effect_descriptor_construct (GType object_type,
                                                          GFile* resource_directory);
GType chess_effect_descriptor_get_type (void) G_GNUC_CONST;
static void _vala_array_add9 (SpitPluggable** * array,
                       int* length,
                       int* size,
                       SpitPluggable* value);
StripesEffectDescriptor* stripes_effect_descriptor_new (GFile* resource_directory);
StripesEffectDescriptor* stripes_effect_descriptor_construct (GType object_type,
                                                              GFile* resource_directory);
GType stripes_effect_descriptor_get_type (void) G_GNUC_CONST;
static void _vala_array_add10 (SpitPluggable** * array,
                        int* length,
                        int* size,
                        SpitPluggable* value);
static const gchar* shotwell_transitions_real_get_module_name (SpitModule* base);
static const gchar* shotwell_transitions_real_get_version (SpitModule* base);
static const gchar* shotwell_transitions_real_get_id (SpitModule* base);
static SpitPluggable** shotwell_transitions_real_get_pluggables (SpitModule* base,
                                                          int* result_length1);
static void shotwell_transitions_finalize (GObject * obj);
SpitModule* spit_entry_point (SpitEntryPointParams* params);
#define SHOTWELL_TRANSITION_DESCRIPTOR_ICON_FILENAME "slideshow-plugin.png"
ShotwellTransitionDescriptor* shotwell_transition_descriptor_construct (GType object_type,
                                                                        GFile* resource_directory);
static gint shotwell_transition_descriptor_real_get_pluggable_interface (SpitPluggable* base,
                                                                  gint min_host_interface,
                                                                  gint max_host_interface);
const gchar* shotwell_transition_descriptor_get_id (ShotwellTransitionDescriptor* self);
static const gchar* shotwell_transition_descriptor_real_get_id (ShotwellTransitionDescriptor* self);
const gchar* shotwell_transition_descriptor_get_pluggable_name (ShotwellTransitionDescriptor* self);
static const gchar* shotwell_transition_descriptor_real_get_pluggable_name (ShotwellTransitionDescriptor* self);
static void shotwell_transition_descriptor_real_get_info (SpitPluggable* base,
                                                   SpitPluggableInfo* info);
static GdkPixbuf** _vala_array_dup1 (GdkPixbuf** self,
                              int length);
static void shotwell_transition_descriptor_real_activation (SpitPluggable* base,
                                                     gboolean enabled);
SpitTransitionsEffect* shotwell_transition_descriptor_create (ShotwellTransitionDescriptor* self,
                                                              SpitHostInterface* host);
static SpitTransitionsEffect* shotwell_transition_descriptor_real_create (ShotwellTransitionDescriptor* self,
                                                                   SpitHostInterface* host);
static void shotwell_transition_descriptor_finalize (GObject * obj);
static void _vala_array_destroy (gpointer array,
                          gint array_length,
                          GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array,
                       gint array_length,
                       GDestroyNotify destroy_func);


static void
_vala_array_add1 (SpitPluggable** * array,
                  int* length,
                  int* size,
                  SpitPluggable* value)
{
#line 15 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	if ((*length) == (*size)) {
#line 15 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 15 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
		*array = g_renew (SpitPluggable*, *array, (*size) + 1);
#line 330 "shotwell-transitions.c"
	}
#line 15 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	(*array)[(*length)++] = value;
#line 15 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	(*array)[*length] = NULL;
#line 336 "shotwell-transitions.c"
}


static void
_vala_array_add2 (SpitPluggable** * array,
                  int* length,
                  int* size,
                  SpitPluggable* value)
{
#line 16 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	if ((*length) == (*size)) {
#line 16 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 16 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
		*array = g_renew (SpitPluggable*, *array, (*size) + 1);
#line 352 "shotwell-transitions.c"
	}
#line 16 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	(*array)[(*length)++] = value;
#line 16 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	(*array)[*length] = NULL;
#line 358 "shotwell-transitions.c"
}


static void
_vala_array_add3 (SpitPluggable** * array,
                  int* length,
                  int* size,
                  SpitPluggable* value)
{
#line 17 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	if ((*length) == (*size)) {
#line 17 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 17 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
		*array = g_renew (SpitPluggable*, *array, (*size) + 1);
#line 374 "shotwell-transitions.c"
	}
#line 17 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	(*array)[(*length)++] = value;
#line 17 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	(*array)[*length] = NULL;
#line 380 "shotwell-transitions.c"
}


static void
_vala_array_add4 (SpitPluggable** * array,
                  int* length,
                  int* size,
                  SpitPluggable* value)
{
#line 18 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	if ((*length) == (*size)) {
#line 18 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 18 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
		*array = g_renew (SpitPluggable*, *array, (*size) + 1);
#line 396 "shotwell-transitions.c"
	}
#line 18 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	(*array)[(*length)++] = value;
#line 18 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	(*array)[*length] = NULL;
#line 402 "shotwell-transitions.c"
}


static void
_vala_array_add5 (SpitPluggable** * array,
                  int* length,
                  int* size,
                  SpitPluggable* value)
{
#line 19 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	if ((*length) == (*size)) {
#line 19 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 19 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
		*array = g_renew (SpitPluggable*, *array, (*size) + 1);
#line 418 "shotwell-transitions.c"
	}
#line 19 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	(*array)[(*length)++] = value;
#line 19 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	(*array)[*length] = NULL;
#line 424 "shotwell-transitions.c"
}


static void
_vala_array_add6 (SpitPluggable** * array,
                  int* length,
                  int* size,
                  SpitPluggable* value)
{
#line 20 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	if ((*length) == (*size)) {
#line 20 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 20 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
		*array = g_renew (SpitPluggable*, *array, (*size) + 1);
#line 440 "shotwell-transitions.c"
	}
#line 20 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	(*array)[(*length)++] = value;
#line 20 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	(*array)[*length] = NULL;
#line 446 "shotwell-transitions.c"
}


static void
_vala_array_add7 (SpitPluggable** * array,
                  int* length,
                  int* size,
                  SpitPluggable* value)
{
#line 21 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	if ((*length) == (*size)) {
#line 21 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 21 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
		*array = g_renew (SpitPluggable*, *array, (*size) + 1);
#line 462 "shotwell-transitions.c"
	}
#line 21 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	(*array)[(*length)++] = value;
#line 21 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	(*array)[*length] = NULL;
#line 468 "shotwell-transitions.c"
}


static void
_vala_array_add8 (SpitPluggable** * array,
                  int* length,
                  int* size,
                  SpitPluggable* value)
{
#line 22 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	if ((*length) == (*size)) {
#line 22 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 22 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
		*array = g_renew (SpitPluggable*, *array, (*size) + 1);
#line 484 "shotwell-transitions.c"
	}
#line 22 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	(*array)[(*length)++] = value;
#line 22 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	(*array)[*length] = NULL;
#line 490 "shotwell-transitions.c"
}


static void
_vala_array_add9 (SpitPluggable** * array,
                  int* length,
                  int* size,
                  SpitPluggable* value)
{
#line 23 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	if ((*length) == (*size)) {
#line 23 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 23 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
		*array = g_renew (SpitPluggable*, *array, (*size) + 1);
#line 506 "shotwell-transitions.c"
	}
#line 23 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	(*array)[(*length)++] = value;
#line 23 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	(*array)[*length] = NULL;
#line 512 "shotwell-transitions.c"
}


static void
_vala_array_add10 (SpitPluggable** * array,
                   int* length,
                   int* size,
                   SpitPluggable* value)
{
#line 24 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	if ((*length) == (*size)) {
#line 24 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 24 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
		*array = g_renew (SpitPluggable*, *array, (*size) + 1);
#line 528 "shotwell-transitions.c"
	}
#line 24 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	(*array)[(*length)++] = value;
#line 24 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	(*array)[*length] = NULL;
#line 534 "shotwell-transitions.c"
}


ShotwellTransitions*
shotwell_transitions_construct (GType object_type,
                                GFile* module_file)
{
	ShotwellTransitions * self = NULL;
	GFile* resource_directory = NULL;
	GFile* _tmp0_;
	SpitPluggable** _tmp1_;
	gint _tmp1__length1;
	FadeEffectDescriptor* _tmp2_;
	SpitPluggable** _tmp3_;
	gint _tmp3__length1;
	SlideEffectDescriptor* _tmp4_;
	SpitPluggable** _tmp5_;
	gint _tmp5__length1;
	CrumbleEffectDescriptor* _tmp6_;
	SpitPluggable** _tmp7_;
	gint _tmp7__length1;
	BlindsEffectDescriptor* _tmp8_;
	SpitPluggable** _tmp9_;
	gint _tmp9__length1;
	CircleEffectDescriptor* _tmp10_;
	SpitPluggable** _tmp11_;
	gint _tmp11__length1;
	CirclesEffectDescriptor* _tmp12_;
	SpitPluggable** _tmp13_;
	gint _tmp13__length1;
	ClockEffectDescriptor* _tmp14_;
	SpitPluggable** _tmp15_;
	gint _tmp15__length1;
	SquaresEffectDescriptor* _tmp16_;
	SpitPluggable** _tmp17_;
	gint _tmp17__length1;
	ChessEffectDescriptor* _tmp18_;
	SpitPluggable** _tmp19_;
	gint _tmp19__length1;
	StripesEffectDescriptor* _tmp20_;
#line 12 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	g_return_val_if_fail (G_IS_FILE (module_file), NULL);
#line 12 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	self = (ShotwellTransitions*) g_object_new (object_type, NULL);
#line 13 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	_tmp0_ = g_file_get_parent (module_file);
#line 13 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	resource_directory = _tmp0_;
#line 15 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	_tmp1_ = self->priv->pluggables;
#line 15 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	_tmp1__length1 = self->priv->pluggables_length1;
#line 15 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	_tmp2_ = fade_effect_descriptor_new (resource_directory);
#line 15 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	_vala_array_add1 (&self->priv->pluggables, &self->priv->pluggables_length1, &self->priv->_pluggables_size_, G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, SPIT_TYPE_PLUGGABLE, SpitPluggable));
#line 16 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	_tmp3_ = self->priv->pluggables;
#line 16 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	_tmp3__length1 = self->priv->pluggables_length1;
#line 16 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	_tmp4_ = slide_effect_descriptor_new (resource_directory);
#line 16 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	_vala_array_add2 (&self->priv->pluggables, &self->priv->pluggables_length1, &self->priv->_pluggables_size_, G_TYPE_CHECK_INSTANCE_CAST (_tmp4_, SPIT_TYPE_PLUGGABLE, SpitPluggable));
#line 17 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	_tmp5_ = self->priv->pluggables;
#line 17 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	_tmp5__length1 = self->priv->pluggables_length1;
#line 17 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	_tmp6_ = crumble_effect_descriptor_new (resource_directory);
#line 17 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	_vala_array_add3 (&self->priv->pluggables, &self->priv->pluggables_length1, &self->priv->_pluggables_size_, G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, SPIT_TYPE_PLUGGABLE, SpitPluggable));
#line 18 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	_tmp7_ = self->priv->pluggables;
#line 18 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	_tmp7__length1 = self->priv->pluggables_length1;
#line 18 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	_tmp8_ = blinds_effect_descriptor_new (resource_directory);
#line 18 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	_vala_array_add4 (&self->priv->pluggables, &self->priv->pluggables_length1, &self->priv->_pluggables_size_, G_TYPE_CHECK_INSTANCE_CAST (_tmp8_, SPIT_TYPE_PLUGGABLE, SpitPluggable));
#line 19 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	_tmp9_ = self->priv->pluggables;
#line 19 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	_tmp9__length1 = self->priv->pluggables_length1;
#line 19 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	_tmp10_ = circle_effect_descriptor_new (resource_directory);
#line 19 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	_vala_array_add5 (&self->priv->pluggables, &self->priv->pluggables_length1, &self->priv->_pluggables_size_, G_TYPE_CHECK_INSTANCE_CAST (_tmp10_, SPIT_TYPE_PLUGGABLE, SpitPluggable));
#line 20 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	_tmp11_ = self->priv->pluggables;
#line 20 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	_tmp11__length1 = self->priv->pluggables_length1;
#line 20 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	_tmp12_ = circles_effect_descriptor_new (resource_directory);
#line 20 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	_vala_array_add6 (&self->priv->pluggables, &self->priv->pluggables_length1, &self->priv->_pluggables_size_, G_TYPE_CHECK_INSTANCE_CAST (_tmp12_, SPIT_TYPE_PLUGGABLE, SpitPluggable));
#line 21 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	_tmp13_ = self->priv->pluggables;
#line 21 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	_tmp13__length1 = self->priv->pluggables_length1;
#line 21 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	_tmp14_ = clock_effect_descriptor_new (resource_directory);
#line 21 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	_vala_array_add7 (&self->priv->pluggables, &self->priv->pluggables_length1, &self->priv->_pluggables_size_, G_TYPE_CHECK_INSTANCE_CAST (_tmp14_, SPIT_TYPE_PLUGGABLE, SpitPluggable));
#line 22 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	_tmp15_ = self->priv->pluggables;
#line 22 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	_tmp15__length1 = self->priv->pluggables_length1;
#line 22 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	_tmp16_ = squares_effect_descriptor_new (resource_directory);
#line 22 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	_vala_array_add8 (&self->priv->pluggables, &self->priv->pluggables_length1, &self->priv->_pluggables_size_, G_TYPE_CHECK_INSTANCE_CAST (_tmp16_, SPIT_TYPE_PLUGGABLE, SpitPluggable));
#line 23 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	_tmp17_ = self->priv->pluggables;
#line 23 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	_tmp17__length1 = self->priv->pluggables_length1;
#line 23 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	_tmp18_ = chess_effect_descriptor_new (resource_directory);
#line 23 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	_vala_array_add9 (&self->priv->pluggables, &self->priv->pluggables_length1, &self->priv->_pluggables_size_, G_TYPE_CHECK_INSTANCE_CAST (_tmp18_, SPIT_TYPE_PLUGGABLE, SpitPluggable));
#line 24 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	_tmp19_ = self->priv->pluggables;
#line 24 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	_tmp19__length1 = self->priv->pluggables_length1;
#line 24 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	_tmp20_ = stripes_effect_descriptor_new (resource_directory);
#line 24 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	_vala_array_add10 (&self->priv->pluggables, &self->priv->pluggables_length1, &self->priv->_pluggables_size_, G_TYPE_CHECK_INSTANCE_CAST (_tmp20_, SPIT_TYPE_PLUGGABLE, SpitPluggable));
#line 12 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	_g_object_unref0 (resource_directory);
#line 12 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	return self;
#line 667 "shotwell-transitions.c"
}


ShotwellTransitions*
shotwell_transitions_new (GFile* module_file)
{
#line 12 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	return shotwell_transitions_construct (TYPE_SHOTWELL_TRANSITIONS, module_file);
#line 676 "shotwell-transitions.c"
}


static const gchar*
shotwell_transitions_real_get_module_name (SpitModule* base)
{
	ShotwellTransitions * self;
	const gchar* result = NULL;
#line 27 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_SHOTWELL_TRANSITIONS, ShotwellTransitions);
#line 28 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	result = _ ("Core Slideshow Transitions");
#line 28 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	return result;
#line 691 "shotwell-transitions.c"
}


static const gchar*
shotwell_transitions_real_get_version (SpitModule* base)
{
	ShotwellTransitions * self;
	const gchar* result = NULL;
#line 31 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_SHOTWELL_TRANSITIONS, ShotwellTransitions);
#line 32 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	result = _VERSION;
#line 32 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	return result;
#line 706 "shotwell-transitions.c"
}


static const gchar*
shotwell_transitions_real_get_id (SpitModule* base)
{
	ShotwellTransitions * self;
	const gchar* result = NULL;
#line 35 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_SHOTWELL_TRANSITIONS, ShotwellTransitions);
#line 36 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	result = "org.yorba.shotwell.transitions";
#line 36 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	return result;
#line 721 "shotwell-transitions.c"
}


static SpitPluggable**
shotwell_transitions_real_get_pluggables (SpitModule* base,
                                          int* result_length1)
{
	ShotwellTransitions * self;
	SpitPluggable** result = NULL;
	SpitPluggable** _tmp0_;
	gint _tmp0__length1;
	SpitPluggable** _tmp1_;
	gint _tmp1__length1;
#line 39 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_SHOTWELL_TRANSITIONS, ShotwellTransitions);
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	_tmp0_ = self->priv->pluggables;
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	_tmp0__length1 = self->priv->pluggables_length1;
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	_tmp1_ = _tmp0_;
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	_tmp1__length1 = _tmp0__length1;
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	if (result_length1) {
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
		*result_length1 = _tmp1__length1;
#line 749 "shotwell-transitions.c"
	}
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	result = _tmp1_;
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	return result;
#line 755 "shotwell-transitions.c"
}


static void
shotwell_transitions_class_init (ShotwellTransitionsClass * klass)
{
#line 9 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	shotwell_transitions_parent_class = g_type_class_peek_parent (klass);
#line 9 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	g_type_class_add_private (klass, sizeof (ShotwellTransitionsPrivate));
#line 9 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	G_OBJECT_CLASS (klass)->finalize = shotwell_transitions_finalize;
#line 768 "shotwell-transitions.c"
}


static void
shotwell_transitions_spit_module_interface_init (SpitModuleIface * iface)
{
#line 9 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	shotwell_transitions_spit_module_parent_iface = g_type_interface_peek_parent (iface);
#line 9 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	iface->get_module_name = (const gchar* (*) (SpitModule *)) shotwell_transitions_real_get_module_name;
#line 9 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	iface->get_version = (const gchar* (*) (SpitModule *)) shotwell_transitions_real_get_version;
#line 9 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	iface->get_id = (const gchar* (*) (SpitModule *)) shotwell_transitions_real_get_id;
#line 9 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	iface->get_pluggables = (SpitPluggable** (*) (SpitModule *, int*)) shotwell_transitions_real_get_pluggables;
#line 785 "shotwell-transitions.c"
}


static void
shotwell_transitions_instance_init (ShotwellTransitions * self)
{
	SpitPluggable** _tmp0_;
#line 9 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	self->priv = SHOTWELL_TRANSITIONS_GET_PRIVATE (self);
#line 10 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	_tmp0_ = g_new0 (SpitPluggable*, 0 + 1);
#line 10 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	self->priv->pluggables = _tmp0_;
#line 10 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	self->priv->pluggables_length1 = 0;
#line 10 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	self->priv->_pluggables_size_ = self->priv->pluggables_length1;
#line 803 "shotwell-transitions.c"
}


static void
shotwell_transitions_finalize (GObject * obj)
{
	ShotwellTransitions * self;
#line 9 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_SHOTWELL_TRANSITIONS, ShotwellTransitions);
#line 10 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	self->priv->pluggables = (_vala_array_free (self->priv->pluggables, self->priv->pluggables_length1, (GDestroyNotify) g_object_unref), NULL);
#line 9 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	G_OBJECT_CLASS (shotwell_transitions_parent_class)->finalize (obj);
#line 817 "shotwell-transitions.c"
}


GType
shotwell_transitions_get_type (void)
{
	static volatile gsize shotwell_transitions_type_id__volatile = 0;
	if (g_once_init_enter (&shotwell_transitions_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (ShotwellTransitionsClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) shotwell_transitions_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ShotwellTransitions), 0, (GInstanceInitFunc) shotwell_transitions_instance_init, NULL };
		static const GInterfaceInfo spit_module_info = { (GInterfaceInitFunc) shotwell_transitions_spit_module_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType shotwell_transitions_type_id;
		shotwell_transitions_type_id = g_type_register_static (G_TYPE_OBJECT, "ShotwellTransitions", &g_define_type_info, 0);
		g_type_add_interface_static (shotwell_transitions_type_id, SPIT_TYPE_MODULE, &spit_module_info);
		g_once_init_leave (&shotwell_transitions_type_id__volatile, shotwell_transitions_type_id);
	}
	return shotwell_transitions_type_id__volatile;
}


SpitModule*
spit_entry_point (SpitEntryPointParams* params)
{
	SpitModule* result = NULL;
	gint _tmp0_;
	gint _tmp1_;
	ShotwellTransitions* _tmp2_ = NULL;
	gint _tmp3_;
#line 46 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	_tmp0_ = (*params).host_min_spit_interface;
#line 46 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	_tmp1_ = (*params).host_max_spit_interface;
#line 46 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	(*params).module_spit_interface = spit_negotiate_interfaces (_tmp0_, _tmp1_, SPIT_CURRENT_INTERFACE);
#line 49 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	_tmp3_ = (*params).module_spit_interface;
#line 49 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	if (_tmp3_ != SPIT_UNSUPPORTED_INTERFACE) {
#line 855 "shotwell-transitions.c"
		GFile* _tmp4_;
		ShotwellTransitions* _tmp5_;
#line 50 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
		_tmp4_ = (*params).module_file;
#line 50 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
		_tmp5_ = shotwell_transitions_new (_tmp4_);
#line 50 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
		_g_object_unref0 (_tmp2_);
#line 50 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
		_tmp2_ = _tmp5_;
#line 866 "shotwell-transitions.c"
	} else {
#line 50 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
		_g_object_unref0 (_tmp2_);
#line 50 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
		_tmp2_ = NULL;
#line 872 "shotwell-transitions.c"
	}
#line 49 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	result = G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, SPIT_TYPE_MODULE, SpitModule);
#line 49 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	return result;
#line 878 "shotwell-transitions.c"
}


ShotwellTransitionDescriptor*
shotwell_transition_descriptor_construct (GType object_type,
                                          GFile* resource_directory)
{
	ShotwellTransitionDescriptor * self = NULL;
	GdkPixbuf** _tmp0_;
	gint _tmp0__length1;
#line 59 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	g_return_val_if_fail (G_IS_FILE (resource_directory), NULL);
#line 59 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	self = (ShotwellTransitionDescriptor*) g_object_new (object_type, NULL);
#line 60 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	_tmp0_ = shotwell_transition_descriptor_icon_pixbuf_set;
#line 60 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	_tmp0__length1 = shotwell_transition_descriptor_icon_pixbuf_set_length1;
#line 60 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	if (_tmp0_ == NULL) {
#line 899 "shotwell-transitions.c"
		gint _tmp1_;
		GdkPixbuf** _tmp2_;
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
		_tmp2_ = resources_load_from_resource (PLUGIN_RESOURCE_PATH "/" SHOTWELL_TRANSITION_DESCRIPTOR_ICON_FILENAME, &_tmp1_);
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
		shotwell_transition_descriptor_icon_pixbuf_set = (_vala_array_free (shotwell_transition_descriptor_icon_pixbuf_set, shotwell_transition_descriptor_icon_pixbuf_set_length1, (GDestroyNotify) g_object_unref), NULL);
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
		shotwell_transition_descriptor_icon_pixbuf_set = _tmp2_;
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
		shotwell_transition_descriptor_icon_pixbuf_set_length1 = _tmp1_;
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
		_shotwell_transition_descriptor_icon_pixbuf_set_size_ = shotwell_transition_descriptor_icon_pixbuf_set_length1;
#line 912 "shotwell-transitions.c"
	}
#line 59 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	return self;
#line 916 "shotwell-transitions.c"
}


static gint
shotwell_transition_descriptor_real_get_pluggable_interface (SpitPluggable* base,
                                                             gint min_host_interface,
                                                             gint max_host_interface)
{
	ShotwellTransitionDescriptor * self;
	gint result = 0;
#line 65 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_SHOTWELL_TRANSITION_DESCRIPTOR, ShotwellTransitionDescriptor);
#line 66 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	result = spit_negotiate_interfaces (min_host_interface, max_host_interface, SPIT_TRANSITIONS_CURRENT_INTERFACE);
#line 66 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	return result;
#line 933 "shotwell-transitions.c"
}


static const gchar*
shotwell_transition_descriptor_real_get_id (ShotwellTransitionDescriptor* self)
{
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	g_critical ("Type `%s' does not implement abstract method `shotwell_transition_descriptor_get_id'", g_type_name (G_TYPE_FROM_INSTANCE (self)));
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	return NULL;
#line 944 "shotwell-transitions.c"
}


const gchar*
shotwell_transition_descriptor_get_id (ShotwellTransitionDescriptor* self)
{
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	g_return_val_if_fail (IS_SHOTWELL_TRANSITION_DESCRIPTOR (self), NULL);
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	return SHOTWELL_TRANSITION_DESCRIPTOR_GET_CLASS (self)->get_id (self);
#line 955 "shotwell-transitions.c"
}


static const gchar*
shotwell_transition_descriptor_real_get_pluggable_name (ShotwellTransitionDescriptor* self)
{
#line 72 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	g_critical ("Type `%s' does not implement abstract method `shotwell_transition_descriptor_get_pluggable_name'", g_type_name (G_TYPE_FROM_INSTANCE (self)));
#line 72 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	return NULL;
#line 966 "shotwell-transitions.c"
}


const gchar*
shotwell_transition_descriptor_get_pluggable_name (ShotwellTransitionDescriptor* self)
{
#line 72 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	g_return_val_if_fail (IS_SHOTWELL_TRANSITION_DESCRIPTOR (self), NULL);
#line 72 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	return SHOTWELL_TRANSITION_DESCRIPTOR_GET_CLASS (self)->get_pluggable_name (self);
#line 977 "shotwell-transitions.c"
}


static gpointer
_g_object_ref0 (gpointer self)
{
#line 83 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	return self ? g_object_ref (self) : NULL;
#line 986 "shotwell-transitions.c"
}


static GdkPixbuf**
_vala_array_dup1 (GdkPixbuf** self,
                  int length)
{
	GdkPixbuf** result;
	int i;
#line 83 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	result = g_new0 (GdkPixbuf*, length + 1);
#line 83 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	for (i = 0; i < length; i++) {
#line 1000 "shotwell-transitions.c"
		GdkPixbuf* _tmp0_;
#line 83 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
		_tmp0_ = _g_object_ref0 (self[i]);
#line 83 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
		result[i] = _tmp0_;
#line 1006 "shotwell-transitions.c"
	}
#line 83 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	return result;
#line 1010 "shotwell-transitions.c"
}


static void
shotwell_transition_descriptor_real_get_info (SpitPluggable* base,
                                              SpitPluggableInfo* info)
{
	ShotwellTransitionDescriptor * self;
	gchar* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	gchar* _tmp4_;
	gchar* _tmp5_;
	gchar* _tmp6_;
	GdkPixbuf** _tmp7_;
	gint _tmp7__length1;
	GdkPixbuf** _tmp8_;
	gint _tmp8__length1;
#line 74 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_SHOTWELL_TRANSITION_DESCRIPTOR, ShotwellTransitionDescriptor);
#line 74 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	g_return_if_fail (info != NULL);
#line 75 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	_tmp0_ = g_strdup ("Maxim Kartashev");
#line 75 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	_g_free0 ((*info).authors);
#line 75 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	(*info).authors = _tmp0_;
#line 76 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	_tmp1_ = g_strdup (_ ("Copyright 2010 Maxim Kartashev, Copyright 2016 Software Freedom Conser" \
"vancy Inc."));
#line 76 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	_g_free0 ((*info).copyright);
#line 76 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	(*info).copyright = _tmp1_;
#line 77 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	_tmp2_ = g_strdup (RESOURCES_TRANSLATORS);
#line 77 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	_g_free0 ((*info).translators);
#line 77 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	(*info).translators = _tmp2_;
#line 78 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	_tmp3_ = g_strdup (_VERSION);
#line 78 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	_g_free0 ((*info).version);
#line 78 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	(*info).version = _tmp3_;
#line 79 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	_tmp4_ = g_strdup (RESOURCES_WEBSITE_NAME);
#line 79 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	_g_free0 ((*info).website_name);
#line 79 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	(*info).website_name = _tmp4_;
#line 80 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	_tmp5_ = g_strdup (RESOURCES_WEBSITE_URL);
#line 80 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	_g_free0 ((*info).website_url);
#line 80 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	(*info).website_url = _tmp5_;
#line 81 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	(*info).is_license_wordwrapped = FALSE;
#line 82 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	_tmp6_ = g_strdup (RESOURCES_LICENSE);
#line 82 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	_g_free0 ((*info).license);
#line 82 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	(*info).license = _tmp6_;
#line 83 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	_tmp7_ = shotwell_transition_descriptor_icon_pixbuf_set;
#line 83 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	_tmp7__length1 = shotwell_transition_descriptor_icon_pixbuf_set_length1;
#line 83 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	_tmp8_ = (_tmp7_ != NULL) ? _vala_array_dup1 (_tmp7_, _tmp7__length1) : ((gpointer) _tmp7_);
#line 83 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	_tmp8__length1 = _tmp7__length1;
#line 83 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	(*info).icons = (_vala_array_free ((*info).icons, (*info).icons_length1, (GDestroyNotify) g_object_unref), NULL);
#line 83 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	(*info).icons = _tmp8_;
#line 83 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	(*info).icons_length1 = _tmp8__length1;
#line 1092 "shotwell-transitions.c"
}


static void
shotwell_transition_descriptor_real_activation (SpitPluggable* base,
                                                gboolean enabled)
{
	ShotwellTransitionDescriptor * self;
#line 86 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_SHOTWELL_TRANSITION_DESCRIPTOR, ShotwellTransitionDescriptor);
#line 1103 "shotwell-transitions.c"
}


static SpitTransitionsEffect*
shotwell_transition_descriptor_real_create (ShotwellTransitionDescriptor* self,
                                            SpitHostInterface* host)
{
#line 89 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	g_critical ("Type `%s' does not implement abstract method `shotwell_transition_descriptor_create'", g_type_name (G_TYPE_FROM_INSTANCE (self)));
#line 89 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	return NULL;
#line 1115 "shotwell-transitions.c"
}


SpitTransitionsEffect*
shotwell_transition_descriptor_create (ShotwellTransitionDescriptor* self,
                                       SpitHostInterface* host)
{
#line 89 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	g_return_val_if_fail (IS_SHOTWELL_TRANSITION_DESCRIPTOR (self), NULL);
#line 89 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	return SHOTWELL_TRANSITION_DESCRIPTOR_GET_CLASS (self)->create (self, host);
#line 1127 "shotwell-transitions.c"
}


static void
shotwell_transition_descriptor_class_init (ShotwellTransitionDescriptorClass * klass)
{
#line 54 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	shotwell_transition_descriptor_parent_class = g_type_class_peek_parent (klass);
#line 54 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	((ShotwellTransitionDescriptorClass *) klass)->get_id = (const gchar* (*) (ShotwellTransitionDescriptor *)) shotwell_transition_descriptor_real_get_id;
#line 54 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	((ShotwellTransitionDescriptorClass *) klass)->get_pluggable_name = (const gchar* (*) (ShotwellTransitionDescriptor *)) shotwell_transition_descriptor_real_get_pluggable_name;
#line 54 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	((ShotwellTransitionDescriptorClass *) klass)->create = (SpitTransitionsEffect* (*) (ShotwellTransitionDescriptor *, SpitHostInterface*)) shotwell_transition_descriptor_real_create;
#line 54 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	G_OBJECT_CLASS (klass)->finalize = shotwell_transition_descriptor_finalize;
#line 1144 "shotwell-transitions.c"
}


static void
shotwell_transition_descriptor_spit_pluggable_interface_init (SpitPluggableIface * iface)
{
#line 54 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	shotwell_transition_descriptor_spit_pluggable_parent_iface = g_type_interface_peek_parent (iface);
#line 54 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	iface->get_pluggable_interface = (gint (*) (SpitPluggable *, gint, gint)) shotwell_transition_descriptor_real_get_pluggable_interface;
#line 54 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	iface->get_id = (const gchar* (*) (SpitPluggable *)) shotwell_transition_descriptor_get_id;
#line 54 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	iface->get_pluggable_name = (const gchar* (*) (SpitPluggable *)) shotwell_transition_descriptor_get_pluggable_name;
#line 54 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	iface->get_info = (void (*) (SpitPluggable *, SpitPluggableInfo*)) shotwell_transition_descriptor_real_get_info;
#line 54 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	iface->activation = (void (*) (SpitPluggable *, gboolean)) shotwell_transition_descriptor_real_activation;
#line 1163 "shotwell-transitions.c"
}


static void
shotwell_transition_descriptor_spit_transitions_descriptor_interface_init (SpitTransitionsDescriptorIface * iface)
{
#line 54 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	shotwell_transition_descriptor_spit_transitions_descriptor_parent_iface = g_type_interface_peek_parent (iface);
#line 54 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	iface->create = (SpitTransitionsEffect* (*) (SpitTransitionsDescriptor *, SpitHostInterface*)) shotwell_transition_descriptor_create;
#line 1174 "shotwell-transitions.c"
}


static void
shotwell_transition_descriptor_instance_init (ShotwellTransitionDescriptor * self)
{
}


static void
shotwell_transition_descriptor_finalize (GObject * obj)
{
	ShotwellTransitionDescriptor * self;
#line 54 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_SHOTWELL_TRANSITION_DESCRIPTOR, ShotwellTransitionDescriptor);
#line 54 "/home/jens/Source/shotwell/plugins/shotwell-transitions/shotwell-transitions.vala"
	G_OBJECT_CLASS (shotwell_transition_descriptor_parent_class)->finalize (obj);
#line 1192 "shotwell-transitions.c"
}


GType
shotwell_transition_descriptor_get_type (void)
{
	static volatile gsize shotwell_transition_descriptor_type_id__volatile = 0;
	if (g_once_init_enter (&shotwell_transition_descriptor_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (ShotwellTransitionDescriptorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) shotwell_transition_descriptor_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ShotwellTransitionDescriptor), 0, (GInstanceInitFunc) shotwell_transition_descriptor_instance_init, NULL };
		static const GInterfaceInfo spit_pluggable_info = { (GInterfaceInitFunc) shotwell_transition_descriptor_spit_pluggable_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		static const GInterfaceInfo spit_transitions_descriptor_info = { (GInterfaceInitFunc) shotwell_transition_descriptor_spit_transitions_descriptor_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType shotwell_transition_descriptor_type_id;
		shotwell_transition_descriptor_type_id = g_type_register_static (G_TYPE_OBJECT, "ShotwellTransitionDescriptor", &g_define_type_info, G_TYPE_FLAG_ABSTRACT);
		g_type_add_interface_static (shotwell_transition_descriptor_type_id, SPIT_TYPE_PLUGGABLE, &spit_pluggable_info);
		g_type_add_interface_static (shotwell_transition_descriptor_type_id, SPIT_TRANSITIONS_TYPE_DESCRIPTOR, &spit_transitions_descriptor_info);
		g_once_init_leave (&shotwell_transition_descriptor_type_id__volatile, shotwell_transition_descriptor_type_id);
	}
	return shotwell_transition_descriptor_type_id__volatile;
}


static void
_vala_array_destroy (gpointer array,
                     gint array_length,
                     GDestroyNotify destroy_func)
{
	if ((array != NULL) && (destroy_func != NULL)) {
		int i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}


static void
_vala_array_free (gpointer array,
                  gint array_length,
                  GDestroyNotify destroy_func)
{
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}



