/* DataView.c generated by valac 0.40.4, the Vala compiler
 * generated from DataView.vala, do not modify */

/* Copyright 2016 Software Freedom Conservancy Inc.
 *
 * This software is licensed under the GNU Lesser General Public License
 * (version 2.1 or later).  See the COPYING file in this distribution.
 */


#include <glib.h>
#include <glib-object.h>
#include <stdlib.h>
#include <string.h>


#define TYPE_DATA_OBJECT (data_object_get_type ())
#define DATA_OBJECT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DATA_OBJECT, DataObject))
#define DATA_OBJECT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DATA_OBJECT, DataObjectClass))
#define IS_DATA_OBJECT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DATA_OBJECT))
#define IS_DATA_OBJECT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DATA_OBJECT))
#define DATA_OBJECT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DATA_OBJECT, DataObjectClass))

typedef struct _DataObject DataObject;
typedef struct _DataObjectClass DataObjectClass;
typedef struct _DataObjectPrivate DataObjectPrivate;

#define TYPE_ALTERATION (alteration_get_type ())
#define ALTERATION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_ALTERATION, Alteration))
#define ALTERATION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_ALTERATION, AlterationClass))
#define IS_ALTERATION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_ALTERATION))
#define IS_ALTERATION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_ALTERATION))
#define ALTERATION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_ALTERATION, AlterationClass))

typedef struct _Alteration Alteration;
typedef struct _AlterationClass AlterationClass;

#define TYPE_DATA_COLLECTION (data_collection_get_type ())
#define DATA_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DATA_COLLECTION, DataCollection))
#define DATA_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DATA_COLLECTION, DataCollectionClass))
#define IS_DATA_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DATA_COLLECTION))
#define IS_DATA_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DATA_COLLECTION))
#define DATA_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DATA_COLLECTION, DataCollectionClass))

typedef struct _DataCollection DataCollection;
typedef struct _DataCollectionClass DataCollectionClass;

#define TYPE_DATA_VIEW (data_view_get_type ())
#define DATA_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DATA_VIEW, DataView))
#define DATA_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DATA_VIEW, DataViewClass))
#define IS_DATA_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DATA_VIEW))
#define IS_DATA_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DATA_VIEW))
#define DATA_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DATA_VIEW, DataViewClass))

typedef struct _DataView DataView;
typedef struct _DataViewClass DataViewClass;
typedef struct _DataViewPrivate DataViewPrivate;

#define TYPE_DATA_SOURCE (data_source_get_type ())
#define DATA_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DATA_SOURCE, DataSource))
#define DATA_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DATA_SOURCE, DataSourceClass))
#define IS_DATA_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DATA_SOURCE))
#define IS_DATA_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DATA_SOURCE))
#define DATA_SOURCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DATA_SOURCE, DataSourceClass))

typedef struct _DataSource DataSource;
typedef struct _DataSourceClass DataSourceClass;
enum  {
	DATA_VIEW_0_PROPERTY,
	DATA_VIEW_NUM_PROPERTIES
};
static GParamSpec* data_view_properties[DATA_VIEW_NUM_PROPERTIES];
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))

#define TYPE_VIEW_COLLECTION (view_collection_get_type ())
#define VIEW_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_VIEW_COLLECTION, ViewCollection))
#define VIEW_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_VIEW_COLLECTION, ViewCollectionClass))
#define IS_VIEW_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_VIEW_COLLECTION))
#define IS_VIEW_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_VIEW_COLLECTION))
#define VIEW_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_VIEW_COLLECTION, ViewCollectionClass))

typedef struct _ViewCollection ViewCollection;
typedef struct _ViewCollectionClass ViewCollectionClass;
#define _data_collection_unref0(var) ((var == NULL) ? NULL : (var = (data_collection_unref (var), NULL)))
enum  {
	DATA_VIEW_STATE_CHANGED_SIGNAL,
	DATA_VIEW_VISIBILITY_CHANGED_SIGNAL,
	DATA_VIEW_VIEW_ALTERED_SIGNAL,
	DATA_VIEW_GEOMETRY_ALTERED_SIGNAL,
	DATA_VIEW_UNSUBSCRIBED_SIGNAL,
	DATA_VIEW_NUM_SIGNALS
};
static guint data_view_signals[DATA_VIEW_NUM_SIGNALS] = {0};

struct _DataObject {
	GObject parent_instance;
	DataObjectPrivate * priv;
};

struct _DataObjectClass {
	GObjectClass parent_class;
	void (*notify_altered) (DataObject* self, Alteration* alteration);
	void (*notify_membership_changed) (DataObject* self, DataCollection* collection);
	void (*notify_collection_property_set) (DataObject* self, const gchar* name, GValue* old, GValue* val);
	void (*notify_collection_property_cleared) (DataObject* self, const gchar* name);
	gchar* (*get_name) (DataObject* self);
	gchar* (*to_string) (DataObject* self);
};

struct _DataView {
	DataObject parent_instance;
	DataViewPrivate * priv;
};

struct _DataViewClass {
	DataObjectClass parent_class;
	void (*notify_view_altered) (DataView* self);
	void (*notify_geometry_altered) (DataView* self);
	void (*notify_unsubscribed) (DataView* self, DataSource* source);
	void (*state_changed) (DataView* self, gboolean selected);
	void (*visibility_changed) (DataView* self, gboolean visible);
	void (*view_altered) (DataView* self);
	void (*geometry_altered) (DataView* self);
	void (*unsubscribed) (DataView* self, DataSource* source);
};

struct _DataViewPrivate {
	DataSource* source;
	gboolean selected;
	gboolean visible;
};


static gpointer data_view_parent_class = NULL;

GType data_object_get_type (void) G_GNUC_CONST;
gpointer alteration_ref (gpointer instance);
void alteration_unref (gpointer instance);
GParamSpec* param_spec_alteration (const gchar* name,
                                   const gchar* nick,
                                   const gchar* blurb,
                                   GType object_type,
                                   GParamFlags flags);
void value_set_alteration (GValue* value,
                           gpointer v_object);
void value_take_alteration (GValue* value,
                            gpointer v_object);
gpointer value_get_alteration (const GValue* value);
GType alteration_get_type (void) G_GNUC_CONST;
gpointer data_collection_ref (gpointer instance);
void data_collection_unref (gpointer instance);
GParamSpec* param_spec_data_collection (const gchar* name,
                                        const gchar* nick,
                                        const gchar* blurb,
                                        GType object_type,
                                        GParamFlags flags);
void value_set_data_collection (GValue* value,
                                gpointer v_object);
void value_take_data_collection (GValue* value,
                                 gpointer v_object);
gpointer value_get_data_collection (const GValue* value);
GType data_collection_get_type (void) G_GNUC_CONST;
GType data_view_get_type (void) G_GNUC_CONST;
GType data_source_get_type (void) G_GNUC_CONST;
#define DATA_VIEW_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_DATA_VIEW, DataViewPrivate))
void data_source_internal_unsubscribe (DataSource* self,
                                       DataView* view);
DataView* data_view_new (DataSource* source);
DataView* data_view_construct (GType object_type,
                               DataSource* source);
#define DATA_OBJECT_INVALID_OBJECT_ID ((gint64) -1)
DataObject* data_object_construct (GType object_type,
                                   gint64 object_id);
void data_source_internal_subscribe (DataSource* self,
                                     DataView* view);
static gchar* data_view_real_get_name (DataObject* base);
gchar* data_object_get_name (DataObject* self);
static gchar* data_view_real_to_string (DataObject* base);
gchar* data_object_to_string (DataObject* self);
DataSource* data_view_get_source (DataView* self);
gboolean data_view_is_selected (DataView* self);
void data_view_internal_set_selected (DataView* self,
                                      gboolean selected);
gboolean data_view_internal_toggle (DataView* self);
gboolean data_view_is_visible (DataView* self);
void data_view_internal_set_visible (DataView* self,
                                     gboolean visible);
void data_view_notify_view_altered (DataView* self);
static void data_view_real_notify_view_altered (DataView* self);
GType view_collection_get_type (void) G_GNUC_CONST;
DataCollection* data_object_get_membership (DataObject* self);
gboolean data_collection_are_notifications_frozen (DataCollection* self);
void view_collection_internal_notify_view_altered (ViewCollection* self,
                                                   DataView* view);
void data_view_notify_geometry_altered (DataView* self);
static void data_view_real_notify_geometry_altered (DataView* self);
void view_collection_internal_notify_geometry_altered (ViewCollection* self,
                                                       DataView* view);
void data_view_notify_unsubscribed (DataView* self,
                                    DataSource* source);
static void data_view_real_notify_unsubscribed (DataView* self,
                                         DataSource* source);
static void data_view_real_state_changed (DataView* self,
                                   gboolean selected);
static void data_view_real_visibility_changed (DataView* self,
                                        gboolean visible);
static void data_view_real_view_altered (DataView* self);
static void data_view_real_geometry_altered (DataView* self);
static void data_view_real_unsubscribed (DataView* self,
                                  DataSource* source);
static void data_view_finalize (GObject * obj);


static gpointer
_g_object_ref0 (gpointer self)
{
#line 33 "/home/jens/Source/shotwell/src/core/DataView.vala"
	return self ? g_object_ref (self) : NULL;
#line 221 "DataView.c"
}


DataView*
data_view_construct (GType object_type,
                     DataSource* source)
{
	DataView * self = NULL;
	DataSource* _tmp0_;
#line 32 "/home/jens/Source/shotwell/src/core/DataView.vala"
	g_return_val_if_fail (IS_DATA_SOURCE (source), NULL);
#line 32 "/home/jens/Source/shotwell/src/core/DataView.vala"
	self = (DataView*) data_object_construct (object_type, DATA_OBJECT_INVALID_OBJECT_ID);
#line 33 "/home/jens/Source/shotwell/src/core/DataView.vala"
	_tmp0_ = _g_object_ref0 (source);
#line 33 "/home/jens/Source/shotwell/src/core/DataView.vala"
	_g_object_unref0 (self->priv->source);
#line 33 "/home/jens/Source/shotwell/src/core/DataView.vala"
	self->priv->source = _tmp0_;
#line 37 "/home/jens/Source/shotwell/src/core/DataView.vala"
	data_source_internal_subscribe (source, self);
#line 32 "/home/jens/Source/shotwell/src/core/DataView.vala"
	return self;
#line 245 "DataView.c"
}


DataView*
data_view_new (DataSource* source)
{
#line 32 "/home/jens/Source/shotwell/src/core/DataView.vala"
	return data_view_construct (TYPE_DATA_VIEW, source);
#line 254 "DataView.c"
}


static gchar*
data_view_real_get_name (DataObject* base)
{
	DataView * self;
	gchar* result = NULL;
	DataSource* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	gchar* _tmp4_;
#line 47 "/home/jens/Source/shotwell/src/core/DataView.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_DATA_VIEW, DataView);
#line 48 "/home/jens/Source/shotwell/src/core/DataView.vala"
	_tmp0_ = self->priv->source;
#line 48 "/home/jens/Source/shotwell/src/core/DataView.vala"
	_tmp1_ = data_object_get_name (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, TYPE_DATA_OBJECT, DataObject));
#line 48 "/home/jens/Source/shotwell/src/core/DataView.vala"
	_tmp2_ = _tmp1_;
#line 48 "/home/jens/Source/shotwell/src/core/DataView.vala"
	_tmp3_ = g_strdup_printf ("View of %s", _tmp2_);
#line 48 "/home/jens/Source/shotwell/src/core/DataView.vala"
	_tmp4_ = _tmp3_;
#line 48 "/home/jens/Source/shotwell/src/core/DataView.vala"
	_g_free0 (_tmp2_);
#line 48 "/home/jens/Source/shotwell/src/core/DataView.vala"
	result = _tmp4_;
#line 48 "/home/jens/Source/shotwell/src/core/DataView.vala"
	return result;
#line 286 "DataView.c"
}


static gchar*
data_view_real_to_string (DataObject* base)
{
	DataView * self;
	gchar* result = NULL;
	gchar* _tmp0_;
	gchar* _tmp1_;
	DataSource* _tmp2_;
	gchar* _tmp3_;
	gchar* _tmp4_;
	gchar* _tmp5_;
	gchar* _tmp6_;
#line 51 "/home/jens/Source/shotwell/src/core/DataView.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_DATA_VIEW, DataView);
#line 52 "/home/jens/Source/shotwell/src/core/DataView.vala"
	_tmp0_ = data_object_get_name (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_DATA_OBJECT, DataObject));
#line 52 "/home/jens/Source/shotwell/src/core/DataView.vala"
	_tmp1_ = _tmp0_;
#line 52 "/home/jens/Source/shotwell/src/core/DataView.vala"
	_tmp2_ = self->priv->source;
#line 52 "/home/jens/Source/shotwell/src/core/DataView.vala"
	_tmp3_ = data_object_to_string (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, TYPE_DATA_OBJECT, DataObject));
#line 52 "/home/jens/Source/shotwell/src/core/DataView.vala"
	_tmp4_ = _tmp3_;
#line 52 "/home/jens/Source/shotwell/src/core/DataView.vala"
	_tmp5_ = g_strdup_printf ("DataView %s [DataSource %s]", _tmp1_, _tmp4_);
#line 52 "/home/jens/Source/shotwell/src/core/DataView.vala"
	_tmp6_ = _tmp5_;
#line 52 "/home/jens/Source/shotwell/src/core/DataView.vala"
	_g_free0 (_tmp4_);
#line 52 "/home/jens/Source/shotwell/src/core/DataView.vala"
	_g_free0 (_tmp1_);
#line 52 "/home/jens/Source/shotwell/src/core/DataView.vala"
	result = _tmp6_;
#line 52 "/home/jens/Source/shotwell/src/core/DataView.vala"
	return result;
#line 326 "DataView.c"
}


DataSource*
data_view_get_source (DataView* self)
{
	DataSource* result = NULL;
	DataSource* _tmp0_;
	DataSource* _tmp1_;
#line 55 "/home/jens/Source/shotwell/src/core/DataView.vala"
	g_return_val_if_fail (IS_DATA_VIEW (self), NULL);
#line 56 "/home/jens/Source/shotwell/src/core/DataView.vala"
	_tmp0_ = self->priv->source;
#line 56 "/home/jens/Source/shotwell/src/core/DataView.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 56 "/home/jens/Source/shotwell/src/core/DataView.vala"
	result = _tmp1_;
#line 56 "/home/jens/Source/shotwell/src/core/DataView.vala"
	return result;
#line 346 "DataView.c"
}


gboolean
data_view_is_selected (DataView* self)
{
	gboolean result = FALSE;
	gboolean _tmp0_;
#line 59 "/home/jens/Source/shotwell/src/core/DataView.vala"
	g_return_val_if_fail (IS_DATA_VIEW (self), FALSE);
#line 60 "/home/jens/Source/shotwell/src/core/DataView.vala"
	_tmp0_ = self->priv->selected;
#line 60 "/home/jens/Source/shotwell/src/core/DataView.vala"
	result = _tmp0_;
#line 60 "/home/jens/Source/shotwell/src/core/DataView.vala"
	return result;
#line 363 "DataView.c"
}


void
data_view_internal_set_selected (DataView* self,
                                 gboolean selected)
{
	gboolean _tmp0_;
#line 64 "/home/jens/Source/shotwell/src/core/DataView.vala"
	g_return_if_fail (IS_DATA_VIEW (self));
#line 65 "/home/jens/Source/shotwell/src/core/DataView.vala"
	_tmp0_ = self->priv->selected;
#line 65 "/home/jens/Source/shotwell/src/core/DataView.vala"
	if (_tmp0_ == selected) {
#line 66 "/home/jens/Source/shotwell/src/core/DataView.vala"
		return;
#line 380 "DataView.c"
	}
#line 68 "/home/jens/Source/shotwell/src/core/DataView.vala"
	self->priv->selected = selected;
#line 69 "/home/jens/Source/shotwell/src/core/DataView.vala"
	g_signal_emit (self, data_view_signals[DATA_VIEW_STATE_CHANGED_SIGNAL], 0, selected);
#line 386 "DataView.c"
}


gboolean
data_view_internal_toggle (DataView* self)
{
	gboolean result = FALSE;
	gboolean _tmp0_;
	gboolean _tmp1_;
	gboolean _tmp2_;
#line 73 "/home/jens/Source/shotwell/src/core/DataView.vala"
	g_return_val_if_fail (IS_DATA_VIEW (self), FALSE);
#line 74 "/home/jens/Source/shotwell/src/core/DataView.vala"
	_tmp0_ = self->priv->selected;
#line 74 "/home/jens/Source/shotwell/src/core/DataView.vala"
	self->priv->selected = !_tmp0_;
#line 75 "/home/jens/Source/shotwell/src/core/DataView.vala"
	_tmp1_ = self->priv->selected;
#line 75 "/home/jens/Source/shotwell/src/core/DataView.vala"
	g_signal_emit (self, data_view_signals[DATA_VIEW_STATE_CHANGED_SIGNAL], 0, _tmp1_);
#line 77 "/home/jens/Source/shotwell/src/core/DataView.vala"
	_tmp2_ = self->priv->selected;
#line 77 "/home/jens/Source/shotwell/src/core/DataView.vala"
	result = _tmp2_;
#line 77 "/home/jens/Source/shotwell/src/core/DataView.vala"
	return result;
#line 413 "DataView.c"
}


gboolean
data_view_is_visible (DataView* self)
{
	gboolean result = FALSE;
	gboolean _tmp0_;
#line 80 "/home/jens/Source/shotwell/src/core/DataView.vala"
	g_return_val_if_fail (IS_DATA_VIEW (self), FALSE);
#line 81 "/home/jens/Source/shotwell/src/core/DataView.vala"
	_tmp0_ = self->priv->visible;
#line 81 "/home/jens/Source/shotwell/src/core/DataView.vala"
	result = _tmp0_;
#line 81 "/home/jens/Source/shotwell/src/core/DataView.vala"
	return result;
#line 430 "DataView.c"
}


void
data_view_internal_set_visible (DataView* self,
                                gboolean visible)
{
	gboolean _tmp0_;
#line 85 "/home/jens/Source/shotwell/src/core/DataView.vala"
	g_return_if_fail (IS_DATA_VIEW (self));
#line 86 "/home/jens/Source/shotwell/src/core/DataView.vala"
	_tmp0_ = self->priv->visible;
#line 86 "/home/jens/Source/shotwell/src/core/DataView.vala"
	if (_tmp0_ == visible) {
#line 87 "/home/jens/Source/shotwell/src/core/DataView.vala"
		return;
#line 447 "DataView.c"
	}
#line 89 "/home/jens/Source/shotwell/src/core/DataView.vala"
	self->priv->visible = visible;
#line 90 "/home/jens/Source/shotwell/src/core/DataView.vala"
	g_signal_emit (self, data_view_signals[DATA_VIEW_VISIBILITY_CHANGED_SIGNAL], 0, visible);
#line 453 "DataView.c"
}


static void
data_view_real_notify_view_altered (DataView* self)
{
	gboolean _tmp0_;
	ViewCollection* vc = NULL;
	DataCollection* _tmp1_;
	ViewCollection* _tmp2_;
	ViewCollection* _tmp3_;
#line 95 "/home/jens/Source/shotwell/src/core/DataView.vala"
	_tmp0_ = self->priv->visible;
#line 95 "/home/jens/Source/shotwell/src/core/DataView.vala"
	if (!_tmp0_) {
#line 96 "/home/jens/Source/shotwell/src/core/DataView.vala"
		return;
#line 471 "DataView.c"
	}
#line 98 "/home/jens/Source/shotwell/src/core/DataView.vala"
	_tmp1_ = data_object_get_membership (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_DATA_OBJECT, DataObject));
#line 98 "/home/jens/Source/shotwell/src/core/DataView.vala"
	_tmp2_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp1_, TYPE_VIEW_COLLECTION) ? ((ViewCollection*) _tmp1_) : NULL;
#line 98 "/home/jens/Source/shotwell/src/core/DataView.vala"
	if (_tmp2_ == NULL) {
#line 98 "/home/jens/Source/shotwell/src/core/DataView.vala"
		_data_collection_unref0 (_tmp1_);
#line 481 "DataView.c"
	}
#line 98 "/home/jens/Source/shotwell/src/core/DataView.vala"
	vc = _tmp2_;
#line 99 "/home/jens/Source/shotwell/src/core/DataView.vala"
	_tmp3_ = vc;
#line 99 "/home/jens/Source/shotwell/src/core/DataView.vala"
	if (_tmp3_ != NULL) {
#line 489 "DataView.c"
		ViewCollection* _tmp4_;
		ViewCollection* _tmp5_;
#line 100 "/home/jens/Source/shotwell/src/core/DataView.vala"
		_tmp4_ = vc;
#line 100 "/home/jens/Source/shotwell/src/core/DataView.vala"
		if (!data_collection_are_notifications_frozen (G_TYPE_CHECK_INSTANCE_CAST (_tmp4_, TYPE_DATA_COLLECTION, DataCollection))) {
#line 101 "/home/jens/Source/shotwell/src/core/DataView.vala"
			g_signal_emit (self, data_view_signals[DATA_VIEW_VIEW_ALTERED_SIGNAL], 0);
#line 498 "DataView.c"
		}
#line 104 "/home/jens/Source/shotwell/src/core/DataView.vala"
		_tmp5_ = vc;
#line 104 "/home/jens/Source/shotwell/src/core/DataView.vala"
		view_collection_internal_notify_view_altered (_tmp5_, self);
#line 504 "DataView.c"
	} else {
#line 106 "/home/jens/Source/shotwell/src/core/DataView.vala"
		g_signal_emit (self, data_view_signals[DATA_VIEW_VIEW_ALTERED_SIGNAL], 0);
#line 508 "DataView.c"
	}
#line 93 "/home/jens/Source/shotwell/src/core/DataView.vala"
	_data_collection_unref0 (vc);
#line 512 "DataView.c"
}


void
data_view_notify_view_altered (DataView* self)
{
#line 93 "/home/jens/Source/shotwell/src/core/DataView.vala"
	g_return_if_fail (IS_DATA_VIEW (self));
#line 93 "/home/jens/Source/shotwell/src/core/DataView.vala"
	DATA_VIEW_GET_CLASS (self)->notify_view_altered (self);
#line 523 "DataView.c"
}


static void
data_view_real_notify_geometry_altered (DataView* self)
{
	gboolean _tmp0_;
	ViewCollection* vc = NULL;
	DataCollection* _tmp1_;
	ViewCollection* _tmp2_;
	ViewCollection* _tmp3_;
#line 112 "/home/jens/Source/shotwell/src/core/DataView.vala"
	_tmp0_ = self->priv->visible;
#line 112 "/home/jens/Source/shotwell/src/core/DataView.vala"
	if (!_tmp0_) {
#line 113 "/home/jens/Source/shotwell/src/core/DataView.vala"
		return;
#line 541 "DataView.c"
	}
#line 115 "/home/jens/Source/shotwell/src/core/DataView.vala"
	_tmp1_ = data_object_get_membership (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_DATA_OBJECT, DataObject));
#line 115 "/home/jens/Source/shotwell/src/core/DataView.vala"
	_tmp2_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp1_, TYPE_VIEW_COLLECTION) ? ((ViewCollection*) _tmp1_) : NULL;
#line 115 "/home/jens/Source/shotwell/src/core/DataView.vala"
	if (_tmp2_ == NULL) {
#line 115 "/home/jens/Source/shotwell/src/core/DataView.vala"
		_data_collection_unref0 (_tmp1_);
#line 551 "DataView.c"
	}
#line 115 "/home/jens/Source/shotwell/src/core/DataView.vala"
	vc = _tmp2_;
#line 116 "/home/jens/Source/shotwell/src/core/DataView.vala"
	_tmp3_ = vc;
#line 116 "/home/jens/Source/shotwell/src/core/DataView.vala"
	if (_tmp3_ != NULL) {
#line 559 "DataView.c"
		ViewCollection* _tmp4_;
		ViewCollection* _tmp5_;
#line 117 "/home/jens/Source/shotwell/src/core/DataView.vala"
		_tmp4_ = vc;
#line 117 "/home/jens/Source/shotwell/src/core/DataView.vala"
		if (!data_collection_are_notifications_frozen (G_TYPE_CHECK_INSTANCE_CAST (_tmp4_, TYPE_DATA_COLLECTION, DataCollection))) {
#line 118 "/home/jens/Source/shotwell/src/core/DataView.vala"
			g_signal_emit (self, data_view_signals[DATA_VIEW_GEOMETRY_ALTERED_SIGNAL], 0);
#line 568 "DataView.c"
		}
#line 121 "/home/jens/Source/shotwell/src/core/DataView.vala"
		_tmp5_ = vc;
#line 121 "/home/jens/Source/shotwell/src/core/DataView.vala"
		view_collection_internal_notify_geometry_altered (_tmp5_, self);
#line 574 "DataView.c"
	} else {
#line 123 "/home/jens/Source/shotwell/src/core/DataView.vala"
		g_signal_emit (self, data_view_signals[DATA_VIEW_GEOMETRY_ALTERED_SIGNAL], 0);
#line 578 "DataView.c"
	}
#line 110 "/home/jens/Source/shotwell/src/core/DataView.vala"
	_data_collection_unref0 (vc);
#line 582 "DataView.c"
}


void
data_view_notify_geometry_altered (DataView* self)
{
#line 110 "/home/jens/Source/shotwell/src/core/DataView.vala"
	g_return_if_fail (IS_DATA_VIEW (self));
#line 110 "/home/jens/Source/shotwell/src/core/DataView.vala"
	DATA_VIEW_GET_CLASS (self)->notify_geometry_altered (self);
#line 593 "DataView.c"
}


static void
data_view_real_notify_unsubscribed (DataView* self,
                                    DataSource* source)
{
#line 128 "/home/jens/Source/shotwell/src/core/DataView.vala"
	g_return_if_fail (IS_DATA_SOURCE (source));
#line 129 "/home/jens/Source/shotwell/src/core/DataView.vala"
	g_signal_emit (self, data_view_signals[DATA_VIEW_UNSUBSCRIBED_SIGNAL], 0, source);
#line 605 "DataView.c"
}


void
data_view_notify_unsubscribed (DataView* self,
                               DataSource* source)
{
#line 128 "/home/jens/Source/shotwell/src/core/DataView.vala"
	g_return_if_fail (IS_DATA_VIEW (self));
#line 128 "/home/jens/Source/shotwell/src/core/DataView.vala"
	DATA_VIEW_GET_CLASS (self)->notify_unsubscribed (self, source);
#line 617 "DataView.c"
}


static void
data_view_real_state_changed (DataView* self,
                              gboolean selected)
{
}


static void
data_view_real_visibility_changed (DataView* self,
                                   gboolean visible)
{
}


static void
data_view_real_view_altered (DataView* self)
{
}


static void
data_view_real_geometry_altered (DataView* self)
{
}


static void
data_view_real_unsubscribed (DataView* self,
                             DataSource* source)
{
#line 29 "/home/jens/Source/shotwell/src/core/DataView.vala"
	g_return_if_fail (IS_DATA_SOURCE (source));
#line 653 "DataView.c"
}


static void
data_view_class_init (DataViewClass * klass)
{
#line 7 "/home/jens/Source/shotwell/src/core/DataView.vala"
	data_view_parent_class = g_type_class_peek_parent (klass);
#line 7 "/home/jens/Source/shotwell/src/core/DataView.vala"
	g_type_class_add_private (klass, sizeof (DataViewPrivate));
#line 7 "/home/jens/Source/shotwell/src/core/DataView.vala"
	((DataObjectClass *) klass)->get_name = (gchar* (*) (DataObject *)) data_view_real_get_name;
#line 7 "/home/jens/Source/shotwell/src/core/DataView.vala"
	((DataObjectClass *) klass)->to_string = (gchar* (*) (DataObject *)) data_view_real_to_string;
#line 7 "/home/jens/Source/shotwell/src/core/DataView.vala"
	((DataViewClass *) klass)->notify_view_altered = (void (*) (DataView *)) data_view_real_notify_view_altered;
#line 7 "/home/jens/Source/shotwell/src/core/DataView.vala"
	((DataViewClass *) klass)->notify_geometry_altered = (void (*) (DataView *)) data_view_real_notify_geometry_altered;
#line 7 "/home/jens/Source/shotwell/src/core/DataView.vala"
	((DataViewClass *) klass)->notify_unsubscribed = (void (*) (DataView *, DataSource*)) data_view_real_notify_unsubscribed;
#line 7 "/home/jens/Source/shotwell/src/core/DataView.vala"
	((DataViewClass *) klass)->state_changed = data_view_real_state_changed;
#line 7 "/home/jens/Source/shotwell/src/core/DataView.vala"
	((DataViewClass *) klass)->visibility_changed = data_view_real_visibility_changed;
#line 7 "/home/jens/Source/shotwell/src/core/DataView.vala"
	((DataViewClass *) klass)->view_altered = data_view_real_view_altered;
#line 7 "/home/jens/Source/shotwell/src/core/DataView.vala"
	((DataViewClass *) klass)->geometry_altered = data_view_real_geometry_altered;
#line 7 "/home/jens/Source/shotwell/src/core/DataView.vala"
	((DataViewClass *) klass)->unsubscribed = data_view_real_unsubscribed;
#line 7 "/home/jens/Source/shotwell/src/core/DataView.vala"
	G_OBJECT_CLASS (klass)->finalize = data_view_finalize;
#line 7 "/home/jens/Source/shotwell/src/core/DataView.vala"
	data_view_signals[DATA_VIEW_STATE_CHANGED_SIGNAL] = g_signal_new ("state-changed", TYPE_DATA_VIEW, G_SIGNAL_RUN_LAST, G_STRUCT_OFFSET (DataViewClass, state_changed), NULL, NULL, g_cclosure_marshal_VOID__BOOLEAN, G_TYPE_NONE, 1, G_TYPE_BOOLEAN);
#line 7 "/home/jens/Source/shotwell/src/core/DataView.vala"
	data_view_signals[DATA_VIEW_VISIBILITY_CHANGED_SIGNAL] = g_signal_new ("visibility-changed", TYPE_DATA_VIEW, G_SIGNAL_RUN_LAST, G_STRUCT_OFFSET (DataViewClass, visibility_changed), NULL, NULL, g_cclosure_marshal_VOID__BOOLEAN, G_TYPE_NONE, 1, G_TYPE_BOOLEAN);
#line 7 "/home/jens/Source/shotwell/src/core/DataView.vala"
	data_view_signals[DATA_VIEW_VIEW_ALTERED_SIGNAL] = g_signal_new ("view-altered", TYPE_DATA_VIEW, G_SIGNAL_RUN_LAST, G_STRUCT_OFFSET (DataViewClass, view_altered), NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
#line 7 "/home/jens/Source/shotwell/src/core/DataView.vala"
	data_view_signals[DATA_VIEW_GEOMETRY_ALTERED_SIGNAL] = g_signal_new ("geometry-altered", TYPE_DATA_VIEW, G_SIGNAL_RUN_LAST, G_STRUCT_OFFSET (DataViewClass, geometry_altered), NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
#line 7 "/home/jens/Source/shotwell/src/core/DataView.vala"
	data_view_signals[DATA_VIEW_UNSUBSCRIBED_SIGNAL] = g_signal_new ("unsubscribed", TYPE_DATA_VIEW, G_SIGNAL_RUN_LAST, G_STRUCT_OFFSET (DataViewClass, unsubscribed), NULL, NULL, g_cclosure_marshal_VOID__OBJECT, G_TYPE_NONE, 1, TYPE_DATA_SOURCE);
#line 696 "DataView.c"
}


static void
data_view_instance_init (DataView * self)
{
#line 7 "/home/jens/Source/shotwell/src/core/DataView.vala"
	self->priv = DATA_VIEW_GET_PRIVATE (self);
#line 9 "/home/jens/Source/shotwell/src/core/DataView.vala"
	self->priv->selected = FALSE;
#line 10 "/home/jens/Source/shotwell/src/core/DataView.vala"
	self->priv->visible = TRUE;
#line 709 "DataView.c"
}


static void
data_view_finalize (GObject * obj)
{
	DataView * self;
	DataSource* _tmp0_;
#line 7 "/home/jens/Source/shotwell/src/core/DataView.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_DATA_VIEW, DataView);
#line 44 "/home/jens/Source/shotwell/src/core/DataView.vala"
	_tmp0_ = self->priv->source;
#line 44 "/home/jens/Source/shotwell/src/core/DataView.vala"
	data_source_internal_unsubscribe (_tmp0_, self);
#line 8 "/home/jens/Source/shotwell/src/core/DataView.vala"
	_g_object_unref0 (self->priv->source);
#line 7 "/home/jens/Source/shotwell/src/core/DataView.vala"
	G_OBJECT_CLASS (data_view_parent_class)->finalize (obj);
#line 728 "DataView.c"
}


GType
data_view_get_type (void)
{
	static volatile gsize data_view_type_id__volatile = 0;
	if (g_once_init_enter (&data_view_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (DataViewClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) data_view_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (DataView), 0, (GInstanceInitFunc) data_view_instance_init, NULL };
		GType data_view_type_id;
		data_view_type_id = g_type_register_static (TYPE_DATA_OBJECT, "DataView", &g_define_type_info, 0);
		g_once_init_leave (&data_view_type_id__volatile, data_view_type_id);
	}
	return data_view_type_id__volatile;
}



