/* _Direct_unitize_entry.c generated by valac 0.40.4, the Vala compiler
 * generated from _Direct_unitize_entry.vala, do not modify */

/* Copyright 2016 Software Freedom Conservancy Inc.
 *
 * This software is licensed under the GNU Lesser General Public License
 * (version 2.1 or later).  See the COPYING file in this distribution.
 *
 * Auto-generated file.  Do not modify!
 */


#include <glib.h>
#include <glib-object.h>




void direct_app_init (GError** error);
void direct_init_entry (GError** error);
void direct_app_terminate (void);
void direct_terminate_entry (void);


void
direct_app_init (GError** error)
{
	GError * _inner_error_ = NULL;
#line 12 "/home/jens/Source/shotwell/src/.unitize/_Direct_unitize_entry.vala"
	direct_init_entry (&_inner_error_);
#line 12 "/home/jens/Source/shotwell/src/.unitize/_Direct_unitize_entry.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 12 "/home/jens/Source/shotwell/src/.unitize/_Direct_unitize_entry.vala"
		g_propagate_error (error, _inner_error_);
#line 12 "/home/jens/Source/shotwell/src/.unitize/_Direct_unitize_entry.vala"
		return;
#line 38 "_Direct_unitize_entry.c"
	}
}


void
direct_app_terminate (void)
{
#line 16 "/home/jens/Source/shotwell/src/.unitize/_Direct_unitize_entry.vala"
	direct_terminate_entry ();
#line 48 "_Direct_unitize_entry.c"
}



