/* shotwell-publishing.c generated by valac 0.40.4, the Vala compiler
 * generated from shotwell-publishing.vala, do not modify */

/* Copyright 2016 Software Freedom Conservancy Inc.
 *
 * This software is licensed under the GNU Lesser General Public License
 * (version 2.1 or later).  See the COPYING file in this distribution.
 */


#include <glib.h>
#include <glib-object.h>
#include <shotwell-plugin-dev-1.0.h>
#include <gio/gio.h>
#include "shotwell-authenticator.h"
#include <gee.h>
#include <stdlib.h>
#include <string.h>
#include <glib/gi18n-lib.h>


#define TYPE_SHOTWELL_PUBLISHING_CORE_SERVICES (shotwell_publishing_core_services_get_type ())
#define SHOTWELL_PUBLISHING_CORE_SERVICES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SHOTWELL_PUBLISHING_CORE_SERVICES, ShotwellPublishingCoreServices))
#define SHOTWELL_PUBLISHING_CORE_SERVICES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SHOTWELL_PUBLISHING_CORE_SERVICES, ShotwellPublishingCoreServicesClass))
#define IS_SHOTWELL_PUBLISHING_CORE_SERVICES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SHOTWELL_PUBLISHING_CORE_SERVICES))
#define IS_SHOTWELL_PUBLISHING_CORE_SERVICES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SHOTWELL_PUBLISHING_CORE_SERVICES))
#define SHOTWELL_PUBLISHING_CORE_SERVICES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SHOTWELL_PUBLISHING_CORE_SERVICES, ShotwellPublishingCoreServicesClass))

typedef struct _ShotwellPublishingCoreServices ShotwellPublishingCoreServices;
typedef struct _ShotwellPublishingCoreServicesClass ShotwellPublishingCoreServicesClass;
typedef struct _ShotwellPublishingCoreServicesPrivate ShotwellPublishingCoreServicesPrivate;
enum  {
	SHOTWELL_PUBLISHING_CORE_SERVICES_0_PROPERTY,
	SHOTWELL_PUBLISHING_CORE_SERVICES_NUM_PROPERTIES
};
static GParamSpec* shotwell_publishing_core_services_properties[SHOTWELL_PUBLISHING_CORE_SERVICES_NUM_PROPERTIES];
#define _g_free0(var) (var = (g_free (var), NULL))

#define TYPE_FACEBOOK_SERVICE (facebook_service_get_type ())
#define FACEBOOK_SERVICE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_FACEBOOK_SERVICE, FacebookService))
#define FACEBOOK_SERVICE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_FACEBOOK_SERVICE, FacebookServiceClass))
#define IS_FACEBOOK_SERVICE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_FACEBOOK_SERVICE))
#define IS_FACEBOOK_SERVICE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_FACEBOOK_SERVICE))
#define FACEBOOK_SERVICE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_FACEBOOK_SERVICE, FacebookServiceClass))

typedef struct _FacebookService FacebookService;
typedef struct _FacebookServiceClass FacebookServiceClass;

#define TYPE_PICASA_SERVICE (picasa_service_get_type ())
#define PICASA_SERVICE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PICASA_SERVICE, PicasaService))
#define PICASA_SERVICE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PICASA_SERVICE, PicasaServiceClass))
#define IS_PICASA_SERVICE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PICASA_SERVICE))
#define IS_PICASA_SERVICE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PICASA_SERVICE))
#define PICASA_SERVICE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PICASA_SERVICE, PicasaServiceClass))

typedef struct _PicasaService PicasaService;
typedef struct _PicasaServiceClass PicasaServiceClass;

#define TYPE_FLICKR_SERVICE (flickr_service_get_type ())
#define FLICKR_SERVICE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_FLICKR_SERVICE, FlickrService))
#define FLICKR_SERVICE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_FLICKR_SERVICE, FlickrServiceClass))
#define IS_FLICKR_SERVICE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_FLICKR_SERVICE))
#define IS_FLICKR_SERVICE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_FLICKR_SERVICE))
#define FLICKR_SERVICE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_FLICKR_SERVICE, FlickrServiceClass))

typedef struct _FlickrService FlickrService;
typedef struct _FlickrServiceClass FlickrServiceClass;

#define TYPE_YOU_TUBE_SERVICE (you_tube_service_get_type ())
#define YOU_TUBE_SERVICE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_YOU_TUBE_SERVICE, YouTubeService))
#define YOU_TUBE_SERVICE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_YOU_TUBE_SERVICE, YouTubeServiceClass))
#define IS_YOU_TUBE_SERVICE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_YOU_TUBE_SERVICE))
#define IS_YOU_TUBE_SERVICE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_YOU_TUBE_SERVICE))
#define YOU_TUBE_SERVICE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_YOU_TUBE_SERVICE, YouTubeServiceClass))

typedef struct _YouTubeService YouTubeService;
typedef struct _YouTubeServiceClass YouTubeServiceClass;

#define TYPE_PIWIGO_SERVICE (piwigo_service_get_type ())
#define PIWIGO_SERVICE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PIWIGO_SERVICE, PiwigoService))
#define PIWIGO_SERVICE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PIWIGO_SERVICE, PiwigoServiceClass))
#define IS_PIWIGO_SERVICE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PIWIGO_SERVICE))
#define IS_PIWIGO_SERVICE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PIWIGO_SERVICE))
#define PIWIGO_SERVICE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PIWIGO_SERVICE, PiwigoServiceClass))

typedef struct _PiwigoService PiwigoService;
typedef struct _PiwigoServiceClass PiwigoServiceClass;

#define TYPE_TUMBLR_SERVICE (tumblr_service_get_type ())
#define TUMBLR_SERVICE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_TUMBLR_SERVICE, TumblrService))
#define TUMBLR_SERVICE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_TUMBLR_SERVICE, TumblrServiceClass))
#define IS_TUMBLR_SERVICE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_TUMBLR_SERVICE))
#define IS_TUMBLR_SERVICE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_TUMBLR_SERVICE))
#define TUMBLR_SERVICE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_TUMBLR_SERVICE, TumblrServiceClass))

typedef struct _TumblrService TumblrService;
typedef struct _TumblrServiceClass TumblrServiceClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

struct _ShotwellPublishingCoreServices {
	GObject parent_instance;
	ShotwellPublishingCoreServicesPrivate * priv;
};

struct _ShotwellPublishingCoreServicesClass {
	GObjectClass parent_class;
};

struct _ShotwellPublishingCoreServicesPrivate {
	SpitPluggable** pluggables;
	gint pluggables_length1;
	gint _pluggables_size_;
};


static gpointer shotwell_publishing_core_services_parent_class = NULL;
static SpitModuleIface * shotwell_publishing_core_services_spit_module_parent_iface = NULL;

GType shotwell_publishing_core_services_get_type (void) G_GNUC_CONST;
#define SHOTWELL_PUBLISHING_CORE_SERVICES_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_SHOTWELL_PUBLISHING_CORE_SERVICES, ShotwellPublishingCoreServicesPrivate))
ShotwellPublishingCoreServices* shotwell_publishing_core_services_new (GFile* module_file);
ShotwellPublishingCoreServices* shotwell_publishing_core_services_construct (GType object_type,
                                                                             GFile* module_file);
FacebookService* facebook_service_new (GFile* resource_directory);
FacebookService* facebook_service_construct (GType object_type,
                                             GFile* resource_directory);
GType facebook_service_get_type (void) G_GNUC_CONST;
static void _vala_array_add1 (SpitPluggable** * array,
                       int* length,
                       int* size,
                       SpitPluggable* value);
PicasaService* picasa_service_new (GFile* resource_directory);
PicasaService* picasa_service_construct (GType object_type,
                                         GFile* resource_directory);
GType picasa_service_get_type (void) G_GNUC_CONST;
static void _vala_array_add2 (SpitPluggable** * array,
                       int* length,
                       int* size,
                       SpitPluggable* value);
FlickrService* flickr_service_new (GFile* resource_directory);
FlickrService* flickr_service_construct (GType object_type,
                                         GFile* resource_directory);
GType flickr_service_get_type (void) G_GNUC_CONST;
static void _vala_array_add3 (SpitPluggable** * array,
                       int* length,
                       int* size,
                       SpitPluggable* value);
YouTubeService* you_tube_service_new (GFile* resource_directory);
YouTubeService* you_tube_service_construct (GType object_type,
                                            GFile* resource_directory);
GType you_tube_service_get_type (void) G_GNUC_CONST;
static void _vala_array_add4 (SpitPluggable** * array,
                       int* length,
                       int* size,
                       SpitPluggable* value);
PiwigoService* piwigo_service_new (GFile* resource_directory);
PiwigoService* piwigo_service_construct (GType object_type,
                                         GFile* resource_directory);
GType piwigo_service_get_type (void) G_GNUC_CONST;
static void _vala_array_add5 (SpitPluggable** * array,
                       int* length,
                       int* size,
                       SpitPluggable* value);
TumblrService* tumblr_service_new (GFile* resource_directory);
TumblrService* tumblr_service_construct (GType object_type,
                                         GFile* resource_directory);
GType tumblr_service_get_type (void) G_GNUC_CONST;
static void _vala_array_add6 (SpitPluggable** * array,
                       int* length,
                       int* size,
                       SpitPluggable* value);
static const gchar* shotwell_publishing_core_services_real_get_module_name (SpitModule* base);
static const gchar* shotwell_publishing_core_services_real_get_version (SpitModule* base);
static const gchar* shotwell_publishing_core_services_real_get_id (SpitModule* base);
static SpitPluggable** shotwell_publishing_core_services_real_get_pluggables (SpitModule* base,
                                                                       int* result_length1);
static void shotwell_publishing_core_services_finalize (GObject * obj);
SpitModule* spit_entry_point (SpitEntryPointParams* params);
static void _vala_array_destroy (gpointer array,
                          gint array_length,
                          GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array,
                       gint array_length,
                       GDestroyNotify destroy_func);


static void
_vala_array_add1 (SpitPluggable** * array,
                  int* length,
                  int* size,
                  SpitPluggable* value)
{
#line 27 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
	if ((*length) == (*size)) {
#line 27 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 27 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
		*array = g_renew (SpitPluggable*, *array, (*size) + 1);
#line 200 "shotwell-publishing.c"
	}
#line 27 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
	(*array)[(*length)++] = value;
#line 27 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
	(*array)[*length] = NULL;
#line 206 "shotwell-publishing.c"
}


static void
_vala_array_add2 (SpitPluggable** * array,
                  int* length,
                  int* size,
                  SpitPluggable* value)
{
#line 33 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
	if ((*length) == (*size)) {
#line 33 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 33 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
		*array = g_renew (SpitPluggable*, *array, (*size) + 1);
#line 222 "shotwell-publishing.c"
	}
#line 33 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
	(*array)[(*length)++] = value;
#line 33 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
	(*array)[*length] = NULL;
#line 228 "shotwell-publishing.c"
}


static void
_vala_array_add3 (SpitPluggable** * array,
                  int* length,
                  int* size,
                  SpitPluggable* value)
{
#line 39 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
	if ((*length) == (*size)) {
#line 39 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 39 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
		*array = g_renew (SpitPluggable*, *array, (*size) + 1);
#line 244 "shotwell-publishing.c"
	}
#line 39 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
	(*array)[(*length)++] = value;
#line 39 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
	(*array)[*length] = NULL;
#line 250 "shotwell-publishing.c"
}


static void
_vala_array_add4 (SpitPluggable** * array,
                  int* length,
                  int* size,
                  SpitPluggable* value)
{
#line 45 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
	if ((*length) == (*size)) {
#line 45 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 45 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
		*array = g_renew (SpitPluggable*, *array, (*size) + 1);
#line 266 "shotwell-publishing.c"
	}
#line 45 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
	(*array)[(*length)++] = value;
#line 45 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
	(*array)[*length] = NULL;
#line 272 "shotwell-publishing.c"
}


static void
_vala_array_add5 (SpitPluggable** * array,
                  int* length,
                  int* size,
                  SpitPluggable* value)
{
#line 50 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
	if ((*length) == (*size)) {
#line 50 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 50 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
		*array = g_renew (SpitPluggable*, *array, (*size) + 1);
#line 288 "shotwell-publishing.c"
	}
#line 50 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
	(*array)[(*length)++] = value;
#line 50 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
	(*array)[*length] = NULL;
#line 294 "shotwell-publishing.c"
}


static void
_vala_array_add6 (SpitPluggable** * array,
                  int* length,
                  int* size,
                  SpitPluggable* value)
{
#line 54 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
	if ((*length) == (*size)) {
#line 54 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 54 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
		*array = g_renew (SpitPluggable*, *array, (*size) + 1);
#line 310 "shotwell-publishing.c"
	}
#line 54 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
	(*array)[(*length)++] = value;
#line 54 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
	(*array)[*length] = NULL;
#line 316 "shotwell-publishing.c"
}


ShotwellPublishingCoreServices*
shotwell_publishing_core_services_construct (GType object_type,
                                             GFile* module_file)
{
	ShotwellPublishingCoreServices * self = NULL;
	GFile* resource_directory = NULL;
	GFile* _tmp0_;
	PublishingAuthenticatorFactory* factory = NULL;
	PublishingAuthenticatorFactory* _tmp1_;
	GeeList* authenicators = NULL;
	PublishingAuthenticatorFactory* _tmp2_;
	GeeList* _tmp3_;
	GFile* _tmp4_;
	gchar* _tmp5_;
	gchar* _tmp6_;
	GeeList* _tmp7_;
	gint _tmp8_;
	gint _tmp9_;
	GeeList* _tmp10_;
	GeeList* _tmp14_;
	GeeList* _tmp18_;
	GeeList* _tmp22_;
	SpitPluggable** _tmp26_;
	gint _tmp26__length1;
	GFile* _tmp27_;
	PiwigoService* _tmp28_;
	SpitPluggable** _tmp29_;
	gint _tmp29__length1;
	GFile* _tmp30_;
	GFile* _tmp31_;
	TumblrService* _tmp32_;
#line 15 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
	g_return_val_if_fail (G_IS_FILE (module_file), NULL);
#line 15 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
	self = (ShotwellPublishingCoreServices*) g_object_new (object_type, NULL);
#line 16 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
	_tmp0_ = g_file_get_parent (module_file);
#line 16 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
	resource_directory = _tmp0_;
#line 17 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
	_tmp1_ = publishing_authenticator_factory_get_instance ();
#line 17 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
	factory = _tmp1_;
#line 18 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
	_tmp2_ = factory;
#line 18 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
	_tmp3_ = spit_publishing_authenticator_factory_get_available_authenticators (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, SPIT_PUBLISHING_TYPE_AUTHENTICATOR_FACTORY, SpitPublishingAuthenticatorFactory));
#line 18 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
	authenicators = _tmp3_;
#line 22 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
	_tmp4_ = resource_directory;
#line 22 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
	_tmp5_ = g_file_get_path (_tmp4_);
#line 22 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
	_tmp6_ = _tmp5_;
#line 22 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
	g_debug ("shotwell-publishing.vala:22: Looking for resources in %s", _tmp6_);
#line 22 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
	_g_free0 (_tmp6_);
#line 23 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
	_tmp7_ = authenicators;
#line 23 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
	_tmp8_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp7_, GEE_TYPE_COLLECTION, GeeCollection));
#line 23 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
	_tmp9_ = _tmp8_;
#line 23 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
	g_debug ("shotwell-publishing.vala:23: Found %d authenicators", _tmp9_);
#line 26 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
	_tmp10_ = authenicators;
#line 26 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
	if (gee_collection_contains (G_TYPE_CHECK_INSTANCE_CAST (_tmp10_, GEE_TYPE_COLLECTION, GeeCollection), "facebook")) {
#line 391 "shotwell-publishing.c"
		SpitPluggable** _tmp11_;
		gint _tmp11__length1;
		GFile* _tmp12_;
		FacebookService* _tmp13_;
#line 27 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
		_tmp11_ = self->priv->pluggables;
#line 27 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
		_tmp11__length1 = self->priv->pluggables_length1;
#line 27 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
		_tmp12_ = resource_directory;
#line 27 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
		_tmp13_ = facebook_service_new (_tmp12_);
#line 27 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
		_vala_array_add1 (&self->priv->pluggables, &self->priv->pluggables_length1, &self->priv->_pluggables_size_, G_TYPE_CHECK_INSTANCE_CAST (_tmp13_, SPIT_TYPE_PLUGGABLE, SpitPluggable));
#line 406 "shotwell-publishing.c"
	}
#line 32 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
	_tmp14_ = authenicators;
#line 32 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
	if (gee_collection_contains (G_TYPE_CHECK_INSTANCE_CAST (_tmp14_, GEE_TYPE_COLLECTION, GeeCollection), "picasa")) {
#line 412 "shotwell-publishing.c"
		SpitPluggable** _tmp15_;
		gint _tmp15__length1;
		GFile* _tmp16_;
		PicasaService* _tmp17_;
#line 33 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
		_tmp15_ = self->priv->pluggables;
#line 33 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
		_tmp15__length1 = self->priv->pluggables_length1;
#line 33 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
		_tmp16_ = resource_directory;
#line 33 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
		_tmp17_ = picasa_service_new (_tmp16_);
#line 33 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
		_vala_array_add2 (&self->priv->pluggables, &self->priv->pluggables_length1, &self->priv->_pluggables_size_, G_TYPE_CHECK_INSTANCE_CAST (_tmp17_, SPIT_TYPE_PLUGGABLE, SpitPluggable));
#line 427 "shotwell-publishing.c"
	}
#line 38 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
	_tmp18_ = authenicators;
#line 38 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
	if (gee_collection_contains (G_TYPE_CHECK_INSTANCE_CAST (_tmp18_, GEE_TYPE_COLLECTION, GeeCollection), "flickr")) {
#line 433 "shotwell-publishing.c"
		SpitPluggable** _tmp19_;
		gint _tmp19__length1;
		GFile* _tmp20_;
		FlickrService* _tmp21_;
#line 39 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
		_tmp19_ = self->priv->pluggables;
#line 39 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
		_tmp19__length1 = self->priv->pluggables_length1;
#line 39 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
		_tmp20_ = resource_directory;
#line 39 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
		_tmp21_ = flickr_service_new (_tmp20_);
#line 39 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
		_vala_array_add3 (&self->priv->pluggables, &self->priv->pluggables_length1, &self->priv->_pluggables_size_, G_TYPE_CHECK_INSTANCE_CAST (_tmp21_, SPIT_TYPE_PLUGGABLE, SpitPluggable));
#line 448 "shotwell-publishing.c"
	}
#line 44 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
	_tmp22_ = authenicators;
#line 44 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
	if (gee_collection_contains (G_TYPE_CHECK_INSTANCE_CAST (_tmp22_, GEE_TYPE_COLLECTION, GeeCollection), "youtube")) {
#line 454 "shotwell-publishing.c"
		SpitPluggable** _tmp23_;
		gint _tmp23__length1;
		GFile* _tmp24_;
		YouTubeService* _tmp25_;
#line 45 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
		_tmp23_ = self->priv->pluggables;
#line 45 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
		_tmp23__length1 = self->priv->pluggables_length1;
#line 45 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
		_tmp24_ = resource_directory;
#line 45 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
		_tmp25_ = you_tube_service_new (_tmp24_);
#line 45 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
		_vala_array_add4 (&self->priv->pluggables, &self->priv->pluggables_length1, &self->priv->_pluggables_size_, G_TYPE_CHECK_INSTANCE_CAST (_tmp25_, SPIT_TYPE_PLUGGABLE, SpitPluggable));
#line 469 "shotwell-publishing.c"
	}
#line 50 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
	_tmp26_ = self->priv->pluggables;
#line 50 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
	_tmp26__length1 = self->priv->pluggables_length1;
#line 50 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
	_tmp27_ = resource_directory;
#line 50 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
	_tmp28_ = piwigo_service_new (_tmp27_);
#line 50 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
	_vala_array_add5 (&self->priv->pluggables, &self->priv->pluggables_length1, &self->priv->_pluggables_size_, G_TYPE_CHECK_INSTANCE_CAST (_tmp28_, SPIT_TYPE_PLUGGABLE, SpitPluggable));
#line 54 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
	_tmp29_ = self->priv->pluggables;
#line 54 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
	_tmp29__length1 = self->priv->pluggables_length1;
#line 54 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
	_tmp30_ = g_file_get_parent (module_file);
#line 54 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
	_tmp31_ = _tmp30_;
#line 54 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
	_tmp32_ = tumblr_service_new (_tmp31_);
#line 54 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
	_vala_array_add6 (&self->priv->pluggables, &self->priv->pluggables_length1, &self->priv->_pluggables_size_, G_TYPE_CHECK_INSTANCE_CAST (_tmp32_, SPIT_TYPE_PLUGGABLE, SpitPluggable));
#line 54 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
	_g_object_unref0 (_tmp31_);
#line 15 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
	_g_object_unref0 (authenicators);
#line 15 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
	_g_object_unref0 (factory);
#line 15 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
	_g_object_unref0 (resource_directory);
#line 15 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
	return self;
#line 503 "shotwell-publishing.c"
}


ShotwellPublishingCoreServices*
shotwell_publishing_core_services_new (GFile* module_file)
{
#line 15 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
	return shotwell_publishing_core_services_construct (TYPE_SHOTWELL_PUBLISHING_CORE_SERVICES, module_file);
#line 512 "shotwell-publishing.c"
}


static const gchar*
shotwell_publishing_core_services_real_get_module_name (SpitModule* base)
{
	ShotwellPublishingCoreServices * self;
	const gchar* result = NULL;
#line 58 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_SHOTWELL_PUBLISHING_CORE_SERVICES, ShotwellPublishingCoreServices);
#line 59 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
	result = _ ("Core Publishing Services");
#line 59 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
	return result;
#line 527 "shotwell-publishing.c"
}


static const gchar*
shotwell_publishing_core_services_real_get_version (SpitModule* base)
{
	ShotwellPublishingCoreServices * self;
	const gchar* result = NULL;
#line 62 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_SHOTWELL_PUBLISHING_CORE_SERVICES, ShotwellPublishingCoreServices);
#line 63 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
	result = _VERSION;
#line 63 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
	return result;
#line 542 "shotwell-publishing.c"
}


static const gchar*
shotwell_publishing_core_services_real_get_id (SpitModule* base)
{
	ShotwellPublishingCoreServices * self;
	const gchar* result = NULL;
#line 66 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_SHOTWELL_PUBLISHING_CORE_SERVICES, ShotwellPublishingCoreServices);
#line 67 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
	result = "org.yorba.shotwell.publishing.core_services";
#line 67 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
	return result;
#line 557 "shotwell-publishing.c"
}


static SpitPluggable**
shotwell_publishing_core_services_real_get_pluggables (SpitModule* base,
                                                       int* result_length1)
{
	ShotwellPublishingCoreServices * self;
	SpitPluggable** result = NULL;
	SpitPluggable** _tmp0_;
	gint _tmp0__length1;
	SpitPluggable** _tmp1_;
	gint _tmp1__length1;
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_SHOTWELL_PUBLISHING_CORE_SERVICES, ShotwellPublishingCoreServices);
#line 71 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
	_tmp0_ = self->priv->pluggables;
#line 71 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
	_tmp0__length1 = self->priv->pluggables_length1;
#line 71 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
	_tmp1_ = _tmp0_;
#line 71 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
	_tmp1__length1 = _tmp0__length1;
#line 71 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
	if (result_length1) {
#line 71 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
		*result_length1 = _tmp1__length1;
#line 585 "shotwell-publishing.c"
	}
#line 71 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
	result = _tmp1_;
#line 71 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
	return result;
#line 591 "shotwell-publishing.c"
}


static void
shotwell_publishing_core_services_class_init (ShotwellPublishingCoreServicesClass * klass)
{
#line 10 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
	shotwell_publishing_core_services_parent_class = g_type_class_peek_parent (klass);
#line 10 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
	g_type_class_add_private (klass, sizeof (ShotwellPublishingCoreServicesPrivate));
#line 10 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
	G_OBJECT_CLASS (klass)->finalize = shotwell_publishing_core_services_finalize;
#line 604 "shotwell-publishing.c"
}


static void
shotwell_publishing_core_services_spit_module_interface_init (SpitModuleIface * iface)
{
#line 10 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
	shotwell_publishing_core_services_spit_module_parent_iface = g_type_interface_peek_parent (iface);
#line 10 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
	iface->get_module_name = (const gchar* (*) (SpitModule *)) shotwell_publishing_core_services_real_get_module_name;
#line 10 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
	iface->get_version = (const gchar* (*) (SpitModule *)) shotwell_publishing_core_services_real_get_version;
#line 10 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
	iface->get_id = (const gchar* (*) (SpitModule *)) shotwell_publishing_core_services_real_get_id;
#line 10 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
	iface->get_pluggables = (SpitPluggable** (*) (SpitModule *, int*)) shotwell_publishing_core_services_real_get_pluggables;
#line 621 "shotwell-publishing.c"
}


static void
shotwell_publishing_core_services_instance_init (ShotwellPublishingCoreServices * self)
{
	SpitPluggable** _tmp0_;
#line 10 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
	self->priv = SHOTWELL_PUBLISHING_CORE_SERVICES_GET_PRIVATE (self);
#line 11 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
	_tmp0_ = g_new0 (SpitPluggable*, 0 + 1);
#line 11 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
	self->priv->pluggables = _tmp0_;
#line 11 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
	self->priv->pluggables_length1 = 0;
#line 11 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
	self->priv->_pluggables_size_ = self->priv->pluggables_length1;
#line 639 "shotwell-publishing.c"
}


static void
shotwell_publishing_core_services_finalize (GObject * obj)
{
	ShotwellPublishingCoreServices * self;
#line 10 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_SHOTWELL_PUBLISHING_CORE_SERVICES, ShotwellPublishingCoreServices);
#line 11 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
	self->priv->pluggables = (_vala_array_free (self->priv->pluggables, self->priv->pluggables_length1, (GDestroyNotify) g_object_unref), NULL);
#line 10 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
	G_OBJECT_CLASS (shotwell_publishing_core_services_parent_class)->finalize (obj);
#line 653 "shotwell-publishing.c"
}


GType
shotwell_publishing_core_services_get_type (void)
{
	static volatile gsize shotwell_publishing_core_services_type_id__volatile = 0;
	if (g_once_init_enter (&shotwell_publishing_core_services_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (ShotwellPublishingCoreServicesClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) shotwell_publishing_core_services_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ShotwellPublishingCoreServices), 0, (GInstanceInitFunc) shotwell_publishing_core_services_instance_init, NULL };
		static const GInterfaceInfo spit_module_info = { (GInterfaceInitFunc) shotwell_publishing_core_services_spit_module_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType shotwell_publishing_core_services_type_id;
		shotwell_publishing_core_services_type_id = g_type_register_static (G_TYPE_OBJECT, "ShotwellPublishingCoreServices", &g_define_type_info, 0);
		g_type_add_interface_static (shotwell_publishing_core_services_type_id, SPIT_TYPE_MODULE, &spit_module_info);
		g_once_init_leave (&shotwell_publishing_core_services_type_id__volatile, shotwell_publishing_core_services_type_id);
	}
	return shotwell_publishing_core_services_type_id__volatile;
}


SpitModule*
spit_entry_point (SpitEntryPointParams* params)
{
	SpitModule* result = NULL;
	gint _tmp0_;
	gint _tmp1_;
	ShotwellPublishingCoreServices* _tmp2_ = NULL;
	gint _tmp3_;
#line 77 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
	_tmp0_ = (*params).host_min_spit_interface;
#line 77 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
	_tmp1_ = (*params).host_max_spit_interface;
#line 77 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
	(*params).module_spit_interface = spit_negotiate_interfaces (_tmp0_, _tmp1_, SPIT_CURRENT_INTERFACE);
#line 80 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
	_tmp3_ = (*params).module_spit_interface;
#line 80 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
	if (_tmp3_ != SPIT_UNSUPPORTED_INTERFACE) {
#line 691 "shotwell-publishing.c"
		GFile* _tmp4_;
		ShotwellPublishingCoreServices* _tmp5_;
#line 81 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
		_tmp4_ = (*params).module_file;
#line 81 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
		_tmp5_ = shotwell_publishing_core_services_new (_tmp4_);
#line 81 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
		_g_object_unref0 (_tmp2_);
#line 81 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
		_tmp2_ = _tmp5_;
#line 702 "shotwell-publishing.c"
	} else {
#line 81 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
		_g_object_unref0 (_tmp2_);
#line 81 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
		_tmp2_ = NULL;
#line 708 "shotwell-publishing.c"
	}
#line 80 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
	result = G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, SPIT_TYPE_MODULE, SpitModule);
#line 80 "/home/jens/Source/shotwell/plugins/shotwell-publishing/shotwell-publishing.vala"
	return result;
#line 714 "shotwell-publishing.c"
}


static void
_vala_array_destroy (gpointer array,
                     gint array_length,
                     GDestroyNotify destroy_func)
{
	if ((array != NULL) && (destroy_func != NULL)) {
		int i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}


static void
_vala_array_free (gpointer array,
                  gint array_length,
                  GDestroyNotify destroy_func)
{
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}



