/* GalleryConnector.c generated by valac 0.40.4, the Vala compiler
 * generated from GalleryConnector.vala, do not modify */

/* Copyright 2012-2013 Joe Sapp nixphoeni@gentoo.org
 *
 * This software is licensed under the GNU LGPL (version 2.1 or later).
 * See the COPYING file in this distribution.
 */


#include <glib.h>
#include <glib-object.h>
#include <stdlib.h>
#include <string.h>
#include <shotwell-plugin-dev-1.0.h>
#include <gio/gio.h>
#include <glib/gi18n-lib.h>
#include <gdk-pixbuf/gdk-pixbuf.h>
#include "shotwell-plugin-common.h"
#include <json-glib/json-glib.h>
#include <gtk/gtk.h>
#include <float.h>
#include <math.h>
#include <gobject/gvaluecollector.h>


#define TYPE_SHOTWELL_PUBLISHING_GALLERY3 (shotwell_publishing_gallery3_get_type ())
#define SHOTWELL_PUBLISHING_GALLERY3(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SHOTWELL_PUBLISHING_GALLERY3, ShotwellPublishingGallery3))
#define SHOTWELL_PUBLISHING_GALLERY3_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SHOTWELL_PUBLISHING_GALLERY3, ShotwellPublishingGallery3Class))
#define IS_SHOTWELL_PUBLISHING_GALLERY3(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SHOTWELL_PUBLISHING_GALLERY3))
#define IS_SHOTWELL_PUBLISHING_GALLERY3_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SHOTWELL_PUBLISHING_GALLERY3))
#define SHOTWELL_PUBLISHING_GALLERY3_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SHOTWELL_PUBLISHING_GALLERY3, ShotwellPublishingGallery3Class))

typedef struct _ShotwellPublishingGallery3 ShotwellPublishingGallery3;
typedef struct _ShotwellPublishingGallery3Class ShotwellPublishingGallery3Class;
typedef struct _ShotwellPublishingGallery3Private ShotwellPublishingGallery3Private;
enum  {
	SHOTWELL_PUBLISHING_GALLERY3_0_PROPERTY,
	SHOTWELL_PUBLISHING_GALLERY3_NUM_PROPERTIES
};
static GParamSpec* shotwell_publishing_gallery3_properties[SHOTWELL_PUBLISHING_GALLERY3_NUM_PROPERTIES];

#define TYPE_GALLERY3_SERVICE (gallery3_service_get_type ())
#define GALLERY3_SERVICE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_GALLERY3_SERVICE, Gallery3Service))
#define GALLERY3_SERVICE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_GALLERY3_SERVICE, Gallery3ServiceClass))
#define IS_GALLERY3_SERVICE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_GALLERY3_SERVICE))
#define IS_GALLERY3_SERVICE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_GALLERY3_SERVICE))
#define GALLERY3_SERVICE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_GALLERY3_SERVICE, Gallery3ServiceClass))

typedef struct _Gallery3Service Gallery3Service;
typedef struct _Gallery3ServiceClass Gallery3ServiceClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
typedef struct _Gallery3ServicePrivate Gallery3ServicePrivate;
enum  {
	GALLERY3_SERVICE_0_PROPERTY,
	GALLERY3_SERVICE_NUM_PROPERTIES
};
static GParamSpec* gallery3_service_properties[GALLERY3_SERVICE_NUM_PROPERTIES];
#define _g_free0(var) (var = (g_free (var), NULL))

#define PUBLISHING_GALLERY3_TYPE_GALLERY_PUBLISHER (publishing_gallery3_gallery_publisher_get_type ())
#define PUBLISHING_GALLERY3_GALLERY_PUBLISHER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_GALLERY3_TYPE_GALLERY_PUBLISHER, PublishingGallery3GalleryPublisher))
#define PUBLISHING_GALLERY3_GALLERY_PUBLISHER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_GALLERY3_TYPE_GALLERY_PUBLISHER, PublishingGallery3GalleryPublisherClass))
#define PUBLISHING_GALLERY3_IS_GALLERY_PUBLISHER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_GALLERY3_TYPE_GALLERY_PUBLISHER))
#define PUBLISHING_GALLERY3_IS_GALLERY_PUBLISHER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_GALLERY3_TYPE_GALLERY_PUBLISHER))
#define PUBLISHING_GALLERY3_GALLERY_PUBLISHER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_GALLERY3_TYPE_GALLERY_PUBLISHER, PublishingGallery3GalleryPublisherClass))

typedef struct _PublishingGallery3GalleryPublisher PublishingGallery3GalleryPublisher;
typedef struct _PublishingGallery3GalleryPublisherClass PublishingGallery3GalleryPublisherClass;

#define PUBLISHING_GALLERY3_TYPE_ALBUM (publishing_gallery3_album_get_type ())
#define PUBLISHING_GALLERY3_ALBUM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_GALLERY3_TYPE_ALBUM, PublishingGallery3Album))
#define PUBLISHING_GALLERY3_ALBUM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_GALLERY3_TYPE_ALBUM, PublishingGallery3AlbumClass))
#define PUBLISHING_GALLERY3_IS_ALBUM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_GALLERY3_TYPE_ALBUM))
#define PUBLISHING_GALLERY3_IS_ALBUM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_GALLERY3_TYPE_ALBUM))
#define PUBLISHING_GALLERY3_ALBUM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_GALLERY3_TYPE_ALBUM, PublishingGallery3AlbumClass))

typedef struct _PublishingGallery3Album PublishingGallery3Album;
typedef struct _PublishingGallery3AlbumClass PublishingGallery3AlbumClass;
typedef struct _PublishingGallery3AlbumPrivate PublishingGallery3AlbumPrivate;
typedef struct _PublishingGallery3ParamSpecAlbum PublishingGallery3ParamSpecAlbum;

#define PUBLISHING_GALLERY3_TYPE_BASE_GALLERY_TRANSACTION (publishing_gallery3_base_gallery_transaction_get_type ())
#define PUBLISHING_GALLERY3_BASE_GALLERY_TRANSACTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_GALLERY3_TYPE_BASE_GALLERY_TRANSACTION, PublishingGallery3BaseGalleryTransaction))
#define PUBLISHING_GALLERY3_BASE_GALLERY_TRANSACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_GALLERY3_TYPE_BASE_GALLERY_TRANSACTION, PublishingGallery3BaseGalleryTransactionClass))
#define PUBLISHING_GALLERY3_IS_BASE_GALLERY_TRANSACTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_GALLERY3_TYPE_BASE_GALLERY_TRANSACTION))
#define PUBLISHING_GALLERY3_IS_BASE_GALLERY_TRANSACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_GALLERY3_TYPE_BASE_GALLERY_TRANSACTION))
#define PUBLISHING_GALLERY3_BASE_GALLERY_TRANSACTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_GALLERY3_TYPE_BASE_GALLERY_TRANSACTION, PublishingGallery3BaseGalleryTransactionClass))

typedef struct _PublishingGallery3BaseGalleryTransaction PublishingGallery3BaseGalleryTransaction;
typedef struct _PublishingGallery3BaseGalleryTransactionClass PublishingGallery3BaseGalleryTransactionClass;
typedef struct _PublishingGallery3BaseGalleryTransactionPrivate PublishingGallery3BaseGalleryTransactionPrivate;

#define PUBLISHING_GALLERY3_TYPE_SESSION (publishing_gallery3_session_get_type ())
#define PUBLISHING_GALLERY3_SESSION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_GALLERY3_TYPE_SESSION, PublishingGallery3Session))
#define PUBLISHING_GALLERY3_SESSION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_GALLERY3_TYPE_SESSION, PublishingGallery3SessionClass))
#define PUBLISHING_GALLERY3_IS_SESSION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_GALLERY3_TYPE_SESSION))
#define PUBLISHING_GALLERY3_IS_SESSION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_GALLERY3_TYPE_SESSION))
#define PUBLISHING_GALLERY3_SESSION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_GALLERY3_TYPE_SESSION, PublishingGallery3SessionClass))

typedef struct _PublishingGallery3Session PublishingGallery3Session;
typedef struct _PublishingGallery3SessionClass PublishingGallery3SessionClass;
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))

#define PUBLISHING_GALLERY3_TYPE_KEY_FETCH_TRANSACTION (publishing_gallery3_key_fetch_transaction_get_type ())
#define PUBLISHING_GALLERY3_KEY_FETCH_TRANSACTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_GALLERY3_TYPE_KEY_FETCH_TRANSACTION, PublishingGallery3KeyFetchTransaction))
#define PUBLISHING_GALLERY3_KEY_FETCH_TRANSACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_GALLERY3_TYPE_KEY_FETCH_TRANSACTION, PublishingGallery3KeyFetchTransactionClass))
#define PUBLISHING_GALLERY3_IS_KEY_FETCH_TRANSACTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_GALLERY3_TYPE_KEY_FETCH_TRANSACTION))
#define PUBLISHING_GALLERY3_IS_KEY_FETCH_TRANSACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_GALLERY3_TYPE_KEY_FETCH_TRANSACTION))
#define PUBLISHING_GALLERY3_KEY_FETCH_TRANSACTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_GALLERY3_TYPE_KEY_FETCH_TRANSACTION, PublishingGallery3KeyFetchTransactionClass))

typedef struct _PublishingGallery3KeyFetchTransaction PublishingGallery3KeyFetchTransaction;
typedef struct _PublishingGallery3KeyFetchTransactionClass PublishingGallery3KeyFetchTransactionClass;
typedef struct _PublishingGallery3KeyFetchTransactionPrivate PublishingGallery3KeyFetchTransactionPrivate;

#define PUBLISHING_GALLERY3_TYPE_GALLERY_REQUEST_TRANSACTION (publishing_gallery3_gallery_request_transaction_get_type ())
#define PUBLISHING_GALLERY3_GALLERY_REQUEST_TRANSACTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_GALLERY3_TYPE_GALLERY_REQUEST_TRANSACTION, PublishingGallery3GalleryRequestTransaction))
#define PUBLISHING_GALLERY3_GALLERY_REQUEST_TRANSACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_GALLERY3_TYPE_GALLERY_REQUEST_TRANSACTION, PublishingGallery3GalleryRequestTransactionClass))
#define PUBLISHING_GALLERY3_IS_GALLERY_REQUEST_TRANSACTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_GALLERY3_TYPE_GALLERY_REQUEST_TRANSACTION))
#define PUBLISHING_GALLERY3_IS_GALLERY_REQUEST_TRANSACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_GALLERY3_TYPE_GALLERY_REQUEST_TRANSACTION))
#define PUBLISHING_GALLERY3_GALLERY_REQUEST_TRANSACTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_GALLERY3_TYPE_GALLERY_REQUEST_TRANSACTION, PublishingGallery3GalleryRequestTransactionClass))

typedef struct _PublishingGallery3GalleryRequestTransaction PublishingGallery3GalleryRequestTransaction;
typedef struct _PublishingGallery3GalleryRequestTransactionClass PublishingGallery3GalleryRequestTransactionClass;
typedef struct _PublishingGallery3GalleryRequestTransactionPrivate PublishingGallery3GalleryRequestTransactionPrivate;

#define PUBLISHING_GALLERY3_TYPE_GET_ALBUM_UR_LS_TRANSACTION (publishing_gallery3_get_album_ur_ls_transaction_get_type ())
#define PUBLISHING_GALLERY3_GET_ALBUM_UR_LS_TRANSACTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_GALLERY3_TYPE_GET_ALBUM_UR_LS_TRANSACTION, PublishingGallery3GetAlbumURLsTransaction))
#define PUBLISHING_GALLERY3_GET_ALBUM_UR_LS_TRANSACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_GALLERY3_TYPE_GET_ALBUM_UR_LS_TRANSACTION, PublishingGallery3GetAlbumURLsTransactionClass))
#define PUBLISHING_GALLERY3_IS_GET_ALBUM_UR_LS_TRANSACTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_GALLERY3_TYPE_GET_ALBUM_UR_LS_TRANSACTION))
#define PUBLISHING_GALLERY3_IS_GET_ALBUM_UR_LS_TRANSACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_GALLERY3_TYPE_GET_ALBUM_UR_LS_TRANSACTION))
#define PUBLISHING_GALLERY3_GET_ALBUM_UR_LS_TRANSACTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_GALLERY3_TYPE_GET_ALBUM_UR_LS_TRANSACTION, PublishingGallery3GetAlbumURLsTransactionClass))

typedef struct _PublishingGallery3GetAlbumURLsTransaction PublishingGallery3GetAlbumURLsTransaction;
typedef struct _PublishingGallery3GetAlbumURLsTransactionClass PublishingGallery3GetAlbumURLsTransactionClass;
typedef struct _PublishingGallery3GetAlbumURLsTransactionPrivate PublishingGallery3GetAlbumURLsTransactionPrivate;

#define PUBLISHING_GALLERY3_TYPE_GET_ALBUMS_TRANSACTION (publishing_gallery3_get_albums_transaction_get_type ())
#define PUBLISHING_GALLERY3_GET_ALBUMS_TRANSACTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_GALLERY3_TYPE_GET_ALBUMS_TRANSACTION, PublishingGallery3GetAlbumsTransaction))
#define PUBLISHING_GALLERY3_GET_ALBUMS_TRANSACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_GALLERY3_TYPE_GET_ALBUMS_TRANSACTION, PublishingGallery3GetAlbumsTransactionClass))
#define PUBLISHING_GALLERY3_IS_GET_ALBUMS_TRANSACTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_GALLERY3_TYPE_GET_ALBUMS_TRANSACTION))
#define PUBLISHING_GALLERY3_IS_GET_ALBUMS_TRANSACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_GALLERY3_TYPE_GET_ALBUMS_TRANSACTION))
#define PUBLISHING_GALLERY3_GET_ALBUMS_TRANSACTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_GALLERY3_TYPE_GET_ALBUMS_TRANSACTION, PublishingGallery3GetAlbumsTransactionClass))

typedef struct _PublishingGallery3GetAlbumsTransaction PublishingGallery3GetAlbumsTransaction;
typedef struct _PublishingGallery3GetAlbumsTransactionClass PublishingGallery3GetAlbumsTransactionClass;
typedef struct _PublishingGallery3GetAlbumsTransactionPrivate PublishingGallery3GetAlbumsTransactionPrivate;
#define _publishing_gallery3_album_unref0(var) ((var == NULL) ? NULL : (var = (publishing_gallery3_album_unref (var), NULL)))

#define PUBLISHING_GALLERY3_TYPE_GALLERY_GET_TAG_TRANSACTION (publishing_gallery3_gallery_get_tag_transaction_get_type ())
#define PUBLISHING_GALLERY3_GALLERY_GET_TAG_TRANSACTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_GALLERY3_TYPE_GALLERY_GET_TAG_TRANSACTION, PublishingGallery3GalleryGetTagTransaction))
#define PUBLISHING_GALLERY3_GALLERY_GET_TAG_TRANSACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_GALLERY3_TYPE_GALLERY_GET_TAG_TRANSACTION, PublishingGallery3GalleryGetTagTransactionClass))
#define PUBLISHING_GALLERY3_IS_GALLERY_GET_TAG_TRANSACTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_GALLERY3_TYPE_GALLERY_GET_TAG_TRANSACTION))
#define PUBLISHING_GALLERY3_IS_GALLERY_GET_TAG_TRANSACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_GALLERY3_TYPE_GALLERY_GET_TAG_TRANSACTION))
#define PUBLISHING_GALLERY3_GALLERY_GET_TAG_TRANSACTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_GALLERY3_TYPE_GALLERY_GET_TAG_TRANSACTION, PublishingGallery3GalleryGetTagTransactionClass))

typedef struct _PublishingGallery3GalleryGetTagTransaction PublishingGallery3GalleryGetTagTransaction;
typedef struct _PublishingGallery3GalleryGetTagTransactionClass PublishingGallery3GalleryGetTagTransactionClass;
typedef struct _PublishingGallery3GalleryGetTagTransactionPrivate PublishingGallery3GalleryGetTagTransactionPrivate;
#define _json_object_unref0(var) ((var == NULL) ? NULL : (var = (json_object_unref (var), NULL)))
#define __vala_JsonNode_free0(var) ((var == NULL) ? NULL : (var = (_vala_JsonNode_free (var), NULL)))

#define PUBLISHING_GALLERY3_TYPE_GALLERY_GET_ITEM_TAGS_UR_LS_TRANSACTION (publishing_gallery3_gallery_get_item_tags_ur_ls_transaction_get_type ())
#define PUBLISHING_GALLERY3_GALLERY_GET_ITEM_TAGS_UR_LS_TRANSACTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_GALLERY3_TYPE_GALLERY_GET_ITEM_TAGS_UR_LS_TRANSACTION, PublishingGallery3GalleryGetItemTagsURLsTransaction))
#define PUBLISHING_GALLERY3_GALLERY_GET_ITEM_TAGS_UR_LS_TRANSACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_GALLERY3_TYPE_GALLERY_GET_ITEM_TAGS_UR_LS_TRANSACTION, PublishingGallery3GalleryGetItemTagsURLsTransactionClass))
#define PUBLISHING_GALLERY3_IS_GALLERY_GET_ITEM_TAGS_UR_LS_TRANSACTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_GALLERY3_TYPE_GALLERY_GET_ITEM_TAGS_UR_LS_TRANSACTION))
#define PUBLISHING_GALLERY3_IS_GALLERY_GET_ITEM_TAGS_UR_LS_TRANSACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_GALLERY3_TYPE_GALLERY_GET_ITEM_TAGS_UR_LS_TRANSACTION))
#define PUBLISHING_GALLERY3_GALLERY_GET_ITEM_TAGS_UR_LS_TRANSACTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_GALLERY3_TYPE_GALLERY_GET_ITEM_TAGS_UR_LS_TRANSACTION, PublishingGallery3GalleryGetItemTagsURLsTransactionClass))

typedef struct _PublishingGallery3GalleryGetItemTagsURLsTransaction PublishingGallery3GalleryGetItemTagsURLsTransaction;
typedef struct _PublishingGallery3GalleryGetItemTagsURLsTransactionClass PublishingGallery3GalleryGetItemTagsURLsTransactionClass;
typedef struct _PublishingGallery3GalleryGetItemTagsURLsTransactionPrivate PublishingGallery3GalleryGetItemTagsURLsTransactionPrivate;

#define PUBLISHING_GALLERY3_TYPE_GALLERY_SET_TAG_RELATIONSHIP_TRANSACTION (publishing_gallery3_gallery_set_tag_relationship_transaction_get_type ())
#define PUBLISHING_GALLERY3_GALLERY_SET_TAG_RELATIONSHIP_TRANSACTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_GALLERY3_TYPE_GALLERY_SET_TAG_RELATIONSHIP_TRANSACTION, PublishingGallery3GallerySetTagRelationshipTransaction))
#define PUBLISHING_GALLERY3_GALLERY_SET_TAG_RELATIONSHIP_TRANSACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_GALLERY3_TYPE_GALLERY_SET_TAG_RELATIONSHIP_TRANSACTION, PublishingGallery3GallerySetTagRelationshipTransactionClass))
#define PUBLISHING_GALLERY3_IS_GALLERY_SET_TAG_RELATIONSHIP_TRANSACTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_GALLERY3_TYPE_GALLERY_SET_TAG_RELATIONSHIP_TRANSACTION))
#define PUBLISHING_GALLERY3_IS_GALLERY_SET_TAG_RELATIONSHIP_TRANSACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_GALLERY3_TYPE_GALLERY_SET_TAG_RELATIONSHIP_TRANSACTION))
#define PUBLISHING_GALLERY3_GALLERY_SET_TAG_RELATIONSHIP_TRANSACTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_GALLERY3_TYPE_GALLERY_SET_TAG_RELATIONSHIP_TRANSACTION, PublishingGallery3GallerySetTagRelationshipTransactionClass))

typedef struct _PublishingGallery3GallerySetTagRelationshipTransaction PublishingGallery3GallerySetTagRelationshipTransaction;
typedef struct _PublishingGallery3GallerySetTagRelationshipTransactionClass PublishingGallery3GallerySetTagRelationshipTransactionClass;
typedef struct _PublishingGallery3GallerySetTagRelationshipTransactionPrivate PublishingGallery3GallerySetTagRelationshipTransactionPrivate;

#define PUBLISHING_GALLERY3_TYPE_GALLERY_ALBUM_CREATE_TRANSACTION (publishing_gallery3_gallery_album_create_transaction_get_type ())
#define PUBLISHING_GALLERY3_GALLERY_ALBUM_CREATE_TRANSACTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_GALLERY3_TYPE_GALLERY_ALBUM_CREATE_TRANSACTION, PublishingGallery3GalleryAlbumCreateTransaction))
#define PUBLISHING_GALLERY3_GALLERY_ALBUM_CREATE_TRANSACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_GALLERY3_TYPE_GALLERY_ALBUM_CREATE_TRANSACTION, PublishingGallery3GalleryAlbumCreateTransactionClass))
#define PUBLISHING_GALLERY3_IS_GALLERY_ALBUM_CREATE_TRANSACTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_GALLERY3_TYPE_GALLERY_ALBUM_CREATE_TRANSACTION))
#define PUBLISHING_GALLERY3_IS_GALLERY_ALBUM_CREATE_TRANSACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_GALLERY3_TYPE_GALLERY_ALBUM_CREATE_TRANSACTION))
#define PUBLISHING_GALLERY3_GALLERY_ALBUM_CREATE_TRANSACTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_GALLERY3_TYPE_GALLERY_ALBUM_CREATE_TRANSACTION, PublishingGallery3GalleryAlbumCreateTransactionClass))

typedef struct _PublishingGallery3GalleryAlbumCreateTransaction PublishingGallery3GalleryAlbumCreateTransaction;
typedef struct _PublishingGallery3GalleryAlbumCreateTransactionClass PublishingGallery3GalleryAlbumCreateTransactionClass;
typedef struct _PublishingGallery3GalleryAlbumCreateTransactionPrivate PublishingGallery3GalleryAlbumCreateTransactionPrivate;

#define PUBLISHING_GALLERY3_TYPE_PUBLISHING_PARAMETERS (publishing_gallery3_publishing_parameters_get_type ())
#define PUBLISHING_GALLERY3_PUBLISHING_PARAMETERS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_GALLERY3_TYPE_PUBLISHING_PARAMETERS, PublishingGallery3PublishingParameters))
#define PUBLISHING_GALLERY3_PUBLISHING_PARAMETERS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_GALLERY3_TYPE_PUBLISHING_PARAMETERS, PublishingGallery3PublishingParametersClass))
#define PUBLISHING_GALLERY3_IS_PUBLISHING_PARAMETERS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_GALLERY3_TYPE_PUBLISHING_PARAMETERS))
#define PUBLISHING_GALLERY3_IS_PUBLISHING_PARAMETERS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_GALLERY3_TYPE_PUBLISHING_PARAMETERS))
#define PUBLISHING_GALLERY3_PUBLISHING_PARAMETERS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_GALLERY3_TYPE_PUBLISHING_PARAMETERS, PublishingGallery3PublishingParametersClass))

typedef struct _PublishingGallery3PublishingParameters PublishingGallery3PublishingParameters;
typedef struct _PublishingGallery3PublishingParametersClass PublishingGallery3PublishingParametersClass;
#define _publishing_gallery3_publishing_parameters_unref0(var) ((var == NULL) ? NULL : (var = (publishing_gallery3_publishing_parameters_unref (var), NULL)))

#define PUBLISHING_GALLERY3_TYPE_GALLERY_UPLOAD_TRANSACTION (publishing_gallery3_gallery_upload_transaction_get_type ())
#define PUBLISHING_GALLERY3_GALLERY_UPLOAD_TRANSACTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_GALLERY3_TYPE_GALLERY_UPLOAD_TRANSACTION, PublishingGallery3GalleryUploadTransaction))
#define PUBLISHING_GALLERY3_GALLERY_UPLOAD_TRANSACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_GALLERY3_TYPE_GALLERY_UPLOAD_TRANSACTION, PublishingGallery3GalleryUploadTransactionClass))
#define PUBLISHING_GALLERY3_IS_GALLERY_UPLOAD_TRANSACTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_GALLERY3_TYPE_GALLERY_UPLOAD_TRANSACTION))
#define PUBLISHING_GALLERY3_IS_GALLERY_UPLOAD_TRANSACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_GALLERY3_TYPE_GALLERY_UPLOAD_TRANSACTION))
#define PUBLISHING_GALLERY3_GALLERY_UPLOAD_TRANSACTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_GALLERY3_TYPE_GALLERY_UPLOAD_TRANSACTION, PublishingGallery3GalleryUploadTransactionClass))

typedef struct _PublishingGallery3GalleryUploadTransaction PublishingGallery3GalleryUploadTransaction;
typedef struct _PublishingGallery3GalleryUploadTransactionClass PublishingGallery3GalleryUploadTransactionClass;
typedef struct _PublishingGallery3GalleryUploadTransactionPrivate PublishingGallery3GalleryUploadTransactionPrivate;
#define _publishing_rest_support_session_unref0(var) ((var == NULL) ? NULL : (var = (publishing_rest_support_session_unref (var), NULL)))
#define _g_hash_table_unref0(var) ((var == NULL) ? NULL : (var = (g_hash_table_unref (var), NULL)))
#define _publishing_rest_support_transaction_unref0(var) ((var == NULL) ? NULL : (var = (publishing_rest_support_transaction_unref (var), NULL)))
typedef struct _PublishingGallery3GalleryPublisherPrivate PublishingGallery3GalleryPublisherPrivate;

#define PUBLISHING_GALLERY3_TYPE_PUBLISHING_OPTIONS_PANE (publishing_gallery3_publishing_options_pane_get_type ())
#define PUBLISHING_GALLERY3_PUBLISHING_OPTIONS_PANE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_GALLERY3_TYPE_PUBLISHING_OPTIONS_PANE, PublishingGallery3PublishingOptionsPane))
#define PUBLISHING_GALLERY3_PUBLISHING_OPTIONS_PANE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_GALLERY3_TYPE_PUBLISHING_OPTIONS_PANE, PublishingGallery3PublishingOptionsPaneClass))
#define PUBLISHING_GALLERY3_IS_PUBLISHING_OPTIONS_PANE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_GALLERY3_TYPE_PUBLISHING_OPTIONS_PANE))
#define PUBLISHING_GALLERY3_IS_PUBLISHING_OPTIONS_PANE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_GALLERY3_TYPE_PUBLISHING_OPTIONS_PANE))
#define PUBLISHING_GALLERY3_PUBLISHING_OPTIONS_PANE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_GALLERY3_TYPE_PUBLISHING_OPTIONS_PANE, PublishingGallery3PublishingOptionsPaneClass))

typedef struct _PublishingGallery3PublishingOptionsPane PublishingGallery3PublishingOptionsPane;
typedef struct _PublishingGallery3PublishingOptionsPaneClass PublishingGallery3PublishingOptionsPaneClass;
enum  {
	PUBLISHING_GALLERY3_GALLERY_PUBLISHER_0_PROPERTY,
	PUBLISHING_GALLERY3_GALLERY_PUBLISHER_NUM_PROPERTIES
};
static GParamSpec* publishing_gallery3_gallery_publisher_properties[PUBLISHING_GALLERY3_GALLERY_PUBLISHER_NUM_PROPERTIES];

#define PUBLISHING_GALLERY3_CREDENTIALS_PANE_TYPE_MODE (publishing_gallery3_credentials_pane_mode_get_type ())

#define PUBLISHING_GALLERY3_TYPE_CREDENTIALS_PANE (publishing_gallery3_credentials_pane_get_type ())
#define PUBLISHING_GALLERY3_CREDENTIALS_PANE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_GALLERY3_TYPE_CREDENTIALS_PANE, PublishingGallery3CredentialsPane))
#define PUBLISHING_GALLERY3_CREDENTIALS_PANE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_GALLERY3_TYPE_CREDENTIALS_PANE, PublishingGallery3CredentialsPaneClass))
#define PUBLISHING_GALLERY3_IS_CREDENTIALS_PANE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_GALLERY3_TYPE_CREDENTIALS_PANE))
#define PUBLISHING_GALLERY3_IS_CREDENTIALS_PANE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_GALLERY3_TYPE_CREDENTIALS_PANE))
#define PUBLISHING_GALLERY3_CREDENTIALS_PANE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_GALLERY3_TYPE_CREDENTIALS_PANE, PublishingGallery3CredentialsPaneClass))

typedef struct _PublishingGallery3CredentialsPane PublishingGallery3CredentialsPane;
typedef struct _PublishingGallery3CredentialsPaneClass PublishingGallery3CredentialsPaneClass;

#define PUBLISHING_GALLERY3_TYPE_UPLOADER (publishing_gallery3_uploader_get_type ())
#define PUBLISHING_GALLERY3_UPLOADER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_GALLERY3_TYPE_UPLOADER, PublishingGallery3Uploader))
#define PUBLISHING_GALLERY3_UPLOADER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_GALLERY3_TYPE_UPLOADER, PublishingGallery3UploaderClass))
#define PUBLISHING_GALLERY3_IS_UPLOADER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_GALLERY3_TYPE_UPLOADER))
#define PUBLISHING_GALLERY3_IS_UPLOADER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_GALLERY3_TYPE_UPLOADER))
#define PUBLISHING_GALLERY3_UPLOADER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_GALLERY3_TYPE_UPLOADER, PublishingGallery3UploaderClass))

typedef struct _PublishingGallery3Uploader PublishingGallery3Uploader;
typedef struct _PublishingGallery3UploaderClass PublishingGallery3UploaderClass;
#define _publishing_rest_support_batch_uploader_unref0(var) ((var == NULL) ? NULL : (var = (publishing_rest_support_batch_uploader_unref (var), NULL)))
typedef struct _PublishingGallery3PublishingOptionsPanePrivate PublishingGallery3PublishingOptionsPanePrivate;
enum  {
	PUBLISHING_GALLERY3_PUBLISHING_OPTIONS_PANE_0_PROPERTY,
	PUBLISHING_GALLERY3_PUBLISHING_OPTIONS_PANE_NUM_PROPERTIES
};
static GParamSpec* publishing_gallery3_publishing_options_pane_properties[PUBLISHING_GALLERY3_PUBLISHING_OPTIONS_PANE_NUM_PROPERTIES];
#define _g_slist_free0(var) ((var == NULL) ? NULL : (var = (g_slist_free (var), NULL)))
enum  {
	PUBLISHING_GALLERY3_PUBLISHING_OPTIONS_PANE_PUBLISH_SIGNAL,
	PUBLISHING_GALLERY3_PUBLISHING_OPTIONS_PANE_LOGOUT_SIGNAL,
	PUBLISHING_GALLERY3_PUBLISHING_OPTIONS_PANE_NUM_SIGNALS
};
static guint publishing_gallery3_publishing_options_pane_signals[PUBLISHING_GALLERY3_PUBLISHING_OPTIONS_PANE_NUM_SIGNALS] = {0};
typedef struct _PublishingGallery3PublishingParametersPrivate PublishingGallery3PublishingParametersPrivate;
typedef struct _PublishingGallery3ParamSpecPublishingParameters PublishingGallery3ParamSpecPublishingParameters;
typedef struct _PublishingGallery3CredentialsPanePrivate PublishingGallery3CredentialsPanePrivate;

#define PUBLISHING_GALLERY3_TYPE_CREDENTIALS_GRID (publishing_gallery3_credentials_grid_get_type ())
#define PUBLISHING_GALLERY3_CREDENTIALS_GRID(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_GALLERY3_TYPE_CREDENTIALS_GRID, PublishingGallery3CredentialsGrid))
#define PUBLISHING_GALLERY3_CREDENTIALS_GRID_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_GALLERY3_TYPE_CREDENTIALS_GRID, PublishingGallery3CredentialsGridClass))
#define PUBLISHING_GALLERY3_IS_CREDENTIALS_GRID(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_GALLERY3_TYPE_CREDENTIALS_GRID))
#define PUBLISHING_GALLERY3_IS_CREDENTIALS_GRID_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_GALLERY3_TYPE_CREDENTIALS_GRID))
#define PUBLISHING_GALLERY3_CREDENTIALS_GRID_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_GALLERY3_TYPE_CREDENTIALS_GRID, PublishingGallery3CredentialsGridClass))

typedef struct _PublishingGallery3CredentialsGrid PublishingGallery3CredentialsGrid;
typedef struct _PublishingGallery3CredentialsGridClass PublishingGallery3CredentialsGridClass;
enum  {
	PUBLISHING_GALLERY3_CREDENTIALS_PANE_0_PROPERTY,
	PUBLISHING_GALLERY3_CREDENTIALS_PANE_NUM_PROPERTIES
};
static GParamSpec* publishing_gallery3_credentials_pane_properties[PUBLISHING_GALLERY3_CREDENTIALS_PANE_NUM_PROPERTIES];
enum  {
	PUBLISHING_GALLERY3_CREDENTIALS_PANE_GO_BACK_SIGNAL,
	PUBLISHING_GALLERY3_CREDENTIALS_PANE_LOGIN_SIGNAL,
	PUBLISHING_GALLERY3_CREDENTIALS_PANE_NUM_SIGNALS
};
static guint publishing_gallery3_credentials_pane_signals[PUBLISHING_GALLERY3_CREDENTIALS_PANE_NUM_SIGNALS] = {0};
typedef struct _PublishingGallery3CredentialsGridPrivate PublishingGallery3CredentialsGridPrivate;
enum  {
	PUBLISHING_GALLERY3_CREDENTIALS_GRID_0_PROPERTY,
	PUBLISHING_GALLERY3_CREDENTIALS_GRID_PANE_WIDGET_PROPERTY,
	PUBLISHING_GALLERY3_CREDENTIALS_GRID_NUM_PROPERTIES
};
static GParamSpec* publishing_gallery3_credentials_grid_properties[PUBLISHING_GALLERY3_CREDENTIALS_GRID_NUM_PROPERTIES];
enum  {
	PUBLISHING_GALLERY3_CREDENTIALS_GRID_GO_BACK_SIGNAL,
	PUBLISHING_GALLERY3_CREDENTIALS_GRID_LOGIN_SIGNAL,
	PUBLISHING_GALLERY3_CREDENTIALS_GRID_NUM_SIGNALS
};
static guint publishing_gallery3_credentials_grid_signals[PUBLISHING_GALLERY3_CREDENTIALS_GRID_NUM_SIGNALS] = {0};
typedef struct _PublishingGallery3SessionPrivate PublishingGallery3SessionPrivate;
typedef struct _PublishingGallery3UploaderPrivate PublishingGallery3UploaderPrivate;
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);
#define _vala_return_if_fail(expr, msg) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return; }
#define _vala_return_val_if_fail(expr, msg, val) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return val; }
#define _vala_warn_if_fail(expr, msg) if G_LIKELY (expr) ; else g_warn_message (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _ShotwellPublishingGallery3 {
	GObject parent_instance;
	ShotwellPublishingGallery3Private * priv;
};

struct _ShotwellPublishingGallery3Class {
	GObjectClass parent_class;
};

struct _ShotwellPublishingGallery3Private {
	SpitPluggable** pluggables;
	gint pluggables_length1;
	gint _pluggables_size_;
};

struct _Gallery3Service {
	GObject parent_instance;
	Gallery3ServicePrivate * priv;
};

struct _Gallery3ServiceClass {
	GObjectClass parent_class;
};

struct _PublishingGallery3Album {
	GTypeInstance parent_instance;
	volatile int ref_count;
	PublishingGallery3AlbumPrivate * priv;
};

struct _PublishingGallery3AlbumClass {
	GTypeClass parent_class;
	void (*finalize) (PublishingGallery3Album *self);
};

struct _PublishingGallery3AlbumPrivate {
	gchar* _name;
	gchar* _title;
	gchar* _summary;
	gchar* _parentname;
	gchar* _url;
	gchar* _path;
	gboolean _editable;
};

struct _PublishingGallery3ParamSpecAlbum {
	GParamSpec parent_instance;
};

struct _PublishingGallery3BaseGalleryTransaction {
	PublishingRESTSupportTransaction parent_instance;
	PublishingGallery3BaseGalleryTransactionPrivate * priv;
	JsonParser* parser;
};

struct _PublishingGallery3BaseGalleryTransactionClass {
	PublishingRESTSupportTransactionClass parent_class;
};

struct _PublishingGallery3KeyFetchTransaction {
	PublishingGallery3BaseGalleryTransaction parent_instance;
	PublishingGallery3KeyFetchTransactionPrivate * priv;
};

struct _PublishingGallery3KeyFetchTransactionClass {
	PublishingGallery3BaseGalleryTransactionClass parent_class;
};

struct _PublishingGallery3KeyFetchTransactionPrivate {
	gchar* key;
};

struct _PublishingGallery3GalleryRequestTransaction {
	PublishingGallery3BaseGalleryTransaction parent_instance;
	PublishingGallery3GalleryRequestTransactionPrivate * priv;
};

struct _PublishingGallery3GalleryRequestTransactionClass {
	PublishingGallery3BaseGalleryTransactionClass parent_class;
};

struct _PublishingGallery3GetAlbumURLsTransaction {
	PublishingGallery3GalleryRequestTransaction parent_instance;
	PublishingGallery3GetAlbumURLsTransactionPrivate * priv;
};

struct _PublishingGallery3GetAlbumURLsTransactionClass {
	PublishingGallery3GalleryRequestTransactionClass parent_class;
};

struct _PublishingGallery3GetAlbumsTransaction {
	PublishingGallery3GalleryRequestTransaction parent_instance;
	PublishingGallery3GetAlbumsTransactionPrivate * priv;
};

struct _PublishingGallery3GetAlbumsTransactionClass {
	PublishingGallery3GalleryRequestTransactionClass parent_class;
};

struct _PublishingGallery3GetAlbumsTransactionPrivate {
	gchar** _album_urls;
	gint _album_urls_length1;
	gint __album_urls_size_;
	guint _urls_sent;
	gboolean _more_urls;
};

struct _PublishingGallery3GalleryGetTagTransaction {
	PublishingGallery3BaseGalleryTransaction parent_instance;
	PublishingGallery3GalleryGetTagTransactionPrivate * priv;
};

struct _PublishingGallery3GalleryGetTagTransactionClass {
	PublishingGallery3BaseGalleryTransactionClass parent_class;
};

struct _PublishingGallery3GalleryGetItemTagsURLsTransaction {
	PublishingGallery3GalleryRequestTransaction parent_instance;
	PublishingGallery3GalleryGetItemTagsURLsTransactionPrivate * priv;
};

struct _PublishingGallery3GalleryGetItemTagsURLsTransactionClass {
	PublishingGallery3GalleryRequestTransactionClass parent_class;
};

struct _PublishingGallery3GalleryGetItemTagsURLsTransactionPrivate {
	gchar* item_tags_path;
};

struct _PublishingGallery3GallerySetTagRelationshipTransaction {
	PublishingGallery3BaseGalleryTransaction parent_instance;
	PublishingGallery3GallerySetTagRelationshipTransactionPrivate * priv;
};

struct _PublishingGallery3GallerySetTagRelationshipTransactionClass {
	PublishingGallery3BaseGalleryTransactionClass parent_class;
};

struct _PublishingGallery3GalleryAlbumCreateTransaction {
	PublishingGallery3BaseGalleryTransaction parent_instance;
	PublishingGallery3GalleryAlbumCreateTransactionPrivate * priv;
};

struct _PublishingGallery3GalleryAlbumCreateTransactionClass {
	PublishingGallery3BaseGalleryTransactionClass parent_class;
};

struct _PublishingGallery3GalleryAlbumCreateTransactionPrivate {
	PublishingGallery3PublishingParameters* _parameters;
	gchar* session_url;
};

struct _PublishingGallery3GalleryUploadTransaction {
	PublishingRESTSupportUploadTransaction parent_instance;
	PublishingGallery3GalleryUploadTransactionPrivate * priv;
};

struct _PublishingGallery3GalleryUploadTransactionClass {
	PublishingRESTSupportUploadTransactionClass parent_class;
};

struct _PublishingGallery3GalleryUploadTransactionPrivate {
	PublishingGallery3Session* session;
	JsonGenerator* generator;
	PublishingGallery3PublishingParameters* parameters;
	gchar* item_url;
	gchar* item_path;
	gchar* item_tags_path;
};

struct _PublishingGallery3GalleryPublisher {
	GObject parent_instance;
	PublishingGallery3GalleryPublisherPrivate * priv;
};

struct _PublishingGallery3GalleryPublisherClass {
	GObjectClass parent_class;
};

struct _PublishingGallery3GalleryPublisherPrivate {
	SpitPublishingPluginHost* host;
	SpitPublishingProgressCallback progress_reporter;
	gpointer progress_reporter_target;
	GDestroyNotify progress_reporter_target_destroy_notify;
	SpitPublishingService* service;
	PublishingGallery3Session* session;
	gboolean running;
	PublishingGallery3Album** albums;
	gint albums_length1;
	gint _albums_size_;
	gchar* key;
	PublishingGallery3PublishingOptionsPane* publishing_options_pane;
};

typedef enum  {
	PUBLISHING_GALLERY3_CREDENTIALS_PANE_MODE_INTRO,
	PUBLISHING_GALLERY3_CREDENTIALS_PANE_MODE_FAILED_RETRY,
	PUBLISHING_GALLERY3_CREDENTIALS_PANE_MODE_NOT_GALLERY_URL
} PublishingGallery3CredentialsPaneMode;

struct _PublishingGallery3PublishingOptionsPane {
	GObject parent_instance;
	PublishingGallery3PublishingOptionsPanePrivate * priv;
};

struct _PublishingGallery3PublishingOptionsPaneClass {
	GObjectClass parent_class;
};

struct _PublishingGallery3PublishingOptionsPanePrivate {
	GtkBuilder* builder;
	GtkGrid* pane_widget;
	GtkLabel* title_label;
	GtkRadioButton* use_existing_radio;
	GtkComboBoxText* existing_albums_combo;
	GtkRadioButton* create_new_radio;
	GtkEntry* new_album_entry;
	GtkComboBoxText* scaling_combo;
	GtkEntry* pixels;
	GtkCheckButton* strip_metadata_check;
	GtkButton* publish_button;
	GtkButton* logout_button;
	PublishingGallery3Album** albums;
	gint albums_length1;
	gint _albums_size_;
	SpitPublishingPluginHost* host;
};

struct _PublishingGallery3PublishingParameters {
	GTypeInstance parent_instance;
	volatile int ref_count;
	PublishingGallery3PublishingParametersPrivate * priv;
};

struct _PublishingGallery3PublishingParametersClass {
	GTypeClass parent_class;
	void (*finalize) (PublishingGallery3PublishingParameters *self);
};

struct _PublishingGallery3PublishingParametersPrivate {
	gchar* _album_title;
	gchar* _album_name;
	gchar* _album_path;
	gchar* _entity_title;
	gint _photo_major_axis_size;
	gboolean _strip_metadata;
};

struct _PublishingGallery3ParamSpecPublishingParameters {
	GParamSpec parent_instance;
};

struct _PublishingGallery3CredentialsPane {
	GObject parent_instance;
	PublishingGallery3CredentialsPanePrivate * priv;
};

struct _PublishingGallery3CredentialsPaneClass {
	GObjectClass parent_class;
};

struct _PublishingGallery3CredentialsPanePrivate {
	PublishingGallery3CredentialsGrid* frame;
	GtkWidget* grid_widget;
};

struct _PublishingGallery3CredentialsGrid {
	GObject parent_instance;
	PublishingGallery3CredentialsGridPrivate * priv;
};

struct _PublishingGallery3CredentialsGridClass {
	GObjectClass parent_class;
};

struct _PublishingGallery3CredentialsGridPrivate {
	GtkGrid* _pane_widget;
	SpitPublishingPluginHost* host;
	GtkBuilder* builder;
	GtkLabel* intro_message_label;
	GtkEntry* url_entry;
	GtkEntry* username_entry;
	GtkEntry* password_entry;
	GtkEntry* key_entry;
	GtkButton* login_button;
	GtkButton* go_back_button;
	gchar* url;
	gchar* username;
	gchar* key;
};

struct _PublishingGallery3Session {
	PublishingRESTSupportSession parent_instance;
	PublishingGallery3SessionPrivate * priv;
};

struct _PublishingGallery3SessionClass {
	PublishingRESTSupportSessionClass parent_class;
};

struct _PublishingGallery3SessionPrivate {
	gchar* _url;
	gchar* _username;
	gchar* _key;
};

struct _PublishingGallery3Uploader {
	PublishingRESTSupportBatchUploader parent_instance;
	PublishingGallery3UploaderPrivate * priv;
};

struct _PublishingGallery3UploaderClass {
	PublishingRESTSupportBatchUploaderClass parent_class;
};

struct _PublishingGallery3UploaderPrivate {
	PublishingGallery3PublishingParameters* parameters;
	gchar* _current_publishable_name;
	SpitPublishingPublisherMediaType _current_media_type;
	PublishingRESTSupportTransaction* _current_transaction;
};


static gpointer shotwell_publishing_gallery3_parent_class = NULL;
static SpitModuleIface * shotwell_publishing_gallery3_spit_module_parent_iface = NULL;
static gpointer gallery3_service_parent_class = NULL;
static GdkPixbuf** gallery3_service_icon_pixbuf_set;
static gint gallery3_service_icon_pixbuf_set_length1;
static GdkPixbuf** gallery3_service_icon_pixbuf_set = NULL;
static gint gallery3_service_icon_pixbuf_set_length1 = 0;
static gint _gallery3_service_icon_pixbuf_set_size_ = 0;
static SpitPluggableIface * gallery3_service_spit_pluggable_parent_iface = NULL;
static SpitPublishingServiceIface * gallery3_service_spit_publishing_service_parent_iface = NULL;
static gpointer publishing_gallery3_album_parent_class = NULL;
static gpointer publishing_gallery3_base_gallery_transaction_parent_class = NULL;
static gpointer publishing_gallery3_key_fetch_transaction_parent_class = NULL;
static gpointer publishing_gallery3_gallery_request_transaction_parent_class = NULL;
static gpointer publishing_gallery3_get_album_ur_ls_transaction_parent_class = NULL;
static gpointer publishing_gallery3_get_albums_transaction_parent_class = NULL;
static gpointer publishing_gallery3_gallery_get_tag_transaction_parent_class = NULL;
static gpointer publishing_gallery3_gallery_get_item_tags_ur_ls_transaction_parent_class = NULL;
static gpointer publishing_gallery3_gallery_set_tag_relationship_transaction_parent_class = NULL;
static gpointer publishing_gallery3_gallery_album_create_transaction_parent_class = NULL;
static gpointer publishing_gallery3_gallery_upload_transaction_parent_class = NULL;
static gpointer publishing_gallery3_gallery_publisher_parent_class = NULL;
static SpitPublishingPublisherIface * publishing_gallery3_gallery_publisher_spit_publishing_publisher_parent_iface = NULL;
static gpointer publishing_gallery3_publishing_options_pane_parent_class = NULL;
static SpitPublishingDialogPaneIface * publishing_gallery3_publishing_options_pane_spit_publishing_dialog_pane_parent_iface = NULL;
static gpointer publishing_gallery3_publishing_parameters_parent_class = NULL;
static gpointer publishing_gallery3_credentials_pane_parent_class = NULL;
static SpitPublishingDialogPaneIface * publishing_gallery3_credentials_pane_spit_publishing_dialog_pane_parent_iface = NULL;
static gpointer publishing_gallery3_credentials_grid_parent_class = NULL;
static gpointer publishing_gallery3_session_parent_class = NULL;
static gpointer publishing_gallery3_uploader_parent_class = NULL;

#define G3_VERSION "0.1"
#define G3_LICENSE "\n" \
"The Gallery3Publishing module is free software; you can redistribute i" \
"t\n" \
"and/or modify it under the terms of the GNU Lesser General Public\n" \
"License as published by the Free Software Foundation; either version 2" \
".1\n" \
"of the License, or (at your option) any later version.\n" \
"\n" \
"The Gallery3Publishing module is distributed in the hope that it will " \
"be\n" \
"useful, but WITHOUT ANY WARRANTY; without even the implied warranty of" \
"\n" \
"MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Less" \
"er\n" \
"General Public License for more details.\n" \
"\n" \
"You should have received a copy of the GNU Lesser General Public Licen" \
"se\n" \
"along with The Gallery3Publishing module; if not, write to the Free\n" \
"Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA\n" \
"02110-1301 USA\n"
#define WEBSITE_URL "https://github.com/sappjw/shotwell-gallery3"
GType shotwell_publishing_gallery3_get_type (void) G_GNUC_CONST;
#define SHOTWELL_PUBLISHING_GALLERY3_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_SHOTWELL_PUBLISHING_GALLERY3, ShotwellPublishingGallery3Private))
ShotwellPublishingGallery3* shotwell_publishing_gallery3_new (GFile* module_file);
ShotwellPublishingGallery3* shotwell_publishing_gallery3_construct (GType object_type,
                                                                    GFile* module_file);
Gallery3Service* gallery3_service_new (GFile* resource_directory);
Gallery3Service* gallery3_service_construct (GType object_type,
                                             GFile* resource_directory);
GType gallery3_service_get_type (void) G_GNUC_CONST;
static void _vala_array_add1 (SpitPluggable** * array,
                       int* length,
                       int* size,
                       SpitPluggable* value);
static const gchar* shotwell_publishing_gallery3_real_get_module_name (SpitModule* base);
static const gchar* shotwell_publishing_gallery3_real_get_version (SpitModule* base);
static const gchar* shotwell_publishing_gallery3_real_get_id (SpitModule* base);
static SpitPluggable** shotwell_publishing_gallery3_real_get_pluggables (SpitModule* base,
                                                                  int* result_length1);
static void shotwell_publishing_gallery3_finalize (GObject * obj);
#define GALLERY3_SERVICE_ICON_FILENAME "gallery3.png"
static gint gallery3_service_real_get_pluggable_interface (SpitPluggable* base,
                                                    gint min_host_interface,
                                                    gint max_host_interface);
static const gchar* gallery3_service_real_get_id (SpitPluggable* base);
static const gchar* gallery3_service_real_get_pluggable_name (SpitPluggable* base);
static void gallery3_service_real_get_info (SpitPluggable* base,
                                     SpitPluggableInfo* info);
static GdkPixbuf** _vala_array_dup1 (GdkPixbuf** self,
                              int length);
static void gallery3_service_real_activation (SpitPluggable* base,
                                       gboolean enabled);
static SpitPublishingPublisher* gallery3_service_real_create_publisher (SpitPublishingService* base,
                                                                 SpitPublishingPluginHost* host);
PublishingGallery3GalleryPublisher* publishing_gallery3_gallery_publisher_new (SpitPublishingService* service,
                                                                               SpitPublishingPluginHost* host);
PublishingGallery3GalleryPublisher* publishing_gallery3_gallery_publisher_construct (GType object_type,
                                                                                     SpitPublishingService* service,
                                                                                     SpitPublishingPluginHost* host);
GType publishing_gallery3_gallery_publisher_get_type (void) G_GNUC_CONST;
static SpitPublishingPublisherMediaType gallery3_service_real_get_supported_media (SpitPublishingService* base);
static void gallery3_service_finalize (GObject * obj);
#define PUBLISHING_GALLERY3_SERVICE_NAME "Gallery3"
#define PUBLISHING_GALLERY3_SERVICE_WELCOME_MESSAGE _ ("You are not currently logged into your Gallery.\n" \
"\n" \
"You must have already signed up for a Gallery3 account to complete the" \
" login process.")
#define PUBLISHING_GALLERY3_DEFAULT_ALBUM_DIR _ ("Shotwell")
#define PUBLISHING_GALLERY3_DEFAULT_ALBUM_TITLE _ ("Shotwell default directory")
#define PUBLISHING_GALLERY3_REST_PATH "/index.php/rest"
gpointer publishing_gallery3_album_ref (gpointer instance);
void publishing_gallery3_album_unref (gpointer instance);
GParamSpec* publishing_gallery3_param_spec_album (const gchar* name,
                                                  const gchar* nick,
                                                  const gchar* blurb,
                                                  GType object_type,
                                                  GParamFlags flags);
void publishing_gallery3_value_set_album (GValue* value,
                                          gpointer v_object);
void publishing_gallery3_value_take_album (GValue* value,
                                           gpointer v_object);
gpointer publishing_gallery3_value_get_album (const GValue* value);
GType publishing_gallery3_album_get_type (void) G_GNUC_CONST;
#define PUBLISHING_GALLERY3_ALBUM_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PUBLISHING_GALLERY3_TYPE_ALBUM, PublishingGallery3AlbumPrivate))
PublishingGallery3Album* publishing_gallery3_album_new (JsonObject* collection);
PublishingGallery3Album* publishing_gallery3_album_construct (GType object_type,
                                                              JsonObject* collection);
static void publishing_gallery3_album_set_title (PublishingGallery3Album* self,
                                          const gchar* value);
static void publishing_gallery3_album_set_name (PublishingGallery3Album* self,
                                         const gchar* value);
static void publishing_gallery3_album_set_parentname (PublishingGallery3Album* self,
                                               const gchar* value);
static void publishing_gallery3_album_set_url (PublishingGallery3Album* self,
                                        const gchar* value);
static void publishing_gallery3_album_set_editable (PublishingGallery3Album* self,
                                             gboolean value);
gchar* publishing_gallery3_strip_session_url (const gchar* url);
const gchar* publishing_gallery3_album_get_url (PublishingGallery3Album* self);
static void publishing_gallery3_album_set_path (PublishingGallery3Album* self,
                                         const gchar* value);
const gchar* publishing_gallery3_album_get_name (PublishingGallery3Album* self);
const gchar* publishing_gallery3_album_get_title (PublishingGallery3Album* self);
const gchar* publishing_gallery3_album_get_summary (PublishingGallery3Album* self);
static void publishing_gallery3_album_set_summary (PublishingGallery3Album* self,
                                            const gchar* value);
const gchar* publishing_gallery3_album_get_parentname (PublishingGallery3Album* self);
const gchar* publishing_gallery3_album_get_path (PublishingGallery3Album* self);
gboolean publishing_gallery3_album_get_editable (PublishingGallery3Album* self);
static void publishing_gallery3_album_finalize (PublishingGallery3Album * obj);
GType publishing_gallery3_base_gallery_transaction_get_type (void) G_GNUC_CONST;
GType publishing_gallery3_session_get_type (void) G_GNUC_CONST;
PublishingGallery3BaseGalleryTransaction* publishing_gallery3_base_gallery_transaction_new (PublishingGallery3Session* session,
                                                                                            const gchar* endpoint_url,
                                                                                            const gchar* item_path,
                                                                                            PublishingRESTSupportHttpMethod method);
PublishingGallery3BaseGalleryTransaction* publishing_gallery3_base_gallery_transaction_construct (GType object_type,
                                                                                                  PublishingGallery3Session* session,
                                                                                                  const gchar* endpoint_url,
                                                                                                  const gchar* item_path,
                                                                                                  PublishingRESTSupportHttpMethod method);
JsonNode* publishing_gallery3_base_gallery_transaction_get_root_node (PublishingGallery3BaseGalleryTransaction* self,
                                                                      GError** error);
static void publishing_gallery3_base_gallery_transaction_finalize (PublishingRESTSupportTransaction * obj);
GType publishing_gallery3_key_fetch_transaction_get_type (void) G_GNUC_CONST;
#define PUBLISHING_GALLERY3_KEY_FETCH_TRANSACTION_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PUBLISHING_GALLERY3_TYPE_KEY_FETCH_TRANSACTION, PublishingGallery3KeyFetchTransactionPrivate))
PublishingGallery3KeyFetchTransaction* publishing_gallery3_key_fetch_transaction_new (PublishingGallery3Session* session,
                                                                                      const gchar* url,
                                                                                      const gchar* username,
                                                                                      const gchar* password);
PublishingGallery3KeyFetchTransaction* publishing_gallery3_key_fetch_transaction_construct (GType object_type,
                                                                                            PublishingGallery3Session* session,
                                                                                            const gchar* url,
                                                                                            const gchar* username,
                                                                                            const gchar* password);
gchar* publishing_gallery3_key_fetch_transaction_get_key (PublishingGallery3KeyFetchTransaction* self);
static void publishing_gallery3_key_fetch_transaction_finalize (PublishingRESTSupportTransaction * obj);
GType publishing_gallery3_gallery_request_transaction_get_type (void) G_GNUC_CONST;
PublishingGallery3GalleryRequestTransaction* publishing_gallery3_gallery_request_transaction_new (PublishingGallery3Session* session,
                                                                                                  const gchar* item,
                                                                                                  PublishingRESTSupportHttpMethod method);
PublishingGallery3GalleryRequestTransaction* publishing_gallery3_gallery_request_transaction_construct (GType object_type,
                                                                                                        PublishingGallery3Session* session,
                                                                                                        const gchar* item,
                                                                                                        PublishingRESTSupportHttpMethod method);
const gchar* publishing_gallery3_session_get_url (PublishingGallery3Session* self);
const gchar* publishing_gallery3_session_get_key (PublishingGallery3Session* self);
GType publishing_gallery3_get_album_ur_ls_transaction_get_type (void) G_GNUC_CONST;
PublishingGallery3GetAlbumURLsTransaction* publishing_gallery3_get_album_ur_ls_transaction_new (PublishingGallery3Session* session);
PublishingGallery3GetAlbumURLsTransaction* publishing_gallery3_get_album_ur_ls_transaction_construct (GType object_type,
                                                                                                      PublishingGallery3Session* session);
gchar** publishing_gallery3_get_album_ur_ls_transaction_get_album_urls (PublishingGallery3GetAlbumURLsTransaction* self,
                                                                        int* result_length1);
static void _vala_array_add2 (gchar** * array,
                       int* length,
                       int* size,
                       gchar* value);
GType publishing_gallery3_get_albums_transaction_get_type (void) G_GNUC_CONST;
#define PUBLISHING_GALLERY3_GET_ALBUMS_TRANSACTION_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PUBLISHING_GALLERY3_TYPE_GET_ALBUMS_TRANSACTION, PublishingGallery3GetAlbumsTransactionPrivate))
PublishingGallery3GetAlbumsTransaction* publishing_gallery3_get_albums_transaction_new (PublishingGallery3Session* session,
                                                                                        gchar** _album_urls,
                                                                                        int _album_urls_length1,
                                                                                        guint start);
PublishingGallery3GetAlbumsTransaction* publishing_gallery3_get_albums_transaction_construct (GType object_type,
                                                                                              PublishingGallery3Session* session,
                                                                                              gchar** _album_urls,
                                                                                              int _album_urls_length1,
                                                                                              guint start);
static void publishing_gallery3_get_albums_transaction_set_album_urls (PublishingGallery3GetAlbumsTransaction* self,
                                                                gchar** value,
                                                                int value_length1);
gchar** publishing_gallery3_get_albums_transaction_get_album_urls (PublishingGallery3GetAlbumsTransaction* self,
                                                                   int* result_length1);
static void publishing_gallery3_get_albums_transaction_set_urls_sent (PublishingGallery3GetAlbumsTransaction* self,
                                                               guint value);
guint publishing_gallery3_get_albums_transaction_get_urls_sent (PublishingGallery3GetAlbumsTransaction* self);
static void _vala_array_add3 (gchar** * array,
                       int* length,
                       int* size,
                       gchar* value);
static void publishing_gallery3_get_albums_transaction_set_more_urls (PublishingGallery3GetAlbumsTransaction* self,
                                                               gboolean value);
PublishingGallery3Album** publishing_gallery3_get_albums_transaction_get_albums (PublishingGallery3GetAlbumsTransaction* self,
                                                                                 int* result_length1,
                                                                                 GError** error);
static void _vala_array_add4 (PublishingGallery3Album** * array,
                       int* length,
                       int* size,
                       PublishingGallery3Album* value);
static gchar** _vala_array_dup2 (gchar** self,
                          int length);
gboolean publishing_gallery3_get_albums_transaction_get_more_urls (PublishingGallery3GetAlbumsTransaction* self);
static void publishing_gallery3_get_albums_transaction_finalize (PublishingRESTSupportTransaction * obj);
GType publishing_gallery3_gallery_get_tag_transaction_get_type (void) G_GNUC_CONST;
PublishingGallery3GalleryGetTagTransaction* publishing_gallery3_gallery_get_tag_transaction_new (PublishingGallery3Session* session,
                                                                                                 const gchar* tag_name);
PublishingGallery3GalleryGetTagTransaction* publishing_gallery3_gallery_get_tag_transaction_construct (GType object_type,
                                                                                                       PublishingGallery3Session* session,
                                                                                                       const gchar* tag_name);
static void _vala_JsonNode_free (JsonNode* self);
gchar* publishing_gallery3_gallery_get_tag_transaction_tag_url (PublishingGallery3GalleryGetTagTransaction* self);
GType publishing_gallery3_gallery_get_item_tags_ur_ls_transaction_get_type (void) G_GNUC_CONST;
#define PUBLISHING_GALLERY3_GALLERY_GET_ITEM_TAGS_UR_LS_TRANSACTION_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PUBLISHING_GALLERY3_TYPE_GALLERY_GET_ITEM_TAGS_UR_LS_TRANSACTION, PublishingGallery3GalleryGetItemTagsURLsTransactionPrivate))
PublishingGallery3GalleryGetItemTagsURLsTransaction* publishing_gallery3_gallery_get_item_tags_ur_ls_transaction_new (PublishingGallery3Session* session,
                                                                                                                      const gchar* item_url);
PublishingGallery3GalleryGetItemTagsURLsTransaction* publishing_gallery3_gallery_get_item_tags_ur_ls_transaction_construct (GType object_type,
                                                                                                                            PublishingGallery3Session* session,
                                                                                                                            const gchar* item_url);
gchar* publishing_gallery3_gallery_get_item_tags_ur_ls_transaction_get_item_tags_path (PublishingGallery3GalleryGetItemTagsURLsTransaction* self);
static void publishing_gallery3_gallery_get_item_tags_ur_ls_transaction_finalize (PublishingRESTSupportTransaction * obj);
GType publishing_gallery3_gallery_set_tag_relationship_transaction_get_type (void) G_GNUC_CONST;
PublishingGallery3GallerySetTagRelationshipTransaction* publishing_gallery3_gallery_set_tag_relationship_transaction_new (PublishingGallery3Session* session,
                                                                                                                          const gchar* item_tags_path,
                                                                                                                          const gchar* tag_url,
                                                                                                                          const gchar* item_url);
PublishingGallery3GallerySetTagRelationshipTransaction* publishing_gallery3_gallery_set_tag_relationship_transaction_construct (GType object_type,
                                                                                                                                PublishingGallery3Session* session,
                                                                                                                                const gchar* item_tags_path,
                                                                                                                                const gchar* tag_url,
                                                                                                                                const gchar* item_url);
GType publishing_gallery3_gallery_album_create_transaction_get_type (void) G_GNUC_CONST;
gpointer publishing_gallery3_publishing_parameters_ref (gpointer instance);
void publishing_gallery3_publishing_parameters_unref (gpointer instance);
GParamSpec* publishing_gallery3_param_spec_publishing_parameters (const gchar* name,
                                                                  const gchar* nick,
                                                                  const gchar* blurb,
                                                                  GType object_type,
                                                                  GParamFlags flags);
void publishing_gallery3_value_set_publishing_parameters (GValue* value,
                                                          gpointer v_object);
void publishing_gallery3_value_take_publishing_parameters (GValue* value,
                                                           gpointer v_object);
gpointer publishing_gallery3_value_get_publishing_parameters (const GValue* value);
GType publishing_gallery3_publishing_parameters_get_type (void) G_GNUC_CONST;
#define PUBLISHING_GALLERY3_GALLERY_ALBUM_CREATE_TRANSACTION_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PUBLISHING_GALLERY3_TYPE_GALLERY_ALBUM_CREATE_TRANSACTION, PublishingGallery3GalleryAlbumCreateTransactionPrivate))
PublishingGallery3GalleryAlbumCreateTransaction* publishing_gallery3_gallery_album_create_transaction_new (PublishingGallery3Session* session,
                                                                                                           PublishingGallery3PublishingParameters* parameters);
PublishingGallery3GalleryAlbumCreateTransaction* publishing_gallery3_gallery_album_create_transaction_construct (GType object_type,
                                                                                                                 PublishingGallery3Session* session,
                                                                                                                 PublishingGallery3PublishingParameters* parameters);
static void publishing_gallery3_gallery_album_create_transaction_set_parameters (PublishingGallery3GalleryAlbumCreateTransaction* self,
                                                                          PublishingGallery3PublishingParameters* value);
const gchar* publishing_gallery3_publishing_parameters_get_album_name (PublishingGallery3PublishingParameters* self);
const gchar* publishing_gallery3_publishing_parameters_get_album_title (PublishingGallery3PublishingParameters* self);
gchar* publishing_gallery3_gallery_album_create_transaction_get_new_album_path (PublishingGallery3GalleryAlbumCreateTransaction* self);
PublishingGallery3PublishingParameters* publishing_gallery3_gallery_album_create_transaction_get_parameters (PublishingGallery3GalleryAlbumCreateTransaction* self);
static void publishing_gallery3_gallery_album_create_transaction_finalize (PublishingRESTSupportTransaction * obj);
GType publishing_gallery3_gallery_upload_transaction_get_type (void) G_GNUC_CONST;
#define PUBLISHING_GALLERY3_GALLERY_UPLOAD_TRANSACTION_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PUBLISHING_GALLERY3_TYPE_GALLERY_UPLOAD_TRANSACTION, PublishingGallery3GalleryUploadTransactionPrivate))
PublishingGallery3GalleryUploadTransaction* publishing_gallery3_gallery_upload_transaction_new (PublishingGallery3Session* session,
                                                                                                PublishingGallery3PublishingParameters* parameters,
                                                                                                SpitPublishingPublishable* publishable);
PublishingGallery3GalleryUploadTransaction* publishing_gallery3_gallery_upload_transaction_construct (GType object_type,
                                                                                                      PublishingGallery3Session* session,
                                                                                                      PublishingGallery3PublishingParameters* parameters,
                                                                                                      SpitPublishingPublishable* publishable);
const gchar* publishing_gallery3_publishing_parameters_get_album_path (PublishingGallery3PublishingParameters* self);
static void _g_free0_ (gpointer var);
static gchar* publishing_gallery3_gallery_upload_transaction_get_new_item_url (PublishingGallery3GalleryUploadTransaction* self);
static void publishing_gallery3_gallery_upload_transaction_do_set_tag_relationship (PublishingGallery3GalleryUploadTransaction* self,
                                                                             const gchar* tag_url,
                                                                             GError** error);
static gchar* publishing_gallery3_gallery_upload_transaction_get_new_item_tags_path (PublishingGallery3GalleryUploadTransaction* self);
static gchar* publishing_gallery3_gallery_upload_transaction_get_tag_url (PublishingGallery3GalleryUploadTransaction* self,
                                                                   const gchar* tag);
static void publishing_gallery3_gallery_upload_transaction_on_upload_completed (PublishingGallery3GalleryUploadTransaction* self,
                                                                         GError** error);
gboolean publishing_gallery3_publishing_parameters_get_strip_metadata (PublishingGallery3PublishingParameters* self);
static void publishing_gallery3_gallery_upload_transaction_real_execute (PublishingRESTSupportTransaction* base,
                                                                  GError** error);
static void publishing_gallery3_gallery_upload_transaction_finalize (PublishingRESTSupportTransaction * obj);
GType publishing_gallery3_publishing_options_pane_get_type (void) G_GNUC_CONST;
#define PUBLISHING_GALLERY3_GALLERY_PUBLISHER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PUBLISHING_GALLERY3_TYPE_GALLERY_PUBLISHER, PublishingGallery3GalleryPublisherPrivate))
#define PUBLISHING_GALLERY3_GALLERY_PUBLISHER_BAD_FILE_MSG _ ("\n" \
"\n" \
"The file “%s” may not be supported by or may be too large for this ins" \
"tance of Gallery3.")
#define PUBLISHING_GALLERY3_GALLERY_PUBLISHER_BAD_MOVIE_MSG _ ("\n" \
"Note that Gallery3 only supports the video types that Flowplayer does.")
PublishingGallery3Session* publishing_gallery3_session_new (void);
PublishingGallery3Session* publishing_gallery3_session_construct (GType object_type);
static gboolean publishing_gallery3_gallery_publisher_real_is_running (SpitPublishingPublisher* base);
static SpitPublishingService* publishing_gallery3_gallery_publisher_real_get_service (SpitPublishingPublisher* base);
static void publishing_gallery3_gallery_publisher_real_start (SpitPublishingPublisher* base);
gchar* publishing_gallery3_gallery_publisher_get_api_key (PublishingGallery3GalleryPublisher* self);
static void publishing_gallery3_gallery_publisher_do_show_service_welcome_pane (PublishingGallery3GalleryPublisher* self);
gchar* publishing_gallery3_gallery_publisher_get_gallery_url (PublishingGallery3GalleryPublisher* self);
gchar* publishing_gallery3_gallery_publisher_get_gallery_username (PublishingGallery3GalleryPublisher* self);
void publishing_gallery3_session_authenticate (PublishingGallery3Session* self,
                                               const gchar* gallery_url,
                                               const gchar* username,
                                               const gchar* key);
static void publishing_gallery3_gallery_publisher_do_fetch_album_urls (PublishingGallery3GalleryPublisher* self);
static void publishing_gallery3_gallery_publisher_real_stop (SpitPublishingPublisher* base);
void publishing_gallery3_gallery_publisher_set_api_key (PublishingGallery3GalleryPublisher* self,
                                                        const gchar* key);
void publishing_gallery3_gallery_publisher_set_gallery_url (PublishingGallery3GalleryPublisher* self,
                                                            const gchar* url);
void publishing_gallery3_gallery_publisher_set_gallery_username (PublishingGallery3GalleryPublisher* self,
                                                                 const gchar* username);
gboolean* publishing_gallery3_gallery_publisher_get_persistent_strip_metadata (PublishingGallery3GalleryPublisher* self);
static gboolean* _bool_dup (gboolean* self);
void publishing_gallery3_gallery_publisher_set_persistent_strip_metadata (PublishingGallery3GalleryPublisher* self,
                                                                          gboolean strip_metadata);
gint* publishing_gallery3_gallery_publisher_get_scaling_constraint_id (PublishingGallery3GalleryPublisher* self);
static gint* _int_dup (gint* self);
void publishing_gallery3_gallery_publisher_set_scaling_constraint_id (PublishingGallery3GalleryPublisher* self,
                                                                      gint constraint);
gint* publishing_gallery3_gallery_publisher_get_scaling_pixels (PublishingGallery3GalleryPublisher* self);
void publishing_gallery3_gallery_publisher_set_scaling_pixels (PublishingGallery3GalleryPublisher* self,
                                                               gint pixels);
static void publishing_gallery3_gallery_publisher_on_service_welcome_login (PublishingGallery3GalleryPublisher* self);
static void _publishing_gallery3_gallery_publisher_on_service_welcome_login_spit_publishing_login_callback (gpointer self);
GType publishing_gallery3_credentials_pane_mode_get_type (void) G_GNUC_CONST;
static void publishing_gallery3_gallery_publisher_do_show_credentials_pane (PublishingGallery3GalleryPublisher* self,
                                                                     PublishingGallery3CredentialsPaneMode mode);
gchar* publishing_gallery3_credentials_pane_mode_to_string (PublishingGallery3CredentialsPaneMode self);
void publishing_gallery3_session_deauthenticate (PublishingGallery3Session* self);
GType publishing_gallery3_credentials_pane_get_type (void) G_GNUC_CONST;
PublishingGallery3CredentialsPane* publishing_gallery3_credentials_pane_new (SpitPublishingPluginHost* host,
                                                                             PublishingGallery3CredentialsPaneMode mode,
                                                                             const gchar* url,
                                                                             const gchar* username,
                                                                             const gchar* key);
PublishingGallery3CredentialsPane* publishing_gallery3_credentials_pane_construct (GType object_type,
                                                                                   SpitPublishingPluginHost* host,
                                                                                   PublishingGallery3CredentialsPaneMode mode,
                                                                                   const gchar* url,
                                                                                   const gchar* username,
                                                                                   const gchar* key);
static void publishing_gallery3_gallery_publisher_on_credentials_go_back (PublishingGallery3GalleryPublisher* self);
static void _publishing_gallery3_gallery_publisher_on_credentials_go_back_publishing_gallery3_credentials_pane_go_back (PublishingGallery3CredentialsPane* _sender,
                                                                                                                 gpointer self);
static void publishing_gallery3_gallery_publisher_on_credentials_login (PublishingGallery3GalleryPublisher* self,
                                                                 const gchar* url,
                                                                 const gchar* username,
                                                                 const gchar* password);
static void _publishing_gallery3_gallery_publisher_on_credentials_login_publishing_gallery3_credentials_pane_login (PublishingGallery3CredentialsPane* _sender,
                                                                                                             const gchar* url,
                                                                                                             const gchar* uname,
                                                                                                             const gchar* password,
                                                                                                             const gchar* key,
                                                                                                             gpointer self);
static void publishing_gallery3_gallery_publisher_do_network_login (PublishingGallery3GalleryPublisher* self,
                                                             const gchar* url,
                                                             const gchar* username,
                                                             const gchar* password);
static void publishing_gallery3_gallery_publisher_on_key_fetch_error (PublishingGallery3GalleryPublisher* self,
                                                               PublishingRESTSupportTransaction* bad_txn,
                                                               GError* err);
static void _publishing_gallery3_gallery_publisher_on_key_fetch_error_publishing_rest_support_transaction_network_error (PublishingRESTSupportTransaction* _sender,
                                                                                                                  GError* err,
                                                                                                                  gpointer self);
static void publishing_gallery3_gallery_publisher_on_key_fetch_complete (PublishingGallery3GalleryPublisher* self,
                                                                  PublishingRESTSupportTransaction* txn);
static void _publishing_gallery3_gallery_publisher_on_key_fetch_complete_publishing_rest_support_transaction_completed (PublishingRESTSupportTransaction* _sender,
                                                                                                                 gpointer self);
static void publishing_gallery3_gallery_publisher_on_album_urls_fetch_error (PublishingGallery3GalleryPublisher* self,
                                                                      PublishingRESTSupportTransaction* bad_txn,
                                                                      GError* err);
static void _publishing_gallery3_gallery_publisher_on_album_urls_fetch_error_publishing_rest_support_transaction_network_error (PublishingRESTSupportTransaction* _sender,
                                                                                                                         GError* err,
                                                                                                                         gpointer self);
static void publishing_gallery3_gallery_publisher_on_album_urls_fetch_complete (PublishingGallery3GalleryPublisher* self,
                                                                         PublishingRESTSupportTransaction* txn);
static void _publishing_gallery3_gallery_publisher_on_album_urls_fetch_complete_publishing_rest_support_transaction_completed (PublishingRESTSupportTransaction* _sender,
                                                                                                                        gpointer self);
static void publishing_gallery3_gallery_publisher_do_fetch_albums (PublishingGallery3GalleryPublisher* self,
                                                            gchar** album_urls,
                                                            int album_urls_length1,
                                                            guint start);
static void publishing_gallery3_gallery_publisher_on_album_fetch_error (PublishingGallery3GalleryPublisher* self,
                                                                 PublishingRESTSupportTransaction* bad_txn,
                                                                 GError* err);
static void _publishing_gallery3_gallery_publisher_on_album_fetch_error_publishing_rest_support_transaction_network_error (PublishingRESTSupportTransaction* _sender,
                                                                                                                    GError* err,
                                                                                                                    gpointer self);
static void publishing_gallery3_gallery_publisher_on_album_fetch_complete (PublishingGallery3GalleryPublisher* self,
                                                                    PublishingRESTSupportTransaction* txn);
static void _publishing_gallery3_gallery_publisher_on_album_fetch_complete_publishing_rest_support_transaction_completed (PublishingRESTSupportTransaction* _sender,
                                                                                                                   gpointer self);
static void publishing_gallery3_gallery_publisher_do_show_publishing_options_pane (PublishingGallery3GalleryPublisher* self,
                                                                            const gchar* url,
                                                                            const gchar* username);
PublishingGallery3PublishingOptionsPane* publishing_gallery3_publishing_options_pane_new (SpitPublishingPluginHost* host,
                                                                                          const gchar* url,
                                                                                          const gchar* username,
                                                                                          PublishingGallery3Album** albums,
                                                                                          int albums_length1,
                                                                                          GtkBuilder* builder,
                                                                                          gboolean strip_metadata,
                                                                                          gint scaling_id,
                                                                                          gint scaling_pixels);
PublishingGallery3PublishingOptionsPane* publishing_gallery3_publishing_options_pane_construct (GType object_type,
                                                                                                SpitPublishingPluginHost* host,
                                                                                                const gchar* url,
                                                                                                const gchar* username,
                                                                                                PublishingGallery3Album** albums,
                                                                                                int albums_length1,
                                                                                                GtkBuilder* builder,
                                                                                                gboolean strip_metadata,
                                                                                                gint scaling_id,
                                                                                                gint scaling_pixels);
static void publishing_gallery3_gallery_publisher_on_publishing_options_pane_publish (PublishingGallery3GalleryPublisher* self,
                                                                               PublishingGallery3PublishingParameters* parameters);
static void _publishing_gallery3_gallery_publisher_on_publishing_options_pane_publish_publishing_gallery3_publishing_options_pane_publish (PublishingGallery3PublishingOptionsPane* _sender,
                                                                                                                                    PublishingGallery3PublishingParameters* parameters,
                                                                                                                                    gpointer self);
static void publishing_gallery3_gallery_publisher_on_publishing_options_pane_logout (PublishingGallery3GalleryPublisher* self);
static void _publishing_gallery3_gallery_publisher_on_publishing_options_pane_logout_publishing_gallery3_publishing_options_pane_logout (PublishingGallery3PublishingOptionsPane* _sender,
                                                                                                                                  gpointer self);
static void publishing_gallery3_gallery_publisher_do_create_album (PublishingGallery3GalleryPublisher* self,
                                                            PublishingGallery3PublishingParameters* parameters);
static void publishing_gallery3_gallery_publisher_on_album_create_error (PublishingGallery3GalleryPublisher* self,
                                                                  PublishingRESTSupportTransaction* bad_txn,
                                                                  GError* err);
static void _publishing_gallery3_gallery_publisher_on_album_create_error_publishing_rest_support_transaction_network_error (PublishingRESTSupportTransaction* _sender,
                                                                                                                     GError* err,
                                                                                                                     gpointer self);
static void publishing_gallery3_gallery_publisher_on_album_create_complete (PublishingGallery3GalleryPublisher* self,
                                                                     PublishingRESTSupportTransaction* txn);
static void _publishing_gallery3_gallery_publisher_on_album_create_complete_publishing_rest_support_transaction_completed (PublishingRESTSupportTransaction* _sender,
                                                                                                                    gpointer self);
static void publishing_gallery3_gallery_publisher_do_publish (PublishingGallery3GalleryPublisher* self,
                                                       PublishingGallery3PublishingParameters* parameters);
gint publishing_gallery3_publishing_parameters_get_photo_major_axis_size (PublishingGallery3PublishingParameters* self);
GType publishing_gallery3_uploader_get_type (void) G_GNUC_CONST;
PublishingGallery3Uploader* publishing_gallery3_uploader_new (PublishingGallery3Session* session,
                                                              SpitPublishingPublishable** publishables,
                                                              int publishables_length1,
                                                              PublishingGallery3PublishingParameters* parameters);
PublishingGallery3Uploader* publishing_gallery3_uploader_construct (GType object_type,
                                                                    PublishingGallery3Session* session,
                                                                    SpitPublishingPublishable** publishables,
                                                                    int publishables_length1,
                                                                    PublishingGallery3PublishingParameters* parameters);
static void publishing_gallery3_gallery_publisher_on_publish_complete (PublishingGallery3GalleryPublisher* self,
                                                                PublishingRESTSupportBatchUploader* uploader,
                                                                gint num_published);
static void _publishing_gallery3_gallery_publisher_on_publish_complete_publishing_rest_support_batch_uploader_upload_complete (PublishingRESTSupportBatchUploader* _sender,
                                                                                                                        gint num_photos_published,
                                                                                                                        gpointer self);
static void publishing_gallery3_gallery_publisher_on_publish_error (PublishingGallery3GalleryPublisher* self,
                                                             PublishingRESTSupportBatchUploader* _uploader,
                                                             GError* err);
static void _publishing_gallery3_gallery_publisher_on_publish_error_publishing_rest_support_batch_uploader_upload_error (PublishingRESTSupportBatchUploader* _sender,
                                                                                                                  GError* err,
                                                                                                                  gpointer self);
static void publishing_gallery3_gallery_publisher_on_upload_status_updated (PublishingGallery3GalleryPublisher* self,
                                                                     gint file_number,
                                                                     gdouble completed_fraction);
static void _publishing_gallery3_gallery_publisher_on_upload_status_updated_spit_publishing_progress_callback (gint file_number,
                                                                                                        gdouble fraction_complete,
                                                                                                        gpointer self);
static void publishing_gallery3_gallery_publisher_do_show_success_pane (PublishingGallery3GalleryPublisher* self);
const gchar* publishing_gallery3_session_get_username (PublishingGallery3Session* self);
static void _vala_array_add5 (PublishingGallery3Album** * array,
                       int* length,
                       int* size,
                       PublishingGallery3Album* value);
void publishing_gallery3_publishing_parameters_set_album_path (PublishingGallery3PublishingParameters* self,
                                                               const gchar* value);
const gchar* publishing_gallery3_uploader_get_current_publishable_name (PublishingGallery3Uploader* self);
guint publishing_gallery3_uploader_get_status_code (PublishingGallery3Uploader* self);
SpitPublishingPublisherMediaType publishing_gallery3_uploader_get_current_publishable_type (PublishingGallery3Uploader* self);
gboolean publishing_gallery3_publishing_parameters_is_to_new_album (PublishingGallery3PublishingParameters* self);
static void publishing_gallery3_gallery_publisher_finalize (GObject * obj);
#define PUBLISHING_GALLERY3_PUBLISHING_OPTIONS_PANE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PUBLISHING_GALLERY3_TYPE_PUBLISHING_OPTIONS_PANE, PublishingGallery3PublishingOptionsPanePrivate))
#define PUBLISHING_GALLERY3_PUBLISHING_OPTIONS_PANE_DEFAULT_ALBUM_NAME ""
#define PUBLISHING_GALLERY3_PUBLISHING_OPTIONS_PANE_LAST_ALBUM_CONFIG_KEY "last-album"
static PublishingGallery3Album** _vala_array_dup3 (PublishingGallery3Album** self,
                                            int length);
static void publishing_gallery3_publishing_options_pane_on_use_existing_radio_clicked (PublishingGallery3PublishingOptionsPane* self);
static void _publishing_gallery3_publishing_options_pane_on_use_existing_radio_clicked_gtk_button_clicked (GtkButton* _sender,
                                                                                                    gpointer self);
static void publishing_gallery3_publishing_options_pane_on_create_new_radio_clicked (PublishingGallery3PublishingOptionsPane* self);
static void _publishing_gallery3_publishing_options_pane_on_create_new_radio_clicked_gtk_button_clicked (GtkButton* _sender,
                                                                                                  gpointer self);
static void publishing_gallery3_publishing_options_pane_on_new_album_entry_changed (PublishingGallery3PublishingOptionsPane* self);
static void _publishing_gallery3_publishing_options_pane_on_new_album_entry_changed_gtk_editable_changed (GtkEditable* _sender,
                                                                                                   gpointer self);
static void publishing_gallery3_publishing_options_pane_on_scaling_constraint_changed (PublishingGallery3PublishingOptionsPane* self);
static void _publishing_gallery3_publishing_options_pane_on_scaling_constraint_changed_gtk_combo_box_changed (GtkComboBox* _sender,
                                                                                                       gpointer self);
static void publishing_gallery3_publishing_options_pane_on_pixels_changed (PublishingGallery3PublishingOptionsPane* self);
static void _publishing_gallery3_publishing_options_pane_on_pixels_changed_gtk_editable_changed (GtkEditable* _sender,
                                                                                          gpointer self);
static void publishing_gallery3_publishing_options_pane_on_logout_clicked (PublishingGallery3PublishingOptionsPane* self);
static void _publishing_gallery3_publishing_options_pane_on_logout_clicked_gtk_button_clicked (GtkButton* _sender,
                                                                                        gpointer self);
static void publishing_gallery3_publishing_options_pane_on_publish_clicked (PublishingGallery3PublishingOptionsPane* self);
static void _publishing_gallery3_publishing_options_pane_on_publish_clicked_gtk_button_clicked (GtkButton* _sender,
                                                                                         gpointer self);
PublishingGallery3PublishingParameters* publishing_gallery3_publishing_parameters_new_to_new_album (const gchar* album_title);
PublishingGallery3PublishingParameters* publishing_gallery3_publishing_parameters_construct_to_new_album (GType object_type,
                                                                                                          const gchar* album_title);
PublishingGallery3PublishingParameters* publishing_gallery3_publishing_parameters_new_to_existing_album (const gchar* album_path);
PublishingGallery3PublishingParameters* publishing_gallery3_publishing_parameters_construct_to_existing_album (GType object_type,
                                                                                                               const gchar* album_path);
void publishing_gallery3_publishing_parameters_set_photo_major_axis_size (PublishingGallery3PublishingParameters* self,
                                                                          gint value);
void publishing_gallery3_publishing_parameters_set_strip_metadata (PublishingGallery3PublishingParameters* self,
                                                                   gboolean value);
static void publishing_gallery3_publishing_options_pane_update_publish_button_sensitivity (PublishingGallery3PublishingOptionsPane* self);
static void publishing_gallery3_publishing_options_pane_update_pixel_entry_sensitivity (PublishingGallery3PublishingOptionsPane* self);
void publishing_gallery3_publishing_options_pane_installed (PublishingGallery3PublishingOptionsPane* self);
static GtkWidget* publishing_gallery3_publishing_options_pane_real_get_widget (SpitPublishingDialogPane* base);
static SpitPublishingDialogPaneGeometryOptions publishing_gallery3_publishing_options_pane_real_get_preferred_geometry (SpitPublishingDialogPane* base);
static void publishing_gallery3_publishing_options_pane_real_on_pane_installed (SpitPublishingDialogPane* base);
static void publishing_gallery3_publishing_options_pane_real_on_pane_uninstalled (SpitPublishingDialogPane* base);
static void g_cclosure_user_marshal_VOID__PUBLISHING_GALLERY3_PUBLISHING_PARAMETERS (GClosure * closure,
                                                                              GValue * return_value,
                                                                              guint n_param_values,
                                                                              const GValue * param_values,
                                                                              gpointer invocation_hint,
                                                                              gpointer marshal_data);
static void publishing_gallery3_publishing_options_pane_finalize (GObject * obj);
#define PUBLISHING_GALLERY3_PUBLISHING_PARAMETERS_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PUBLISHING_GALLERY3_TYPE_PUBLISHING_PARAMETERS, PublishingGallery3PublishingParametersPrivate))
static PublishingGallery3PublishingParameters* publishing_gallery3_publishing_parameters_new (void);
static PublishingGallery3PublishingParameters* publishing_gallery3_publishing_parameters_construct (GType object_type);
static void publishing_gallery3_publishing_parameters_set_album_name (PublishingGallery3PublishingParameters* self,
                                                               const gchar* value);
static void publishing_gallery3_publishing_parameters_set_album_title (PublishingGallery3PublishingParameters* self,
                                                                const gchar* value);
const gchar* publishing_gallery3_publishing_parameters_get_entity_title (PublishingGallery3PublishingParameters* self);
static void publishing_gallery3_publishing_parameters_set_entity_title (PublishingGallery3PublishingParameters* self,
                                                                 const gchar* value);
static void publishing_gallery3_publishing_parameters_finalize (PublishingGallery3PublishingParameters * obj);
GType publishing_gallery3_credentials_grid_get_type (void) G_GNUC_CONST;
#define PUBLISHING_GALLERY3_CREDENTIALS_PANE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PUBLISHING_GALLERY3_TYPE_CREDENTIALS_PANE, PublishingGallery3CredentialsPanePrivate))
PublishingGallery3CredentialsGrid* publishing_gallery3_credentials_grid_new (SpitPublishingPluginHost* host,
                                                                             PublishingGallery3CredentialsPaneMode mode,
                                                                             const gchar* url,
                                                                             const gchar* username,
                                                                             const gchar* key,
                                                                             GtkBuilder* builder);
PublishingGallery3CredentialsGrid* publishing_gallery3_credentials_grid_construct (GType object_type,
                                                                                   SpitPublishingPluginHost* host,
                                                                                   PublishingGallery3CredentialsPaneMode mode,
                                                                                   const gchar* url,
                                                                                   const gchar* username,
                                                                                   const gchar* key,
                                                                                   GtkBuilder* builder);
GtkGrid* publishing_gallery3_credentials_grid_get_pane_widget (PublishingGallery3CredentialsGrid* self);
void publishing_gallery3_credentials_pane_notify_go_back (PublishingGallery3CredentialsPane* self);
void publishing_gallery3_credentials_pane_notify_login (PublishingGallery3CredentialsPane* self,
                                                        const gchar* url,
                                                        const gchar* uname,
                                                        const gchar* password,
                                                        const gchar* key);
static GtkWidget* publishing_gallery3_credentials_pane_real_get_widget (SpitPublishingDialogPane* base);
static SpitPublishingDialogPaneGeometryOptions publishing_gallery3_credentials_pane_real_get_preferred_geometry (SpitPublishingDialogPane* base);
static void publishing_gallery3_credentials_pane_real_on_pane_installed (SpitPublishingDialogPane* base);
static void _publishing_gallery3_credentials_pane_notify_go_back_publishing_gallery3_credentials_grid_go_back (PublishingGallery3CredentialsGrid* _sender,
                                                                                                        gpointer self);
static void _publishing_gallery3_credentials_pane_notify_login_publishing_gallery3_credentials_grid_login (PublishingGallery3CredentialsGrid* _sender,
                                                                                                    const gchar* url,
                                                                                                    const gchar* username,
                                                                                                    const gchar* password,
                                                                                                    const gchar* key,
                                                                                                    gpointer self);
void publishing_gallery3_credentials_grid_installed (PublishingGallery3CredentialsGrid* self);
static void publishing_gallery3_credentials_pane_real_on_pane_uninstalled (SpitPublishingDialogPane* base);
static void g_cclosure_user_marshal_VOID__STRING_STRING_STRING_STRING (GClosure * closure,
                                                                GValue * return_value,
                                                                guint n_param_values,
                                                                const GValue * param_values,
                                                                gpointer invocation_hint,
                                                                gpointer marshal_data);
static void publishing_gallery3_credentials_pane_finalize (GObject * obj);
#define PUBLISHING_GALLERY3_CREDENTIALS_GRID_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PUBLISHING_GALLERY3_TYPE_CREDENTIALS_GRID, PublishingGallery3CredentialsGridPrivate))
#define PUBLISHING_GALLERY3_CREDENTIALS_GRID_INTRO_MESSAGE _ ("Enter the URL for your Gallery3 site and the username and password (or" \
" API key) for your Gallery3 account.")
#define PUBLISHING_GALLERY3_CREDENTIALS_GRID_FAILED_RETRY_MESSAGE _ ("The username and password or API key were incorrect. To try again, re-" \
"enter your username and password below.")
#define PUBLISHING_GALLERY3_CREDENTIALS_GRID_NOT_GALLERY_URL_MESSAGE _ ("The URL entered does not appear to be the main directory of a Gallery3" \
" instance. Please make sure you typed it correctly and it does not hav" \
"e any trailing components (e.g., index.php).")
static void publishing_gallery3_credentials_grid_set_pane_widget (PublishingGallery3CredentialsGrid* self,
                                                           GtkGrid* value);
static void publishing_gallery3_credentials_grid_on_url_or_username_changed (PublishingGallery3CredentialsGrid* self);
static void _publishing_gallery3_credentials_grid_on_url_or_username_changed_gtk_editable_changed (GtkEditable* _sender,
                                                                                            gpointer self);
static void publishing_gallery3_credentials_grid_on_go_back_button_clicked (PublishingGallery3CredentialsGrid* self);
static void _publishing_gallery3_credentials_grid_on_go_back_button_clicked_gtk_button_clicked (GtkButton* _sender,
                                                                                         gpointer self);
static void publishing_gallery3_credentials_grid_on_login_button_clicked (PublishingGallery3CredentialsGrid* self);
static void _publishing_gallery3_credentials_grid_on_login_button_clicked_gtk_button_clicked (GtkButton* _sender,
                                                                                       gpointer self);
static void publishing_gallery3_credentials_grid_finalize (GObject * obj);
static void _vala_publishing_gallery3_credentials_grid_get_property (GObject * object,
                                                              guint property_id,
                                                              GValue * value,
                                                              GParamSpec * pspec);
static void _vala_publishing_gallery3_credentials_grid_set_property (GObject * object,
                                                              guint property_id,
                                                              const GValue * value,
                                                              GParamSpec * pspec);
#define PUBLISHING_GALLERY3_SESSION_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PUBLISHING_GALLERY3_TYPE_SESSION, PublishingGallery3SessionPrivate))
static gboolean publishing_gallery3_session_real_is_authenticated (PublishingRESTSupportSession* base);
static void publishing_gallery3_session_set_url (PublishingGallery3Session* self,
                                          const gchar* value);
static void publishing_gallery3_session_set_username (PublishingGallery3Session* self,
                                               const gchar* value);
static void publishing_gallery3_session_set_key (PublishingGallery3Session* self,
                                          const gchar* value);
static void publishing_gallery3_session_finalize (PublishingRESTSupportSession * obj);
#define PUBLISHING_GALLERY3_UPLOADER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PUBLISHING_GALLERY3_TYPE_UPLOADER, PublishingGallery3UploaderPrivate))
static PublishingRESTSupportTransaction* publishing_gallery3_uploader_real_create_transaction (PublishingRESTSupportBatchUploader* base,
                                                                                        SpitPublishingPublishable* publishable);
static void publishing_gallery3_uploader_finalize (PublishingRESTSupportBatchUploader * obj);
static void _vala_array_destroy (gpointer array,
                          gint array_length,
                          GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array,
                       gint array_length,
                       GDestroyNotify destroy_func);


static void
_vala_array_add1 (SpitPluggable** * array,
                  int* length,
                  int* size,
                  SpitPluggable* value)
{
#line 37 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if ((*length) == (*size)) {
#line 37 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 37 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		*array = g_renew (SpitPluggable*, *array, (*size) + 1);
#line 1274 "GalleryConnector.c"
	}
#line 37 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	(*array)[(*length)++] = value;
#line 37 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	(*array)[*length] = NULL;
#line 1280 "GalleryConnector.c"
}


ShotwellPublishingGallery3*
shotwell_publishing_gallery3_construct (GType object_type,
                                        GFile* module_file)
{
	ShotwellPublishingGallery3 * self = NULL;
	GFile* resource_directory = NULL;
	GFile* _tmp0_;
	SpitPluggable** _tmp1_;
	gint _tmp1__length1;
	Gallery3Service* _tmp2_;
#line 34 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (G_IS_FILE (module_file), NULL);
#line 34 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = (ShotwellPublishingGallery3*) g_object_new (object_type, NULL);
#line 35 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = g_file_get_parent (module_file);
#line 35 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	resource_directory = _tmp0_;
#line 37 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = self->priv->pluggables;
#line 37 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1__length1 = self->priv->pluggables_length1;
#line 37 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp2_ = gallery3_service_new (resource_directory);
#line 37 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_vala_array_add1 (&self->priv->pluggables, &self->priv->pluggables_length1, &self->priv->_pluggables_size_, G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, SPIT_TYPE_PLUGGABLE, SpitPluggable));
#line 34 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_object_unref0 (resource_directory);
#line 34 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return self;
#line 1314 "GalleryConnector.c"
}


ShotwellPublishingGallery3*
shotwell_publishing_gallery3_new (GFile* module_file)
{
#line 34 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return shotwell_publishing_gallery3_construct (TYPE_SHOTWELL_PUBLISHING_GALLERY3, module_file);
#line 1323 "GalleryConnector.c"
}


static const gchar*
shotwell_publishing_gallery3_real_get_module_name (SpitModule* base)
{
	ShotwellPublishingGallery3 * self;
	const gchar* result = NULL;
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_SHOTWELL_PUBLISHING_GALLERY3, ShotwellPublishingGallery3);
#line 41 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = _ ("Gallery3 publishing module");
#line 41 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 1338 "GalleryConnector.c"
}


static const gchar*
shotwell_publishing_gallery3_real_get_version (SpitModule* base)
{
	ShotwellPublishingGallery3 * self;
	const gchar* result = NULL;
#line 44 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_SHOTWELL_PUBLISHING_GALLERY3, ShotwellPublishingGallery3);
#line 45 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = G3_VERSION;
#line 45 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 1353 "GalleryConnector.c"
}


static const gchar*
shotwell_publishing_gallery3_real_get_id (SpitModule* base)
{
	ShotwellPublishingGallery3 * self;
	const gchar* result = NULL;
#line 48 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_SHOTWELL_PUBLISHING_GALLERY3, ShotwellPublishingGallery3);
#line 49 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = "org.yorba.shotwell.sharing.gallery3";
#line 49 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 1368 "GalleryConnector.c"
}


static SpitPluggable**
shotwell_publishing_gallery3_real_get_pluggables (SpitModule* base,
                                                  int* result_length1)
{
	ShotwellPublishingGallery3 * self;
	SpitPluggable** result = NULL;
	SpitPluggable** _tmp0_;
	gint _tmp0__length1;
	SpitPluggable** _tmp1_;
	gint _tmp1__length1;
#line 52 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_SHOTWELL_PUBLISHING_GALLERY3, ShotwellPublishingGallery3);
#line 53 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->pluggables;
#line 53 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0__length1 = self->priv->pluggables_length1;
#line 53 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = _tmp0_;
#line 53 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1__length1 = _tmp0__length1;
#line 53 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (result_length1) {
#line 53 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		*result_length1 = _tmp1__length1;
#line 1396 "GalleryConnector.c"
	}
#line 53 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = _tmp1_;
#line 53 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 1402 "GalleryConnector.c"
}


static void
shotwell_publishing_gallery3_class_init (ShotwellPublishingGallery3Class * klass)
{
#line 31 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	shotwell_publishing_gallery3_parent_class = g_type_class_peek_parent (klass);
#line 31 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_type_class_add_private (klass, sizeof (ShotwellPublishingGallery3Private));
#line 31 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	G_OBJECT_CLASS (klass)->finalize = shotwell_publishing_gallery3_finalize;
#line 1415 "GalleryConnector.c"
}


static void
shotwell_publishing_gallery3_spit_module_interface_init (SpitModuleIface * iface)
{
#line 31 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	shotwell_publishing_gallery3_spit_module_parent_iface = g_type_interface_peek_parent (iface);
#line 31 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	iface->get_module_name = (const gchar* (*) (SpitModule *)) shotwell_publishing_gallery3_real_get_module_name;
#line 31 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	iface->get_version = (const gchar* (*) (SpitModule *)) shotwell_publishing_gallery3_real_get_version;
#line 31 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	iface->get_id = (const gchar* (*) (SpitModule *)) shotwell_publishing_gallery3_real_get_id;
#line 31 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	iface->get_pluggables = (SpitPluggable** (*) (SpitModule *, int*)) shotwell_publishing_gallery3_real_get_pluggables;
#line 1432 "GalleryConnector.c"
}


static void
shotwell_publishing_gallery3_instance_init (ShotwellPublishingGallery3 * self)
{
	SpitPluggable** _tmp0_;
#line 31 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv = SHOTWELL_PUBLISHING_GALLERY3_GET_PRIVATE (self);
#line 32 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = g_new0 (SpitPluggable*, 0 + 1);
#line 32 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->pluggables = _tmp0_;
#line 32 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->pluggables_length1 = 0;
#line 32 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->_pluggables_size_ = self->priv->pluggables_length1;
#line 1450 "GalleryConnector.c"
}


static void
shotwell_publishing_gallery3_finalize (GObject * obj)
{
	ShotwellPublishingGallery3 * self;
#line 31 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_SHOTWELL_PUBLISHING_GALLERY3, ShotwellPublishingGallery3);
#line 32 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->pluggables = (_vala_array_free (self->priv->pluggables, self->priv->pluggables_length1, (GDestroyNotify) g_object_unref), NULL);
#line 31 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	G_OBJECT_CLASS (shotwell_publishing_gallery3_parent_class)->finalize (obj);
#line 1464 "GalleryConnector.c"
}


GType
shotwell_publishing_gallery3_get_type (void)
{
	static volatile gsize shotwell_publishing_gallery3_type_id__volatile = 0;
	if (g_once_init_enter (&shotwell_publishing_gallery3_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (ShotwellPublishingGallery3Class), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) shotwell_publishing_gallery3_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ShotwellPublishingGallery3), 0, (GInstanceInitFunc) shotwell_publishing_gallery3_instance_init, NULL };
		static const GInterfaceInfo spit_module_info = { (GInterfaceInitFunc) shotwell_publishing_gallery3_spit_module_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType shotwell_publishing_gallery3_type_id;
		shotwell_publishing_gallery3_type_id = g_type_register_static (G_TYPE_OBJECT, "ShotwellPublishingGallery3", &g_define_type_info, 0);
		g_type_add_interface_static (shotwell_publishing_gallery3_type_id, SPIT_TYPE_MODULE, &spit_module_info);
		g_once_init_leave (&shotwell_publishing_gallery3_type_id__volatile, shotwell_publishing_gallery3_type_id);
	}
	return shotwell_publishing_gallery3_type_id__volatile;
}


Gallery3Service*
gallery3_service_construct (GType object_type,
                            GFile* resource_directory)
{
	Gallery3Service * self = NULL;
	GdkPixbuf** _tmp0_;
	gint _tmp0__length1;
#line 64 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (G_IS_FILE (resource_directory), NULL);
#line 64 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = (Gallery3Service*) g_object_new (object_type, NULL);
#line 65 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = gallery3_service_icon_pixbuf_set;
#line 65 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0__length1 = gallery3_service_icon_pixbuf_set_length1;
#line 65 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (_tmp0_ == NULL) {
#line 1501 "GalleryConnector.c"
		gint _tmp1_;
		GdkPixbuf** _tmp2_;
#line 66 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp2_ = resources_load_from_resource (PLUGIN_RESOURCE_PATH "/" GALLERY3_SERVICE_ICON_FILENAME, &_tmp1_);
#line 66 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		gallery3_service_icon_pixbuf_set = (_vala_array_free (gallery3_service_icon_pixbuf_set, gallery3_service_icon_pixbuf_set_length1, (GDestroyNotify) g_object_unref), NULL);
#line 66 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		gallery3_service_icon_pixbuf_set = _tmp2_;
#line 66 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		gallery3_service_icon_pixbuf_set_length1 = _tmp1_;
#line 66 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_gallery3_service_icon_pixbuf_set_size_ = gallery3_service_icon_pixbuf_set_length1;
#line 1514 "GalleryConnector.c"
	}
#line 64 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return self;
#line 1518 "GalleryConnector.c"
}


Gallery3Service*
gallery3_service_new (GFile* resource_directory)
{
#line 64 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return gallery3_service_construct (TYPE_GALLERY3_SERVICE, resource_directory);
#line 1527 "GalleryConnector.c"
}


static gint
gallery3_service_real_get_pluggable_interface (SpitPluggable* base,
                                               gint min_host_interface,
                                               gint max_host_interface)
{
	Gallery3Service * self;
	gint result = 0;
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_GALLERY3_SERVICE, Gallery3Service);
#line 72 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = spit_negotiate_interfaces (min_host_interface, max_host_interface, SPIT_PUBLISHING_CURRENT_INTERFACE);
#line 72 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 1544 "GalleryConnector.c"
}


static const gchar*
gallery3_service_real_get_id (SpitPluggable* base)
{
	Gallery3Service * self;
	const gchar* result = NULL;
#line 77 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_GALLERY3_SERVICE, Gallery3Service);
#line 78 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = "publishing-gallery3";
#line 78 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 1559 "GalleryConnector.c"
}


static const gchar*
gallery3_service_real_get_pluggable_name (SpitPluggable* base)
{
	Gallery3Service * self;
	const gchar* result = NULL;
#line 81 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_GALLERY3_SERVICE, Gallery3Service);
#line 82 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = "Gallery3";
#line 82 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 1574 "GalleryConnector.c"
}


static gpointer
_g_object_ref0 (gpointer self)
{
#line 93 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return self ? g_object_ref (self) : NULL;
#line 1583 "GalleryConnector.c"
}


static GdkPixbuf**
_vala_array_dup1 (GdkPixbuf** self,
                  int length)
{
	GdkPixbuf** result;
	int i;
#line 93 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = g_new0 (GdkPixbuf*, length + 1);
#line 93 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	for (i = 0; i < length; i++) {
#line 1597 "GalleryConnector.c"
		GdkPixbuf* _tmp0_;
#line 93 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp0_ = _g_object_ref0 (self[i]);
#line 93 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		result[i] = _tmp0_;
#line 1603 "GalleryConnector.c"
	}
#line 93 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 1607 "GalleryConnector.c"
}


static void
gallery3_service_real_get_info (SpitPluggable* base,
                                SpitPluggableInfo* info)
{
	Gallery3Service * self;
	gchar* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	gchar* _tmp4_;
	gchar* _tmp5_;
	GdkPixbuf** _tmp6_;
	gint _tmp6__length1;
	GdkPixbuf** _tmp7_;
	gint _tmp7__length1;
#line 85 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_GALLERY3_SERVICE, Gallery3Service);
#line 85 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (info != NULL);
#line 86 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = g_strdup ("Joe Sapp");
#line 86 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 ((*info).authors);
#line 86 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	(*info).authors = _tmp0_;
#line 87 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = g_strdup ("2012-2013 Joe Sapp");
#line 87 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 ((*info).copyright);
#line 87 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	(*info).copyright = _tmp1_;
#line 88 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp2_ = g_strdup (RESOURCES_TRANSLATORS);
#line 88 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 ((*info).translators);
#line 88 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	(*info).translators = _tmp2_;
#line 89 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp3_ = g_strdup (G3_VERSION);
#line 89 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 ((*info).version);
#line 89 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	(*info).version = _tmp3_;
#line 90 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp4_ = g_strdup (WEBSITE_URL);
#line 90 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 ((*info).website_url);
#line 90 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	(*info).website_url = _tmp4_;
#line 91 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	(*info).is_license_wordwrapped = FALSE;
#line 92 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp5_ = g_strdup (G3_LICENSE);
#line 92 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 ((*info).license);
#line 92 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	(*info).license = _tmp5_;
#line 93 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp6_ = gallery3_service_icon_pixbuf_set;
#line 93 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp6__length1 = gallery3_service_icon_pixbuf_set_length1;
#line 93 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp7_ = (_tmp6_ != NULL) ? _vala_array_dup1 (_tmp6_, _tmp6__length1) : ((gpointer) _tmp6_);
#line 93 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp7__length1 = _tmp6__length1;
#line 93 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	(*info).icons = (_vala_array_free ((*info).icons, (*info).icons_length1, (GDestroyNotify) g_object_unref), NULL);
#line 93 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	(*info).icons = _tmp7_;
#line 93 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	(*info).icons_length1 = _tmp7__length1;
#line 1682 "GalleryConnector.c"
}


static void
gallery3_service_real_activation (SpitPluggable* base,
                                  gboolean enabled)
{
	Gallery3Service * self;
#line 96 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_GALLERY3_SERVICE, Gallery3Service);
#line 1693 "GalleryConnector.c"
}


static SpitPublishingPublisher*
gallery3_service_real_create_publisher (SpitPublishingService* base,
                                        SpitPublishingPluginHost* host)
{
	Gallery3Service * self;
	SpitPublishingPublisher* result = NULL;
	PublishingGallery3GalleryPublisher* _tmp0_;
#line 99 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_GALLERY3_SERVICE, Gallery3Service);
#line 99 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (SPIT_PUBLISHING_IS_PLUGIN_HOST (host), NULL);
#line 101 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = publishing_gallery3_gallery_publisher_new (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_SERVICE, SpitPublishingService), host);
#line 101 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_PUBLISHING_TYPE_PUBLISHER, SpitPublishingPublisher);
#line 101 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 1714 "GalleryConnector.c"
}


static SpitPublishingPublisherMediaType
gallery3_service_real_get_supported_media (SpitPublishingService* base)
{
	Gallery3Service * self;
	SpitPublishingPublisherMediaType result = 0;
#line 104 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_GALLERY3_SERVICE, Gallery3Service);
#line 105 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = SPIT_PUBLISHING_PUBLISHER_MEDIA_TYPE_PHOTO | SPIT_PUBLISHING_PUBLISHER_MEDIA_TYPE_VIDEO;
#line 105 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 1729 "GalleryConnector.c"
}


static void
gallery3_service_class_init (Gallery3ServiceClass * klass)
{
#line 58 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	gallery3_service_parent_class = g_type_class_peek_parent (klass);
#line 58 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	G_OBJECT_CLASS (klass)->finalize = gallery3_service_finalize;
#line 1740 "GalleryConnector.c"
}


static void
gallery3_service_spit_pluggable_interface_init (SpitPluggableIface * iface)
{
#line 58 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	gallery3_service_spit_pluggable_parent_iface = g_type_interface_peek_parent (iface);
#line 58 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	iface->get_pluggable_interface = (gint (*) (SpitPluggable *, gint, gint)) gallery3_service_real_get_pluggable_interface;
#line 58 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	iface->get_id = (const gchar* (*) (SpitPluggable *)) gallery3_service_real_get_id;
#line 58 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	iface->get_pluggable_name = (const gchar* (*) (SpitPluggable *)) gallery3_service_real_get_pluggable_name;
#line 58 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	iface->get_info = (void (*) (SpitPluggable *, SpitPluggableInfo*)) gallery3_service_real_get_info;
#line 58 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	iface->activation = (void (*) (SpitPluggable *, gboolean)) gallery3_service_real_activation;
#line 1759 "GalleryConnector.c"
}


static void
gallery3_service_spit_publishing_service_interface_init (SpitPublishingServiceIface * iface)
{
#line 58 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	gallery3_service_spit_publishing_service_parent_iface = g_type_interface_peek_parent (iface);
#line 58 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	iface->create_publisher = (SpitPublishingPublisher* (*) (SpitPublishingService *, SpitPublishingPluginHost*)) gallery3_service_real_create_publisher;
#line 58 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	iface->get_supported_media = (SpitPublishingPublisherMediaType (*) (SpitPublishingService *)) gallery3_service_real_get_supported_media;
#line 1772 "GalleryConnector.c"
}


static void
gallery3_service_instance_init (Gallery3Service * self)
{
}


static void
gallery3_service_finalize (GObject * obj)
{
	Gallery3Service * self;
#line 58 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_GALLERY3_SERVICE, Gallery3Service);
#line 58 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	G_OBJECT_CLASS (gallery3_service_parent_class)->finalize (obj);
#line 1790 "GalleryConnector.c"
}


GType
gallery3_service_get_type (void)
{
	static volatile gsize gallery3_service_type_id__volatile = 0;
	if (g_once_init_enter (&gallery3_service_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (Gallery3ServiceClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gallery3_service_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (Gallery3Service), 0, (GInstanceInitFunc) gallery3_service_instance_init, NULL };
		static const GInterfaceInfo spit_pluggable_info = { (GInterfaceInitFunc) gallery3_service_spit_pluggable_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		static const GInterfaceInfo spit_publishing_service_info = { (GInterfaceInitFunc) gallery3_service_spit_publishing_service_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType gallery3_service_type_id;
		gallery3_service_type_id = g_type_register_static (G_TYPE_OBJECT, "Gallery3Service", &g_define_type_info, 0);
		g_type_add_interface_static (gallery3_service_type_id, SPIT_TYPE_PLUGGABLE, &spit_pluggable_info);
		g_type_add_interface_static (gallery3_service_type_id, SPIT_PUBLISHING_TYPE_SERVICE, &spit_publishing_service_info);
		g_once_init_leave (&gallery3_service_type_id__volatile, gallery3_service_type_id);
	}
	return gallery3_service_type_id__volatile;
}


PublishingGallery3Album*
publishing_gallery3_album_construct (GType object_type,
                                     JsonObject* collection)
{
	PublishingGallery3Album* self = NULL;
	JsonObject* entity = NULL;
	JsonObject* _tmp0_;
	const gchar* _tmp1_;
	const gchar* _tmp2_;
	const gchar* _tmp3_;
	const gchar* _tmp4_;
	const gchar* _tmp5_;
	gchar* _tmp6_;
	gchar* _tmp7_;
#line 132 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (collection != NULL, NULL);
#line 132 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = (PublishingGallery3Album*) g_type_create_instance (object_type);
#line 134 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = json_object_get_object_member (collection, "entity");
#line 134 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	entity = _tmp0_;
#line 137 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = json_object_get_string_member (entity, "title");
#line 137 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_album_set_title (self, _tmp1_);
#line 138 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp2_ = json_object_get_string_member (entity, "name");
#line 138 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_album_set_name (self, _tmp2_);
#line 139 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp3_ = json_object_get_string_member (entity, "parent");
#line 139 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_album_set_parentname (self, _tmp3_);
#line 140 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp4_ = json_object_get_string_member (collection, "url");
#line 140 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_album_set_url (self, _tmp4_);
#line 141 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_album_set_editable (self, json_object_get_boolean_member (entity, "can_edit"));
#line 145 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp5_ = self->priv->_url;
#line 145 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp6_ = publishing_gallery3_strip_session_url (_tmp5_);
#line 145 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp7_ = _tmp6_;
#line 145 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_album_set_path (self, _tmp7_);
#line 145 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (_tmp7_);
#line 132 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return self;
#line 1864 "GalleryConnector.c"
}


PublishingGallery3Album*
publishing_gallery3_album_new (JsonObject* collection)
{
#line 132 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return publishing_gallery3_album_construct (PUBLISHING_GALLERY3_TYPE_ALBUM, collection);
#line 1873 "GalleryConnector.c"
}


const gchar*
publishing_gallery3_album_get_name (PublishingGallery3Album* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 123 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (PUBLISHING_GALLERY3_IS_ALBUM (self), NULL);
#line 123 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->_name;
#line 123 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = _tmp0_;
#line 123 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 1890 "GalleryConnector.c"
}


static void
publishing_gallery3_album_set_name (PublishingGallery3Album* self,
                                    const gchar* value)
{
	gchar* _tmp0_;
#line 123 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_ALBUM (self));
#line 123 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = g_strdup (value);
#line 123 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (self->priv->_name);
#line 123 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->_name = _tmp0_;
#line 1907 "GalleryConnector.c"
}


const gchar*
publishing_gallery3_album_get_title (PublishingGallery3Album* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 124 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (PUBLISHING_GALLERY3_IS_ALBUM (self), NULL);
#line 124 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->_title;
#line 124 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = _tmp0_;
#line 124 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 1924 "GalleryConnector.c"
}


static void
publishing_gallery3_album_set_title (PublishingGallery3Album* self,
                                     const gchar* value)
{
	gchar* _tmp0_;
#line 124 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_ALBUM (self));
#line 124 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = g_strdup (value);
#line 124 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (self->priv->_title);
#line 124 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->_title = _tmp0_;
#line 1941 "GalleryConnector.c"
}


const gchar*
publishing_gallery3_album_get_summary (PublishingGallery3Album* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 125 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (PUBLISHING_GALLERY3_IS_ALBUM (self), NULL);
#line 125 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->_summary;
#line 125 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = _tmp0_;
#line 125 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 1958 "GalleryConnector.c"
}


static void
publishing_gallery3_album_set_summary (PublishingGallery3Album* self,
                                       const gchar* value)
{
	gchar* _tmp0_;
#line 125 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_ALBUM (self));
#line 125 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = g_strdup (value);
#line 125 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (self->priv->_summary);
#line 125 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->_summary = _tmp0_;
#line 1975 "GalleryConnector.c"
}


const gchar*
publishing_gallery3_album_get_parentname (PublishingGallery3Album* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 126 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (PUBLISHING_GALLERY3_IS_ALBUM (self), NULL);
#line 126 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->_parentname;
#line 126 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = _tmp0_;
#line 126 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 1992 "GalleryConnector.c"
}


static void
publishing_gallery3_album_set_parentname (PublishingGallery3Album* self,
                                          const gchar* value)
{
	gchar* _tmp0_;
#line 126 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_ALBUM (self));
#line 126 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = g_strdup (value);
#line 126 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (self->priv->_parentname);
#line 126 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->_parentname = _tmp0_;
#line 2009 "GalleryConnector.c"
}


const gchar*
publishing_gallery3_album_get_url (PublishingGallery3Album* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 127 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (PUBLISHING_GALLERY3_IS_ALBUM (self), NULL);
#line 127 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->_url;
#line 127 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = _tmp0_;
#line 127 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 2026 "GalleryConnector.c"
}


static void
publishing_gallery3_album_set_url (PublishingGallery3Album* self,
                                   const gchar* value)
{
	gchar* _tmp0_;
#line 127 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_ALBUM (self));
#line 127 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = g_strdup (value);
#line 127 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (self->priv->_url);
#line 127 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->_url = _tmp0_;
#line 2043 "GalleryConnector.c"
}


const gchar*
publishing_gallery3_album_get_path (PublishingGallery3Album* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 128 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (PUBLISHING_GALLERY3_IS_ALBUM (self), NULL);
#line 128 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->_path;
#line 128 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = _tmp0_;
#line 128 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 2060 "GalleryConnector.c"
}


static void
publishing_gallery3_album_set_path (PublishingGallery3Album* self,
                                    const gchar* value)
{
	gchar* _tmp0_;
#line 128 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_ALBUM (self));
#line 128 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = g_strdup (value);
#line 128 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (self->priv->_path);
#line 128 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->_path = _tmp0_;
#line 2077 "GalleryConnector.c"
}


gboolean
publishing_gallery3_album_get_editable (PublishingGallery3Album* self)
{
	gboolean result;
	gboolean _tmp0_;
#line 129 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (PUBLISHING_GALLERY3_IS_ALBUM (self), FALSE);
#line 129 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->_editable;
#line 129 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = _tmp0_;
#line 129 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 2094 "GalleryConnector.c"
}


static void
publishing_gallery3_album_set_editable (PublishingGallery3Album* self,
                                        gboolean value)
{
#line 129 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_ALBUM (self));
#line 129 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->_editable = value;
#line 2106 "GalleryConnector.c"
}


static void
publishing_gallery3_value_album_init (GValue* value)
{
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	value->data[0].v_pointer = NULL;
#line 2115 "GalleryConnector.c"
}


static void
publishing_gallery3_value_album_free_value (GValue* value)
{
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (value->data[0].v_pointer) {
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		publishing_gallery3_album_unref (value->data[0].v_pointer);
#line 2126 "GalleryConnector.c"
	}
}


static void
publishing_gallery3_value_album_copy_value (const GValue* src_value,
                                            GValue* dest_value)
{
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (src_value->data[0].v_pointer) {
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		dest_value->data[0].v_pointer = publishing_gallery3_album_ref (src_value->data[0].v_pointer);
#line 2139 "GalleryConnector.c"
	} else {
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		dest_value->data[0].v_pointer = NULL;
#line 2143 "GalleryConnector.c"
	}
}


static gpointer
publishing_gallery3_value_album_peek_pointer (const GValue* value)
{
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return value->data[0].v_pointer;
#line 2153 "GalleryConnector.c"
}


static gchar*
publishing_gallery3_value_album_collect_value (GValue* value,
                                               guint n_collect_values,
                                               GTypeCValue* collect_values,
                                               guint collect_flags)
{
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (collect_values[0].v_pointer) {
#line 2165 "GalleryConnector.c"
		PublishingGallery3Album * object;
		object = collect_values[0].v_pointer;
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		if (object->parent_instance.g_class == NULL) {
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 2172 "GalleryConnector.c"
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 2176 "GalleryConnector.c"
		}
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		value->data[0].v_pointer = publishing_gallery3_album_ref (object);
#line 2180 "GalleryConnector.c"
	} else {
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		value->data[0].v_pointer = NULL;
#line 2184 "GalleryConnector.c"
	}
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return NULL;
#line 2188 "GalleryConnector.c"
}


static gchar*
publishing_gallery3_value_album_lcopy_value (const GValue* value,
                                             guint n_collect_values,
                                             GTypeCValue* collect_values,
                                             guint collect_flags)
{
	PublishingGallery3Album ** object_p;
	object_p = collect_values[0].v_pointer;
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (!object_p) {
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
#line 2204 "GalleryConnector.c"
	}
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (!value->data[0].v_pointer) {
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		*object_p = NULL;
#line 2210 "GalleryConnector.c"
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		*object_p = value->data[0].v_pointer;
#line 2214 "GalleryConnector.c"
	} else {
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		*object_p = publishing_gallery3_album_ref (value->data[0].v_pointer);
#line 2218 "GalleryConnector.c"
	}
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return NULL;
#line 2222 "GalleryConnector.c"
}


GParamSpec*
publishing_gallery3_param_spec_album (const gchar* name,
                                      const gchar* nick,
                                      const gchar* blurb,
                                      GType object_type,
                                      GParamFlags flags)
{
	PublishingGallery3ParamSpecAlbum* spec;
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (g_type_is_a (object_type, PUBLISHING_GALLERY3_TYPE_ALBUM), NULL);
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	G_PARAM_SPEC (spec)->value_type = object_type;
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return G_PARAM_SPEC (spec);
#line 2242 "GalleryConnector.c"
}


gpointer
publishing_gallery3_value_get_album (const GValue* value)
{
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_GALLERY3_TYPE_ALBUM), NULL);
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return value->data[0].v_pointer;
#line 2253 "GalleryConnector.c"
}


void
publishing_gallery3_value_set_album (GValue* value,
                                     gpointer v_object)
{
	PublishingGallery3Album * old;
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_GALLERY3_TYPE_ALBUM));
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	old = value->data[0].v_pointer;
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (v_object) {
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, PUBLISHING_GALLERY3_TYPE_ALBUM));
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		value->data[0].v_pointer = v_object;
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		publishing_gallery3_album_ref (value->data[0].v_pointer);
#line 2276 "GalleryConnector.c"
	} else {
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		value->data[0].v_pointer = NULL;
#line 2280 "GalleryConnector.c"
	}
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (old) {
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		publishing_gallery3_album_unref (old);
#line 2286 "GalleryConnector.c"
	}
}


void
publishing_gallery3_value_take_album (GValue* value,
                                      gpointer v_object)
{
	PublishingGallery3Album * old;
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_GALLERY3_TYPE_ALBUM));
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	old = value->data[0].v_pointer;
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (v_object) {
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, PUBLISHING_GALLERY3_TYPE_ALBUM));
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		value->data[0].v_pointer = v_object;
#line 2308 "GalleryConnector.c"
	} else {
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		value->data[0].v_pointer = NULL;
#line 2312 "GalleryConnector.c"
	}
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (old) {
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		publishing_gallery3_album_unref (old);
#line 2318 "GalleryConnector.c"
	}
}


static void
publishing_gallery3_album_class_init (PublishingGallery3AlbumClass * klass)
{
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_album_parent_class = g_type_class_peek_parent (klass);
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	((PublishingGallery3AlbumClass *) klass)->finalize = publishing_gallery3_album_finalize;
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_type_class_add_private (klass, sizeof (PublishingGallery3AlbumPrivate));
#line 2332 "GalleryConnector.c"
}


static void
publishing_gallery3_album_instance_init (PublishingGallery3Album * self)
{
	gchar* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	gchar* _tmp4_;
	gchar* _tmp5_;
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv = PUBLISHING_GALLERY3_ALBUM_GET_PRIVATE (self);
#line 123 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = g_strdup ("");
#line 123 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->_name = _tmp0_;
#line 124 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = g_strdup ("");
#line 124 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->_title = _tmp1_;
#line 125 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp2_ = g_strdup ("");
#line 125 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->_summary = _tmp2_;
#line 126 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp3_ = g_strdup ("");
#line 126 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->_parentname = _tmp3_;
#line 127 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp4_ = g_strdup ("");
#line 127 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->_url = _tmp4_;
#line 128 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp5_ = g_strdup ("");
#line 128 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->_path = _tmp5_;
#line 129 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->_editable = FALSE;
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->ref_count = 1;
#line 2375 "GalleryConnector.c"
}


static void
publishing_gallery3_album_finalize (PublishingGallery3Album * obj)
{
	PublishingGallery3Album * self;
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_GALLERY3_TYPE_ALBUM, PublishingGallery3Album);
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_handlers_destroy (self);
#line 123 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (self->priv->_name);
#line 124 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (self->priv->_title);
#line 125 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (self->priv->_summary);
#line 126 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (self->priv->_parentname);
#line 127 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (self->priv->_url);
#line 128 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (self->priv->_path);
#line 2399 "GalleryConnector.c"
}


GType
publishing_gallery3_album_get_type (void)
{
	static volatile gsize publishing_gallery3_album_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_gallery3_album_type_id__volatile)) {
		static const GTypeValueTable g_define_type_value_table = { publishing_gallery3_value_album_init, publishing_gallery3_value_album_free_value, publishing_gallery3_value_album_copy_value, publishing_gallery3_value_album_peek_pointer, "p", publishing_gallery3_value_album_collect_value, "p", publishing_gallery3_value_album_lcopy_value };
		static const GTypeInfo g_define_type_info = { sizeof (PublishingGallery3AlbumClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_gallery3_album_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingGallery3Album), 0, (GInstanceInitFunc) publishing_gallery3_album_instance_init, &g_define_type_value_table };
		static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
		GType publishing_gallery3_album_type_id;
		publishing_gallery3_album_type_id = g_type_register_fundamental (g_type_fundamental_next (), "PublishingGallery3Album", &g_define_type_info, &g_define_type_fundamental_info, 0);
		g_once_init_leave (&publishing_gallery3_album_type_id__volatile, publishing_gallery3_album_type_id);
	}
	return publishing_gallery3_album_type_id__volatile;
}


gpointer
publishing_gallery3_album_ref (gpointer instance)
{
	PublishingGallery3Album * self;
	self = instance;
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_atomic_int_inc (&self->ref_count);
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return instance;
#line 2428 "GalleryConnector.c"
}


void
publishing_gallery3_album_unref (gpointer instance)
{
	PublishingGallery3Album * self;
	self = instance;
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		PUBLISHING_GALLERY3_ALBUM_GET_CLASS (self)->finalize (self);
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_type_free_instance ((GTypeInstance *) self);
#line 2443 "GalleryConnector.c"
	}
}


static gchar
string_get (const gchar* self,
            glong index)
{
	gchar result = '\0';
	gchar _tmp0_;
#line 1124 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, '\0');
#line 1125 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	_tmp0_ = ((gchar*) self)[index];
#line 1125 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	result = _tmp0_;
#line 1125 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	return result;
#line 2462 "GalleryConnector.c"
}


PublishingGallery3BaseGalleryTransaction*
publishing_gallery3_base_gallery_transaction_construct (GType object_type,
                                                        PublishingGallery3Session* session,
                                                        const gchar* endpoint_url,
                                                        const gchar* item_path,
                                                        PublishingRESTSupportHttpMethod method)
{
	PublishingGallery3BaseGalleryTransaction* self = NULL;
	gboolean _tmp0_ = FALSE;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	gchar* _tmp4_;
	JsonParser* _tmp5_;
#line 157 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (PUBLISHING_GALLERY3_IS_SESSION (session), NULL);
#line 157 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (endpoint_url != NULL, NULL);
#line 157 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (item_path != NULL, NULL);
#line 163 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (g_strcmp0 (item_path, "") != 0) {
#line 163 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp0_ = string_get (item_path, (glong) 0) != '/';
#line 2490 "GalleryConnector.c"
	} else {
#line 163 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp0_ = FALSE;
#line 2494 "GalleryConnector.c"
	}
#line 163 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (_tmp0_) {
#line 164 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_warning ("GalleryConnector.vala:164: Bad item path, this is a bug!");
#line 165 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_error ("GalleryConnector.vala:165: %s", item_path);
#line 2502 "GalleryConnector.c"
	}
#line 168 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = g_strconcat (endpoint_url, PUBLISHING_GALLERY3_REST_PATH, NULL);
#line 168 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp2_ = _tmp1_;
#line 168 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp3_ = g_strconcat (_tmp2_, item_path, NULL);
#line 168 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp4_ = _tmp3_;
#line 168 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = (PublishingGallery3BaseGalleryTransaction*) publishing_rest_support_transaction_construct_with_endpoint_url (object_type, G_TYPE_CHECK_INSTANCE_CAST (session, PUBLISHING_REST_SUPPORT_TYPE_SESSION, PublishingRESTSupportSession), _tmp4_, method);
#line 168 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (_tmp4_);
#line 168 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (_tmp2_);
#line 172 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp5_ = json_parser_new ();
#line 172 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_object_unref0 (self->parser);
#line 172 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->parser = _tmp5_;
#line 157 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return self;
#line 2526 "GalleryConnector.c"
}


PublishingGallery3BaseGalleryTransaction*
publishing_gallery3_base_gallery_transaction_new (PublishingGallery3Session* session,
                                                  const gchar* endpoint_url,
                                                  const gchar* item_path,
                                                  PublishingRESTSupportHttpMethod method)
{
#line 157 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return publishing_gallery3_base_gallery_transaction_construct (PUBLISHING_GALLERY3_TYPE_BASE_GALLERY_TRANSACTION, session, endpoint_url, item_path, method);
#line 2538 "GalleryConnector.c"
}


JsonNode*
publishing_gallery3_base_gallery_transaction_get_root_node (PublishingGallery3BaseGalleryTransaction* self,
                                                            GError** error)
{
	JsonNode* result = NULL;
	gchar* json_object = NULL;
	JsonNode* root_node = NULL;
	gchar* _tmp0_;
	gboolean _tmp1_ = FALSE;
	const gchar* _tmp2_;
	JsonParser* _tmp15_;
	JsonNode* _tmp16_;
	GError * _inner_error_ = NULL;
#line 176 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (PUBLISHING_GALLERY3_IS_BASE_GALLERY_TRANSACTION (self), NULL);
#line 182 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = publishing_rest_support_transaction_get_response (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction));
#line 182 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (json_object);
#line 182 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	json_object = _tmp0_;
#line 184 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp2_ = json_object;
#line 184 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (NULL == _tmp2_) {
#line 184 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp1_ = TRUE;
#line 2569 "GalleryConnector.c"
	} else {
		const gchar* _tmp3_;
		gint _tmp4_;
		gint _tmp5_;
#line 184 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp3_ = json_object;
#line 184 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp4_ = strlen (_tmp3_);
#line 184 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp5_ = _tmp4_;
#line 184 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp1_ = 0 == _tmp5_;
#line 2582 "GalleryConnector.c"
	}
#line 184 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (_tmp1_) {
#line 2586 "GalleryConnector.c"
		gchar* _tmp6_;
		gchar* _tmp7_;
		GError* _tmp8_;
		GError* _tmp9_;
#line 185 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp6_ = publishing_rest_support_transaction_get_endpoint_url (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction));
#line 185 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp7_ = _tmp6_;
#line 185 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp8_ = g_error_new (SPIT_PUBLISHING_PUBLISHING_ERROR, SPIT_PUBLISHING_PUBLISHING_ERROR_MALFORMED_RESPONSE, "No response data from %s", _tmp7_);
#line 185 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp9_ = _tmp8_;
#line 185 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_free0 (_tmp7_);
#line 185 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_inner_error_ = _tmp9_;
#line 185 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 185 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			g_propagate_error (error, _inner_error_);
#line 185 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_g_free0 (json_object);
#line 185 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			return NULL;
#line 2611 "GalleryConnector.c"
		} else {
#line 185 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_g_free0 (json_object);
#line 185 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 185 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			g_clear_error (&_inner_error_);
#line 185 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			return NULL;
#line 2621 "GalleryConnector.c"
		}
	}
	{
		JsonParser* _tmp10_;
		const gchar* _tmp11_;
#line 189 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp10_ = self->parser;
#line 189 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp11_ = json_object;
#line 189 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		json_parser_load_from_data (_tmp10_, _tmp11_, (gssize) -1, &_inner_error_);
#line 189 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 2635 "GalleryConnector.c"
			goto __catch0_g_error;
		}
	}
	goto __finally0;
	__catch0_g_error:
	{
		GError* e = NULL;
		GError* _tmp12_;
		const gchar* _tmp13_;
		GError* _tmp14_;
#line 188 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		e = _inner_error_;
#line 188 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_inner_error_ = NULL;
#line 193 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_warning ("GalleryConnector.vala:193: ERROR: didn't load JSON data");
#line 194 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		publishing_rest_support_transaction_set_is_executed (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), FALSE);
#line 195 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp12_ = e;
#line 195 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp13_ = _tmp12_->message;
#line 195 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp14_ = g_error_new_literal (SPIT_PUBLISHING_PUBLISHING_ERROR, SPIT_PUBLISHING_PUBLISHING_ERROR_PROTOCOL_ERROR, _tmp13_);
#line 195 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_inner_error_ = _tmp14_;
#line 195 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_error_free0 (e);
#line 2664 "GalleryConnector.c"
		goto __finally0;
	}
	__finally0:
#line 188 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 188 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 188 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			g_propagate_error (error, _inner_error_);
#line 188 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_g_free0 (json_object);
#line 188 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			return NULL;
#line 2678 "GalleryConnector.c"
		} else {
#line 188 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_g_free0 (json_object);
#line 188 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 188 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			g_clear_error (&_inner_error_);
#line 188 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			return NULL;
#line 2688 "GalleryConnector.c"
		}
	}
#line 198 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp15_ = self->parser;
#line 198 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp16_ = json_parser_get_root (_tmp15_);
#line 198 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	root_node = _tmp16_;
#line 199 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (json_node_is_null (root_node)) {
#line 2699 "GalleryConnector.c"
		GError* _tmp17_;
#line 200 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp17_ = g_error_new_literal (SPIT_PUBLISHING_PUBLISHING_ERROR, SPIT_PUBLISHING_PUBLISHING_ERROR_MALFORMED_RESPONSE, "Root node is null, doesn't appear to be JSON data");
#line 200 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_inner_error_ = _tmp17_;
#line 200 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 200 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			g_propagate_error (error, _inner_error_);
#line 200 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_g_free0 (json_object);
#line 200 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			return NULL;
#line 2713 "GalleryConnector.c"
		} else {
#line 200 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_g_free0 (json_object);
#line 200 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 200 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			g_clear_error (&_inner_error_);
#line 200 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			return NULL;
#line 2723 "GalleryConnector.c"
		}
	}
#line 203 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = root_node;
#line 203 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (json_object);
#line 203 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 2732 "GalleryConnector.c"
}


static void
publishing_gallery3_base_gallery_transaction_class_init (PublishingGallery3BaseGalleryTransactionClass * klass)
{
#line 151 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_base_gallery_transaction_parent_class = g_type_class_peek_parent (klass);
#line 151 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	((PublishingRESTSupportTransactionClass *) klass)->finalize = publishing_gallery3_base_gallery_transaction_finalize;
#line 2743 "GalleryConnector.c"
}


static void
publishing_gallery3_base_gallery_transaction_instance_init (PublishingGallery3BaseGalleryTransaction * self)
{
}


static void
publishing_gallery3_base_gallery_transaction_finalize (PublishingRESTSupportTransaction * obj)
{
	PublishingGallery3BaseGalleryTransaction * self;
#line 151 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_GALLERY3_TYPE_BASE_GALLERY_TRANSACTION, PublishingGallery3BaseGalleryTransaction);
#line 154 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_object_unref0 (self->parser);
#line 151 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	PUBLISHING_REST_SUPPORT_TRANSACTION_CLASS (publishing_gallery3_base_gallery_transaction_parent_class)->finalize (obj);
#line 2763 "GalleryConnector.c"
}


GType
publishing_gallery3_base_gallery_transaction_get_type (void)
{
	static volatile gsize publishing_gallery3_base_gallery_transaction_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_gallery3_base_gallery_transaction_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingGallery3BaseGalleryTransactionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_gallery3_base_gallery_transaction_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingGallery3BaseGalleryTransaction), 0, (GInstanceInitFunc) publishing_gallery3_base_gallery_transaction_instance_init, NULL };
		GType publishing_gallery3_base_gallery_transaction_type_id;
		publishing_gallery3_base_gallery_transaction_type_id = g_type_register_static (PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, "PublishingGallery3BaseGalleryTransaction", &g_define_type_info, 0);
		g_once_init_leave (&publishing_gallery3_base_gallery_transaction_type_id__volatile, publishing_gallery3_base_gallery_transaction_type_id);
	}
	return publishing_gallery3_base_gallery_transaction_type_id__volatile;
}


PublishingGallery3KeyFetchTransaction*
publishing_gallery3_key_fetch_transaction_construct (GType object_type,
                                                     PublishingGallery3Session* session,
                                                     const gchar* url,
                                                     const gchar* username,
                                                     const gchar* password)
{
	PublishingGallery3KeyFetchTransaction* self = NULL;
#line 216 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (PUBLISHING_GALLERY3_IS_SESSION (session), NULL);
#line 216 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (url != NULL, NULL);
#line 216 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (username != NULL, NULL);
#line 216 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (password != NULL, NULL);
#line 218 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = (PublishingGallery3KeyFetchTransaction*) publishing_gallery3_base_gallery_transaction_construct (object_type, session, url, "", PUBLISHING_REST_SUPPORT_HTTP_METHOD_POST);
#line 219 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_rest_support_transaction_add_argument (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "user", username);
#line 220 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_rest_support_transaction_add_argument (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "password", password);
#line 216 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return self;
#line 2805 "GalleryConnector.c"
}


PublishingGallery3KeyFetchTransaction*
publishing_gallery3_key_fetch_transaction_new (PublishingGallery3Session* session,
                                               const gchar* url,
                                               const gchar* username,
                                               const gchar* password)
{
#line 216 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return publishing_gallery3_key_fetch_transaction_construct (PUBLISHING_GALLERY3_TYPE_KEY_FETCH_TRANSACTION, session, url, username, password);
#line 2817 "GalleryConnector.c"
}


static gchar*
string_slice (const gchar* self,
              glong start,
              glong end)
{
	gchar* result = NULL;
	glong string_length = 0L;
	gint _tmp0_;
	gint _tmp1_;
	gboolean _tmp4_ = FALSE;
	gboolean _tmp6_ = FALSE;
	gchar* _tmp8_;
#line 1369 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, NULL);
#line 1370 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	_tmp0_ = strlen (self);
#line 1370 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	_tmp1_ = _tmp0_;
#line 1370 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	string_length = (glong) _tmp1_;
#line 1371 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	if (start < ((glong) 0)) {
#line 2843 "GalleryConnector.c"
		glong _tmp2_;
#line 1372 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		_tmp2_ = string_length;
#line 1372 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		start = _tmp2_ + start;
#line 2849 "GalleryConnector.c"
	}
#line 1374 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	if (end < ((glong) 0)) {
#line 2853 "GalleryConnector.c"
		glong _tmp3_;
#line 1375 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		_tmp3_ = string_length;
#line 1375 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		end = _tmp3_ + end;
#line 2859 "GalleryConnector.c"
	}
#line 1377 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	if (start >= ((glong) 0)) {
#line 2863 "GalleryConnector.c"
		glong _tmp5_;
#line 1377 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		_tmp5_ = string_length;
#line 1377 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		_tmp4_ = start <= _tmp5_;
#line 2869 "GalleryConnector.c"
	} else {
#line 1377 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		_tmp4_ = FALSE;
#line 2873 "GalleryConnector.c"
	}
#line 1377 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	g_return_val_if_fail (_tmp4_, NULL);
#line 1378 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	if (end >= ((glong) 0)) {
#line 2879 "GalleryConnector.c"
		glong _tmp7_;
#line 1378 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		_tmp7_ = string_length;
#line 1378 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		_tmp6_ = end <= _tmp7_;
#line 2885 "GalleryConnector.c"
	} else {
#line 1378 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		_tmp6_ = FALSE;
#line 2889 "GalleryConnector.c"
	}
#line 1378 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	g_return_val_if_fail (_tmp6_, NULL);
#line 1379 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	g_return_val_if_fail (start <= end, NULL);
#line 1380 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	_tmp8_ = g_strndup (((gchar*) self) + start, (gsize) (end - start));
#line 1380 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	result = _tmp8_;
#line 1380 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	return result;
#line 2901 "GalleryConnector.c"
}


gchar*
publishing_gallery3_key_fetch_transaction_get_key (PublishingGallery3KeyFetchTransaction* self)
{
	gchar* result = NULL;
	const gchar* _tmp0_;
	gchar* _tmp3_;
	gboolean _tmp4_ = FALSE;
	gboolean _tmp5_ = FALSE;
	const gchar* _tmp6_;
	const gchar* _tmp14_;
	gchar* _tmp15_;
	const gchar* _tmp16_;
	gchar* _tmp17_;
#line 223 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (PUBLISHING_GALLERY3_IS_KEY_FETCH_TRANSACTION (self), NULL);
#line 225 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->key;
#line 225 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (g_strcmp0 (_tmp0_, "") != 0) {
#line 2924 "GalleryConnector.c"
		const gchar* _tmp1_;
		gchar* _tmp2_;
#line 226 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp1_ = self->priv->key;
#line 226 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp2_ = g_strdup (_tmp1_);
#line 226 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		result = _tmp2_;
#line 226 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		return result;
#line 2935 "GalleryConnector.c"
	}
#line 228 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp3_ = publishing_rest_support_transaction_get_response (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction));
#line 228 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (self->priv->key);
#line 228 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->key = _tmp3_;
#line 231 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp6_ = self->priv->key;
#line 231 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (NULL == _tmp6_) {
#line 231 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp5_ = TRUE;
#line 2949 "GalleryConnector.c"
	} else {
		const gchar* _tmp7_;
#line 231 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp7_ = self->priv->key;
#line 231 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp5_ = g_strcmp0 ("", _tmp7_) == 0;
#line 2956 "GalleryConnector.c"
	}
#line 231 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (_tmp5_) {
#line 231 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp4_ = TRUE;
#line 2962 "GalleryConnector.c"
	} else {
		const gchar* _tmp8_;
		gint _tmp9_;
		gint _tmp10_;
#line 231 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp8_ = self->priv->key;
#line 231 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp9_ = strlen (_tmp8_);
#line 231 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp10_ = _tmp9_;
#line 231 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp4_ = 0 == _tmp10_;
#line 2975 "GalleryConnector.c"
	}
#line 231 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (_tmp4_) {
#line 2979 "GalleryConnector.c"
		gchar* _tmp11_;
		gchar* _tmp12_;
		gchar* _tmp13_;
#line 232 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp11_ = publishing_rest_support_transaction_get_endpoint_url (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction));
#line 232 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp12_ = _tmp11_;
#line 232 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_warning ("GalleryConnector.vala:232: No response data from \"%s\"", _tmp12_);
#line 232 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_free0 (_tmp12_);
#line 233 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp13_ = g_strdup ("");
#line 233 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		result = _tmp13_;
#line 233 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		return result;
#line 2997 "GalleryConnector.c"
	}
#line 237 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp14_ = self->priv->key;
#line 237 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp15_ = string_slice (_tmp14_, (glong) 1, (glong) -1);
#line 237 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (self->priv->key);
#line 237 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->key = _tmp15_;
#line 239 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp16_ = self->priv->key;
#line 239 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp17_ = g_strdup (_tmp16_);
#line 239 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = _tmp17_;
#line 239 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 3015 "GalleryConnector.c"
}


static void
publishing_gallery3_key_fetch_transaction_class_init (PublishingGallery3KeyFetchTransactionClass * klass)
{
#line 209 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_key_fetch_transaction_parent_class = g_type_class_peek_parent (klass);
#line 209 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	((PublishingRESTSupportTransactionClass *) klass)->finalize = publishing_gallery3_key_fetch_transaction_finalize;
#line 209 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_type_class_add_private (klass, sizeof (PublishingGallery3KeyFetchTransactionPrivate));
#line 3028 "GalleryConnector.c"
}


static void
publishing_gallery3_key_fetch_transaction_instance_init (PublishingGallery3KeyFetchTransaction * self)
{
	gchar* _tmp0_;
#line 209 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv = PUBLISHING_GALLERY3_KEY_FETCH_TRANSACTION_GET_PRIVATE (self);
#line 211 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = g_strdup ("");
#line 211 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->key = _tmp0_;
#line 3042 "GalleryConnector.c"
}


static void
publishing_gallery3_key_fetch_transaction_finalize (PublishingRESTSupportTransaction * obj)
{
	PublishingGallery3KeyFetchTransaction * self;
#line 209 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_GALLERY3_TYPE_KEY_FETCH_TRANSACTION, PublishingGallery3KeyFetchTransaction);
#line 211 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (self->priv->key);
#line 209 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	PUBLISHING_REST_SUPPORT_TRANSACTION_CLASS (publishing_gallery3_key_fetch_transaction_parent_class)->finalize (obj);
#line 3056 "GalleryConnector.c"
}


GType
publishing_gallery3_key_fetch_transaction_get_type (void)
{
	static volatile gsize publishing_gallery3_key_fetch_transaction_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_gallery3_key_fetch_transaction_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingGallery3KeyFetchTransactionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_gallery3_key_fetch_transaction_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingGallery3KeyFetchTransaction), 0, (GInstanceInitFunc) publishing_gallery3_key_fetch_transaction_instance_init, NULL };
		GType publishing_gallery3_key_fetch_transaction_type_id;
		publishing_gallery3_key_fetch_transaction_type_id = g_type_register_static (PUBLISHING_GALLERY3_TYPE_BASE_GALLERY_TRANSACTION, "PublishingGallery3KeyFetchTransaction", &g_define_type_info, 0);
		g_once_init_leave (&publishing_gallery3_key_fetch_transaction_type_id__volatile, publishing_gallery3_key_fetch_transaction_type_id);
	}
	return publishing_gallery3_key_fetch_transaction_type_id__volatile;
}


PublishingGallery3GalleryRequestTransaction*
publishing_gallery3_gallery_request_transaction_construct (GType object_type,
                                                           PublishingGallery3Session* session,
                                                           const gchar* item,
                                                           PublishingRESTSupportHttpMethod method)
{
	PublishingGallery3GalleryRequestTransaction* self = NULL;
#line 249 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (PUBLISHING_GALLERY3_IS_SESSION (session), NULL);
#line 249 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (item != NULL, NULL);
#line 253 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (!publishing_rest_support_session_is_authenticated (G_TYPE_CHECK_INSTANCE_CAST (session, PUBLISHING_REST_SUPPORT_TYPE_SESSION, PublishingRESTSupportSession))) {
#line 254 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_error ("GalleryConnector.vala:254: Not authenticated");
#line 3089 "GalleryConnector.c"
	} else {
		const gchar* _tmp0_;
		const gchar* _tmp1_;
		const gchar* _tmp2_;
		const gchar* _tmp3_;
#line 257 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp0_ = publishing_gallery3_session_get_url (session);
#line 257 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp1_ = _tmp0_;
#line 257 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		self = (PublishingGallery3GalleryRequestTransaction*) publishing_gallery3_base_gallery_transaction_construct (object_type, session, _tmp1_, item, method);
#line 258 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp2_ = publishing_gallery3_session_get_key (session);
#line 258 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp3_ = _tmp2_;
#line 258 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		publishing_rest_support_transaction_add_header (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "X-Gallery-Request-Key", _tmp3_);
#line 259 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		publishing_rest_support_transaction_add_header (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "X-Gallery-Request-Method", "GET");
#line 3109 "GalleryConnector.c"
	}
#line 249 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return self;
#line 3113 "GalleryConnector.c"
}


PublishingGallery3GalleryRequestTransaction*
publishing_gallery3_gallery_request_transaction_new (PublishingGallery3Session* session,
                                                     const gchar* item,
                                                     PublishingRESTSupportHttpMethod method)
{
#line 249 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return publishing_gallery3_gallery_request_transaction_construct (PUBLISHING_GALLERY3_TYPE_GALLERY_REQUEST_TRANSACTION, session, item, method);
#line 3124 "GalleryConnector.c"
}


static void
publishing_gallery3_gallery_request_transaction_class_init (PublishingGallery3GalleryRequestTransactionClass * klass)
{
#line 244 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_gallery_request_transaction_parent_class = g_type_class_peek_parent (klass);
#line 3133 "GalleryConnector.c"
}


static void
publishing_gallery3_gallery_request_transaction_instance_init (PublishingGallery3GalleryRequestTransaction * self)
{
}


GType
publishing_gallery3_gallery_request_transaction_get_type (void)
{
	static volatile gsize publishing_gallery3_gallery_request_transaction_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_gallery3_gallery_request_transaction_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingGallery3GalleryRequestTransactionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_gallery3_gallery_request_transaction_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingGallery3GalleryRequestTransaction), 0, (GInstanceInitFunc) publishing_gallery3_gallery_request_transaction_instance_init, NULL };
		GType publishing_gallery3_gallery_request_transaction_type_id;
		publishing_gallery3_gallery_request_transaction_type_id = g_type_register_static (PUBLISHING_GALLERY3_TYPE_BASE_GALLERY_TRANSACTION, "PublishingGallery3GalleryRequestTransaction", &g_define_type_info, 0);
		g_once_init_leave (&publishing_gallery3_gallery_request_transaction_type_id__volatile, publishing_gallery3_gallery_request_transaction_type_id);
	}
	return publishing_gallery3_gallery_request_transaction_type_id__volatile;
}


PublishingGallery3GetAlbumURLsTransaction*
publishing_gallery3_get_album_ur_ls_transaction_construct (GType object_type,
                                                           PublishingGallery3Session* session)
{
	PublishingGallery3GetAlbumURLsTransaction* self = NULL;
#line 268 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (PUBLISHING_GALLERY3_IS_SESSION (session), NULL);
#line 270 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = (PublishingGallery3GetAlbumURLsTransaction*) publishing_gallery3_gallery_request_transaction_construct (object_type, session, "/item/1", PUBLISHING_REST_SUPPORT_HTTP_METHOD_GET);
#line 271 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_rest_support_transaction_add_argument (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "type", "album");
#line 272 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_rest_support_transaction_add_argument (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "scope", "all");
#line 268 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return self;
#line 3172 "GalleryConnector.c"
}


PublishingGallery3GetAlbumURLsTransaction*
publishing_gallery3_get_album_ur_ls_transaction_new (PublishingGallery3Session* session)
{
#line 268 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return publishing_gallery3_get_album_ur_ls_transaction_construct (PUBLISHING_GALLERY3_TYPE_GET_ALBUM_UR_LS_TRANSACTION, session);
#line 3181 "GalleryConnector.c"
}


static void
_vala_array_add2 (gchar** * array,
                  int* length,
                  int* size,
                  gchar* value)
{
#line 294 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if ((*length) == (*size)) {
#line 294 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 294 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		*array = g_renew (gchar*, *array, (*size) + 1);
#line 3197 "GalleryConnector.c"
	}
#line 294 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	(*array)[(*length)++] = value;
#line 294 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	(*array)[*length] = NULL;
#line 3203 "GalleryConnector.c"
}


gchar**
publishing_gallery3_get_album_ur_ls_transaction_get_album_urls (PublishingGallery3GetAlbumURLsTransaction* self,
                                                                int* result_length1)
{
	gchar** result = NULL;
	JsonNode* root_node = NULL;
	JsonArray* all_members = NULL;
	JsonObject* _tmp2_;
	JsonArray* _tmp3_;
	gchar** member_urls = NULL;
	gint member_urls_length1;
	gint _member_urls_size_;
	gchar** _tmp13_;
	gint _tmp13__length1;
	GError * _inner_error_ = NULL;
#line 276 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (PUBLISHING_GALLERY3_IS_GET_ALBUM_UR_LS_TRANSACTION (self), NULL);
#line 3224 "GalleryConnector.c"
	{
		JsonNode* _tmp0_ = NULL;
		JsonNode* _tmp1_;
#line 282 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp1_ = publishing_gallery3_base_gallery_transaction_get_root_node (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_GALLERY3_TYPE_BASE_GALLERY_TRANSACTION, PublishingGallery3BaseGalleryTransaction), &_inner_error_);
#line 282 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp0_ = _tmp1_;
#line 282 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 282 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 3236 "GalleryConnector.c"
				goto __catch1_spit_publishing_publishing_error;
			}
#line 282 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 282 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			g_clear_error (&_inner_error_);
#line 282 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			return NULL;
#line 3245 "GalleryConnector.c"
		}
#line 282 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		root_node = _tmp0_;
#line 3249 "GalleryConnector.c"
	}
	goto __finally1;
	__catch1_spit_publishing_publishing_error:
	{
		GError* e = NULL;
#line 281 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		e = _inner_error_;
#line 281 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_inner_error_ = NULL;
#line 285 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_error ("GalleryConnector.vala:285: Could not get root node");
#line 281 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_error_free0 (e);
#line 3263 "GalleryConnector.c"
	}
	__finally1:
#line 281 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 281 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 281 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_clear_error (&_inner_error_);
#line 281 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		return NULL;
#line 3274 "GalleryConnector.c"
	}
#line 288 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp2_ = json_node_get_object (root_node);
#line 288 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp3_ = json_object_get_array_member (_tmp2_, "members");
#line 288 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	all_members = _tmp3_;
#line 291 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	member_urls = NULL;
#line 291 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	member_urls_length1 = 0;
#line 291 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_member_urls_size_ = member_urls_length1;
#line 3288 "GalleryConnector.c"
	{
		guint i = 0U;
#line 293 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		i = (guint) 0;
#line 3293 "GalleryConnector.c"
		{
			gboolean _tmp4_ = FALSE;
#line 293 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp4_ = TRUE;
#line 293 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			while (TRUE) {
#line 3300 "GalleryConnector.c"
				guint _tmp6_;
				JsonArray* _tmp7_;
				gchar** _tmp8_;
				gint _tmp8__length1;
				JsonArray* _tmp9_;
				guint _tmp10_;
				const gchar* _tmp11_;
				gchar* _tmp12_;
#line 293 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				if (!_tmp4_) {
#line 3311 "GalleryConnector.c"
					guint _tmp5_;
#line 293 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
					_tmp5_ = i;
#line 293 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
					i = _tmp5_ + 1;
#line 3317 "GalleryConnector.c"
				}
#line 293 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp4_ = FALSE;
#line 293 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp6_ = i;
#line 293 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp7_ = all_members;
#line 293 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				if (!(_tmp6_ <= (json_array_get_length (_tmp7_) - 1))) {
#line 293 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
					break;
#line 3329 "GalleryConnector.c"
				}
#line 294 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp8_ = member_urls;
#line 294 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp8__length1 = member_urls_length1;
#line 294 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp9_ = all_members;
#line 294 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp10_ = i;
#line 294 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp11_ = json_array_get_string_element (_tmp9_, _tmp10_);
#line 294 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp12_ = g_strdup (_tmp11_);
#line 294 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_vala_array_add2 (&member_urls, &member_urls_length1, &_member_urls_size_, _tmp12_);
#line 3345 "GalleryConnector.c"
			}
		}
	}
#line 296 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp13_ = member_urls;
#line 296 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp13__length1 = member_urls_length1;
#line 296 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (result_length1) {
#line 296 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		*result_length1 = _tmp13__length1;
#line 3357 "GalleryConnector.c"
	}
#line 296 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = _tmp13_;
#line 296 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 3363 "GalleryConnector.c"
}


static void
publishing_gallery3_get_album_ur_ls_transaction_class_init (PublishingGallery3GetAlbumURLsTransactionClass * klass)
{
#line 266 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_get_album_ur_ls_transaction_parent_class = g_type_class_peek_parent (klass);
#line 3372 "GalleryConnector.c"
}


static void
publishing_gallery3_get_album_ur_ls_transaction_instance_init (PublishingGallery3GetAlbumURLsTransaction * self)
{
}


GType
publishing_gallery3_get_album_ur_ls_transaction_get_type (void)
{
	static volatile gsize publishing_gallery3_get_album_ur_ls_transaction_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_gallery3_get_album_ur_ls_transaction_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingGallery3GetAlbumURLsTransactionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_gallery3_get_album_ur_ls_transaction_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingGallery3GetAlbumURLsTransaction), 0, (GInstanceInitFunc) publishing_gallery3_get_album_ur_ls_transaction_instance_init, NULL };
		GType publishing_gallery3_get_album_ur_ls_transaction_type_id;
		publishing_gallery3_get_album_ur_ls_transaction_type_id = g_type_register_static (PUBLISHING_GALLERY3_TYPE_GALLERY_REQUEST_TRANSACTION, "PublishingGallery3GetAlbumURLsTransaction", &g_define_type_info, 0);
		g_once_init_leave (&publishing_gallery3_get_album_ur_ls_transaction_type_id__volatile, publishing_gallery3_get_album_ur_ls_transaction_type_id);
	}
	return publishing_gallery3_get_album_ur_ls_transaction_type_id__volatile;
}


static void
_vala_array_add3 (gchar** * array,
                  int* length,
                  int* size,
                  gchar* value)
{
#line 340 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if ((*length) == (*size)) {
#line 340 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 340 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		*array = g_renew (gchar*, *array, (*size) + 1);
#line 3408 "GalleryConnector.c"
	}
#line 340 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	(*array)[(*length)++] = value;
#line 340 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	(*array)[*length] = NULL;
#line 3414 "GalleryConnector.c"
}


static gchar*
_vala_g_strjoinv (const gchar* separator,
                  gchar** str_array,
                  int str_array_length1)
{
	gchar* result = NULL;
	gboolean _tmp0_ = FALSE;
#line 1092 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	if (separator == NULL) {
#line 1093 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		separator = "";
#line 3429 "GalleryConnector.c"
	}
#line 1095 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	if (str_array != NULL) {
#line 3433 "GalleryConnector.c"
		gboolean _tmp1_ = FALSE;
#line 1095 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		if (str_array_length1 > 0) {
#line 1095 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
			_tmp1_ = TRUE;
#line 3439 "GalleryConnector.c"
		} else {
			gboolean _tmp2_ = FALSE;
#line 1095 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
			if (str_array_length1 == -1) {
#line 3444 "GalleryConnector.c"
				const gchar* _tmp3_;
#line 1095 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
				_tmp3_ = str_array[0];
#line 1095 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
				_tmp2_ = _tmp3_ != NULL;
#line 3450 "GalleryConnector.c"
			} else {
#line 1095 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
				_tmp2_ = FALSE;
#line 3454 "GalleryConnector.c"
			}
#line 1095 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
			_tmp1_ = _tmp2_;
#line 3458 "GalleryConnector.c"
		}
#line 1095 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		_tmp0_ = _tmp1_;
#line 3462 "GalleryConnector.c"
	} else {
#line 1095 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		_tmp0_ = FALSE;
#line 3466 "GalleryConnector.c"
	}
#line 1095 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	if (_tmp0_) {
#line 3470 "GalleryConnector.c"
		gint i = 0;
		gsize len = 0UL;
		gint _tmp20_;
		gint _tmp22_;
		gint _tmp23_;
		gsize _tmp24_;
		gint _tmp25_;
		gint _tmp26_;
		gint _tmp27_;
		const gchar* res = NULL;
		gsize _tmp28_;
		void* _tmp29_;
		void* ptr = NULL;
		const gchar* _tmp30_;
		const gchar* _tmp31_;
		void* _tmp32_;
		const gchar* _tmp45_;
#line 1097 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		len = (gsize) 1;
#line 3490 "GalleryConnector.c"
		{
			gboolean _tmp4_ = FALSE;
#line 1098 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
			i = 0;
#line 1098 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
			_tmp4_ = TRUE;
#line 1098 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
			while (TRUE) {
#line 3499 "GalleryConnector.c"
				gboolean _tmp6_ = FALSE;
				gboolean _tmp7_ = FALSE;
				gint _tmp12_ = 0;
				gint _tmp13_;
				const gchar* _tmp14_;
				gsize _tmp19_;
#line 1098 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
				if (!_tmp4_) {
#line 3508 "GalleryConnector.c"
					gint _tmp5_;
#line 1098 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
					_tmp5_ = i;
#line 1098 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
					i = _tmp5_ + 1;
#line 3514 "GalleryConnector.c"
				}
#line 1098 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
				_tmp4_ = FALSE;
#line 1098 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
				if (str_array_length1 != -1) {
#line 3520 "GalleryConnector.c"
					gint _tmp8_;
#line 1098 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
					_tmp8_ = i;
#line 1098 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
					_tmp7_ = _tmp8_ < str_array_length1;
#line 3526 "GalleryConnector.c"
				} else {
#line 1098 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
					_tmp7_ = FALSE;
#line 3530 "GalleryConnector.c"
				}
#line 1098 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
				if (_tmp7_) {
#line 1098 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
					_tmp6_ = TRUE;
#line 3536 "GalleryConnector.c"
				} else {
					gboolean _tmp9_ = FALSE;
#line 1098 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
					if (str_array_length1 == -1) {
#line 3541 "GalleryConnector.c"
						gint _tmp10_;
						const gchar* _tmp11_;
#line 1098 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
						_tmp10_ = i;
#line 1098 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
						_tmp11_ = str_array[_tmp10_];
#line 1098 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
						_tmp9_ = _tmp11_ != NULL;
#line 3550 "GalleryConnector.c"
					} else {
#line 1098 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
						_tmp9_ = FALSE;
#line 3554 "GalleryConnector.c"
					}
#line 1098 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
					_tmp6_ = _tmp9_;
#line 3558 "GalleryConnector.c"
				}
#line 1098 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
				if (!_tmp6_) {
#line 1098 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
					break;
#line 3564 "GalleryConnector.c"
				}
#line 1099 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
				_tmp13_ = i;
#line 1099 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
				_tmp14_ = str_array[_tmp13_];
#line 1099 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
				if (_tmp14_ != NULL) {
#line 3572 "GalleryConnector.c"
					gint _tmp15_;
					const gchar* _tmp16_;
					gint _tmp17_;
					gint _tmp18_;
#line 1099 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
					_tmp15_ = i;
#line 1099 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
					_tmp16_ = str_array[_tmp15_];
#line 1099 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
					_tmp17_ = strlen ((const gchar*) _tmp16_);
#line 1099 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
					_tmp18_ = _tmp17_;
#line 1099 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
					_tmp12_ = _tmp18_;
#line 3587 "GalleryConnector.c"
				} else {
#line 1099 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
					_tmp12_ = 0;
#line 3591 "GalleryConnector.c"
				}
#line 1099 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
				_tmp19_ = len;
#line 1099 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
				len = _tmp19_ + _tmp12_;
#line 3597 "GalleryConnector.c"
			}
		}
#line 1101 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		_tmp20_ = i;
#line 1101 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		if (_tmp20_ == 0) {
#line 3604 "GalleryConnector.c"
			gchar* _tmp21_;
#line 1102 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
			_tmp21_ = g_strdup ("");
#line 1102 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
			result = _tmp21_;
#line 1102 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
			return result;
#line 3612 "GalleryConnector.c"
		}
#line 1104 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		_tmp22_ = i;
#line 1104 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		str_array_length1 = _tmp22_;
#line 1104 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		_tmp23_ = str_array_length1;
#line 1105 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		_tmp24_ = len;
#line 1105 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		_tmp25_ = strlen ((const gchar*) separator);
#line 1105 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		_tmp26_ = _tmp25_;
#line 1105 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		_tmp27_ = i;
#line 1105 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		len = _tmp24_ + (_tmp26_ * (_tmp27_ - 1));
#line 1107 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		_tmp28_ = len;
#line 1107 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		_tmp29_ = g_malloc (_tmp28_);
#line 1107 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		res = _tmp29_;
#line 1108 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		_tmp30_ = res;
#line 1108 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		_tmp31_ = str_array[0];
#line 1108 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		_tmp32_ = g_stpcpy ((void*) _tmp30_, (const gchar*) _tmp31_);
#line 1108 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		ptr = _tmp32_;
#line 3644 "GalleryConnector.c"
		{
			gboolean _tmp33_ = FALSE;
#line 1109 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
			i = 1;
#line 1109 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
			_tmp33_ = TRUE;
#line 1109 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
			while (TRUE) {
#line 3653 "GalleryConnector.c"
				gint _tmp35_;
				void* _tmp36_;
				void* _tmp37_;
				const gchar* _tmp38_ = NULL;
				gint _tmp39_;
				const gchar* _tmp40_;
				void* _tmp43_;
				void* _tmp44_;
#line 1109 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
				if (!_tmp33_) {
#line 3664 "GalleryConnector.c"
					gint _tmp34_;
#line 1109 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
					_tmp34_ = i;
#line 1109 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
					i = _tmp34_ + 1;
#line 3670 "GalleryConnector.c"
				}
#line 1109 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
				_tmp33_ = FALSE;
#line 1109 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
				_tmp35_ = i;
#line 1109 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
				if (!(_tmp35_ < str_array_length1)) {
#line 1109 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
					break;
#line 3680 "GalleryConnector.c"
				}
#line 1110 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
				_tmp36_ = ptr;
#line 1110 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
				_tmp37_ = g_stpcpy (_tmp36_, (const gchar*) separator);
#line 1110 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
				ptr = _tmp37_;
#line 1111 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
				_tmp39_ = i;
#line 1111 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
				_tmp40_ = str_array[_tmp39_];
#line 1111 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
				if (_tmp40_ != NULL) {
#line 3694 "GalleryConnector.c"
					gint _tmp41_;
					const gchar* _tmp42_;
#line 1111 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
					_tmp41_ = i;
#line 1111 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
					_tmp42_ = str_array[_tmp41_];
#line 1111 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
					_tmp38_ = (const gchar*) _tmp42_;
#line 3703 "GalleryConnector.c"
				} else {
#line 1111 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
					_tmp38_ = "";
#line 3707 "GalleryConnector.c"
				}
#line 1111 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
				_tmp43_ = ptr;
#line 1111 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
				_tmp44_ = g_stpcpy (_tmp43_, _tmp38_);
#line 1111 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
				ptr = _tmp44_;
#line 3715 "GalleryConnector.c"
			}
		}
#line 1114 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		_tmp45_ = res;
#line 1114 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		res = NULL;
#line 1114 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		result = (gchar*) _tmp45_;
#line 1114 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		return result;
#line 3726 "GalleryConnector.c"
	} else {
		gchar* _tmp46_;
#line 1116 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		_tmp46_ = g_strdup ("");
#line 1116 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		result = _tmp46_;
#line 1116 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		return result;
#line 3735 "GalleryConnector.c"
	}
}


PublishingGallery3GetAlbumsTransaction*
publishing_gallery3_get_albums_transaction_construct (GType object_type,
                                                      PublishingGallery3Session* session,
                                                      gchar** _album_urls,
                                                      int _album_urls_length1,
                                                      guint start)
{
	PublishingGallery3GetAlbumsTransaction* self = NULL;
	gchar* url_list = NULL;
	gchar* _tmp0_;
	gchar** my_album_urls = NULL;
	gint my_album_urls_length1;
	gint _my_album_urls_size_;
	gchar* endpoint_url = NULL;
	gchar* _tmp1_;
	gint _tmp2_ = 0;
	const gchar* _tmp3_;
	gint url_length = 0;
	gint _tmp7_;
	gchar** _tmp8_;
	gint _tmp8__length1;
	gchar** _tmp9_;
	gint _tmp9__length1;
	const gchar* _tmp46_;
	gchar* _tmp47_;
	const gchar* _tmp48_;
#line 312 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (PUBLISHING_GALLERY3_IS_SESSION (session), NULL);
#line 315 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = (PublishingGallery3GetAlbumsTransaction*) publishing_gallery3_gallery_request_transaction_construct (object_type, session, "/items", PUBLISHING_REST_SUPPORT_HTTP_METHOD_GET);
#line 316 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_rest_support_transaction_add_argument (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "scope", "all");
#line 319 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_get_albums_transaction_set_album_urls (self, _album_urls, _album_urls_length1);
#line 328 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = g_strdup ("[");
#line 328 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	url_list = _tmp0_;
#line 329 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	my_album_urls = NULL;
#line 329 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	my_album_urls_length1 = 0;
#line 329 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_my_album_urls_size_ = my_album_urls_length1;
#line 330 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = publishing_rest_support_session_get_endpoint_url (G_TYPE_CHECK_INSTANCE_CAST (session, PUBLISHING_REST_SUPPORT_TYPE_SESSION, PublishingRESTSupportSession));
#line 330 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	endpoint_url = _tmp1_;
#line 331 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp3_ = endpoint_url;
#line 331 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (NULL != _tmp3_) {
#line 3792 "GalleryConnector.c"
		const gchar* _tmp4_;
		gint _tmp5_;
		gint _tmp6_;
#line 332 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp4_ = endpoint_url;
#line 332 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp5_ = strlen (_tmp4_);
#line 332 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp6_ = _tmp5_;
#line 332 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp2_ = _tmp6_;
#line 3804 "GalleryConnector.c"
	} else {
#line 332 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp2_ = 0;
#line 3808 "GalleryConnector.c"
	}
#line 331 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	url_length = _tmp2_;
#line 333 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp7_ = url_length;
#line 333 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	url_length = _tmp7_ + 18;
#line 336 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp8_ = publishing_gallery3_get_albums_transaction_get_album_urls (self, &_tmp8__length1);
#line 336 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp9_ = _tmp8_;
#line 336 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp9__length1 = _tmp8__length1;
#line 336 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (start <= ((guint) (_tmp9__length1 - 1))) {
#line 3824 "GalleryConnector.c"
		const gchar* _tmp38_;
		gchar** _tmp39_;
		gint _tmp39__length1;
		gchar* _tmp40_;
		gchar* _tmp41_;
		gchar* _tmp42_;
		guint _tmp43_;
		gchar** _tmp44_;
		gint _tmp44__length1;
		gchar** _tmp45_;
		gint _tmp45__length1;
#line 338 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		publishing_gallery3_get_albums_transaction_set_urls_sent (self, start);
#line 3838 "GalleryConnector.c"
		{
			gboolean _tmp10_ = FALSE;
#line 339 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp10_ = TRUE;
#line 339 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			while (TRUE) {
#line 3845 "GalleryConnector.c"
				gchar** _tmp22_;
				gint _tmp22__length1;
				gchar** _tmp23_;
				gint _tmp23__length1;
				gchar** _tmp24_;
				gint _tmp24__length1;
				guint _tmp25_;
				const gchar* _tmp26_;
				gchar* _tmp27_;
				gchar* _tmp28_;
				gchar* _tmp29_;
				gint _tmp30_;
				gchar** _tmp31_;
				gint _tmp31__length1;
				gchar** _tmp32_;
				gint _tmp32__length1;
				guint _tmp33_;
				const gchar* _tmp34_;
				gint _tmp35_;
				gint _tmp36_;
				guint _tmp37_;
#line 339 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				if (!_tmp10_) {
#line 3869 "GalleryConnector.c"
					gboolean _tmp11_ = FALSE;
					guint _tmp12_;
					gchar** _tmp13_;
					gint _tmp13__length1;
					gchar** _tmp14_;
					gint _tmp14__length1;
#line 344 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
					_tmp12_ = self->priv->_urls_sent;
#line 344 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
					_tmp13_ = publishing_gallery3_get_albums_transaction_get_album_urls (self, &_tmp13__length1);
#line 344 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
					_tmp14_ = _tmp13_;
#line 344 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
					_tmp14__length1 = _tmp13__length1;
#line 344 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
					if (_tmp12_ <= ((guint) (_tmp14__length1 - 1))) {
#line 3886 "GalleryConnector.c"
						gint _tmp15_;
						gchar** _tmp16_;
						gint _tmp16__length1;
						gchar** _tmp17_;
						gint _tmp17__length1;
						guint _tmp18_;
						const gchar* _tmp19_;
						gint _tmp20_;
						gint _tmp21_;
#line 345 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
						_tmp15_ = url_length;
#line 345 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
						_tmp16_ = publishing_gallery3_get_albums_transaction_get_album_urls (self, &_tmp16__length1);
#line 345 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
						_tmp17_ = _tmp16_;
#line 345 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
						_tmp17__length1 = _tmp16__length1;
#line 345 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
						_tmp18_ = self->priv->_urls_sent;
#line 345 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
						_tmp19_ = _tmp17_[_tmp18_];
#line 345 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
						_tmp20_ = strlen (_tmp19_);
#line 345 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
						_tmp21_ = _tmp20_;
#line 345 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
						_tmp11_ = ((_tmp15_ + _tmp21_) + 3) <= 255;
#line 3914 "GalleryConnector.c"
					} else {
#line 344 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
						_tmp11_ = FALSE;
#line 3918 "GalleryConnector.c"
					}
#line 344 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
					if (!_tmp11_) {
#line 344 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
						break;
#line 3924 "GalleryConnector.c"
					}
				}
#line 339 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp10_ = FALSE;
#line 340 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp22_ = my_album_urls;
#line 340 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp22__length1 = my_album_urls_length1;
#line 340 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp23_ = publishing_gallery3_get_albums_transaction_get_album_urls (self, &_tmp23__length1);
#line 340 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp24_ = _tmp23_;
#line 340 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp24__length1 = _tmp23__length1;
#line 340 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp25_ = self->priv->_urls_sent;
#line 340 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp26_ = _tmp24_[_tmp25_];
#line 340 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp27_ = g_strconcat ("\"", _tmp26_, NULL);
#line 340 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp28_ = _tmp27_;
#line 340 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp29_ = g_strconcat (_tmp28_, "\"", NULL);
#line 340 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_vala_array_add3 (&my_album_urls, &my_album_urls_length1, &_my_album_urls_size_, _tmp29_);
#line 340 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_g_free0 (_tmp28_);
#line 342 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp30_ = url_length;
#line 342 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp31_ = publishing_gallery3_get_albums_transaction_get_album_urls (self, &_tmp31__length1);
#line 342 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp32_ = _tmp31_;
#line 342 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp32__length1 = _tmp31__length1;
#line 342 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp33_ = self->priv->_urls_sent;
#line 342 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp34_ = _tmp32_[_tmp33_];
#line 342 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp35_ = strlen (_tmp34_);
#line 342 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp36_ = _tmp35_;
#line 342 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				url_length = _tmp30_ + (_tmp36_ + 3);
#line 343 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp37_ = self->priv->_urls_sent;
#line 343 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				publishing_gallery3_get_albums_transaction_set_urls_sent (self, _tmp37_ + 1);
#line 3975 "GalleryConnector.c"
			}
		}
#line 347 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp38_ = url_list;
#line 347 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp39_ = my_album_urls;
#line 347 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp39__length1 = my_album_urls_length1;
#line 347 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp40_ = _vala_g_strjoinv (",", _tmp39_, _tmp39__length1);
#line 347 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp41_ = _tmp40_;
#line 347 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp42_ = g_strconcat (_tmp38_, _tmp41_, NULL);
#line 347 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_free0 (url_list);
#line 347 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		url_list = _tmp42_;
#line 347 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_free0 (_tmp41_);
#line 349 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp43_ = self->priv->_urls_sent;
#line 349 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp44_ = publishing_gallery3_get_albums_transaction_get_album_urls (self, &_tmp44__length1);
#line 349 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp45_ = _tmp44_;
#line 349 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp45__length1 = _tmp44__length1;
#line 349 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		publishing_gallery3_get_albums_transaction_set_more_urls (self, _tmp43_ <= ((guint) (_tmp45__length1 - 1)));
#line 4006 "GalleryConnector.c"
	}
#line 352 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp46_ = url_list;
#line 352 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp47_ = g_strconcat (_tmp46_, "]", NULL);
#line 352 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (url_list);
#line 352 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	url_list = _tmp47_;
#line 354 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp48_ = url_list;
#line 354 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_rest_support_transaction_add_argument (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "urls", _tmp48_);
#line 312 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (endpoint_url);
#line 312 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	my_album_urls = (_vala_array_free (my_album_urls, my_album_urls_length1, (GDestroyNotify) g_free), NULL);
#line 312 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (url_list);
#line 312 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return self;
#line 4028 "GalleryConnector.c"
}


PublishingGallery3GetAlbumsTransaction*
publishing_gallery3_get_albums_transaction_new (PublishingGallery3Session* session,
                                                gchar** _album_urls,
                                                int _album_urls_length1,
                                                guint start)
{
#line 312 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return publishing_gallery3_get_albums_transaction_construct (PUBLISHING_GALLERY3_TYPE_GET_ALBUMS_TRANSACTION, session, _album_urls, _album_urls_length1, start);
#line 4040 "GalleryConnector.c"
}


static gpointer
_publishing_gallery3_album_ref0 (gpointer self)
{
#line 371 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return self ? publishing_gallery3_album_ref (self) : NULL;
#line 4049 "GalleryConnector.c"
}


static void
_vala_array_add4 (PublishingGallery3Album** * array,
                  int* length,
                  int* size,
                  PublishingGallery3Album* value)
{
#line 371 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if ((*length) == (*size)) {
#line 371 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 371 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		*array = g_renew (PublishingGallery3Album*, *array, (*size) + 1);
#line 4065 "GalleryConnector.c"
	}
#line 371 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	(*array)[(*length)++] = value;
#line 371 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	(*array)[*length] = NULL;
#line 4071 "GalleryConnector.c"
}


static const gchar*
string_to_string (const gchar* self)
{
	const gchar* result = NULL;
#line 1456 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, NULL);
#line 1457 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	result = self;
#line 1457 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	return result;
#line 4085 "GalleryConnector.c"
}


PublishingGallery3Album**
publishing_gallery3_get_albums_transaction_get_albums (PublishingGallery3GetAlbumsTransaction* self,
                                                       int* result_length1,
                                                       GError** error)
{
	PublishingGallery3Album** result = NULL;
	PublishingGallery3Album** albums = NULL;
	gint albums_length1;
	gint _albums_size_;
	PublishingGallery3Album* tmp_album = NULL;
	JsonNode* root_node = NULL;
	JsonNode* _tmp0_;
	JsonArray* members = NULL;
	JsonArray* _tmp1_;
	PublishingGallery3Album** _tmp22_;
	gint _tmp22__length1;
	GError * _inner_error_ = NULL;
#line 358 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (PUBLISHING_GALLERY3_IS_GET_ALBUMS_TRANSACTION (self), NULL);
#line 361 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	albums = NULL;
#line 361 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	albums_length1 = 0;
#line 361 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_albums_size_ = albums_length1;
#line 363 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = publishing_gallery3_base_gallery_transaction_get_root_node (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_GALLERY3_TYPE_BASE_GALLERY_TRANSACTION, PublishingGallery3BaseGalleryTransaction), &_inner_error_);
#line 363 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	root_node = _tmp0_;
#line 363 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 363 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 363 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			g_propagate_error (error, _inner_error_);
#line 363 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_publishing_gallery3_album_unref0 (tmp_album);
#line 363 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			albums = (_vala_array_free (albums, albums_length1, (GDestroyNotify) publishing_gallery3_album_unref), NULL);
#line 363 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			return NULL;
#line 4130 "GalleryConnector.c"
		} else {
#line 363 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_publishing_gallery3_album_unref0 (tmp_album);
#line 363 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			albums = (_vala_array_free (albums, albums_length1, (GDestroyNotify) publishing_gallery3_album_unref), NULL);
#line 363 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 363 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			g_clear_error (&_inner_error_);
#line 363 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			return NULL;
#line 4142 "GalleryConnector.c"
		}
	}
#line 364 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = json_node_get_array (root_node);
#line 364 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	members = _tmp1_;
#line 4149 "GalleryConnector.c"
	{
		guint i = 0U;
#line 367 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		i = (guint) 0;
#line 4154 "GalleryConnector.c"
		{
			gboolean _tmp2_ = FALSE;
#line 367 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp2_ = TRUE;
#line 367 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			while (TRUE) {
#line 4161 "GalleryConnector.c"
				guint _tmp4_;
				JsonArray* _tmp5_;
				JsonArray* _tmp6_;
				guint _tmp7_;
				JsonObject* _tmp8_;
				PublishingGallery3Album* _tmp9_;
				PublishingGallery3Album* _tmp10_;
				gboolean _tmp11_;
				gboolean _tmp12_;
#line 367 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				if (!_tmp2_) {
#line 4173 "GalleryConnector.c"
					guint _tmp3_;
#line 367 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
					_tmp3_ = i;
#line 367 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
					i = _tmp3_ + 1;
#line 4179 "GalleryConnector.c"
				}
#line 367 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp2_ = FALSE;
#line 367 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp4_ = i;
#line 367 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp5_ = members;
#line 367 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				if (!(_tmp4_ <= (json_array_get_length (_tmp5_) - 1))) {
#line 367 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
					break;
#line 4191 "GalleryConnector.c"
				}
#line 368 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp6_ = members;
#line 368 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp7_ = i;
#line 368 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp8_ = json_array_get_object_element (_tmp6_, _tmp7_);
#line 368 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp9_ = publishing_gallery3_album_new (_tmp8_);
#line 368 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_publishing_gallery3_album_unref0 (tmp_album);
#line 368 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				tmp_album = _tmp9_;
#line 370 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp10_ = tmp_album;
#line 370 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp11_ = publishing_gallery3_album_get_editable (_tmp10_);
#line 370 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp12_ = _tmp11_;
#line 370 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				if (_tmp12_) {
#line 4213 "GalleryConnector.c"
					PublishingGallery3Album** _tmp13_;
					gint _tmp13__length1;
					PublishingGallery3Album* _tmp14_;
					PublishingGallery3Album* _tmp15_;
#line 371 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
					_tmp13_ = albums;
#line 371 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
					_tmp13__length1 = albums_length1;
#line 371 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
					_tmp14_ = tmp_album;
#line 371 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
					_tmp15_ = _publishing_gallery3_album_ref0 (_tmp14_);
#line 371 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
					_vala_array_add4 (&albums, &albums_length1, &_albums_size_, _tmp15_);
#line 4228 "GalleryConnector.c"
				} else {
					PublishingGallery3Album* _tmp16_;
					const gchar* _tmp17_;
					const gchar* _tmp18_;
					const gchar* _tmp19_;
					gchar* _tmp20_;
					gchar* _tmp21_;
#line 373 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
					_tmp16_ = tmp_album;
#line 373 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
					_tmp17_ = publishing_gallery3_album_get_title (_tmp16_);
#line 373 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
					_tmp18_ = _tmp17_;
#line 373 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
					_tmp19_ = string_to_string (_tmp18_);
#line 373 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
					_tmp20_ = g_strconcat ("Album \"", _tmp19_, "\" is not editable", NULL);
#line 373 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
					_tmp21_ = _tmp20_;
#line 373 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
					g_warning ("GalleryConnector.vala:373: %s", _tmp21_);
#line 373 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
					_g_free0 (_tmp21_);
#line 4252 "GalleryConnector.c"
				}
			}
		}
	}
#line 376 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp22_ = albums;
#line 376 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp22__length1 = albums_length1;
#line 376 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (result_length1) {
#line 376 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		*result_length1 = _tmp22__length1;
#line 4265 "GalleryConnector.c"
	}
#line 376 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = _tmp22_;
#line 376 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_publishing_gallery3_album_unref0 (tmp_album);
#line 376 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 4273 "GalleryConnector.c"
}


gchar**
publishing_gallery3_get_albums_transaction_get_album_urls (PublishingGallery3GetAlbumsTransaction* self,
                                                           int* result_length1)
{
	gchar** result;
	gchar** _tmp0_;
	gint _tmp0__length1;
	gchar** _tmp1_;
	gint _tmp1__length1;
#line 306 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (PUBLISHING_GALLERY3_IS_GET_ALBUMS_TRANSACTION (self), NULL);
#line 306 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->_album_urls;
#line 306 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0__length1 = self->priv->_album_urls_length1;
#line 306 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = _tmp0_;
#line 306 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1__length1 = _tmp0__length1;
#line 306 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (result_length1) {
#line 306 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		*result_length1 = _tmp1__length1;
#line 4300 "GalleryConnector.c"
	}
#line 306 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = _tmp1_;
#line 306 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 4306 "GalleryConnector.c"
}


static gchar**
_vala_array_dup2 (gchar** self,
                  int length)
{
	gchar** result;
	int i;
#line 306 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = g_new0 (gchar*, length + 1);
#line 306 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	for (i = 0; i < length; i++) {
#line 4320 "GalleryConnector.c"
		gchar* _tmp0_;
#line 306 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp0_ = g_strdup (self[i]);
#line 306 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		result[i] = _tmp0_;
#line 4326 "GalleryConnector.c"
	}
#line 306 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 4330 "GalleryConnector.c"
}


static void
publishing_gallery3_get_albums_transaction_set_album_urls (PublishingGallery3GetAlbumsTransaction* self,
                                                           gchar** value,
                                                           int value_length1)
{
	gchar** _tmp0_;
	gint _tmp0__length1;
#line 306 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_GET_ALBUMS_TRANSACTION (self));
#line 306 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = (value != NULL) ? _vala_array_dup2 (value, value_length1) : ((gpointer) value);
#line 306 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0__length1 = value_length1;
#line 306 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->_album_urls = (_vala_array_free (self->priv->_album_urls, self->priv->_album_urls_length1, (GDestroyNotify) g_free), NULL);
#line 306 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->_album_urls = _tmp0_;
#line 306 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->_album_urls_length1 = _tmp0__length1;
#line 306 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->__album_urls_size_ = self->priv->_album_urls_length1;
#line 4355 "GalleryConnector.c"
}


guint
publishing_gallery3_get_albums_transaction_get_urls_sent (PublishingGallery3GetAlbumsTransaction* self)
{
	guint result;
	guint _tmp0_;
#line 308 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (PUBLISHING_GALLERY3_IS_GET_ALBUMS_TRANSACTION (self), 0U);
#line 308 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->_urls_sent;
#line 308 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = _tmp0_;
#line 308 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 4372 "GalleryConnector.c"
}


static void
publishing_gallery3_get_albums_transaction_set_urls_sent (PublishingGallery3GetAlbumsTransaction* self,
                                                          guint value)
{
#line 308 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_GET_ALBUMS_TRANSACTION (self));
#line 308 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->_urls_sent = value;
#line 4384 "GalleryConnector.c"
}


gboolean
publishing_gallery3_get_albums_transaction_get_more_urls (PublishingGallery3GetAlbumsTransaction* self)
{
	gboolean result;
	gboolean _tmp0_;
#line 310 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (PUBLISHING_GALLERY3_IS_GET_ALBUMS_TRANSACTION (self), FALSE);
#line 310 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->_more_urls;
#line 310 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = _tmp0_;
#line 310 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 4401 "GalleryConnector.c"
}


static void
publishing_gallery3_get_albums_transaction_set_more_urls (PublishingGallery3GetAlbumsTransaction* self,
                                                          gboolean value)
{
#line 310 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_GET_ALBUMS_TRANSACTION (self));
#line 310 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->_more_urls = value;
#line 4413 "GalleryConnector.c"
}


static void
publishing_gallery3_get_albums_transaction_class_init (PublishingGallery3GetAlbumsTransactionClass * klass)
{
#line 302 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_get_albums_transaction_parent_class = g_type_class_peek_parent (klass);
#line 302 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	((PublishingRESTSupportTransactionClass *) klass)->finalize = publishing_gallery3_get_albums_transaction_finalize;
#line 302 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_type_class_add_private (klass, sizeof (PublishingGallery3GetAlbumsTransactionPrivate));
#line 4426 "GalleryConnector.c"
}


static void
publishing_gallery3_get_albums_transaction_instance_init (PublishingGallery3GetAlbumsTransaction * self)
{
#line 302 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv = PUBLISHING_GALLERY3_GET_ALBUMS_TRANSACTION_GET_PRIVATE (self);
#line 306 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->_album_urls = NULL;
#line 306 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->_album_urls_length1 = 0;
#line 306 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->__album_urls_size_ = self->priv->_album_urls_length1;
#line 308 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->_urls_sent = (guint) 0;
#line 310 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->_more_urls = FALSE;
#line 4445 "GalleryConnector.c"
}


static void
publishing_gallery3_get_albums_transaction_finalize (PublishingRESTSupportTransaction * obj)
{
	PublishingGallery3GetAlbumsTransaction * self;
#line 302 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_GALLERY3_TYPE_GET_ALBUMS_TRANSACTION, PublishingGallery3GetAlbumsTransaction);
#line 306 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->_album_urls = (_vala_array_free (self->priv->_album_urls, self->priv->_album_urls_length1, (GDestroyNotify) g_free), NULL);
#line 302 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	PUBLISHING_REST_SUPPORT_TRANSACTION_CLASS (publishing_gallery3_get_albums_transaction_parent_class)->finalize (obj);
#line 4459 "GalleryConnector.c"
}


GType
publishing_gallery3_get_albums_transaction_get_type (void)
{
	static volatile gsize publishing_gallery3_get_albums_transaction_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_gallery3_get_albums_transaction_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingGallery3GetAlbumsTransactionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_gallery3_get_albums_transaction_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingGallery3GetAlbumsTransaction), 0, (GInstanceInitFunc) publishing_gallery3_get_albums_transaction_instance_init, NULL };
		GType publishing_gallery3_get_albums_transaction_type_id;
		publishing_gallery3_get_albums_transaction_type_id = g_type_register_static (PUBLISHING_GALLERY3_TYPE_GALLERY_REQUEST_TRANSACTION, "PublishingGallery3GetAlbumsTransaction", &g_define_type_info, 0);
		g_once_init_leave (&publishing_gallery3_get_albums_transaction_type_id__volatile, publishing_gallery3_get_albums_transaction_type_id);
	}
	return publishing_gallery3_get_albums_transaction_type_id__volatile;
}


static void
_vala_JsonNode_free (JsonNode* self)
{
#line 388 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_boxed_free (json_node_get_type (), self);
#line 4482 "GalleryConnector.c"
}


PublishingGallery3GalleryGetTagTransaction*
publishing_gallery3_gallery_get_tag_transaction_construct (GType object_type,
                                                           PublishingGallery3Session* session,
                                                           const gchar* tag_name)
{
	PublishingGallery3GalleryGetTagTransaction* self = NULL;
#line 386 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (PUBLISHING_GALLERY3_IS_SESSION (session), NULL);
#line 386 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (tag_name != NULL, NULL);
#line 388 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (!publishing_rest_support_session_is_authenticated (G_TYPE_CHECK_INSTANCE_CAST (session, PUBLISHING_REST_SUPPORT_TYPE_SESSION, PublishingRESTSupportSession))) {
#line 389 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_error ("GalleryConnector.vala:389: Not authenticated");
#line 4500 "GalleryConnector.c"
	} else {
		JsonGenerator* entity = NULL;
		JsonGenerator* _tmp0_;
		JsonNode* root_node = NULL;
		JsonNode* _tmp1_;
		JsonObject* obj = NULL;
		JsonObject* _tmp2_;
		const gchar* _tmp3_;
		const gchar* _tmp4_;
		const gchar* _tmp5_;
		const gchar* _tmp6_;
		gsize entity_length = 0UL;
		gchar* entity_value = NULL;
		gsize _tmp7_ = 0UL;
		gchar* _tmp8_;
#line 392 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp0_ = json_generator_new ();
#line 392 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		entity = _tmp0_;
#line 393 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp1_ = json_node_new (JSON_NODE_OBJECT);
#line 393 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		root_node = _tmp1_;
#line 394 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp2_ = json_object_new ();
#line 394 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		obj = _tmp2_;
#line 396 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp3_ = publishing_gallery3_session_get_url (session);
#line 396 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp4_ = _tmp3_;
#line 396 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		self = (PublishingGallery3GalleryGetTagTransaction*) publishing_gallery3_base_gallery_transaction_construct (object_type, session, _tmp4_, "/tags", PUBLISHING_REST_SUPPORT_HTTP_METHOD_POST);
#line 399 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp5_ = publishing_gallery3_session_get_key (session);
#line 399 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp6_ = _tmp5_;
#line 399 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		publishing_rest_support_transaction_add_header (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "X-Gallery-Request-Key", _tmp6_);
#line 400 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		publishing_rest_support_transaction_add_header (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "X-Gallery-Request-Method", "POST");
#line 402 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		json_object_set_string_member (obj, "name", tag_name);
#line 403 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		json_node_set_object (root_node, obj);
#line 404 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		json_generator_set_root (entity, root_node);
#line 407 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp8_ = json_generator_to_data (entity, &_tmp7_);
#line 407 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		entity_length = _tmp7_;
#line 407 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		entity_value = _tmp8_;
#line 409 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_debug ("GalleryConnector.vala:409: created entity: %s", entity_value);
#line 411 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		publishing_rest_support_transaction_add_argument (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "entity", entity_value);
#line 388 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_free0 (entity_value);
#line 388 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_json_object_unref0 (obj);
#line 388 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		__vala_JsonNode_free0 (root_node);
#line 388 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_object_unref0 (entity);
#line 4566 "GalleryConnector.c"
	}
#line 386 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return self;
#line 4570 "GalleryConnector.c"
}


PublishingGallery3GalleryGetTagTransaction*
publishing_gallery3_gallery_get_tag_transaction_new (PublishingGallery3Session* session,
                                                     const gchar* tag_name)
{
#line 386 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return publishing_gallery3_gallery_get_tag_transaction_construct (PUBLISHING_GALLERY3_TYPE_GALLERY_GET_TAG_TRANSACTION, session, tag_name);
#line 4580 "GalleryConnector.c"
}


gchar*
publishing_gallery3_gallery_get_tag_transaction_tag_url (PublishingGallery3GalleryGetTagTransaction* self)
{
	gchar* result = NULL;
	JsonNode* root_node = NULL;
	gchar* url = NULL;
	JsonObject* _tmp2_;
	const gchar* _tmp3_;
	gchar* _tmp4_;
	GError * _inner_error_ = NULL;
#line 416 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (PUBLISHING_GALLERY3_IS_GALLERY_GET_TAG_TRANSACTION (self), NULL);
#line 4596 "GalleryConnector.c"
	{
		JsonNode* _tmp0_ = NULL;
		JsonNode* _tmp1_;
#line 422 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp1_ = publishing_gallery3_base_gallery_transaction_get_root_node (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_GALLERY3_TYPE_BASE_GALLERY_TRANSACTION, PublishingGallery3BaseGalleryTransaction), &_inner_error_);
#line 422 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp0_ = _tmp1_;
#line 422 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 422 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 4608 "GalleryConnector.c"
				goto __catch2_spit_publishing_publishing_error;
			}
#line 422 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_g_free0 (url);
#line 422 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 422 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			g_clear_error (&_inner_error_);
#line 422 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			return NULL;
#line 4619 "GalleryConnector.c"
		}
#line 422 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		root_node = _tmp0_;
#line 4623 "GalleryConnector.c"
	}
	goto __finally2;
	__catch2_spit_publishing_publishing_error:
	{
		GError* e = NULL;
#line 421 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		e = _inner_error_;
#line 421 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_inner_error_ = NULL;
#line 425 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_error ("GalleryConnector.vala:425: Could not get root node");
#line 421 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_error_free0 (e);
#line 4637 "GalleryConnector.c"
	}
	__finally2:
#line 421 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 421 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_free0 (url);
#line 421 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 421 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_clear_error (&_inner_error_);
#line 421 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		return NULL;
#line 4650 "GalleryConnector.c"
	}
#line 428 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp2_ = json_node_get_object (root_node);
#line 428 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp3_ = json_object_get_string_member (_tmp2_, "url");
#line 428 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp4_ = g_strdup (_tmp3_);
#line 428 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (url);
#line 428 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	url = _tmp4_;
#line 431 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = url;
#line 431 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 4666 "GalleryConnector.c"
}


static void
publishing_gallery3_gallery_get_tag_transaction_class_init (PublishingGallery3GalleryGetTagTransactionClass * klass)
{
#line 384 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_gallery_get_tag_transaction_parent_class = g_type_class_peek_parent (klass);
#line 4675 "GalleryConnector.c"
}


static void
publishing_gallery3_gallery_get_tag_transaction_instance_init (PublishingGallery3GalleryGetTagTransaction * self)
{
}


GType
publishing_gallery3_gallery_get_tag_transaction_get_type (void)
{
	static volatile gsize publishing_gallery3_gallery_get_tag_transaction_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_gallery3_gallery_get_tag_transaction_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingGallery3GalleryGetTagTransactionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_gallery3_gallery_get_tag_transaction_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingGallery3GalleryGetTagTransaction), 0, (GInstanceInitFunc) publishing_gallery3_gallery_get_tag_transaction_instance_init, NULL };
		GType publishing_gallery3_gallery_get_tag_transaction_type_id;
		publishing_gallery3_gallery_get_tag_transaction_type_id = g_type_register_static (PUBLISHING_GALLERY3_TYPE_BASE_GALLERY_TRANSACTION, "PublishingGallery3GalleryGetTagTransaction", &g_define_type_info, 0);
		g_once_init_leave (&publishing_gallery3_gallery_get_tag_transaction_type_id__volatile, publishing_gallery3_gallery_get_tag_transaction_type_id);
	}
	return publishing_gallery3_gallery_get_tag_transaction_type_id__volatile;
}


PublishingGallery3GalleryGetItemTagsURLsTransaction*
publishing_gallery3_gallery_get_item_tags_ur_ls_transaction_construct (GType object_type,
                                                                       PublishingGallery3Session* session,
                                                                       const gchar* item_url)
{
	PublishingGallery3GalleryGetItemTagsURLsTransaction* self = NULL;
#line 443 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (PUBLISHING_GALLERY3_IS_SESSION (session), NULL);
#line 443 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (item_url != NULL, NULL);
#line 446 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = (PublishingGallery3GalleryGetItemTagsURLsTransaction*) publishing_gallery3_gallery_request_transaction_construct (object_type, session, item_url, PUBLISHING_REST_SUPPORT_HTTP_METHOD_GET);
#line 443 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return self;
#line 4713 "GalleryConnector.c"
}


PublishingGallery3GalleryGetItemTagsURLsTransaction*
publishing_gallery3_gallery_get_item_tags_ur_ls_transaction_new (PublishingGallery3Session* session,
                                                                 const gchar* item_url)
{
#line 443 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return publishing_gallery3_gallery_get_item_tags_ur_ls_transaction_construct (PUBLISHING_GALLERY3_TYPE_GALLERY_GET_ITEM_TAGS_UR_LS_TRANSACTION, session, item_url);
#line 4723 "GalleryConnector.c"
}


gchar*
publishing_gallery3_gallery_get_item_tags_ur_ls_transaction_get_item_tags_path (PublishingGallery3GalleryGetItemTagsURLsTransaction* self)
{
	gchar* result = NULL;
	JsonNode* root_node = NULL;
	JsonObject* relationships = NULL;
	JsonObject* tags = NULL;
	const gchar* _tmp0_;
	const gchar* _tmp13_;
	gchar* _tmp14_;
	GError * _inner_error_ = NULL;
#line 450 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (PUBLISHING_GALLERY3_IS_GALLERY_GET_ITEM_TAGS_UR_LS_TRANSACTION (self), NULL);
#line 455 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->item_tags_path;
#line 455 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (g_strcmp0 ("", _tmp0_) == 0) {
#line 4744 "GalleryConnector.c"
		JsonNode* _tmp3_;
		JsonObject* _tmp4_;
		JsonObject* _tmp5_;
		JsonObject* _tmp6_;
		JsonObject* _tmp7_;
		JsonObject* _tmp8_;
		const gchar* _tmp9_;
		gchar* _tmp10_;
		const gchar* _tmp11_;
		gchar* _tmp12_;
		{
			JsonNode* _tmp1_ = NULL;
			JsonNode* _tmp2_;
#line 458 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp2_ = publishing_gallery3_base_gallery_transaction_get_root_node (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_GALLERY3_TYPE_BASE_GALLERY_TRANSACTION, PublishingGallery3BaseGalleryTransaction), &_inner_error_);
#line 458 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp1_ = _tmp2_;
#line 458 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 458 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 4766 "GalleryConnector.c"
					goto __catch3_spit_publishing_publishing_error;
				}
#line 458 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 458 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				g_clear_error (&_inner_error_);
#line 458 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				return NULL;
#line 4775 "GalleryConnector.c"
			}
#line 458 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			root_node = _tmp1_;
#line 4779 "GalleryConnector.c"
		}
		goto __finally3;
		__catch3_spit_publishing_publishing_error:
		{
			GError* e = NULL;
#line 457 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			e = _inner_error_;
#line 457 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_inner_error_ = NULL;
#line 461 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			g_error ("GalleryConnector.vala:461: Could not get root node");
#line 457 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_g_error_free0 (e);
#line 4793 "GalleryConnector.c"
		}
		__finally3:
#line 457 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 457 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 457 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			g_clear_error (&_inner_error_);
#line 457 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			return NULL;
#line 4804 "GalleryConnector.c"
		}
#line 464 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp3_ = root_node;
#line 464 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp4_ = json_node_get_object (_tmp3_);
#line 464 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp5_ = json_object_get_object_member (_tmp4_, "relationships");
#line 464 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		relationships = _tmp5_;
#line 466 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp6_ = relationships;
#line 466 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp7_ = json_object_get_object_member (_tmp6_, "tags");
#line 466 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		tags = _tmp7_;
#line 468 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp8_ = tags;
#line 468 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp9_ = json_object_get_string_member (_tmp8_, "url");
#line 468 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp10_ = g_strdup (_tmp9_);
#line 468 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_free0 (self->priv->item_tags_path);
#line 468 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		self->priv->item_tags_path = _tmp10_;
#line 471 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp11_ = self->priv->item_tags_path;
#line 471 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp12_ = publishing_gallery3_strip_session_url (_tmp11_);
#line 471 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_free0 (self->priv->item_tags_path);
#line 471 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		self->priv->item_tags_path = _tmp12_;
#line 4838 "GalleryConnector.c"
	}
#line 475 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp13_ = self->priv->item_tags_path;
#line 475 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp14_ = g_strdup (_tmp13_);
#line 475 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = _tmp14_;
#line 475 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 4848 "GalleryConnector.c"
}


static void
publishing_gallery3_gallery_get_item_tags_ur_ls_transaction_class_init (PublishingGallery3GalleryGetItemTagsURLsTransactionClass * klass)
{
#line 438 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_gallery_get_item_tags_ur_ls_transaction_parent_class = g_type_class_peek_parent (klass);
#line 438 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	((PublishingRESTSupportTransactionClass *) klass)->finalize = publishing_gallery3_gallery_get_item_tags_ur_ls_transaction_finalize;
#line 438 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_type_class_add_private (klass, sizeof (PublishingGallery3GalleryGetItemTagsURLsTransactionPrivate));
#line 4861 "GalleryConnector.c"
}


static void
publishing_gallery3_gallery_get_item_tags_ur_ls_transaction_instance_init (PublishingGallery3GalleryGetItemTagsURLsTransaction * self)
{
	gchar* _tmp0_;
#line 438 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv = PUBLISHING_GALLERY3_GALLERY_GET_ITEM_TAGS_UR_LS_TRANSACTION_GET_PRIVATE (self);
#line 441 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = g_strdup ("");
#line 441 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->item_tags_path = _tmp0_;
#line 4875 "GalleryConnector.c"
}


static void
publishing_gallery3_gallery_get_item_tags_ur_ls_transaction_finalize (PublishingRESTSupportTransaction * obj)
{
	PublishingGallery3GalleryGetItemTagsURLsTransaction * self;
#line 438 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_GALLERY3_TYPE_GALLERY_GET_ITEM_TAGS_UR_LS_TRANSACTION, PublishingGallery3GalleryGetItemTagsURLsTransaction);
#line 441 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (self->priv->item_tags_path);
#line 438 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	PUBLISHING_REST_SUPPORT_TRANSACTION_CLASS (publishing_gallery3_gallery_get_item_tags_ur_ls_transaction_parent_class)->finalize (obj);
#line 4889 "GalleryConnector.c"
}


GType
publishing_gallery3_gallery_get_item_tags_ur_ls_transaction_get_type (void)
{
	static volatile gsize publishing_gallery3_gallery_get_item_tags_ur_ls_transaction_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_gallery3_gallery_get_item_tags_ur_ls_transaction_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingGallery3GalleryGetItemTagsURLsTransactionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_gallery3_gallery_get_item_tags_ur_ls_transaction_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingGallery3GalleryGetItemTagsURLsTransaction), 0, (GInstanceInitFunc) publishing_gallery3_gallery_get_item_tags_ur_ls_transaction_instance_init, NULL };
		GType publishing_gallery3_gallery_get_item_tags_ur_ls_transaction_type_id;
		publishing_gallery3_gallery_get_item_tags_ur_ls_transaction_type_id = g_type_register_static (PUBLISHING_GALLERY3_TYPE_GALLERY_REQUEST_TRANSACTION, "PublishingGallery3GalleryGetItemTagsURLsTransaction", &g_define_type_info, 0);
		g_once_init_leave (&publishing_gallery3_gallery_get_item_tags_ur_ls_transaction_type_id__volatile, publishing_gallery3_gallery_get_item_tags_ur_ls_transaction_type_id);
	}
	return publishing_gallery3_gallery_get_item_tags_ur_ls_transaction_type_id__volatile;
}


PublishingGallery3GallerySetTagRelationshipTransaction*
publishing_gallery3_gallery_set_tag_relationship_transaction_construct (GType object_type,
                                                                        PublishingGallery3Session* session,
                                                                        const gchar* item_tags_path,
                                                                        const gchar* tag_url,
                                                                        const gchar* item_url)
{
	PublishingGallery3GallerySetTagRelationshipTransaction* self = NULL;
#line 485 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (PUBLISHING_GALLERY3_IS_SESSION (session), NULL);
#line 485 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (item_tags_path != NULL, NULL);
#line 485 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (tag_url != NULL, NULL);
#line 485 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (item_url != NULL, NULL);
#line 488 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (!publishing_rest_support_session_is_authenticated (G_TYPE_CHECK_INSTANCE_CAST (session, PUBLISHING_REST_SUPPORT_TYPE_SESSION, PublishingRESTSupportSession))) {
#line 489 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_error ("GalleryConnector.vala:489: Not authenticated");
#line 4927 "GalleryConnector.c"
	} else {
		JsonGenerator* entity = NULL;
		JsonGenerator* _tmp0_;
		JsonNode* root_node = NULL;
		JsonNode* _tmp1_;
		JsonObject* obj = NULL;
		JsonObject* _tmp2_;
		const gchar* _tmp3_;
		const gchar* _tmp4_;
		const gchar* _tmp5_;
		const gchar* _tmp6_;
		gsize entity_length = 0UL;
		gchar* entity_value = NULL;
		gsize _tmp7_ = 0UL;
		gchar* _tmp8_;
#line 492 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp0_ = json_generator_new ();
#line 492 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		entity = _tmp0_;
#line 493 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp1_ = json_node_new (JSON_NODE_OBJECT);
#line 493 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		root_node = _tmp1_;
#line 494 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp2_ = json_object_new ();
#line 494 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		obj = _tmp2_;
#line 496 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp3_ = publishing_gallery3_session_get_url (session);
#line 496 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp4_ = _tmp3_;
#line 496 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		self = (PublishingGallery3GallerySetTagRelationshipTransaction*) publishing_gallery3_base_gallery_transaction_construct (object_type, session, _tmp4_, item_tags_path, PUBLISHING_REST_SUPPORT_HTTP_METHOD_POST);
#line 499 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp5_ = publishing_gallery3_session_get_key (session);
#line 499 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp6_ = _tmp5_;
#line 499 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		publishing_rest_support_transaction_add_header (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "X-Gallery-Request-Key", _tmp6_);
#line 500 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		publishing_rest_support_transaction_add_header (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "X-Gallery-Request-Method", "POST");
#line 502 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		json_object_set_string_member (obj, "tag", tag_url);
#line 503 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		json_object_set_string_member (obj, "item", item_url);
#line 504 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		json_node_set_object (root_node, obj);
#line 505 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		json_generator_set_root (entity, root_node);
#line 508 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp8_ = json_generator_to_data (entity, &_tmp7_);
#line 508 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		entity_length = _tmp7_;
#line 508 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		entity_value = _tmp8_;
#line 510 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_debug ("GalleryConnector.vala:510: created entity: %s", entity_value);
#line 512 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		publishing_rest_support_transaction_add_argument (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "entity", entity_value);
#line 488 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_free0 (entity_value);
#line 488 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_json_object_unref0 (obj);
#line 488 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		__vala_JsonNode_free0 (root_node);
#line 488 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_object_unref0 (entity);
#line 4995 "GalleryConnector.c"
	}
#line 485 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return self;
#line 4999 "GalleryConnector.c"
}


PublishingGallery3GallerySetTagRelationshipTransaction*
publishing_gallery3_gallery_set_tag_relationship_transaction_new (PublishingGallery3Session* session,
                                                                  const gchar* item_tags_path,
                                                                  const gchar* tag_url,
                                                                  const gchar* item_url)
{
#line 485 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return publishing_gallery3_gallery_set_tag_relationship_transaction_construct (PUBLISHING_GALLERY3_TYPE_GALLERY_SET_TAG_RELATIONSHIP_TRANSACTION, session, item_tags_path, tag_url, item_url);
#line 5011 "GalleryConnector.c"
}


static void
publishing_gallery3_gallery_set_tag_relationship_transaction_class_init (PublishingGallery3GallerySetTagRelationshipTransactionClass * klass)
{
#line 482 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_gallery_set_tag_relationship_transaction_parent_class = g_type_class_peek_parent (klass);
#line 5020 "GalleryConnector.c"
}


static void
publishing_gallery3_gallery_set_tag_relationship_transaction_instance_init (PublishingGallery3GallerySetTagRelationshipTransaction * self)
{
}


GType
publishing_gallery3_gallery_set_tag_relationship_transaction_get_type (void)
{
	static volatile gsize publishing_gallery3_gallery_set_tag_relationship_transaction_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_gallery3_gallery_set_tag_relationship_transaction_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingGallery3GallerySetTagRelationshipTransactionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_gallery3_gallery_set_tag_relationship_transaction_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingGallery3GallerySetTagRelationshipTransaction), 0, (GInstanceInitFunc) publishing_gallery3_gallery_set_tag_relationship_transaction_instance_init, NULL };
		GType publishing_gallery3_gallery_set_tag_relationship_transaction_type_id;
		publishing_gallery3_gallery_set_tag_relationship_transaction_type_id = g_type_register_static (PUBLISHING_GALLERY3_TYPE_BASE_GALLERY_TRANSACTION, "PublishingGallery3GallerySetTagRelationshipTransaction", &g_define_type_info, 0);
		g_once_init_leave (&publishing_gallery3_gallery_set_tag_relationship_transaction_type_id__volatile, publishing_gallery3_gallery_set_tag_relationship_transaction_type_id);
	}
	return publishing_gallery3_gallery_set_tag_relationship_transaction_type_id__volatile;
}


PublishingGallery3GalleryAlbumCreateTransaction*
publishing_gallery3_gallery_album_create_transaction_construct (GType object_type,
                                                                PublishingGallery3Session* session,
                                                                PublishingGallery3PublishingParameters* parameters)
{
	PublishingGallery3GalleryAlbumCreateTransaction* self = NULL;
#line 529 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (PUBLISHING_GALLERY3_IS_SESSION (session), NULL);
#line 529 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (PUBLISHING_GALLERY3_IS_PUBLISHING_PARAMETERS (parameters), NULL);
#line 532 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (!publishing_rest_support_session_is_authenticated (G_TYPE_CHECK_INSTANCE_CAST (session, PUBLISHING_REST_SUPPORT_TYPE_SESSION, PublishingRESTSupportSession))) {
#line 533 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_error ("GalleryConnector.vala:533: Not authenticated");
#line 5058 "GalleryConnector.c"
	} else {
		JsonGenerator* entity = NULL;
		JsonGenerator* _tmp0_;
		JsonNode* root_node = NULL;
		JsonNode* _tmp1_;
		JsonObject* obj = NULL;
		JsonObject* _tmp2_;
		const gchar* _tmp3_;
		const gchar* _tmp4_;
		const gchar* _tmp5_;
		const gchar* _tmp6_;
		const gchar* _tmp7_;
		const gchar* _tmp8_;
		gchar* _tmp9_;
		const gchar* _tmp10_;
		const gchar* _tmp11_;
		const gchar* _tmp12_;
		const gchar* _tmp13_;
		gchar* entity_value = NULL;
		gchar* _tmp14_;
#line 536 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp0_ = json_generator_new ();
#line 536 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		entity = _tmp0_;
#line 537 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp1_ = json_node_new (JSON_NODE_OBJECT);
#line 537 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		root_node = _tmp1_;
#line 538 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp2_ = json_object_new ();
#line 538 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		obj = _tmp2_;
#line 540 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp3_ = publishing_gallery3_session_get_url (session);
#line 540 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp4_ = _tmp3_;
#line 540 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		self = (PublishingGallery3GalleryAlbumCreateTransaction*) publishing_gallery3_base_gallery_transaction_construct (object_type, session, _tmp4_, "/item/1", PUBLISHING_REST_SUPPORT_HTTP_METHOD_POST);
#line 542 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp5_ = publishing_gallery3_session_get_key (session);
#line 542 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp6_ = _tmp5_;
#line 542 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		publishing_rest_support_transaction_add_header (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "X-Gallery-Request-Key", _tmp6_);
#line 543 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		publishing_rest_support_transaction_add_header (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "X-Gallery-Request-Method", "POST");
#line 545 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp7_ = publishing_gallery3_session_get_url (session);
#line 545 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp8_ = _tmp7_;
#line 545 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp9_ = g_strdup (_tmp8_);
#line 545 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_free0 (self->priv->session_url);
#line 545 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		self->priv->session_url = _tmp9_;
#line 546 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		publishing_gallery3_gallery_album_create_transaction_set_parameters (self, parameters);
#line 548 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp10_ = publishing_gallery3_publishing_parameters_get_album_name (parameters);
#line 548 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp11_ = _tmp10_;
#line 548 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		json_object_set_string_member (obj, "name", _tmp11_);
#line 549 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		json_object_set_string_member (obj, "type", "album");
#line 550 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp12_ = publishing_gallery3_publishing_parameters_get_album_title (parameters);
#line 550 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp13_ = _tmp12_;
#line 550 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		json_object_set_string_member (obj, "title", _tmp13_);
#line 551 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		json_node_set_object (root_node, obj);
#line 552 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		json_generator_set_root (entity, root_node);
#line 554 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp14_ = json_generator_to_data (entity, NULL);
#line 554 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		entity_value = _tmp14_;
#line 556 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_debug ("GalleryConnector.vala:556: created entity: %s", entity_value);
#line 558 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		publishing_rest_support_transaction_add_argument (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "entity", entity_value);
#line 532 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_free0 (entity_value);
#line 532 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_json_object_unref0 (obj);
#line 532 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		__vala_JsonNode_free0 (root_node);
#line 532 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_object_unref0 (entity);
#line 5151 "GalleryConnector.c"
	}
#line 529 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return self;
#line 5155 "GalleryConnector.c"
}


PublishingGallery3GalleryAlbumCreateTransaction*
publishing_gallery3_gallery_album_create_transaction_new (PublishingGallery3Session* session,
                                                          PublishingGallery3PublishingParameters* parameters)
{
#line 529 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return publishing_gallery3_gallery_album_create_transaction_construct (PUBLISHING_GALLERY3_TYPE_GALLERY_ALBUM_CREATE_TRANSACTION, session, parameters);
#line 5165 "GalleryConnector.c"
}


gchar*
publishing_gallery3_gallery_album_create_transaction_get_new_album_path (PublishingGallery3GalleryAlbumCreateTransaction* self)
{
	gchar* result = NULL;
	JsonNode* root_node = NULL;
	gchar* new_path = NULL;
	JsonObject* _tmp2_;
	const gchar* _tmp3_;
	gchar* _tmp4_;
	const gchar* _tmp5_;
	gchar* _tmp6_;
	GError * _inner_error_ = NULL;
#line 563 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (PUBLISHING_GALLERY3_IS_GALLERY_ALBUM_CREATE_TRANSACTION (self), NULL);
#line 5183 "GalleryConnector.c"
	{
		JsonNode* _tmp0_ = NULL;
		JsonNode* _tmp1_;
#line 569 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp1_ = publishing_gallery3_base_gallery_transaction_get_root_node (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_GALLERY3_TYPE_BASE_GALLERY_TRANSACTION, PublishingGallery3BaseGalleryTransaction), &_inner_error_);
#line 569 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp0_ = _tmp1_;
#line 569 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 569 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 5195 "GalleryConnector.c"
				goto __catch4_spit_publishing_publishing_error;
			}
#line 569 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_g_free0 (new_path);
#line 569 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 569 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			g_clear_error (&_inner_error_);
#line 569 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			return NULL;
#line 5206 "GalleryConnector.c"
		}
#line 569 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		root_node = _tmp0_;
#line 5210 "GalleryConnector.c"
	}
	goto __finally4;
	__catch4_spit_publishing_publishing_error:
	{
		GError* e = NULL;
#line 568 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		e = _inner_error_;
#line 568 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_inner_error_ = NULL;
#line 572 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_error ("GalleryConnector.vala:572: Could not get root node");
#line 568 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_error_free0 (e);
#line 5224 "GalleryConnector.c"
	}
	__finally4:
#line 568 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 568 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_free0 (new_path);
#line 568 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 568 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_clear_error (&_inner_error_);
#line 568 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		return NULL;
#line 5237 "GalleryConnector.c"
	}
#line 575 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp2_ = json_node_get_object (root_node);
#line 575 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp3_ = json_object_get_string_member (_tmp2_, "url");
#line 575 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp4_ = g_strdup (_tmp3_);
#line 575 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (new_path);
#line 575 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	new_path = _tmp4_;
#line 577 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp5_ = new_path;
#line 577 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp6_ = publishing_gallery3_strip_session_url (_tmp5_);
#line 577 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (new_path);
#line 577 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	new_path = _tmp6_;
#line 579 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = new_path;
#line 579 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 5261 "GalleryConnector.c"
}


PublishingGallery3PublishingParameters*
publishing_gallery3_gallery_album_create_transaction_get_parameters (PublishingGallery3GalleryAlbumCreateTransaction* self)
{
	PublishingGallery3PublishingParameters* result;
	PublishingGallery3PublishingParameters* _tmp0_;
#line 522 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (PUBLISHING_GALLERY3_IS_GALLERY_ALBUM_CREATE_TRANSACTION (self), NULL);
#line 522 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->_parameters;
#line 522 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = _tmp0_;
#line 522 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 5278 "GalleryConnector.c"
}


static gpointer
_publishing_gallery3_publishing_parameters_ref0 (gpointer self)
{
#line 522 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return self ? publishing_gallery3_publishing_parameters_ref (self) : NULL;
#line 5287 "GalleryConnector.c"
}


static void
publishing_gallery3_gallery_album_create_transaction_set_parameters (PublishingGallery3GalleryAlbumCreateTransaction* self,
                                                                     PublishingGallery3PublishingParameters* value)
{
	PublishingGallery3PublishingParameters* _tmp0_;
#line 522 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_GALLERY_ALBUM_CREATE_TRANSACTION (self));
#line 522 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = _publishing_gallery3_publishing_parameters_ref0 (value);
#line 522 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_publishing_gallery3_publishing_parameters_unref0 (self->priv->_parameters);
#line 522 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->_parameters = _tmp0_;
#line 5304 "GalleryConnector.c"
}


static void
publishing_gallery3_gallery_album_create_transaction_class_init (PublishingGallery3GalleryAlbumCreateTransactionClass * klass)
{
#line 519 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_gallery_album_create_transaction_parent_class = g_type_class_peek_parent (klass);
#line 519 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	((PublishingRESTSupportTransactionClass *) klass)->finalize = publishing_gallery3_gallery_album_create_transaction_finalize;
#line 519 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_type_class_add_private (klass, sizeof (PublishingGallery3GalleryAlbumCreateTransactionPrivate));
#line 5317 "GalleryConnector.c"
}


static void
publishing_gallery3_gallery_album_create_transaction_instance_init (PublishingGallery3GalleryAlbumCreateTransaction * self)
{
#line 519 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv = PUBLISHING_GALLERY3_GALLERY_ALBUM_CREATE_TRANSACTION_GET_PRIVATE (self);
#line 5326 "GalleryConnector.c"
}


static void
publishing_gallery3_gallery_album_create_transaction_finalize (PublishingRESTSupportTransaction * obj)
{
	PublishingGallery3GalleryAlbumCreateTransaction * self;
#line 519 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_GALLERY3_TYPE_GALLERY_ALBUM_CREATE_TRANSACTION, PublishingGallery3GalleryAlbumCreateTransaction);
#line 522 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_publishing_gallery3_publishing_parameters_unref0 (self->priv->_parameters);
#line 524 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (self->priv->session_url);
#line 519 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	PUBLISHING_REST_SUPPORT_TRANSACTION_CLASS (publishing_gallery3_gallery_album_create_transaction_parent_class)->finalize (obj);
#line 5342 "GalleryConnector.c"
}


GType
publishing_gallery3_gallery_album_create_transaction_get_type (void)
{
	static volatile gsize publishing_gallery3_gallery_album_create_transaction_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_gallery3_gallery_album_create_transaction_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingGallery3GalleryAlbumCreateTransactionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_gallery3_gallery_album_create_transaction_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingGallery3GalleryAlbumCreateTransaction), 0, (GInstanceInitFunc) publishing_gallery3_gallery_album_create_transaction_instance_init, NULL };
		GType publishing_gallery3_gallery_album_create_transaction_type_id;
		publishing_gallery3_gallery_album_create_transaction_type_id = g_type_register_static (PUBLISHING_GALLERY3_TYPE_BASE_GALLERY_TRANSACTION, "PublishingGallery3GalleryAlbumCreateTransaction", &g_define_type_info, 0);
		g_once_init_leave (&publishing_gallery3_gallery_album_create_transaction_type_id__volatile, publishing_gallery3_gallery_album_create_transaction_type_id);
	}
	return publishing_gallery3_gallery_album_create_transaction_type_id__volatile;
}


static gpointer
_publishing_rest_support_session_ref0 (gpointer self)
{
#line 609 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return self ? publishing_rest_support_session_ref (self) : NULL;
#line 5365 "GalleryConnector.c"
}


static void
_g_free0_ (gpointer var)
{
#line 614 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	var = (g_free (var), NULL);
#line 5374 "GalleryConnector.c"
}


PublishingGallery3GalleryUploadTransaction*
publishing_gallery3_gallery_upload_transaction_construct (GType object_type,
                                                          PublishingGallery3Session* session,
                                                          PublishingGallery3PublishingParameters* parameters,
                                                          SpitPublishingPublishable* publishable)
{
	PublishingGallery3GalleryUploadTransaction* self = NULL;
	const gchar* _tmp0_;
	const gchar* _tmp1_;
	const gchar* _tmp4_;
	const gchar* _tmp5_;
	gchar* _tmp6_;
	gchar* _tmp7_;
	const gchar* _tmp8_;
	const gchar* _tmp9_;
	gchar* _tmp10_;
	gchar* _tmp11_;
	PublishingGallery3PublishingParameters* _tmp12_;
	PublishingGallery3Session* _tmp13_;
	const gchar* _tmp14_;
	const gchar* _tmp15_;
	GHashTable* disposition_table = NULL;
	GHashFunc _tmp16_;
	GEqualFunc _tmp17_;
	GHashTable* _tmp18_;
	gchar* title = NULL;
	gchar* _tmp19_;
	gchar* filename = NULL;
	gchar* _tmp20_;
	gboolean _tmp21_ = FALSE;
	const gchar* _tmp22_;
	GHashTable* _tmp26_;
	gchar* _tmp27_;
	const gchar* _tmp28_;
	const gchar* _tmp29_;
	gchar* _tmp30_;
	GHashTable* _tmp31_;
	gchar* _tmp32_;
	gchar* _tmp33_;
	GHashTable* _tmp34_;
	JsonGenerator* _tmp35_;
	gchar* desc = NULL;
	gchar* _tmp36_;
	const gchar* _tmp37_ = NULL;
	gchar* type = NULL;
	gchar* _tmp38_;
	JsonNode* root_node = NULL;
	JsonNode* _tmp39_;
	JsonObject* obj = NULL;
	JsonObject* _tmp40_;
	const gchar* _tmp41_;
	const gchar* _tmp42_;
	const gchar* _tmp43_;
	JsonGenerator* _tmp44_;
	JsonGenerator* _tmp45_;
	gchar* _tmp46_;
	gchar* _tmp47_;
#line 595 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (PUBLISHING_GALLERY3_IS_SESSION (session), NULL);
#line 595 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (PUBLISHING_GALLERY3_IS_PUBLISHING_PARAMETERS (parameters), NULL);
#line 595 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (SPIT_PUBLISHING_IS_PUBLISHABLE (publishable), NULL);
#line 600 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = publishing_gallery3_publishing_parameters_get_album_path (parameters);
#line 600 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = _tmp0_;
#line 600 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (string_get (_tmp1_, (glong) 0) != '/') {
#line 5447 "GalleryConnector.c"
		const gchar* _tmp2_;
		const gchar* _tmp3_;
#line 601 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_warning ("GalleryConnector.vala:601: Bad upload item path, this is a bug!");
#line 602 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp2_ = publishing_gallery3_publishing_parameters_get_album_path (parameters);
#line 602 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp3_ = _tmp2_;
#line 602 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_error ("GalleryConnector.vala:602: %s", _tmp3_);
#line 5458 "GalleryConnector.c"
	}
#line 605 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp4_ = publishing_gallery3_session_get_url (session);
#line 605 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp5_ = _tmp4_;
#line 605 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp6_ = g_strconcat (_tmp5_, PUBLISHING_GALLERY3_REST_PATH, NULL);
#line 605 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp7_ = _tmp6_;
#line 605 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp8_ = publishing_gallery3_publishing_parameters_get_album_path (parameters);
#line 605 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp9_ = _tmp8_;
#line 605 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp10_ = g_strconcat (_tmp7_, _tmp9_, NULL);
#line 605 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp11_ = _tmp10_;
#line 605 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = (PublishingGallery3GalleryUploadTransaction*) publishing_rest_support_upload_transaction_construct_with_endpoint_url (object_type, G_TYPE_CHECK_INSTANCE_CAST (session, PUBLISHING_REST_SUPPORT_TYPE_SESSION, PublishingRESTSupportSession), publishable, _tmp11_);
#line 605 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (_tmp11_);
#line 605 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (_tmp7_);
#line 608 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp12_ = _publishing_gallery3_publishing_parameters_ref0 (parameters);
#line 608 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_publishing_gallery3_publishing_parameters_unref0 (self->priv->parameters);
#line 608 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->parameters = _tmp12_;
#line 609 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp13_ = _publishing_rest_support_session_ref0 (session);
#line 609 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_publishing_rest_support_session_unref0 (self->priv->session);
#line 609 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->session = _tmp13_;
#line 611 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp14_ = publishing_gallery3_session_get_key (session);
#line 611 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp15_ = _tmp14_;
#line 611 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_rest_support_transaction_add_header (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "X-Gallery-Request-Key", _tmp15_);
#line 612 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_rest_support_transaction_add_header (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "X-Gallery-Request-Method", "POST");
#line 614 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp16_ = g_str_hash;
#line 614 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp17_ = g_str_equal;
#line 614 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp18_ = g_hash_table_new_full (_tmp16_, _tmp17_, _g_free0_, _g_free0_);
#line 614 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	disposition_table = _tmp18_;
#line 617 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp19_ = spit_publishing_publishable_get_publishing_name (publishable);
#line 617 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	title = _tmp19_;
#line 618 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp20_ = spit_publishing_publishable_get_param_string (publishable, SPIT_PUBLISHING_PUBLISHABLE_PARAM_STRING_BASENAME);
#line 618 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	filename = _tmp20_;
#line 620 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp22_ = title;
#line 620 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (_tmp22_ == NULL) {
#line 620 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp21_ = TRUE;
#line 5524 "GalleryConnector.c"
	} else {
		const gchar* _tmp23_;
#line 620 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp23_ = title;
#line 620 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp21_ = g_strcmp0 (_tmp23_, "") == 0;
#line 5531 "GalleryConnector.c"
	}
#line 620 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (_tmp21_) {
#line 5535 "GalleryConnector.c"
		const gchar* _tmp24_;
		gchar* _tmp25_;
#line 622 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp24_ = filename;
#line 622 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp25_ = g_strdup (_tmp24_);
#line 622 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_free0 (title);
#line 622 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		title = _tmp25_;
#line 5546 "GalleryConnector.c"
	}
#line 624 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp26_ = disposition_table;
#line 624 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp27_ = g_strdup ("filename");
#line 624 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp28_ = filename;
#line 624 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp29_ = string_to_string (_tmp28_);
#line 624 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp30_ = g_strdup (_tmp29_);
#line 624 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_hash_table_insert (_tmp26_, _tmp27_, _tmp30_);
#line 625 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp31_ = disposition_table;
#line 625 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp32_ = g_strdup ("name");
#line 625 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp33_ = g_strdup ("file");
#line 625 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_hash_table_insert (_tmp31_, _tmp32_, _tmp33_);
#line 627 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp34_ = disposition_table;
#line 627 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_rest_support_upload_transaction_set_binary_disposition_table (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_UPLOAD_TRANSACTION, PublishingRESTSupportUploadTransaction), _tmp34_);
#line 630 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp35_ = json_generator_new ();
#line 630 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_object_unref0 (self->priv->generator);
#line 630 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->generator = _tmp35_;
#line 631 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp36_ = spit_publishing_publishable_get_param_string (publishable, SPIT_PUBLISHING_PUBLISHABLE_PARAM_STRING_COMMENT);
#line 631 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	desc = _tmp36_;
#line 633 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (spit_publishing_publishable_get_media_type (publishable) == SPIT_PUBLISHING_PUBLISHER_MEDIA_TYPE_VIDEO) {
#line 635 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp37_ = "movie";
#line 5586 "GalleryConnector.c"
	} else {
#line 635 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp37_ = "photo";
#line 5590 "GalleryConnector.c"
	}
#line 633 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp38_ = g_strdup (_tmp37_);
#line 633 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	type = _tmp38_;
#line 637 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp39_ = json_node_new (JSON_NODE_OBJECT);
#line 637 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	root_node = _tmp39_;
#line 638 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp40_ = json_object_new ();
#line 638 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	obj = _tmp40_;
#line 639 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp41_ = filename;
#line 639 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	json_object_set_string_member (obj, "name", _tmp41_);
#line 640 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	json_object_set_string_member (obj, "type", type);
#line 641 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp42_ = title;
#line 641 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	json_object_set_string_member (obj, "title", _tmp42_);
#line 642 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp43_ = desc;
#line 642 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	json_object_set_string_member (obj, "description", _tmp43_);
#line 644 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	json_node_set_object (root_node, obj);
#line 645 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp44_ = self->priv->generator;
#line 645 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	json_generator_set_root (_tmp44_, root_node);
#line 647 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp45_ = self->priv->generator;
#line 647 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp46_ = json_generator_to_data (_tmp45_, NULL);
#line 647 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp47_ = _tmp46_;
#line 647 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_rest_support_transaction_add_argument (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "entity", _tmp47_);
#line 647 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (_tmp47_);
#line 595 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_json_object_unref0 (obj);
#line 595 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	__vala_JsonNode_free0 (root_node);
#line 595 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (type);
#line 595 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (desc);
#line 595 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (filename);
#line 595 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (title);
#line 595 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_hash_table_unref0 (disposition_table);
#line 595 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return self;
#line 5650 "GalleryConnector.c"
}


PublishingGallery3GalleryUploadTransaction*
publishing_gallery3_gallery_upload_transaction_new (PublishingGallery3Session* session,
                                                    PublishingGallery3PublishingParameters* parameters,
                                                    SpitPublishingPublishable* publishable)
{
#line 595 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return publishing_gallery3_gallery_upload_transaction_construct (PUBLISHING_GALLERY3_TYPE_GALLERY_UPLOAD_TRANSACTION, session, parameters, publishable);
#line 5661 "GalleryConnector.c"
}


static gchar*
publishing_gallery3_gallery_upload_transaction_get_new_item_url (PublishingGallery3GalleryUploadTransaction* self)
{
	gchar* result = NULL;
	gchar* json_object = NULL;
	gchar* new_url = NULL;
	JsonNode* root_node = NULL;
	JsonParser* parser = NULL;
	JsonParser* _tmp0_;
	gchar* _tmp1_;
	gboolean _tmp2_ = FALSE;
	const gchar* _tmp3_;
	const gchar* _tmp10_;
	JsonParser* _tmp14_;
	JsonNode* _tmp15_;
	JsonNode* _tmp16_;
	JsonNode* _tmp18_;
	JsonObject* _tmp19_;
	const gchar* _tmp20_;
	gchar* _tmp21_;
	GError * _inner_error_ = NULL;
#line 650 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (PUBLISHING_GALLERY3_IS_GALLERY_UPLOAD_TRANSACTION (self), NULL);
#line 655 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = json_parser_new ();
#line 655 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	parser = _tmp0_;
#line 657 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = publishing_rest_support_transaction_get_response (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction));
#line 657 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (json_object);
#line 657 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	json_object = _tmp1_;
#line 659 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp3_ = json_object;
#line 659 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (NULL == _tmp3_) {
#line 659 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp2_ = TRUE;
#line 5704 "GalleryConnector.c"
	} else {
		const gchar* _tmp4_;
		gint _tmp5_;
		gint _tmp6_;
#line 659 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp4_ = json_object;
#line 659 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp5_ = strlen (_tmp4_);
#line 659 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp6_ = _tmp5_;
#line 659 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp2_ = 0 == _tmp6_;
#line 5717 "GalleryConnector.c"
	}
#line 659 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (_tmp2_) {
#line 5721 "GalleryConnector.c"
		gchar* _tmp7_;
		gchar* _tmp8_;
		gchar* _tmp9_;
#line 660 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp7_ = publishing_rest_support_transaction_get_endpoint_url (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction));
#line 660 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp8_ = _tmp7_;
#line 660 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_warning ("GalleryConnector.vala:660: No response data from %s", _tmp8_);
#line 660 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_free0 (_tmp8_);
#line 661 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp9_ = g_strdup ("");
#line 661 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		result = _tmp9_;
#line 661 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_object_unref0 (parser);
#line 661 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_free0 (new_url);
#line 661 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_free0 (json_object);
#line 661 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		return result;
#line 5745 "GalleryConnector.c"
	}
#line 664 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp10_ = json_object;
#line 664 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_debug ("GalleryConnector.vala:664: json_object: %s", _tmp10_);
#line 5751 "GalleryConnector.c"
	{
		JsonParser* _tmp11_;
		const gchar* _tmp12_;
#line 667 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp11_ = parser;
#line 667 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp12_ = json_object;
#line 667 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		json_parser_load_from_data (_tmp11_, _tmp12_, (gssize) -1, &_inner_error_);
#line 667 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 5763 "GalleryConnector.c"
			goto __catch5_g_error;
		}
	}
	goto __finally5;
	__catch5_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp13_;
#line 666 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		e = _inner_error_;
#line 666 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_inner_error_ = NULL;
#line 672 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_warning ("GalleryConnector.vala:672: ERROR: didn't load JSON data");
#line 673 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		publishing_rest_support_transaction_set_is_executed (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), FALSE);
#line 674 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp13_ = e->message;
#line 674 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_error ("GalleryConnector.vala:674: %s", _tmp13_);
#line 666 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_error_free0 (e);
#line 5786 "GalleryConnector.c"
	}
	__finally5:
#line 666 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 666 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_object_unref0 (parser);
#line 666 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_free0 (new_url);
#line 666 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_free0 (json_object);
#line 666 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 666 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_clear_error (&_inner_error_);
#line 666 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		return NULL;
#line 5803 "GalleryConnector.c"
	}
#line 677 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp14_ = parser;
#line 677 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp15_ = json_parser_get_root (_tmp14_);
#line 677 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	root_node = _tmp15_;
#line 678 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp16_ = root_node;
#line 678 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (json_node_is_null (_tmp16_)) {
#line 5815 "GalleryConnector.c"
		gchar* _tmp17_;
#line 679 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_warning ("GalleryConnector.vala:679: Root node is null, doesn't appear to be JSO" \
"N data");
#line 680 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp17_ = g_strdup ("");
#line 680 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		result = _tmp17_;
#line 680 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_object_unref0 (parser);
#line 680 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_free0 (new_url);
#line 680 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_free0 (json_object);
#line 680 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		return result;
#line 5831 "GalleryConnector.c"
	}
#line 683 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp18_ = root_node;
#line 683 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp19_ = json_node_get_object (_tmp18_);
#line 683 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp20_ = json_object_get_string_member (_tmp19_, "url");
#line 683 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp21_ = g_strdup (_tmp20_);
#line 683 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (new_url);
#line 683 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	new_url = _tmp21_;
#line 686 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = new_url;
#line 686 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_object_unref0 (parser);
#line 686 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (json_object);
#line 686 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 5853 "GalleryConnector.c"
}


static void
publishing_gallery3_gallery_upload_transaction_do_set_tag_relationship (PublishingGallery3GalleryUploadTransaction* self,
                                                                        const gchar* tag_url,
                                                                        GError** error)
{
	PublishingGallery3GallerySetTagRelationshipTransaction* tag_txn = NULL;
	PublishingRESTSupportSession* _tmp0_;
	PublishingGallery3Session* _tmp1_;
	const gchar* _tmp2_;
	const gchar* _tmp3_;
	PublishingGallery3GallerySetTagRelationshipTransaction* _tmp4_;
	PublishingGallery3GallerySetTagRelationshipTransaction* _tmp5_;
	gchar* _tmp6_;
	gchar* _tmp7_;
	GError * _inner_error_ = NULL;
#line 690 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_GALLERY_UPLOAD_TRANSACTION (self));
#line 690 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (tag_url != NULL);
#line 692 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = publishing_rest_support_transaction_get_parent_session (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction));
#line 692 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, PUBLISHING_GALLERY3_TYPE_SESSION, PublishingGallery3Session);
#line 692 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp2_ = self->priv->item_tags_path;
#line 692 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp3_ = self->priv->item_url;
#line 692 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp4_ = publishing_gallery3_gallery_set_tag_relationship_transaction_new (_tmp1_, _tmp2_, tag_url, _tmp3_);
#line 692 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp5_ = _tmp4_;
#line 692 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_publishing_rest_support_session_unref0 (_tmp1_);
#line 692 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	tag_txn = _tmp5_;
#line 697 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_rest_support_transaction_execute (G_TYPE_CHECK_INSTANCE_CAST (tag_txn, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), &_inner_error_);
#line 697 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 697 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 697 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			g_propagate_error (error, _inner_error_);
#line 697 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_publishing_rest_support_transaction_unref0 (tag_txn);
#line 697 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			return;
#line 5904 "GalleryConnector.c"
		} else {
#line 697 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_publishing_rest_support_transaction_unref0 (tag_txn);
#line 697 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 697 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			g_clear_error (&_inner_error_);
#line 697 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			return;
#line 5914 "GalleryConnector.c"
		}
	}
#line 699 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp6_ = publishing_rest_support_transaction_get_response (G_TYPE_CHECK_INSTANCE_CAST (tag_txn, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction));
#line 699 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp7_ = _tmp6_;
#line 699 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_debug ("GalleryConnector.vala:699: Response from setting tag relationship: %s", _tmp7_);
#line 699 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (_tmp7_);
#line 690 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_publishing_rest_support_transaction_unref0 (tag_txn);
#line 5927 "GalleryConnector.c"
}


static gchar*
publishing_gallery3_gallery_upload_transaction_get_new_item_tags_path (PublishingGallery3GalleryUploadTransaction* self)
{
	gchar* result = NULL;
	PublishingGallery3GalleryGetItemTagsURLsTransaction* tag_urls_txn = NULL;
	PublishingRESTSupportSession* _tmp0_;
	PublishingGallery3Session* _tmp1_;
	const gchar* _tmp2_;
	PublishingGallery3GalleryGetItemTagsURLsTransaction* _tmp3_;
	PublishingGallery3GalleryGetItemTagsURLsTransaction* _tmp4_;
	PublishingGallery3GalleryGetItemTagsURLsTransaction* _tmp9_;
	gchar* _tmp10_;
	GError * _inner_error_ = NULL;
#line 703 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (PUBLISHING_GALLERY3_IS_GALLERY_UPLOAD_TRANSACTION (self), NULL);
#line 704 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = publishing_rest_support_transaction_get_parent_session (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction));
#line 704 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, PUBLISHING_GALLERY3_TYPE_SESSION, PublishingGallery3Session);
#line 704 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp2_ = self->priv->item_path;
#line 704 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp3_ = publishing_gallery3_gallery_get_item_tags_ur_ls_transaction_new (_tmp1_, _tmp2_);
#line 704 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp4_ = _tmp3_;
#line 704 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_publishing_rest_support_session_unref0 (_tmp1_);
#line 704 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	tag_urls_txn = _tmp4_;
#line 5960 "GalleryConnector.c"
	{
		PublishingGallery3GalleryGetItemTagsURLsTransaction* _tmp5_;
#line 709 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp5_ = tag_urls_txn;
#line 709 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		publishing_rest_support_transaction_execute (G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), &_inner_error_);
#line 709 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 709 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 5971 "GalleryConnector.c"
				goto __catch6_spit_publishing_publishing_error;
			}
#line 709 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_publishing_rest_support_transaction_unref0 (tag_urls_txn);
#line 709 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 709 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			g_clear_error (&_inner_error_);
#line 709 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			return NULL;
#line 5982 "GalleryConnector.c"
		}
	}
	goto __finally6;
	__catch6_spit_publishing_publishing_error:
	{
		GError* err = NULL;
		GError* _tmp6_;
		const gchar* _tmp7_;
		gchar* _tmp8_;
#line 708 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		err = _inner_error_;
#line 708 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_inner_error_ = NULL;
#line 711 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp6_ = err;
#line 711 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp7_ = _tmp6_->message;
#line 711 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_debug ("GalleryConnector.vala:711: Problem getting the item_tags URL: %s", _tmp7_);
#line 713 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp8_ = g_strdup ("");
#line 713 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		result = _tmp8_;
#line 713 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_error_free0 (err);
#line 713 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_publishing_rest_support_transaction_unref0 (tag_urls_txn);
#line 713 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		return result;
#line 6012 "GalleryConnector.c"
	}
	__finally6:
#line 708 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 708 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_publishing_rest_support_transaction_unref0 (tag_urls_txn);
#line 708 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 708 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_clear_error (&_inner_error_);
#line 708 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		return NULL;
#line 6025 "GalleryConnector.c"
	}
#line 716 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp9_ = tag_urls_txn;
#line 716 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp10_ = publishing_gallery3_gallery_get_item_tags_ur_ls_transaction_get_item_tags_path (_tmp9_);
#line 716 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = _tmp10_;
#line 716 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_publishing_rest_support_transaction_unref0 (tag_urls_txn);
#line 716 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 6037 "GalleryConnector.c"
}


static gchar*
publishing_gallery3_gallery_upload_transaction_get_tag_url (PublishingGallery3GalleryUploadTransaction* self,
                                                            const gchar* tag)
{
	gchar* result = NULL;
	PublishingGallery3GalleryGetTagTransaction* tag_txn = NULL;
	PublishingRESTSupportSession* _tmp0_;
	PublishingGallery3Session* _tmp1_;
	PublishingGallery3GalleryGetTagTransaction* _tmp2_;
	PublishingGallery3GalleryGetTagTransaction* _tmp3_;
	PublishingGallery3GalleryGetTagTransaction* _tmp8_;
	gchar* _tmp9_;
	GError * _inner_error_ = NULL;
#line 719 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (PUBLISHING_GALLERY3_IS_GALLERY_UPLOAD_TRANSACTION (self), NULL);
#line 719 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (tag != NULL, NULL);
#line 721 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = publishing_rest_support_transaction_get_parent_session (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction));
#line 721 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, PUBLISHING_GALLERY3_TYPE_SESSION, PublishingGallery3Session);
#line 721 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp2_ = publishing_gallery3_gallery_get_tag_transaction_new (_tmp1_, tag);
#line 721 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp3_ = _tmp2_;
#line 721 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_publishing_rest_support_session_unref0 (_tmp1_);
#line 721 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	tag_txn = _tmp3_;
#line 6070 "GalleryConnector.c"
	{
		PublishingGallery3GalleryGetTagTransaction* _tmp4_;
#line 726 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp4_ = tag_txn;
#line 726 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		publishing_rest_support_transaction_execute (G_TYPE_CHECK_INSTANCE_CAST (_tmp4_, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), &_inner_error_);
#line 726 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 726 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 6081 "GalleryConnector.c"
				goto __catch7_spit_publishing_publishing_error;
			}
#line 726 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_publishing_rest_support_transaction_unref0 (tag_txn);
#line 726 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 726 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			g_clear_error (&_inner_error_);
#line 726 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			return NULL;
#line 6092 "GalleryConnector.c"
		}
	}
	goto __finally7;
	__catch7_spit_publishing_publishing_error:
	{
		GError* err = NULL;
		GError* _tmp5_;
		const gchar* _tmp6_;
		gchar* _tmp7_;
#line 725 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		err = _inner_error_;
#line 725 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_inner_error_ = NULL;
#line 728 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp5_ = err;
#line 728 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp6_ = _tmp5_->message;
#line 728 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_debug ("GalleryConnector.vala:728: Problem getting the tags URL: %s", _tmp6_);
#line 730 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp7_ = g_strdup ("");
#line 730 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		result = _tmp7_;
#line 730 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_error_free0 (err);
#line 730 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_publishing_rest_support_transaction_unref0 (tag_txn);
#line 730 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		return result;
#line 6122 "GalleryConnector.c"
	}
	__finally7:
#line 725 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 725 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_publishing_rest_support_transaction_unref0 (tag_txn);
#line 725 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 725 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_clear_error (&_inner_error_);
#line 725 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		return NULL;
#line 6135 "GalleryConnector.c"
	}
#line 733 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp8_ = tag_txn;
#line 733 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp9_ = publishing_gallery3_gallery_get_tag_transaction_tag_url (_tmp8_);
#line 733 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = _tmp9_;
#line 733 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_publishing_rest_support_transaction_unref0 (tag_txn);
#line 733 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 6147 "GalleryConnector.c"
}


static gpointer
_g_error_copy0 (gpointer self)
{
#line 781 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return self ? g_error_copy (self) : NULL;
#line 6156 "GalleryConnector.c"
}


static void
publishing_gallery3_gallery_upload_transaction_on_upload_completed (PublishingGallery3GalleryUploadTransaction* self,
                                                                    GError** error)
{
	PublishingGallery3PublishingParameters* _tmp0_;
	gboolean _tmp1_;
	gboolean _tmp2_;
	GError * _inner_error_ = NULL;
#line 737 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_GALLERY_UPLOAD_TRANSACTION (self));
#line 740 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_debug ("GalleryConnector.vala:740: EVENT: upload completed");
#line 742 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->parameters;
#line 742 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = publishing_gallery3_publishing_parameters_get_strip_metadata (_tmp0_);
#line 742 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp2_ = _tmp1_;
#line 742 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (!_tmp2_) {
#line 6180 "GalleryConnector.c"
		gchar** keywords = NULL;
		gint keywords_length1 = 0;
		gint _keywords_size_ = 0;
		SpitPublishingPublishable* _tmp3_;
		gint _tmp4_;
		gchar** _tmp5_;
		gchar** _tmp6_;
		gint _tmp6__length1;
		gchar* _tmp7_;
		const gchar* _tmp8_;
		gchar* _tmp9_;
		gchar* _tmp10_;
		const gchar* _tmp11_;
		const gchar* _tmp12_;
		gboolean _tmp13_ = FALSE;
		const gchar* _tmp14_;
		gchar** _tmp17_;
		gint _tmp17__length1;
#line 746 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_debug ("GalleryConnector.vala:746: EVENT: evaluating tags");
#line 748 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp3_ = G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_UPLOAD_TRANSACTION, PublishingRESTSupportUploadTransaction)->publishable;
#line 748 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp5_ = spit_publishing_publishable_get_publishing_keywords (_tmp3_, &_tmp4_);
#line 748 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		keywords = (_vala_array_free (keywords, keywords_length1, (GDestroyNotify) g_free), NULL);
#line 748 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		keywords = _tmp5_;
#line 748 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		keywords_length1 = _tmp4_;
#line 748 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_keywords_size_ = keywords_length1;
#line 751 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp6_ = keywords;
#line 751 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp6__length1 = keywords_length1;
#line 751 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		if (NULL == _tmp6_) {
#line 752 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			g_debug ("GalleryConnector.vala:752: No tags");
#line 753 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			keywords = (_vala_array_free (keywords, keywords_length1, (GDestroyNotify) g_free), NULL);
#line 753 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			return;
#line 6225 "GalleryConnector.c"
		}
#line 757 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp7_ = publishing_gallery3_gallery_upload_transaction_get_new_item_url (self);
#line 757 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_free0 (self->priv->item_url);
#line 757 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		self->priv->item_url = _tmp7_;
#line 758 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp8_ = self->priv->item_url;
#line 758 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp9_ = publishing_gallery3_strip_session_url (_tmp8_);
#line 758 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_free0 (self->priv->item_path);
#line 758 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		self->priv->item_path = _tmp9_;
#line 759 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp10_ = publishing_gallery3_gallery_upload_transaction_get_new_item_tags_path (self);
#line 759 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_free0 (self->priv->item_tags_path);
#line 759 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		self->priv->item_tags_path = _tmp10_;
#line 760 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp11_ = self->priv->item_path;
#line 760 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_debug ("GalleryConnector.vala:760: new item path is %s", _tmp11_);
#line 761 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp12_ = self->priv->item_tags_path;
#line 761 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_debug ("GalleryConnector.vala:761: item_tags path is %s", _tmp12_);
#line 764 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp14_ = self->priv->item_path;
#line 764 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		if (g_strcmp0 ("", _tmp14_) == 0) {
#line 764 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp13_ = TRUE;
#line 6261 "GalleryConnector.c"
		} else {
			const gchar* _tmp15_;
#line 764 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp15_ = self->priv->item_tags_path;
#line 764 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp13_ = g_strcmp0 ("", _tmp15_) == 0;
#line 6268 "GalleryConnector.c"
		}
#line 764 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		if (_tmp13_) {
#line 6272 "GalleryConnector.c"
			GError* _tmp16_;
#line 765 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp16_ = g_error_new_literal (SPIT_PUBLISHING_PUBLISHING_ERROR, SPIT_PUBLISHING_PUBLISHING_ERROR_COMMUNICATION_FAILED, "Could not obtain URL of uploaded item or its " "\"item_tags\" relationship URL");
#line 765 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_inner_error_ = _tmp16_;
#line 765 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 765 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				g_propagate_error (error, _inner_error_);
#line 765 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				keywords = (_vala_array_free (keywords, keywords_length1, (GDestroyNotify) g_free), NULL);
#line 765 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				return;
#line 6286 "GalleryConnector.c"
			} else {
#line 765 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				keywords = (_vala_array_free (keywords, keywords_length1, (GDestroyNotify) g_free), NULL);
#line 765 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 765 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				g_clear_error (&_inner_error_);
#line 765 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				return;
#line 6296 "GalleryConnector.c"
			}
		}
#line 772 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp17_ = keywords;
#line 772 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp17__length1 = keywords_length1;
#line 6303 "GalleryConnector.c"
		{
			gchar** tag_collection = NULL;
			gint tag_collection_length1 = 0;
			gint _tag_collection_size_ = 0;
			gint tag_it = 0;
#line 772 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			tag_collection = _tmp17_;
#line 772 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			tag_collection_length1 = _tmp17__length1;
#line 772 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			for (tag_it = 0; tag_it < _tmp17__length1; tag_it = tag_it + 1) {
#line 6315 "GalleryConnector.c"
				gchar* _tmp18_;
				gchar* tag = NULL;
#line 772 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp18_ = g_strdup (tag_collection[tag_it]);
#line 772 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				tag = _tmp18_;
#line 6322 "GalleryConnector.c"
				{
					const gchar* _tmp19_;
					const gchar* _tmp20_;
					gchar* _tmp21_;
					gchar* _tmp22_;
					gchar* new_tag_url = NULL;
					const gchar* _tmp23_;
					gchar* _tmp24_;
#line 773 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
					_tmp19_ = tag;
#line 773 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
					_tmp20_ = string_to_string (_tmp19_);
#line 773 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
					_tmp21_ = g_strconcat ("Found tag: ", _tmp20_, NULL);
#line 773 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
					_tmp22_ = _tmp21_;
#line 773 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
					g_debug ("GalleryConnector.vala:773: %s", _tmp22_);
#line 773 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
					_g_free0 (_tmp22_);
#line 774 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
					_tmp23_ = tag;
#line 774 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
					_tmp24_ = publishing_gallery3_gallery_upload_transaction_get_tag_url (self, _tmp23_);
#line 774 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
					new_tag_url = _tmp24_;
#line 6349 "GalleryConnector.c"
					{
						const gchar* _tmp25_;
#line 777 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
						_tmp25_ = new_tag_url;
#line 777 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
						publishing_gallery3_gallery_upload_transaction_do_set_tag_relationship (self, _tmp25_, &_inner_error_);
#line 777 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
						if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 777 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
							if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 6360 "GalleryConnector.c"
								goto __catch8_spit_publishing_publishing_error;
							}
#line 777 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
							_g_free0 (new_tag_url);
#line 777 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
							_g_free0 (tag);
#line 777 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
							keywords = (_vala_array_free (keywords, keywords_length1, (GDestroyNotify) g_free), NULL);
#line 777 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
							g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 777 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
							g_clear_error (&_inner_error_);
#line 777 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
							return;
#line 6375 "GalleryConnector.c"
						}
					}
					goto __finally8;
					__catch8_spit_publishing_publishing_error:
					{
						GError* err = NULL;
						GError* _tmp26_;
						const gchar* _tmp27_;
						GError* _tmp28_;
						GError* _tmp29_;
#line 776 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
						err = _inner_error_;
#line 776 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
						_inner_error_ = NULL;
#line 779 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
						_tmp26_ = err;
#line 779 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
						_tmp27_ = _tmp26_->message;
#line 779 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
						g_debug ("Problem setting the relationship between tag " "and item: %s", _tmp27_);
#line 781 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
						_tmp28_ = err;
#line 781 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
						_tmp29_ = _g_error_copy0 (_tmp28_);
#line 781 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
						_inner_error_ = _tmp29_;
#line 781 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
						_g_error_free0 (err);
#line 6404 "GalleryConnector.c"
						goto __finally8;
					}
					__finally8:
#line 776 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
					if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 776 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
						if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 776 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
							g_propagate_error (error, _inner_error_);
#line 776 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
							_g_free0 (new_tag_url);
#line 776 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
							_g_free0 (tag);
#line 776 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
							keywords = (_vala_array_free (keywords, keywords_length1, (GDestroyNotify) g_free), NULL);
#line 776 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
							return;
#line 6422 "GalleryConnector.c"
						} else {
#line 776 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
							_g_free0 (new_tag_url);
#line 776 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
							_g_free0 (tag);
#line 776 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
							keywords = (_vala_array_free (keywords, keywords_length1, (GDestroyNotify) g_free), NULL);
#line 776 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
							g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 776 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
							g_clear_error (&_inner_error_);
#line 776 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
							return;
#line 6436 "GalleryConnector.c"
						}
					}
#line 772 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
					_g_free0 (new_tag_url);
#line 772 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
					_g_free0 (tag);
#line 6443 "GalleryConnector.c"
				}
			}
		}
#line 742 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		keywords = (_vala_array_free (keywords, keywords_length1, (GDestroyNotify) g_free), NULL);
#line 6449 "GalleryConnector.c"
	}
}


static void
publishing_gallery3_gallery_upload_transaction_real_execute (PublishingRESTSupportTransaction* base,
                                                             GError** error)
{
	PublishingGallery3GalleryUploadTransaction * self;
	GError * _inner_error_ = NULL;
#line 789 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_GALLERY3_TYPE_GALLERY_UPLOAD_TRANSACTION, PublishingGallery3GalleryUploadTransaction);
#line 791 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	PUBLISHING_REST_SUPPORT_TRANSACTION_CLASS (publishing_gallery3_gallery_upload_transaction_parent_class)->execute (G_TYPE_CHECK_INSTANCE_CAST (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_UPLOAD_TRANSACTION, PublishingRESTSupportUploadTransaction), PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), &_inner_error_);
#line 791 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 791 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 791 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			g_propagate_error (error, _inner_error_);
#line 791 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			return;
#line 6472 "GalleryConnector.c"
		} else {
#line 791 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 791 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			g_clear_error (&_inner_error_);
#line 791 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			return;
#line 6480 "GalleryConnector.c"
		}
	}
#line 794 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_gallery_upload_transaction_on_upload_completed (self, &_inner_error_);
#line 794 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 794 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 794 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			g_propagate_error (error, _inner_error_);
#line 794 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			return;
#line 6493 "GalleryConnector.c"
		} else {
#line 794 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 794 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			g_clear_error (&_inner_error_);
#line 794 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			return;
#line 6501 "GalleryConnector.c"
		}
	}
}


static void
publishing_gallery3_gallery_upload_transaction_class_init (PublishingGallery3GalleryUploadTransactionClass * klass)
{
#line 585 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_gallery_upload_transaction_parent_class = g_type_class_peek_parent (klass);
#line 585 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	((PublishingRESTSupportTransactionClass *) klass)->finalize = publishing_gallery3_gallery_upload_transaction_finalize;
#line 585 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_type_class_add_private (klass, sizeof (PublishingGallery3GalleryUploadTransactionPrivate));
#line 585 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	((PublishingRESTSupportTransactionClass *) klass)->execute = (void (*) (PublishingRESTSupportTransaction *, GError**)) publishing_gallery3_gallery_upload_transaction_real_execute;
#line 6518 "GalleryConnector.c"
}


static void
publishing_gallery3_gallery_upload_transaction_instance_init (PublishingGallery3GalleryUploadTransaction * self)
{
#line 585 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv = PUBLISHING_GALLERY3_GALLERY_UPLOAD_TRANSACTION_GET_PRIVATE (self);
#line 6527 "GalleryConnector.c"
}


static void
publishing_gallery3_gallery_upload_transaction_finalize (PublishingRESTSupportTransaction * obj)
{
	PublishingGallery3GalleryUploadTransaction * self;
#line 585 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_GALLERY3_TYPE_GALLERY_UPLOAD_TRANSACTION, PublishingGallery3GalleryUploadTransaction);
#line 588 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_publishing_rest_support_session_unref0 (self->priv->session);
#line 589 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_object_unref0 (self->priv->generator);
#line 590 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_publishing_gallery3_publishing_parameters_unref0 (self->priv->parameters);
#line 591 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (self->priv->item_url);
#line 592 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (self->priv->item_path);
#line 593 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (self->priv->item_tags_path);
#line 585 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	PUBLISHING_REST_SUPPORT_TRANSACTION_CLASS (publishing_gallery3_gallery_upload_transaction_parent_class)->finalize (obj);
#line 6551 "GalleryConnector.c"
}


GType
publishing_gallery3_gallery_upload_transaction_get_type (void)
{
	static volatile gsize publishing_gallery3_gallery_upload_transaction_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_gallery3_gallery_upload_transaction_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingGallery3GalleryUploadTransactionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_gallery3_gallery_upload_transaction_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingGallery3GalleryUploadTransaction), 0, (GInstanceInitFunc) publishing_gallery3_gallery_upload_transaction_instance_init, NULL };
		GType publishing_gallery3_gallery_upload_transaction_type_id;
		publishing_gallery3_gallery_upload_transaction_type_id = g_type_register_static (PUBLISHING_REST_SUPPORT_TYPE_UPLOAD_TRANSACTION, "PublishingGallery3GalleryUploadTransaction", &g_define_type_info, 0);
		g_once_init_leave (&publishing_gallery3_gallery_upload_transaction_type_id__volatile, publishing_gallery3_gallery_upload_transaction_type_id);
	}
	return publishing_gallery3_gallery_upload_transaction_type_id__volatile;
}


PublishingGallery3GalleryPublisher*
publishing_gallery3_gallery_publisher_construct (GType object_type,
                                                 SpitPublishingService* service,
                                                 SpitPublishingPluginHost* host)
{
	PublishingGallery3GalleryPublisher * self = NULL;
	PublishingGallery3Session* _tmp0_;
#line 814 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (SPIT_PUBLISHING_IS_SERVICE (service), NULL);
#line 814 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (SPIT_PUBLISHING_IS_PLUGIN_HOST (host), NULL);
#line 814 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = (PublishingGallery3GalleryPublisher*) g_object_new (object_type, NULL);
#line 816 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->service = service;
#line 817 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->host = host;
#line 818 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = publishing_gallery3_session_new ();
#line 818 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_publishing_rest_support_session_unref0 (self->priv->session);
#line 818 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->session = _tmp0_;
#line 814 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return self;
#line 6594 "GalleryConnector.c"
}


PublishingGallery3GalleryPublisher*
publishing_gallery3_gallery_publisher_new (SpitPublishingService* service,
                                           SpitPublishingPluginHost* host)
{
#line 814 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return publishing_gallery3_gallery_publisher_construct (PUBLISHING_GALLERY3_TYPE_GALLERY_PUBLISHER, service, host);
#line 6604 "GalleryConnector.c"
}


static gboolean
publishing_gallery3_gallery_publisher_real_is_running (SpitPublishingPublisher* base)
{
	PublishingGallery3GalleryPublisher * self;
	gboolean result = FALSE;
	gboolean _tmp0_;
#line 821 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_GALLERY3_TYPE_GALLERY_PUBLISHER, PublishingGallery3GalleryPublisher);
#line 822 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->running;
#line 822 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = _tmp0_;
#line 822 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 6622 "GalleryConnector.c"
}


static SpitPublishingService*
publishing_gallery3_gallery_publisher_real_get_service (SpitPublishingPublisher* base)
{
	PublishingGallery3GalleryPublisher * self;
	SpitPublishingService* result = NULL;
	SpitPublishingService* _tmp0_;
	SpitPublishingService* _tmp1_;
#line 825 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_GALLERY3_TYPE_GALLERY_PUBLISHER, PublishingGallery3GalleryPublisher);
#line 826 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->service;
#line 826 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 826 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = _tmp1_;
#line 826 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 6643 "GalleryConnector.c"
}


static void
publishing_gallery3_gallery_publisher_real_start (SpitPublishingPublisher* base)
{
	PublishingGallery3GalleryPublisher * self;
	SpitPublishingPluginHost* _tmp0_;
	gchar* _tmp1_;
	gboolean _tmp2_ = FALSE;
	const gchar* _tmp3_;
#line 829 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_GALLERY3_TYPE_GALLERY_PUBLISHER, PublishingGallery3GalleryPublisher);
#line 830 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (spit_publishing_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_PUBLISHER, SpitPublishingPublisher))) {
#line 831 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		return;
#line 6661 "GalleryConnector.c"
	}
#line 833 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->host;
#line 833 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (_tmp0_ == NULL) {
#line 834 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_error ("GalleryConnector.vala:834: %s", "GalleryPublisher: start( ): can't start; this " "publisher is not restartable.");
#line 6669 "GalleryConnector.c"
	}
#line 837 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_debug ("GalleryConnector.vala:837: GalleryPublisher: starting interaction.");
#line 839 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->running = TRUE;
#line 841 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = publishing_gallery3_gallery_publisher_get_api_key (self);
#line 841 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (self->priv->key);
#line 841 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->key = _tmp1_;
#line 843 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp3_ = self->priv->key;
#line 843 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (NULL == _tmp3_) {
#line 843 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp2_ = TRUE;
#line 6687 "GalleryConnector.c"
	} else {
		const gchar* _tmp4_;
#line 843 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp4_ = self->priv->key;
#line 843 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp2_ = g_strcmp0 ("", _tmp4_) == 0;
#line 6694 "GalleryConnector.c"
	}
#line 843 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (_tmp2_) {
#line 844 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		publishing_gallery3_gallery_publisher_do_show_service_welcome_pane (self);
#line 6700 "GalleryConnector.c"
	} else {
		gchar* url = NULL;
		gchar* _tmp5_;
		gchar* username = NULL;
		gchar* _tmp6_;
		gboolean _tmp7_ = FALSE;
		gboolean _tmp8_ = FALSE;
		const gchar* _tmp9_;
#line 846 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp5_ = publishing_gallery3_gallery_publisher_get_gallery_url (self);
#line 846 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		url = _tmp5_;
#line 847 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp6_ = publishing_gallery3_gallery_publisher_get_gallery_username (self);
#line 847 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		username = _tmp6_;
#line 849 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp9_ = username;
#line 849 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		if (NULL == _tmp9_) {
#line 849 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp8_ = TRUE;
#line 6723 "GalleryConnector.c"
		} else {
			const gchar* _tmp10_;
#line 849 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp10_ = self->priv->key;
#line 849 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp8_ = NULL == _tmp10_;
#line 6730 "GalleryConnector.c"
		}
#line 849 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		if (_tmp8_) {
#line 849 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp7_ = TRUE;
#line 6736 "GalleryConnector.c"
		} else {
			const gchar* _tmp11_;
#line 849 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp11_ = url;
#line 849 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp7_ = NULL == _tmp11_;
#line 6743 "GalleryConnector.c"
		}
#line 849 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		if (_tmp7_) {
#line 850 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			publishing_gallery3_gallery_publisher_do_show_service_welcome_pane (self);
#line 6749 "GalleryConnector.c"
		} else {
			const gchar* _tmp12_;
			const gchar* _tmp13_;
			SpitPublishingPluginHost* _tmp14_;
			PublishingGallery3Session* _tmp15_;
			const gchar* _tmp16_;
			const gchar* _tmp17_;
			const gchar* _tmp18_;
#line 852 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp12_ = username;
#line 852 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp13_ = url;
#line 852 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			g_debug ("ACTION: attempting network login for user " "'%s' at URL '%s' from saved credentials.", _tmp12_, _tmp13_);
#line 856 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp14_ = self->priv->host;
#line 856 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			spit_publishing_plugin_host_install_account_fetch_wait_pane (_tmp14_);
#line 858 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp15_ = self->priv->session;
#line 858 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp16_ = url;
#line 858 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp17_ = username;
#line 858 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp18_ = self->priv->key;
#line 858 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			publishing_gallery3_session_authenticate (_tmp15_, _tmp16_, _tmp17_, _tmp18_);
#line 861 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			publishing_gallery3_gallery_publisher_do_fetch_album_urls (self);
#line 6780 "GalleryConnector.c"
		}
#line 843 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_free0 (username);
#line 843 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_free0 (url);
#line 6786 "GalleryConnector.c"
	}
}


static void
publishing_gallery3_gallery_publisher_real_stop (SpitPublishingPublisher* base)
{
	PublishingGallery3GalleryPublisher * self;
#line 866 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_GALLERY3_TYPE_GALLERY_PUBLISHER, PublishingGallery3GalleryPublisher);
#line 867 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_debug ("GalleryConnector.vala:867: GalleryPublisher: stop( ) invoked.");
#line 869 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->running = FALSE;
#line 6801 "GalleryConnector.c"
}


gchar*
publishing_gallery3_gallery_publisher_get_api_key (PublishingGallery3GalleryPublisher* self)
{
	gchar* result = NULL;
	SpitPublishingPluginHost* _tmp0_;
	gchar* _tmp1_;
#line 874 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (PUBLISHING_GALLERY3_IS_GALLERY_PUBLISHER (self), NULL);
#line 875 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->host;
#line 875 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = spit_host_interface_get_config_string (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), "api-key", NULL);
#line 875 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = _tmp1_;
#line 875 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 6821 "GalleryConnector.c"
}


void
publishing_gallery3_gallery_publisher_set_api_key (PublishingGallery3GalleryPublisher* self,
                                                   const gchar* key)
{
	SpitPublishingPluginHost* _tmp0_;
#line 878 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_GALLERY_PUBLISHER (self));
#line 878 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (key != NULL);
#line 879 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->host;
#line 879 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	spit_host_interface_set_config_string (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), "api-key", key);
#line 6838 "GalleryConnector.c"
}


gchar*
publishing_gallery3_gallery_publisher_get_gallery_url (PublishingGallery3GalleryPublisher* self)
{
	gchar* result = NULL;
	SpitPublishingPluginHost* _tmp0_;
	gchar* _tmp1_;
#line 883 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (PUBLISHING_GALLERY3_IS_GALLERY_PUBLISHER (self), NULL);
#line 884 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->host;
#line 884 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = spit_host_interface_get_config_string (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), "url", NULL);
#line 884 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = _tmp1_;
#line 884 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 6858 "GalleryConnector.c"
}


void
publishing_gallery3_gallery_publisher_set_gallery_url (PublishingGallery3GalleryPublisher* self,
                                                       const gchar* url)
{
	SpitPublishingPluginHost* _tmp0_;
#line 887 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_GALLERY_PUBLISHER (self));
#line 887 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (url != NULL);
#line 888 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->host;
#line 888 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	spit_host_interface_set_config_string (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), "url", url);
#line 6875 "GalleryConnector.c"
}


gchar*
publishing_gallery3_gallery_publisher_get_gallery_username (PublishingGallery3GalleryPublisher* self)
{
	gchar* result = NULL;
	SpitPublishingPluginHost* _tmp0_;
	gchar* _tmp1_;
#line 892 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (PUBLISHING_GALLERY3_IS_GALLERY_PUBLISHER (self), NULL);
#line 893 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->host;
#line 893 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = spit_host_interface_get_config_string (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), "username", NULL);
#line 893 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = _tmp1_;
#line 893 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 6895 "GalleryConnector.c"
}


void
publishing_gallery3_gallery_publisher_set_gallery_username (PublishingGallery3GalleryPublisher* self,
                                                            const gchar* username)
{
	SpitPublishingPluginHost* _tmp0_;
#line 896 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_GALLERY_PUBLISHER (self));
#line 896 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (username != NULL);
#line 897 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->host;
#line 897 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	spit_host_interface_set_config_string (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), "username", username);
#line 6912 "GalleryConnector.c"
}


static gboolean*
_bool_dup (gboolean* self)
{
	gboolean* dup;
#line 901 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	dup = g_new0 (gboolean, 1);
#line 901 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	memcpy (dup, self, sizeof (gboolean));
#line 901 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return dup;
#line 6926 "GalleryConnector.c"
}


static gpointer
__bool_dup0 (gpointer self)
{
#line 901 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return self ? _bool_dup (self) : NULL;
#line 6935 "GalleryConnector.c"
}


gboolean*
publishing_gallery3_gallery_publisher_get_persistent_strip_metadata (PublishingGallery3GalleryPublisher* self)
{
	gboolean* result = NULL;
	SpitPublishingPluginHost* _tmp0_;
	gboolean _tmp1_;
	gboolean* _tmp2_;
#line 900 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (PUBLISHING_GALLERY3_IS_GALLERY_PUBLISHER (self), NULL);
#line 901 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->host;
#line 901 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = spit_host_interface_get_config_bool (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), "strip-metadata", FALSE);
#line 901 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp2_ = __bool_dup0 (&_tmp1_);
#line 901 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = _tmp2_;
#line 901 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 6958 "GalleryConnector.c"
}


void
publishing_gallery3_gallery_publisher_set_persistent_strip_metadata (PublishingGallery3GalleryPublisher* self,
                                                                     gboolean strip_metadata)
{
	SpitPublishingPluginHost* _tmp0_;
#line 904 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_GALLERY_PUBLISHER (self));
#line 905 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->host;
#line 905 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	spit_host_interface_set_config_bool (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), "strip-metadata", strip_metadata);
#line 6973 "GalleryConnector.c"
}


static gint*
_int_dup (gint* self)
{
	gint* dup;
#line 909 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	dup = g_new0 (gint, 1);
#line 909 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	memcpy (dup, self, sizeof (gint));
#line 909 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return dup;
#line 6987 "GalleryConnector.c"
}


static gpointer
__int_dup0 (gpointer self)
{
#line 909 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return self ? _int_dup (self) : NULL;
#line 6996 "GalleryConnector.c"
}


gint*
publishing_gallery3_gallery_publisher_get_scaling_constraint_id (PublishingGallery3GalleryPublisher* self)
{
	gint* result = NULL;
	SpitPublishingPluginHost* _tmp0_;
	gint _tmp1_;
	gint* _tmp2_;
#line 908 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (PUBLISHING_GALLERY3_IS_GALLERY_PUBLISHER (self), NULL);
#line 909 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->host;
#line 909 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = spit_host_interface_get_config_int (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), "scaling-constraint-id", 0);
#line 909 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp2_ = __int_dup0 (&_tmp1_);
#line 909 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = _tmp2_;
#line 909 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 7019 "GalleryConnector.c"
}


void
publishing_gallery3_gallery_publisher_set_scaling_constraint_id (PublishingGallery3GalleryPublisher* self,
                                                                 gint constraint)
{
	SpitPublishingPluginHost* _tmp0_;
#line 912 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_GALLERY_PUBLISHER (self));
#line 913 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->host;
#line 913 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	spit_host_interface_set_config_int (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), "scaling-constraint-id", constraint);
#line 7034 "GalleryConnector.c"
}


gint*
publishing_gallery3_gallery_publisher_get_scaling_pixels (PublishingGallery3GalleryPublisher* self)
{
	gint* result = NULL;
	SpitPublishingPluginHost* _tmp0_;
	gint _tmp1_;
	gint* _tmp2_;
#line 916 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (PUBLISHING_GALLERY3_IS_GALLERY_PUBLISHER (self), NULL);
#line 917 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->host;
#line 917 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = spit_host_interface_get_config_int (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), "scaling-pixels", 1024);
#line 917 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp2_ = __int_dup0 (&_tmp1_);
#line 917 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = _tmp2_;
#line 917 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 7057 "GalleryConnector.c"
}


void
publishing_gallery3_gallery_publisher_set_scaling_pixels (PublishingGallery3GalleryPublisher* self,
                                                          gint pixels)
{
	SpitPublishingPluginHost* _tmp0_;
#line 920 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_GALLERY_PUBLISHER (self));
#line 921 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->host;
#line 921 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	spit_host_interface_set_config_int (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), "scaling-pixels", pixels);
#line 7072 "GalleryConnector.c"
}


static void
_publishing_gallery3_gallery_publisher_on_service_welcome_login_spit_publishing_login_callback (gpointer self)
{
#line 928 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_gallery_publisher_on_service_welcome_login ((PublishingGallery3GalleryPublisher*) self);
#line 7081 "GalleryConnector.c"
}


static void
publishing_gallery3_gallery_publisher_do_show_service_welcome_pane (PublishingGallery3GalleryPublisher* self)
{
	SpitPublishingPluginHost* _tmp0_;
#line 925 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_GALLERY_PUBLISHER (self));
#line 926 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_debug ("GalleryConnector.vala:926: ACTION: showing service welcome pane.");
#line 928 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->host;
#line 928 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	spit_publishing_plugin_host_install_welcome_pane (_tmp0_, PUBLISHING_GALLERY3_SERVICE_WELCOME_MESSAGE, _publishing_gallery3_gallery_publisher_on_service_welcome_login_spit_publishing_login_callback, self);
#line 7097 "GalleryConnector.c"
}


static void
_publishing_gallery3_gallery_publisher_on_credentials_go_back_publishing_gallery3_credentials_pane_go_back (PublishingGallery3CredentialsPane* _sender,
                                                                                                            gpointer self)
{
#line 941 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_gallery_publisher_on_credentials_go_back ((PublishingGallery3GalleryPublisher*) self);
#line 7107 "GalleryConnector.c"
}


static void
_publishing_gallery3_gallery_publisher_on_credentials_login_publishing_gallery3_credentials_pane_login (PublishingGallery3CredentialsPane* _sender,
                                                                                                        const gchar* url,
                                                                                                        const gchar* uname,
                                                                                                        const gchar* password,
                                                                                                        const gchar* key,
                                                                                                        gpointer self)
{
#line 942 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_gallery_publisher_on_credentials_login ((PublishingGallery3GalleryPublisher*) self, url, uname, password);
#line 7121 "GalleryConnector.c"
}


static void
publishing_gallery3_gallery_publisher_do_show_credentials_pane (PublishingGallery3GalleryPublisher* self,
                                                                PublishingGallery3CredentialsPaneMode mode)
{
	gchar* _tmp0_;
	gchar* _tmp1_;
	PublishingGallery3Session* _tmp2_;
	PublishingGallery3CredentialsPane* creds_pane = NULL;
	SpitPublishingPluginHost* _tmp3_;
	gchar* _tmp4_;
	gchar* _tmp5_;
	gchar* _tmp6_;
	gchar* _tmp7_;
	gchar* _tmp8_;
	gchar* _tmp9_;
	PublishingGallery3CredentialsPane* _tmp10_;
	PublishingGallery3CredentialsPane* _tmp11_;
	SpitPublishingPluginHost* _tmp12_;
#line 932 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_GALLERY_PUBLISHER (self));
#line 933 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = publishing_gallery3_credentials_pane_mode_to_string (mode);
#line 933 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = _tmp0_;
#line 933 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_debug ("GalleryConnector.vala:933: ACTION: showing credentials capture pane in" \
" %s mode.", _tmp1_);
#line 933 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (_tmp1_);
#line 936 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp2_ = self->priv->session;
#line 936 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_session_deauthenticate (_tmp2_);
#line 938 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp3_ = self->priv->host;
#line 938 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp4_ = publishing_gallery3_gallery_publisher_get_gallery_url (self);
#line 938 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp5_ = _tmp4_;
#line 938 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp6_ = publishing_gallery3_gallery_publisher_get_gallery_username (self);
#line 938 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp7_ = _tmp6_;
#line 938 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp8_ = publishing_gallery3_gallery_publisher_get_api_key (self);
#line 938 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp9_ = _tmp8_;
#line 938 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp10_ = publishing_gallery3_credentials_pane_new (_tmp3_, mode, _tmp5_, _tmp7_, _tmp9_);
#line 938 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp11_ = _tmp10_;
#line 938 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (_tmp9_);
#line 938 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (_tmp7_);
#line 938 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (_tmp5_);
#line 938 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	creds_pane = _tmp11_;
#line 941 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_connect_object (creds_pane, "go-back", (GCallback) _publishing_gallery3_gallery_publisher_on_credentials_go_back_publishing_gallery3_credentials_pane_go_back, self, 0);
#line 942 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_connect_object (creds_pane, "login", (GCallback) _publishing_gallery3_gallery_publisher_on_credentials_login_publishing_gallery3_credentials_pane_login, self, 0);
#line 944 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp12_ = self->priv->host;
#line 944 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	spit_publishing_plugin_host_install_dialog_pane (_tmp12_, G_TYPE_CHECK_INSTANCE_CAST (creds_pane, SPIT_PUBLISHING_TYPE_DIALOG_PANE, SpitPublishingDialogPane), SPIT_PUBLISHING_PLUGIN_HOST_BUTTON_MODE_CANCEL);
#line 932 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_object_unref0 (creds_pane);
#line 7193 "GalleryConnector.c"
}


static void
_publishing_gallery3_gallery_publisher_on_key_fetch_error_publishing_rest_support_transaction_network_error (PublishingRESTSupportTransaction* _sender,
                                                                                                             GError* err,
                                                                                                             gpointer self)
{
#line 956 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_gallery_publisher_on_key_fetch_error ((PublishingGallery3GalleryPublisher*) self, _sender, err);
#line 7204 "GalleryConnector.c"
}


static void
_publishing_gallery3_gallery_publisher_on_key_fetch_complete_publishing_rest_support_transaction_completed (PublishingRESTSupportTransaction* _sender,
                                                                                                            gpointer self)
{
#line 957 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_gallery_publisher_on_key_fetch_complete ((PublishingGallery3GalleryPublisher*) self, _sender);
#line 7214 "GalleryConnector.c"
}


static void
publishing_gallery3_gallery_publisher_do_network_login (PublishingGallery3GalleryPublisher* self,
                                                        const gchar* url,
                                                        const gchar* username,
                                                        const gchar* password)
{
	SpitPublishingPluginHost* _tmp0_;
	PublishingGallery3KeyFetchTransaction* fetch_trans = NULL;
	PublishingGallery3Session* _tmp1_;
	PublishingGallery3KeyFetchTransaction* _tmp2_;
	GError * _inner_error_ = NULL;
#line 947 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_GALLERY_PUBLISHER (self));
#line 947 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (url != NULL);
#line 947 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (username != NULL);
#line 947 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (password != NULL);
#line 949 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_debug ("ACTION: attempting network login for user '%s' at URL " "'%s'.", username, url);
#line 952 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->host;
#line 952 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	spit_publishing_plugin_host_install_login_wait_pane (_tmp0_);
#line 954 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = self->priv->session;
#line 954 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp2_ = publishing_gallery3_key_fetch_transaction_new (_tmp1_, url, username, password);
#line 954 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	fetch_trans = _tmp2_;
#line 956 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (fetch_trans, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "network-error", (GCallback) _publishing_gallery3_gallery_publisher_on_key_fetch_error_publishing_rest_support_transaction_network_error, self, 0);
#line 957 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (fetch_trans, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "completed", (GCallback) _publishing_gallery3_gallery_publisher_on_key_fetch_complete_publishing_rest_support_transaction_completed, self, 0);
#line 7253 "GalleryConnector.c"
	{
#line 960 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		publishing_rest_support_transaction_execute (G_TYPE_CHECK_INSTANCE_CAST (fetch_trans, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), &_inner_error_);
#line 960 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 960 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 7261 "GalleryConnector.c"
				goto __catch9_spit_publishing_publishing_error;
			}
#line 960 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_publishing_rest_support_transaction_unref0 (fetch_trans);
#line 960 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 960 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			g_clear_error (&_inner_error_);
#line 960 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			return;
#line 7272 "GalleryConnector.c"
		}
	}
	goto __finally9;
	__catch9_spit_publishing_publishing_error:
	{
		GError* err = NULL;
		GError* _tmp3_;
#line 959 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		err = _inner_error_;
#line 959 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_inner_error_ = NULL;
#line 962 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_debug ("GalleryConnector.vala:962: Caught an error attempting to login");
#line 965 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp3_ = err;
#line 965 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		publishing_gallery3_gallery_publisher_on_key_fetch_error (self, G_TYPE_CHECK_INSTANCE_CAST (fetch_trans, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), _tmp3_);
#line 959 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_error_free0 (err);
#line 7292 "GalleryConnector.c"
	}
	__finally9:
#line 959 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 959 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_publishing_rest_support_transaction_unref0 (fetch_trans);
#line 959 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 959 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_clear_error (&_inner_error_);
#line 959 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		return;
#line 7305 "GalleryConnector.c"
	}
#line 947 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_publishing_rest_support_transaction_unref0 (fetch_trans);
#line 7309 "GalleryConnector.c"
}


static void
_publishing_gallery3_gallery_publisher_on_album_urls_fetch_error_publishing_rest_support_transaction_network_error (PublishingRESTSupportTransaction* _sender,
                                                                                                                    GError* err,
                                                                                                                    gpointer self)
{
#line 975 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_gallery_publisher_on_album_urls_fetch_error ((PublishingGallery3GalleryPublisher*) self, _sender, err);
#line 7320 "GalleryConnector.c"
}


static void
_publishing_gallery3_gallery_publisher_on_album_urls_fetch_complete_publishing_rest_support_transaction_completed (PublishingRESTSupportTransaction* _sender,
                                                                                                                   gpointer self)
{
#line 976 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_gallery_publisher_on_album_urls_fetch_complete ((PublishingGallery3GalleryPublisher*) self, _sender);
#line 7330 "GalleryConnector.c"
}


static void
publishing_gallery3_gallery_publisher_do_fetch_album_urls (PublishingGallery3GalleryPublisher* self)
{
	SpitPublishingPluginHost* _tmp0_;
	PublishingGallery3GetAlbumURLsTransaction* album_trans = NULL;
	PublishingGallery3Session* _tmp1_;
	PublishingGallery3GetAlbumURLsTransaction* _tmp2_;
	GError * _inner_error_ = NULL;
#line 969 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_GALLERY_PUBLISHER (self));
#line 971 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->host;
#line 971 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	spit_publishing_plugin_host_install_account_fetch_wait_pane (_tmp0_);
#line 973 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = self->priv->session;
#line 973 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp2_ = publishing_gallery3_get_album_ur_ls_transaction_new (_tmp1_);
#line 973 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	album_trans = _tmp2_;
#line 975 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (album_trans, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "network-error", (GCallback) _publishing_gallery3_gallery_publisher_on_album_urls_fetch_error_publishing_rest_support_transaction_network_error, self, 0);
#line 976 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (album_trans, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "completed", (GCallback) _publishing_gallery3_gallery_publisher_on_album_urls_fetch_complete_publishing_rest_support_transaction_completed, self, 0);
#line 7358 "GalleryConnector.c"
	{
#line 979 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		publishing_rest_support_transaction_execute (G_TYPE_CHECK_INSTANCE_CAST (album_trans, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), &_inner_error_);
#line 979 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 979 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 7366 "GalleryConnector.c"
				goto __catch10_spit_publishing_publishing_error;
			}
#line 979 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_publishing_rest_support_transaction_unref0 (album_trans);
#line 979 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 979 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			g_clear_error (&_inner_error_);
#line 979 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			return;
#line 7377 "GalleryConnector.c"
		}
	}
	goto __finally10;
	__catch10_spit_publishing_publishing_error:
	{
		GError* err = NULL;
		GError* _tmp3_;
#line 978 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		err = _inner_error_;
#line 978 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_inner_error_ = NULL;
#line 981 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_debug ("GalleryConnector.vala:981: Caught an error attempting to fetch albums");
#line 984 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp3_ = err;
#line 984 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		publishing_gallery3_gallery_publisher_on_album_urls_fetch_error (self, G_TYPE_CHECK_INSTANCE_CAST (album_trans, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), _tmp3_);
#line 978 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_error_free0 (err);
#line 7397 "GalleryConnector.c"
	}
	__finally10:
#line 978 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 978 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_publishing_rest_support_transaction_unref0 (album_trans);
#line 978 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 978 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_clear_error (&_inner_error_);
#line 978 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		return;
#line 7410 "GalleryConnector.c"
	}
#line 969 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_publishing_rest_support_transaction_unref0 (album_trans);
#line 7414 "GalleryConnector.c"
}


static void
_publishing_gallery3_gallery_publisher_on_album_fetch_error_publishing_rest_support_transaction_network_error (PublishingRESTSupportTransaction* _sender,
                                                                                                               GError* err,
                                                                                                               gpointer self)
{
#line 993 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_gallery_publisher_on_album_fetch_error ((PublishingGallery3GalleryPublisher*) self, _sender, err);
#line 7425 "GalleryConnector.c"
}


static void
_publishing_gallery3_gallery_publisher_on_album_fetch_complete_publishing_rest_support_transaction_completed (PublishingRESTSupportTransaction* _sender,
                                                                                                              gpointer self)
{
#line 994 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_gallery_publisher_on_album_fetch_complete ((PublishingGallery3GalleryPublisher*) self, _sender);
#line 7435 "GalleryConnector.c"
}


static void
publishing_gallery3_gallery_publisher_do_fetch_albums (PublishingGallery3GalleryPublisher* self,
                                                       gchar** album_urls,
                                                       int album_urls_length1,
                                                       guint start)
{
	PublishingGallery3GetAlbumsTransaction* album_trans = NULL;
	PublishingGallery3Session* _tmp0_;
	PublishingGallery3GetAlbumsTransaction* _tmp1_;
	GError * _inner_error_ = NULL;
#line 989 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_GALLERY_PUBLISHER (self));
#line 991 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->session;
#line 991 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = publishing_gallery3_get_albums_transaction_new (_tmp0_, album_urls, album_urls_length1, start);
#line 991 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	album_trans = _tmp1_;
#line 993 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (album_trans, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "network-error", (GCallback) _publishing_gallery3_gallery_publisher_on_album_fetch_error_publishing_rest_support_transaction_network_error, self, 0);
#line 994 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (album_trans, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "completed", (GCallback) _publishing_gallery3_gallery_publisher_on_album_fetch_complete_publishing_rest_support_transaction_completed, self, 0);
#line 7461 "GalleryConnector.c"
	{
#line 997 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		publishing_rest_support_transaction_execute (G_TYPE_CHECK_INSTANCE_CAST (album_trans, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), &_inner_error_);
#line 997 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 997 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 7469 "GalleryConnector.c"
				goto __catch11_spit_publishing_publishing_error;
			}
#line 997 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_publishing_rest_support_transaction_unref0 (album_trans);
#line 997 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 997 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			g_clear_error (&_inner_error_);
#line 997 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			return;
#line 7480 "GalleryConnector.c"
		}
	}
	goto __finally11;
	__catch11_spit_publishing_publishing_error:
	{
		GError* err = NULL;
		GError* _tmp2_;
#line 996 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		err = _inner_error_;
#line 996 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_inner_error_ = NULL;
#line 1001 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp2_ = err;
#line 1001 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		publishing_gallery3_gallery_publisher_on_album_fetch_error (self, G_TYPE_CHECK_INSTANCE_CAST (album_trans, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), _tmp2_);
#line 996 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_error_free0 (err);
#line 7498 "GalleryConnector.c"
	}
	__finally11:
#line 996 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 996 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_publishing_rest_support_transaction_unref0 (album_trans);
#line 996 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 996 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_clear_error (&_inner_error_);
#line 996 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		return;
#line 7511 "GalleryConnector.c"
	}
#line 989 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_publishing_rest_support_transaction_unref0 (album_trans);
#line 7515 "GalleryConnector.c"
}


static void
_publishing_gallery3_gallery_publisher_on_publishing_options_pane_publish_publishing_gallery3_publishing_options_pane_publish (PublishingGallery3PublishingOptionsPane* _sender,
                                                                                                                               PublishingGallery3PublishingParameters* parameters,
                                                                                                                               gpointer self)
{
#line 1032 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_gallery_publisher_on_publishing_options_pane_publish ((PublishingGallery3GalleryPublisher*) self, parameters);
#line 7526 "GalleryConnector.c"
}


static void
_publishing_gallery3_gallery_publisher_on_publishing_options_pane_logout_publishing_gallery3_publishing_options_pane_logout (PublishingGallery3PublishingOptionsPane* _sender,
                                                                                                                             gpointer self)
{
#line 1034 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_gallery_publisher_on_publishing_options_pane_logout ((PublishingGallery3GalleryPublisher*) self);
#line 7536 "GalleryConnector.c"
}


static void
publishing_gallery3_gallery_publisher_do_show_publishing_options_pane (PublishingGallery3GalleryPublisher* self,
                                                                       const gchar* url,
                                                                       const gchar* username)
{
	GtkBuilder* builder = NULL;
	GtkBuilder* _tmp0_;
	SpitPublishingPluginHost* _tmp9_;
	PublishingGallery3Album** _tmp10_;
	gint _tmp10__length1;
	GtkBuilder* _tmp11_;
	gboolean* _tmp12_;
	gboolean* _tmp13_;
	gint* _tmp14_;
	gint* _tmp15_;
	gint* _tmp16_;
	gint* _tmp17_;
	PublishingGallery3PublishingOptionsPane* _tmp18_;
	PublishingGallery3PublishingOptionsPane* _tmp19_;
	PublishingGallery3PublishingOptionsPane* _tmp20_;
	SpitPublishingPluginHost* _tmp21_;
	PublishingGallery3PublishingOptionsPane* _tmp22_;
	GError * _inner_error_ = NULL;
#line 1006 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_GALLERY_PUBLISHER (self));
#line 1006 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (url != NULL);
#line 1006 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (username != NULL);
#line 1009 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_debug ("GalleryConnector.vala:1009: ACTION: showing publishing options pane");
#line 1011 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = gtk_builder_new ();
#line 1011 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	builder = _tmp0_;
#line 7575 "GalleryConnector.c"
	{
		GtkBuilder* _tmp1_;
#line 1014 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp1_ = builder;
#line 1014 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		gtk_builder_add_from_resource (_tmp1_, PLUGIN_RESOURCE_PATH "/gallery3_publishing_options_pane.ui", &_inner_error_);
#line 1014 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 7584 "GalleryConnector.c"
			goto __catch12_g_error;
		}
	}
	goto __finally12;
	__catch12_g_error:
	{
		GError* e = NULL;
		GError* _tmp2_;
		const gchar* _tmp3_;
		SpitPublishingPluginHost* _tmp4_;
		gchar* _tmp5_;
		gchar* _tmp6_;
		GError* _tmp7_;
		GError* _tmp8_;
#line 1013 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		e = _inner_error_;
#line 1013 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_inner_error_ = NULL;
#line 1018 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp2_ = e;
#line 1018 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp3_ = _tmp2_->message;
#line 1018 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_warning ("GalleryConnector.vala:1018: Could not parse UI file! Error: %s.", _tmp3_);
#line 1019 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp4_ = self->priv->host;
#line 1019 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp5_ = g_strdup_printf (_ ("A file required for publishing is unavailable. Publishing to %s can’t " \
"continue."), PUBLISHING_GALLERY3_SERVICE_NAME);
#line 1019 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp6_ = _tmp5_;
#line 1019 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp7_ = g_error_new_literal (SPIT_PUBLISHING_PUBLISHING_ERROR, SPIT_PUBLISHING_PUBLISHING_ERROR_LOCAL_FILE_ERROR, _tmp6_);
#line 1019 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp8_ = _tmp7_;
#line 1019 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		spit_publishing_plugin_host_post_error (_tmp4_, _tmp8_);
#line 1019 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_error_free0 (_tmp8_);
#line 1019 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_free0 (_tmp6_);
#line 1025 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_error_free0 (e);
#line 1025 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_object_unref0 (builder);
#line 1025 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		return;
#line 7631 "GalleryConnector.c"
	}
	__finally12:
#line 1013 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1013 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_object_unref0 (builder);
#line 1013 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1013 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_clear_error (&_inner_error_);
#line 1013 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		return;
#line 7644 "GalleryConnector.c"
	}
#line 1028 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp9_ = self->priv->host;
#line 1028 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp10_ = self->priv->albums;
#line 1028 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp10__length1 = self->priv->albums_length1;
#line 1028 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp11_ = builder;
#line 1028 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp12_ = publishing_gallery3_gallery_publisher_get_persistent_strip_metadata (self);
#line 1028 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp13_ = _tmp12_;
#line 1028 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp14_ = publishing_gallery3_gallery_publisher_get_scaling_constraint_id (self);
#line 1028 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp15_ = _tmp14_;
#line 1028 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp16_ = publishing_gallery3_gallery_publisher_get_scaling_pixels (self);
#line 1028 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp17_ = _tmp16_;
#line 1028 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp18_ = publishing_gallery3_publishing_options_pane_new (_tmp9_, url, username, _tmp10_, _tmp10__length1, _tmp11_, *_tmp13_, *_tmp15_, *_tmp17_);
#line 1028 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_object_unref0 (self->priv->publishing_options_pane);
#line 1028 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->publishing_options_pane = _tmp18_;
#line 1028 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (_tmp17_);
#line 1028 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (_tmp15_);
#line 1028 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (_tmp13_);
#line 1032 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp19_ = self->priv->publishing_options_pane;
#line 1032 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_connect_object (_tmp19_, "publish", (GCallback) _publishing_gallery3_gallery_publisher_on_publishing_options_pane_publish_publishing_gallery3_publishing_options_pane_publish, self, 0);
#line 1034 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp20_ = self->priv->publishing_options_pane;
#line 1034 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_connect_object (_tmp20_, "logout", (GCallback) _publishing_gallery3_gallery_publisher_on_publishing_options_pane_logout_publishing_gallery3_publishing_options_pane_logout, self, 0);
#line 1036 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp21_ = self->priv->host;
#line 1036 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp22_ = self->priv->publishing_options_pane;
#line 1036 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	spit_publishing_plugin_host_install_dialog_pane (_tmp21_, G_TYPE_CHECK_INSTANCE_CAST (_tmp22_, SPIT_PUBLISHING_TYPE_DIALOG_PANE, SpitPublishingDialogPane), SPIT_PUBLISHING_PLUGIN_HOST_BUTTON_MODE_CANCEL);
#line 1006 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_object_unref0 (builder);
#line 7694 "GalleryConnector.c"
}


static void
_publishing_gallery3_gallery_publisher_on_album_create_error_publishing_rest_support_transaction_network_error (PublishingRESTSupportTransaction* _sender,
                                                                                                                GError* err,
                                                                                                                gpointer self)
{
#line 1046 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_gallery_publisher_on_album_create_error ((PublishingGallery3GalleryPublisher*) self, _sender, err);
#line 7705 "GalleryConnector.c"
}


static void
_publishing_gallery3_gallery_publisher_on_album_create_complete_publishing_rest_support_transaction_completed (PublishingRESTSupportTransaction* _sender,
                                                                                                               gpointer self)
{
#line 1047 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_gallery_publisher_on_album_create_complete ((PublishingGallery3GalleryPublisher*) self, _sender);
#line 7715 "GalleryConnector.c"
}


static void
publishing_gallery3_gallery_publisher_do_create_album (PublishingGallery3GalleryPublisher* self,
                                                       PublishingGallery3PublishingParameters* parameters)
{
	PublishingGallery3GalleryAlbumCreateTransaction* album_trans = NULL;
	PublishingGallery3Session* _tmp0_;
	PublishingGallery3GalleryAlbumCreateTransaction* _tmp1_;
	GError * _inner_error_ = NULL;
#line 1040 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_GALLERY_PUBLISHER (self));
#line 1040 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_PUBLISHING_PARAMETERS (parameters));
#line 1042 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_debug ("GalleryConnector.vala:1042: ACTION: creating album");
#line 1044 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->session;
#line 1044 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = publishing_gallery3_gallery_album_create_transaction_new (_tmp0_, parameters);
#line 1044 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	album_trans = _tmp1_;
#line 1046 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (album_trans, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "network-error", (GCallback) _publishing_gallery3_gallery_publisher_on_album_create_error_publishing_rest_support_transaction_network_error, self, 0);
#line 1047 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (album_trans, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "completed", (GCallback) _publishing_gallery3_gallery_publisher_on_album_create_complete_publishing_rest_support_transaction_completed, self, 0);
#line 7743 "GalleryConnector.c"
	{
#line 1050 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		publishing_rest_support_transaction_execute (G_TYPE_CHECK_INSTANCE_CAST (album_trans, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), &_inner_error_);
#line 1050 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1050 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 7751 "GalleryConnector.c"
				goto __catch13_spit_publishing_publishing_error;
			}
#line 1050 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_publishing_rest_support_transaction_unref0 (album_trans);
#line 1050 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1050 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			g_clear_error (&_inner_error_);
#line 1050 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			return;
#line 7762 "GalleryConnector.c"
		}
	}
	goto __finally13;
	__catch13_spit_publishing_publishing_error:
	{
		GError* err = NULL;
		GError* _tmp2_;
#line 1049 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		err = _inner_error_;
#line 1049 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_inner_error_ = NULL;
#line 1054 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp2_ = err;
#line 1054 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		publishing_gallery3_gallery_publisher_on_album_create_error (self, G_TYPE_CHECK_INSTANCE_CAST (album_trans, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), _tmp2_);
#line 1049 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_error_free0 (err);
#line 7780 "GalleryConnector.c"
	}
	__finally13:
#line 1049 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1049 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_publishing_rest_support_transaction_unref0 (album_trans);
#line 1049 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1049 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_clear_error (&_inner_error_);
#line 1049 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		return;
#line 7793 "GalleryConnector.c"
	}
#line 1040 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_publishing_rest_support_transaction_unref0 (album_trans);
#line 7797 "GalleryConnector.c"
}


static void
_publishing_gallery3_gallery_publisher_on_publish_complete_publishing_rest_support_batch_uploader_upload_complete (PublishingRESTSupportBatchUploader* _sender,
                                                                                                                   gint num_photos_published,
                                                                                                                   gpointer self)
{
#line 1083 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_gallery_publisher_on_publish_complete ((PublishingGallery3GalleryPublisher*) self, _sender, num_photos_published);
#line 7808 "GalleryConnector.c"
}


static void
_publishing_gallery3_gallery_publisher_on_publish_error_publishing_rest_support_batch_uploader_upload_error (PublishingRESTSupportBatchUploader* _sender,
                                                                                                             GError* err,
                                                                                                             gpointer self)
{
#line 1084 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_gallery_publisher_on_publish_error ((PublishingGallery3GalleryPublisher*) self, _sender, err);
#line 7819 "GalleryConnector.c"
}


static void
_publishing_gallery3_gallery_publisher_on_upload_status_updated_spit_publishing_progress_callback (gint file_number,
                                                                                                   gdouble fraction_complete,
                                                                                                   gpointer self)
{
#line 1085 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_gallery_publisher_on_upload_status_updated ((PublishingGallery3GalleryPublisher*) self, file_number, fraction_complete);
#line 7830 "GalleryConnector.c"
}


static void
publishing_gallery3_gallery_publisher_do_publish (PublishingGallery3GalleryPublisher* self,
                                                  PublishingGallery3PublishingParameters* parameters)
{
	gboolean _tmp0_;
	gboolean _tmp1_;
	gint _tmp2_ = 0;
	gint _tmp3_;
	gint _tmp4_;
	gint _tmp5_;
	gint _tmp6_;
	SpitPublishingPluginHost* _tmp7_;
	SpitPublishingPluginHost* _tmp8_;
	gint _tmp9_;
	gint _tmp10_;
	gboolean _tmp11_;
	gboolean _tmp12_;
	void* _tmp13_;
	GDestroyNotify _tmp14_;
	SpitPublishingProgressCallback _tmp15_;
	PublishingGallery3Uploader* uploader = NULL;
	PublishingGallery3Session* _tmp16_;
	SpitPublishingPluginHost* _tmp17_;
	gint _tmp18_;
	SpitPublishingPublishable** _tmp19_;
	SpitPublishingPublishable** _tmp20_;
	gint _tmp20__length1;
	PublishingGallery3Uploader* _tmp21_;
	PublishingGallery3Uploader* _tmp22_;
	PublishingGallery3Uploader* _tmp23_;
	PublishingGallery3Uploader* _tmp24_;
	PublishingGallery3Uploader* _tmp25_;
#line 1059 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_GALLERY_PUBLISHER (self));
#line 1059 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_PUBLISHING_PARAMETERS (parameters));
#line 1061 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_debug ("GalleryConnector.vala:1061: ACTION: publishing items");
#line 1063 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = publishing_gallery3_publishing_parameters_get_strip_metadata (parameters);
#line 1063 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = _tmp0_;
#line 1063 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_gallery_publisher_set_persistent_strip_metadata (self, _tmp1_);
#line 1065 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp3_ = publishing_gallery3_publishing_parameters_get_photo_major_axis_size (parameters);
#line 1065 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp4_ = _tmp3_;
#line 1065 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (_tmp4_ <= 0) {
#line 1065 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp2_ = 0;
#line 7886 "GalleryConnector.c"
	} else {
#line 1065 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp2_ = 1;
#line 7890 "GalleryConnector.c"
	}
#line 1064 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_gallery_publisher_set_scaling_constraint_id (self, _tmp2_);
#line 1066 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp5_ = publishing_gallery3_publishing_parameters_get_photo_major_axis_size (parameters);
#line 1066 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp6_ = _tmp5_;
#line 1066 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_gallery_publisher_set_scaling_pixels (self, _tmp6_);
#line 1067 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp7_ = self->priv->host;
#line 1067 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	spit_publishing_plugin_host_set_service_locked (_tmp7_, TRUE);
#line 1068 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp8_ = self->priv->host;
#line 1068 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp9_ = publishing_gallery3_publishing_parameters_get_photo_major_axis_size (parameters);
#line 1068 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp10_ = _tmp9_;
#line 1068 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp11_ = publishing_gallery3_publishing_parameters_get_strip_metadata (parameters);
#line 1068 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp12_ = _tmp11_;
#line 1068 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp15_ = spit_publishing_plugin_host_serialize_publishables (_tmp8_, _tmp10_, _tmp12_, &_tmp13_, &_tmp14_);
#line 1068 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	(self->priv->progress_reporter_target_destroy_notify == NULL) ? NULL : (self->priv->progress_reporter_target_destroy_notify (self->priv->progress_reporter_target), NULL);
#line 1068 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->progress_reporter = NULL;
#line 1068 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->progress_reporter_target = NULL;
#line 1068 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->progress_reporter_target_destroy_notify = NULL;
#line 1068 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->progress_reporter = _tmp15_;
#line 1068 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->progress_reporter_target = _tmp13_;
#line 1068 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->progress_reporter_target_destroy_notify = _tmp14_;
#line 1077 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (!spit_publishing_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_PUBLISHER, SpitPublishingPublisher))) {
#line 1078 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		return;
#line 7934 "GalleryConnector.c"
	}
#line 1080 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp16_ = self->priv->session;
#line 1080 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp17_ = self->priv->host;
#line 1080 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp19_ = spit_publishing_plugin_host_get_publishables (_tmp17_, &_tmp18_);
#line 1080 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp20_ = _tmp19_;
#line 1080 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp20__length1 = _tmp18_;
#line 1080 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp21_ = publishing_gallery3_uploader_new (_tmp16_, _tmp20_, _tmp18_, parameters);
#line 1080 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp22_ = _tmp21_;
#line 1080 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp20_ = (_vala_array_free (_tmp20_, _tmp20__length1, (GDestroyNotify) g_object_unref), NULL);
#line 1080 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	uploader = _tmp22_;
#line 1083 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp23_ = uploader;
#line 1083 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp23_, PUBLISHING_REST_SUPPORT_TYPE_BATCH_UPLOADER, PublishingRESTSupportBatchUploader), "upload-complete", (GCallback) _publishing_gallery3_gallery_publisher_on_publish_complete_publishing_rest_support_batch_uploader_upload_complete, self, 0);
#line 1084 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp24_ = uploader;
#line 1084 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp24_, PUBLISHING_REST_SUPPORT_TYPE_BATCH_UPLOADER, PublishingRESTSupportBatchUploader), "upload-error", (GCallback) _publishing_gallery3_gallery_publisher_on_publish_error_publishing_rest_support_batch_uploader_upload_error, self, 0);
#line 1085 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp25_ = uploader;
#line 1085 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_rest_support_batch_uploader_upload (G_TYPE_CHECK_INSTANCE_CAST (_tmp25_, PUBLISHING_REST_SUPPORT_TYPE_BATCH_UPLOADER, PublishingRESTSupportBatchUploader), _publishing_gallery3_gallery_publisher_on_upload_status_updated_spit_publishing_progress_callback, self);
#line 1059 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_publishing_rest_support_batch_uploader_unref0 (uploader);
#line 7968 "GalleryConnector.c"
}


static void
publishing_gallery3_gallery_publisher_do_show_success_pane (PublishingGallery3GalleryPublisher* self)
{
	SpitPublishingPluginHost* _tmp0_;
	SpitPublishingPluginHost* _tmp1_;
#line 1089 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_GALLERY_PUBLISHER (self));
#line 1090 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_debug ("GalleryConnector.vala:1090: ACTION: showing success pane.");
#line 1092 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->host;
#line 1092 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	spit_publishing_plugin_host_set_service_locked (_tmp0_, FALSE);
#line 1093 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = self->priv->host;
#line 1093 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	spit_publishing_plugin_host_install_success_pane (_tmp1_);
#line 7989 "GalleryConnector.c"
}


static void
publishing_gallery3_gallery_publisher_on_service_welcome_login (PublishingGallery3GalleryPublisher* self)
{
#line 1097 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_GALLERY_PUBLISHER (self));
#line 1098 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (!spit_publishing_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_PUBLISHER, SpitPublishingPublisher))) {
#line 1099 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		return;
#line 8002 "GalleryConnector.c"
	}
#line 1101 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_debug ("GalleryConnector.vala:1101: EVENT: user clicked 'Login' in welcome pan" \
"e.");
#line 1103 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_gallery_publisher_do_show_credentials_pane (self, PUBLISHING_GALLERY3_CREDENTIALS_PANE_MODE_INTRO);
#line 8008 "GalleryConnector.c"
}


static void
publishing_gallery3_gallery_publisher_on_credentials_login (PublishingGallery3GalleryPublisher* self,
                                                            const gchar* url,
                                                            const gchar* username,
                                                            const gchar* password)
{
#line 1106 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_GALLERY_PUBLISHER (self));
#line 1106 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (url != NULL);
#line 1106 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (username != NULL);
#line 1106 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (password != NULL);
#line 1108 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (!spit_publishing_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_PUBLISHER, SpitPublishingPublisher))) {
#line 1109 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		return;
#line 8030 "GalleryConnector.c"
	}
#line 1111 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_debug ("GalleryConnector.vala:1111: EVENT: user '%s' clicked 'Login' in creden" \
"tials pane.", username);
#line 1114 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_gallery_publisher_set_gallery_url (self, url);
#line 1115 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_gallery_publisher_set_gallery_username (self, username);
#line 1116 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_gallery_publisher_do_network_login (self, url, username, password);
#line 8040 "GalleryConnector.c"
}


static void
publishing_gallery3_gallery_publisher_on_credentials_go_back (PublishingGallery3GalleryPublisher* self)
{
#line 1119 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_GALLERY_PUBLISHER (self));
#line 1120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (!spit_publishing_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_PUBLISHER, SpitPublishingPublisher))) {
#line 1121 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		return;
#line 8053 "GalleryConnector.c"
	}
#line 1123 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_debug ("GalleryConnector.vala:1123: EVENT: user is attempting to go back.");
#line 1125 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_gallery_publisher_do_show_service_welcome_pane (self);
#line 8059 "GalleryConnector.c"
}


static void
publishing_gallery3_gallery_publisher_on_key_fetch_error (PublishingGallery3GalleryPublisher* self,
                                                          PublishingRESTSupportTransaction* bad_txn,
                                                          GError* err)
{
	guint _tmp0_;
	guint _tmp1_;
	PublishingGallery3Session* _tmp2_;
	gchar* _tmp3_;
	gchar* _tmp4_;
#line 1128 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_GALLERY_PUBLISHER (self));
#line 1128 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_REST_SUPPORT_IS_TRANSACTION (bad_txn));
#line 1131 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_parse_name ("completed", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp0_, NULL, FALSE);
#line 1131 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_handlers_disconnect_matched (bad_txn, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp0_, 0, NULL, (GCallback) _publishing_gallery3_gallery_publisher_on_key_fetch_complete_publishing_rest_support_transaction_completed, self);
#line 1132 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_parse_name ("network-error", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp1_, NULL, FALSE);
#line 1132 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_handlers_disconnect_matched (bad_txn, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _publishing_gallery3_gallery_publisher_on_key_fetch_error_publishing_rest_support_transaction_network_error, self);
#line 1134 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (!spit_publishing_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_PUBLISHER, SpitPublishingPublisher))) {
#line 1135 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		return;
#line 8089 "GalleryConnector.c"
	}
#line 1138 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp2_ = self->priv->session;
#line 1138 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (publishing_rest_support_session_is_authenticated (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, PUBLISHING_REST_SUPPORT_TYPE_SESSION, PublishingRESTSupportSession))) {
#line 1139 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		return;
#line 8097 "GalleryConnector.c"
	}
#line 1141 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp3_ = publishing_rest_support_transaction_get_response (bad_txn);
#line 1141 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp4_ = _tmp3_;
#line 1141 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_debug ("EVENT: network transaction to fetch key for login " "failed; response = '%s'.", _tmp4_);
#line 1141 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (_tmp4_);
#line 1150 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (publishing_rest_support_transaction_get_status_code (bad_txn) == ((guint) 403)) {
#line 1152 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		publishing_gallery3_gallery_publisher_do_show_credentials_pane (self, PUBLISHING_GALLERY3_CREDENTIALS_PANE_MODE_FAILED_RETRY);
#line 8111 "GalleryConnector.c"
	} else {
#line 1154 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		if (publishing_rest_support_transaction_get_status_code (bad_txn) == ((guint) 400)) {
#line 1157 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			publishing_gallery3_gallery_publisher_do_show_credentials_pane (self, PUBLISHING_GALLERY3_CREDENTIALS_PANE_MODE_NOT_GALLERY_URL);
#line 8117 "GalleryConnector.c"
		} else {
			SpitPublishingPluginHost* _tmp5_;
#line 1160 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp5_ = self->priv->host;
#line 1160 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			spit_publishing_plugin_host_post_error (_tmp5_, err);
#line 8124 "GalleryConnector.c"
		}
	}
}


static void
publishing_gallery3_gallery_publisher_on_key_fetch_complete (PublishingGallery3GalleryPublisher* self,
                                                             PublishingRESTSupportTransaction* txn)
{
	guint _tmp0_;
	guint _tmp1_;
	PublishingGallery3Session* _tmp2_;
	gchar* _tmp3_;
	const gchar* _tmp4_;
#line 1164 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_GALLERY_PUBLISHER (self));
#line 1164 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_REST_SUPPORT_IS_TRANSACTION (txn));
#line 1166 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_parse_name ("completed", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp0_, NULL, FALSE);
#line 1166 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_handlers_disconnect_matched (txn, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp0_, 0, NULL, (GCallback) _publishing_gallery3_gallery_publisher_on_key_fetch_complete_publishing_rest_support_transaction_completed, self);
#line 1167 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_parse_name ("network-error", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp1_, NULL, FALSE);
#line 1167 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_handlers_disconnect_matched (txn, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _publishing_gallery3_gallery_publisher_on_key_fetch_error_publishing_rest_support_transaction_network_error, self);
#line 1169 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (!spit_publishing_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_PUBLISHER, SpitPublishingPublisher))) {
#line 1170 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		return;
#line 8155 "GalleryConnector.c"
	}
#line 1173 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp2_ = self->priv->session;
#line 1173 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (publishing_rest_support_session_is_authenticated (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, PUBLISHING_REST_SUPPORT_TYPE_SESSION, PublishingRESTSupportSession))) {
#line 1174 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		return;
#line 8163 "GalleryConnector.c"
	}
#line 1176 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp3_ = publishing_gallery3_key_fetch_transaction_get_key (G_TYPE_CHECK_INSTANCE_TYPE (txn, PUBLISHING_GALLERY3_TYPE_KEY_FETCH_TRANSACTION) ? ((PublishingGallery3KeyFetchTransaction*) txn) : NULL);
#line 1176 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (self->priv->key);
#line 1176 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->key = _tmp3_;
#line 1178 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp4_ = self->priv->key;
#line 1178 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (_tmp4_ == NULL) {
#line 1178 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_error ("GalleryConnector.vala:1178: key doesn\'t exist");
#line 8177 "GalleryConnector.c"
	} else {
		gchar* url = NULL;
		gchar* _tmp5_;
		gchar* username = NULL;
		gchar* _tmp6_;
		const gchar* _tmp7_;
		PublishingGallery3Session* _tmp8_;
		const gchar* _tmp9_;
		const gchar* _tmp10_;
		const gchar* _tmp11_;
#line 1180 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp5_ = publishing_gallery3_gallery_publisher_get_gallery_url (self);
#line 1180 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		url = _tmp5_;
#line 1181 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp6_ = publishing_gallery3_gallery_publisher_get_gallery_username (self);
#line 1181 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		username = _tmp6_;
#line 1183 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_debug ("GalleryConnector.vala:1183: %s", "EVENT: network transaction to fetch key completed " "successfully.");
#line 1186 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp7_ = self->priv->key;
#line 1186 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		publishing_gallery3_gallery_publisher_set_api_key (self, _tmp7_);
#line 1187 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp8_ = self->priv->session;
#line 1187 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp9_ = url;
#line 1187 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp10_ = username;
#line 1187 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp11_ = self->priv->key;
#line 1187 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		publishing_gallery3_session_authenticate (_tmp8_, _tmp9_, _tmp10_, _tmp11_);
#line 1190 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		publishing_gallery3_gallery_publisher_do_fetch_album_urls (self);
#line 1178 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_free0 (username);
#line 1178 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_free0 (url);
#line 8218 "GalleryConnector.c"
	}
}


static void
publishing_gallery3_gallery_publisher_on_album_urls_fetch_error (PublishingGallery3GalleryPublisher* self,
                                                                 PublishingRESTSupportTransaction* bad_txn,
                                                                 GError* err)
{
	guint _tmp0_;
	guint _tmp1_;
	PublishingGallery3Session* _tmp2_;
	gchar* _tmp3_;
	gchar* _tmp4_;
#line 1194 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_GALLERY_PUBLISHER (self));
#line 1194 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_REST_SUPPORT_IS_TRANSACTION (bad_txn));
#line 1197 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_parse_name ("completed", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp0_, NULL, FALSE);
#line 1197 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_handlers_disconnect_matched (bad_txn, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp0_, 0, NULL, (GCallback) _publishing_gallery3_gallery_publisher_on_album_urls_fetch_complete_publishing_rest_support_transaction_completed, self);
#line 1198 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_parse_name ("network-error", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp1_, NULL, FALSE);
#line 1198 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_handlers_disconnect_matched (bad_txn, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _publishing_gallery3_gallery_publisher_on_album_urls_fetch_error_publishing_rest_support_transaction_network_error, self);
#line 1200 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (!spit_publishing_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_PUBLISHER, SpitPublishingPublisher))) {
#line 1201 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		return;
#line 8249 "GalleryConnector.c"
	}
#line 1204 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp2_ = self->priv->session;
#line 1204 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (!publishing_rest_support_session_is_authenticated (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, PUBLISHING_REST_SUPPORT_TYPE_SESSION, PublishingRESTSupportSession))) {
#line 1205 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		return;
#line 8257 "GalleryConnector.c"
	}
#line 1207 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp3_ = publishing_rest_support_transaction_get_response (bad_txn);
#line 1207 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp4_ = _tmp3_;
#line 1207 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_debug ("EVENT: network transaction to fetch album URLs " "failed; response = \'%s\'.", _tmp4_);
#line 1207 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (_tmp4_);
#line 1216 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (publishing_rest_support_transaction_get_status_code (bad_txn) == ((guint) 403)) {
#line 1218 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		publishing_gallery3_gallery_publisher_do_show_credentials_pane (self, PUBLISHING_GALLERY3_CREDENTIALS_PANE_MODE_FAILED_RETRY);
#line 8271 "GalleryConnector.c"
	} else {
#line 1220 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		if (publishing_rest_support_transaction_get_status_code (bad_txn) == ((guint) 400)) {
#line 1223 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			publishing_gallery3_gallery_publisher_do_show_credentials_pane (self, PUBLISHING_GALLERY3_CREDENTIALS_PANE_MODE_NOT_GALLERY_URL);
#line 8277 "GalleryConnector.c"
		} else {
			SpitPublishingPluginHost* _tmp5_;
#line 1226 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp5_ = self->priv->host;
#line 1226 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			spit_publishing_plugin_host_post_error (_tmp5_, err);
#line 8284 "GalleryConnector.c"
		}
	}
}


static void
publishing_gallery3_gallery_publisher_on_album_urls_fetch_complete (PublishingGallery3GalleryPublisher* self,
                                                                    PublishingRESTSupportTransaction* txn)
{
	guint _tmp0_;
	guint _tmp1_;
	PublishingGallery3Session* _tmp2_;
	gchar** album_urls = NULL;
	gint _tmp3_;
	gchar** _tmp4_;
	gint album_urls_length1;
	gint _album_urls_size_;
	gchar** _tmp5_;
	gint _tmp5__length1;
#line 1230 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_GALLERY_PUBLISHER (self));
#line 1230 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_REST_SUPPORT_IS_TRANSACTION (txn));
#line 1232 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_parse_name ("completed", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp0_, NULL, FALSE);
#line 1232 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_handlers_disconnect_matched (txn, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp0_, 0, NULL, (GCallback) _publishing_gallery3_gallery_publisher_on_album_urls_fetch_complete_publishing_rest_support_transaction_completed, self);
#line 1233 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_parse_name ("network-error", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp1_, NULL, FALSE);
#line 1233 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_handlers_disconnect_matched (txn, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _publishing_gallery3_gallery_publisher_on_album_urls_fetch_error_publishing_rest_support_transaction_network_error, self);
#line 1235 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (!spit_publishing_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_PUBLISHER, SpitPublishingPublisher))) {
#line 1236 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		return;
#line 8320 "GalleryConnector.c"
	}
#line 1239 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp2_ = self->priv->session;
#line 1239 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (!publishing_rest_support_session_is_authenticated (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, PUBLISHING_REST_SUPPORT_TYPE_SESSION, PublishingRESTSupportSession))) {
#line 1240 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		return;
#line 8328 "GalleryConnector.c"
	}
#line 1242 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_debug ("GalleryConnector.vala:1242: EVENT: retrieving all album URLs.");
#line 1244 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp4_ = publishing_gallery3_get_album_ur_ls_transaction_get_album_urls (G_TYPE_CHECK_INSTANCE_TYPE (txn, PUBLISHING_GALLERY3_TYPE_GET_ALBUM_UR_LS_TRANSACTION) ? ((PublishingGallery3GetAlbumURLsTransaction*) txn) : NULL, &_tmp3_);
#line 1244 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	album_urls = _tmp4_;
#line 1244 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	album_urls_length1 = _tmp3_;
#line 1244 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_album_urls_size_ = album_urls_length1;
#line 1247 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp5_ = album_urls;
#line 1247 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp5__length1 = album_urls_length1;
#line 1247 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (NULL == _tmp5_) {
#line 8346 "GalleryConnector.c"
		gchar* url = NULL;
		PublishingGallery3Session* _tmp6_;
		const gchar* _tmp7_;
		const gchar* _tmp8_;
		gchar* _tmp9_;
		gchar* username = NULL;
		PublishingGallery3Session* _tmp10_;
		const gchar* _tmp11_;
		const gchar* _tmp12_;
		gchar* _tmp13_;
		const gchar* _tmp14_;
		const gchar* _tmp15_;
#line 1249 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp6_ = self->priv->session;
#line 1249 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp7_ = publishing_gallery3_session_get_url (_tmp6_);
#line 1249 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp8_ = _tmp7_;
#line 1249 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp9_ = g_strdup (_tmp8_);
#line 1249 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		url = _tmp9_;
#line 1250 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp10_ = self->priv->session;
#line 1250 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp11_ = publishing_gallery3_session_get_username (_tmp10_);
#line 1250 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp12_ = _tmp11_;
#line 1250 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp13_ = g_strdup (_tmp12_);
#line 1250 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		username = _tmp13_;
#line 1252 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp14_ = url;
#line 1252 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp15_ = username;
#line 1252 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		publishing_gallery3_gallery_publisher_do_show_publishing_options_pane (self, _tmp14_, _tmp15_);
#line 1247 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_free0 (username);
#line 1247 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_free0 (url);
#line 8389 "GalleryConnector.c"
	} else {
		gchar** _tmp16_;
		gint _tmp16__length1;
#line 1256 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp16_ = album_urls;
#line 1256 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp16__length1 = album_urls_length1;
#line 1256 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		publishing_gallery3_gallery_publisher_do_fetch_albums (self, _tmp16_, _tmp16__length1, (guint) 0);
#line 8399 "GalleryConnector.c"
	}
#line 1230 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	album_urls = (_vala_array_free (album_urls, album_urls_length1, (GDestroyNotify) g_free), NULL);
#line 8403 "GalleryConnector.c"
}


static void
publishing_gallery3_gallery_publisher_on_album_fetch_error (PublishingGallery3GalleryPublisher* self,
                                                            PublishingRESTSupportTransaction* bad_txn,
                                                            GError* err)
{
	guint _tmp0_;
	guint _tmp1_;
	PublishingGallery3Session* _tmp2_;
	gchar* _tmp3_;
	gchar* _tmp4_;
#line 1259 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_GALLERY_PUBLISHER (self));
#line 1259 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_REST_SUPPORT_IS_TRANSACTION (bad_txn));
#line 1262 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_parse_name ("completed", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp0_, NULL, FALSE);
#line 1262 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_handlers_disconnect_matched (bad_txn, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp0_, 0, NULL, (GCallback) _publishing_gallery3_gallery_publisher_on_album_fetch_complete_publishing_rest_support_transaction_completed, self);
#line 1263 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_parse_name ("network-error", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp1_, NULL, FALSE);
#line 1263 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_handlers_disconnect_matched (bad_txn, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _publishing_gallery3_gallery_publisher_on_album_fetch_error_publishing_rest_support_transaction_network_error, self);
#line 1265 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (!spit_publishing_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_PUBLISHER, SpitPublishingPublisher))) {
#line 1266 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		return;
#line 8433 "GalleryConnector.c"
	}
#line 1269 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp2_ = self->priv->session;
#line 1269 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (!publishing_rest_support_session_is_authenticated (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, PUBLISHING_REST_SUPPORT_TYPE_SESSION, PublishingRESTSupportSession))) {
#line 1270 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		return;
#line 8441 "GalleryConnector.c"
	}
#line 1272 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp3_ = publishing_rest_support_transaction_get_response (bad_txn);
#line 1272 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp4_ = _tmp3_;
#line 1272 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_debug ("EVENT: network transaction to fetch albums " "failed; response = \'%s\'.", _tmp4_);
#line 1272 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (_tmp4_);
#line 1281 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (publishing_rest_support_transaction_get_status_code (bad_txn) == ((guint) 403)) {
#line 1283 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		publishing_gallery3_gallery_publisher_do_show_credentials_pane (self, PUBLISHING_GALLERY3_CREDENTIALS_PANE_MODE_FAILED_RETRY);
#line 8455 "GalleryConnector.c"
	} else {
#line 1285 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		if (publishing_rest_support_transaction_get_status_code (bad_txn) == ((guint) 400)) {
#line 1288 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			publishing_gallery3_gallery_publisher_do_show_credentials_pane (self, PUBLISHING_GALLERY3_CREDENTIALS_PANE_MODE_NOT_GALLERY_URL);
#line 8461 "GalleryConnector.c"
		} else {
			SpitPublishingPluginHost* _tmp5_;
#line 1291 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp5_ = self->priv->host;
#line 1291 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			spit_publishing_plugin_host_post_error (_tmp5_, err);
#line 8468 "GalleryConnector.c"
		}
	}
}


static void
_vala_array_add5 (PublishingGallery3Album** * array,
                  int* length,
                  int* size,
                  PublishingGallery3Album* value)
{
#line 1320 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if ((*length) == (*size)) {
#line 1320 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 1320 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		*array = g_renew (PublishingGallery3Album*, *array, (*size) + 1);
#line 8486 "GalleryConnector.c"
	}
#line 1320 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	(*array)[(*length)++] = value;
#line 1320 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	(*array)[*length] = NULL;
#line 8492 "GalleryConnector.c"
}


static void
publishing_gallery3_gallery_publisher_on_album_fetch_complete (PublishingGallery3GalleryPublisher* self,
                                                               PublishingRESTSupportTransaction* txn)
{
	guint _tmp0_;
	guint _tmp1_;
	PublishingGallery3Album** new_albums = NULL;
	gint new_albums_length1;
	gint _new_albums_size_;
	PublishingGallery3Session* _tmp2_;
	gboolean _tmp17_;
	gboolean _tmp18_;
	GError * _inner_error_ = NULL;
#line 1295 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_GALLERY_PUBLISHER (self));
#line 1295 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_REST_SUPPORT_IS_TRANSACTION (txn));
#line 1297 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_parse_name ("completed", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp0_, NULL, FALSE);
#line 1297 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_handlers_disconnect_matched (txn, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp0_, 0, NULL, (GCallback) _publishing_gallery3_gallery_publisher_on_album_fetch_complete_publishing_rest_support_transaction_completed, self);
#line 1298 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_parse_name ("network-error", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp1_, NULL, FALSE);
#line 1298 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_handlers_disconnect_matched (txn, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _publishing_gallery3_gallery_publisher_on_album_fetch_error_publishing_rest_support_transaction_network_error, self);
#line 1300 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	new_albums = NULL;
#line 1300 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	new_albums_length1 = 0;
#line 1300 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_new_albums_size_ = new_albums_length1;
#line 1302 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (!spit_publishing_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_PUBLISHER, SpitPublishingPublisher))) {
#line 1303 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		new_albums = (_vala_array_free (new_albums, new_albums_length1, (GDestroyNotify) publishing_gallery3_album_unref), NULL);
#line 1303 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		return;
#line 8533 "GalleryConnector.c"
	}
#line 1306 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp2_ = self->priv->session;
#line 1306 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (!publishing_rest_support_session_is_authenticated (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, PUBLISHING_REST_SUPPORT_TYPE_SESSION, PublishingRESTSupportSession))) {
#line 1307 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		new_albums = (_vala_array_free (new_albums, new_albums_length1, (GDestroyNotify) publishing_gallery3_album_unref), NULL);
#line 1307 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		return;
#line 8543 "GalleryConnector.c"
	}
#line 1309 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_debug ("GalleryConnector.vala:1309: EVENT: user is attempting to populate the " \
"album list.");
#line 8547 "GalleryConnector.c"
	{
		PublishingGallery3Album** _tmp3_ = NULL;
		gint _tmp4_;
		PublishingGallery3Album** _tmp5_;
		gint _tmp3__length1;
		gint __tmp3__size_;
		PublishingGallery3Album** _tmp6_;
		gint _tmp6__length1;
#line 1313 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp5_ = publishing_gallery3_get_albums_transaction_get_albums (G_TYPE_CHECK_INSTANCE_TYPE (txn, PUBLISHING_GALLERY3_TYPE_GET_ALBUMS_TRANSACTION) ? ((PublishingGallery3GetAlbumsTransaction*) txn) : NULL, &_tmp4_, &_inner_error_);
#line 1313 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp3_ = _tmp5_;
#line 1313 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp3__length1 = _tmp4_;
#line 1313 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		__tmp3__size_ = _tmp3__length1;
#line 1313 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1313 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 8568 "GalleryConnector.c"
				goto __catch14_spit_publishing_publishing_error;
			}
#line 1313 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			new_albums = (_vala_array_free (new_albums, new_albums_length1, (GDestroyNotify) publishing_gallery3_album_unref), NULL);
#line 1313 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1313 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			g_clear_error (&_inner_error_);
#line 1313 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			return;
#line 8579 "GalleryConnector.c"
		}
#line 1312 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp6_ = _tmp3_;
#line 1312 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp6__length1 = _tmp3__length1;
#line 1312 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp3_ = NULL;
#line 1312 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp3__length1 = 0;
#line 1312 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		new_albums = (_vala_array_free (new_albums, new_albums_length1, (GDestroyNotify) publishing_gallery3_album_unref), NULL);
#line 1312 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		new_albums = _tmp6_;
#line 1312 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		new_albums_length1 = _tmp6__length1;
#line 1312 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_new_albums_size_ = new_albums_length1;
#line 1311 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp3_ = (_vala_array_free (_tmp3_, _tmp3__length1, (GDestroyNotify) publishing_gallery3_album_unref), NULL);
#line 8599 "GalleryConnector.c"
	}
	goto __finally14;
	__catch14_spit_publishing_publishing_error:
	{
		GError* err = NULL;
		GError* _tmp7_;
#line 1311 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		err = _inner_error_;
#line 1311 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_inner_error_ = NULL;
#line 1315 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp7_ = err;
#line 1315 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		publishing_gallery3_gallery_publisher_on_album_fetch_error (self, txn, _tmp7_);
#line 1311 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_error_free0 (err);
#line 8616 "GalleryConnector.c"
	}
	__finally14:
#line 1311 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1311 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		new_albums = (_vala_array_free (new_albums, new_albums_length1, (GDestroyNotify) publishing_gallery3_album_unref), NULL);
#line 1311 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1311 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_clear_error (&_inner_error_);
#line 1311 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		return;
#line 8629 "GalleryConnector.c"
	}
	{
		gint i = 0;
#line 1319 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		i = 0;
#line 8635 "GalleryConnector.c"
		{
			gboolean _tmp8_ = FALSE;
#line 1319 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp8_ = TRUE;
#line 1319 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			while (TRUE) {
#line 8642 "GalleryConnector.c"
				gint _tmp10_;
				PublishingGallery3Album** _tmp11_;
				gint _tmp11__length1;
				PublishingGallery3Album** _tmp12_;
				gint _tmp12__length1;
				PublishingGallery3Album** _tmp13_;
				gint _tmp13__length1;
				gint _tmp14_;
				PublishingGallery3Album* _tmp15_;
				PublishingGallery3Album* _tmp16_;
#line 1319 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				if (!_tmp8_) {
#line 8655 "GalleryConnector.c"
					gint _tmp9_;
#line 1319 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
					_tmp9_ = i;
#line 1319 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
					i = _tmp9_ + 1;
#line 8661 "GalleryConnector.c"
				}
#line 1319 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp8_ = FALSE;
#line 1319 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp10_ = i;
#line 1319 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp11_ = new_albums;
#line 1319 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp11__length1 = new_albums_length1;
#line 1319 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				if (!(_tmp10_ <= (_tmp11__length1 - 1))) {
#line 1319 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
					break;
#line 8675 "GalleryConnector.c"
				}
#line 1320 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp12_ = self->priv->albums;
#line 1320 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp12__length1 = self->priv->albums_length1;
#line 1320 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp13_ = new_albums;
#line 1320 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp13__length1 = new_albums_length1;
#line 1320 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp14_ = i;
#line 1320 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp15_ = _tmp13_[_tmp14_];
#line 1320 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp16_ = _publishing_gallery3_album_ref0 (_tmp15_);
#line 1320 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_vala_array_add5 (&self->priv->albums, &self->priv->albums_length1, &self->priv->_albums_size_, _tmp16_);
#line 8693 "GalleryConnector.c"
			}
		}
	}
#line 1322 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp17_ = publishing_gallery3_get_albums_transaction_get_more_urls (G_TYPE_CHECK_INSTANCE_TYPE (txn, PUBLISHING_GALLERY3_TYPE_GET_ALBUMS_TRANSACTION) ? ((PublishingGallery3GetAlbumsTransaction*) txn) : NULL);
#line 1322 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp18_ = _tmp17_;
#line 1322 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (_tmp18_) {
#line 8703 "GalleryConnector.c"
		gchar** _tmp19_;
		gint _tmp19__length1;
		gchar** _tmp20_;
		gint _tmp20__length1;
		guint _tmp21_;
		guint _tmp22_;
#line 1324 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp19_ = publishing_gallery3_get_albums_transaction_get_album_urls (G_TYPE_CHECK_INSTANCE_TYPE (txn, PUBLISHING_GALLERY3_TYPE_GET_ALBUMS_TRANSACTION) ? ((PublishingGallery3GetAlbumsTransaction*) txn) : NULL, &_tmp19__length1);
#line 1324 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp20_ = _tmp19_;
#line 1324 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp20__length1 = _tmp19__length1;
#line 1324 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp21_ = publishing_gallery3_get_albums_transaction_get_urls_sent (G_TYPE_CHECK_INSTANCE_TYPE (txn, PUBLISHING_GALLERY3_TYPE_GET_ALBUMS_TRANSACTION) ? ((PublishingGallery3GetAlbumsTransaction*) txn) : NULL);
#line 1324 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp22_ = _tmp21_;
#line 1324 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		publishing_gallery3_gallery_publisher_do_fetch_albums (self, _tmp20_, _tmp20__length1, _tmp22_);
#line 8722 "GalleryConnector.c"
	} else {
		gchar* url = NULL;
		PublishingGallery3Session* _tmp23_;
		const gchar* _tmp24_;
		const gchar* _tmp25_;
		gchar* _tmp26_;
		gchar* username = NULL;
		PublishingGallery3Session* _tmp27_;
		const gchar* _tmp28_;
		const gchar* _tmp29_;
		gchar* _tmp30_;
		const gchar* _tmp31_;
		const gchar* _tmp32_;
#line 1330 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp23_ = self->priv->session;
#line 1330 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp24_ = publishing_gallery3_session_get_url (_tmp23_);
#line 1330 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp25_ = _tmp24_;
#line 1330 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp26_ = g_strdup (_tmp25_);
#line 1330 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		url = _tmp26_;
#line 1331 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp27_ = self->priv->session;
#line 1331 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp28_ = publishing_gallery3_session_get_username (_tmp27_);
#line 1331 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp29_ = _tmp28_;
#line 1331 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp30_ = g_strdup (_tmp29_);
#line 1331 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		username = _tmp30_;
#line 1333 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp31_ = url;
#line 1333 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp32_ = username;
#line 1333 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		publishing_gallery3_gallery_publisher_do_show_publishing_options_pane (self, _tmp31_, _tmp32_);
#line 1322 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_free0 (username);
#line 1322 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_free0 (url);
#line 8766 "GalleryConnector.c"
	}
#line 1295 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	new_albums = (_vala_array_free (new_albums, new_albums_length1, (GDestroyNotify) publishing_gallery3_album_unref), NULL);
#line 8770 "GalleryConnector.c"
}


static void
publishing_gallery3_gallery_publisher_on_album_create_error (PublishingGallery3GalleryPublisher* self,
                                                             PublishingRESTSupportTransaction* bad_txn,
                                                             GError* err)
{
	guint _tmp0_;
	guint _tmp1_;
	PublishingGallery3Session* _tmp2_;
	gchar* _tmp3_;
	gchar* _tmp4_;
#line 1338 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_GALLERY_PUBLISHER (self));
#line 1338 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_REST_SUPPORT_IS_TRANSACTION (bad_txn));
#line 1341 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_parse_name ("completed", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp0_, NULL, FALSE);
#line 1341 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_handlers_disconnect_matched (bad_txn, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp0_, 0, NULL, (GCallback) _publishing_gallery3_gallery_publisher_on_album_create_complete_publishing_rest_support_transaction_completed, self);
#line 1342 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_parse_name ("network-error", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp1_, NULL, FALSE);
#line 1342 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_handlers_disconnect_matched (bad_txn, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _publishing_gallery3_gallery_publisher_on_album_create_error_publishing_rest_support_transaction_network_error, self);
#line 1344 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (!spit_publishing_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_PUBLISHER, SpitPublishingPublisher))) {
#line 1345 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		return;
#line 8800 "GalleryConnector.c"
	}
#line 1348 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp2_ = self->priv->session;
#line 1348 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (!publishing_rest_support_session_is_authenticated (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, PUBLISHING_REST_SUPPORT_TYPE_SESSION, PublishingRESTSupportSession))) {
#line 1349 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		return;
#line 8808 "GalleryConnector.c"
	}
#line 1351 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp3_ = publishing_rest_support_transaction_get_response (bad_txn);
#line 1351 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp4_ = _tmp3_;
#line 1351 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_debug ("EVENT: network transaction to create an album " "failed; response = \'%s\'.", _tmp4_);
#line 1351 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (_tmp4_);
#line 1360 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (publishing_rest_support_transaction_get_status_code (bad_txn) == ((guint) 403)) {
#line 1362 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		publishing_gallery3_gallery_publisher_do_show_credentials_pane (self, PUBLISHING_GALLERY3_CREDENTIALS_PANE_MODE_FAILED_RETRY);
#line 8822 "GalleryConnector.c"
	} else {
#line 1364 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		if (publishing_rest_support_transaction_get_status_code (bad_txn) == ((guint) 400)) {
#line 1367 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			publishing_gallery3_gallery_publisher_do_show_credentials_pane (self, PUBLISHING_GALLERY3_CREDENTIALS_PANE_MODE_NOT_GALLERY_URL);
#line 8828 "GalleryConnector.c"
		} else {
			SpitPublishingPluginHost* _tmp5_;
#line 1370 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp5_ = self->priv->host;
#line 1370 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			spit_publishing_plugin_host_post_error (_tmp5_, err);
#line 8835 "GalleryConnector.c"
		}
	}
}


static void
publishing_gallery3_gallery_publisher_on_album_create_complete (PublishingGallery3GalleryPublisher* self,
                                                                PublishingRESTSupportTransaction* txn)
{
	guint _tmp0_;
	guint _tmp1_;
	PublishingGallery3Session* _tmp2_;
	PublishingGallery3PublishingParameters* new_params = NULL;
	PublishingGallery3PublishingParameters* _tmp3_;
	PublishingGallery3PublishingParameters* _tmp4_;
	PublishingGallery3PublishingParameters* _tmp5_;
	PublishingGallery3PublishingParameters* _tmp6_;
	gchar* _tmp7_;
	gchar* _tmp8_;
	PublishingGallery3PublishingParameters* _tmp9_;
	const gchar* _tmp10_;
	const gchar* _tmp11_;
	PublishingGallery3PublishingParameters* _tmp12_;
#line 1374 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_GALLERY_PUBLISHER (self));
#line 1374 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_REST_SUPPORT_IS_TRANSACTION (txn));
#line 1376 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_parse_name ("completed", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp0_, NULL, FALSE);
#line 1376 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_handlers_disconnect_matched (txn, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp0_, 0, NULL, (GCallback) _publishing_gallery3_gallery_publisher_on_album_create_complete_publishing_rest_support_transaction_completed, self);
#line 1377 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_parse_name ("network-error", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp1_, NULL, FALSE);
#line 1377 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_handlers_disconnect_matched (txn, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _publishing_gallery3_gallery_publisher_on_album_create_error_publishing_rest_support_transaction_network_error, self);
#line 1379 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (!spit_publishing_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_PUBLISHER, SpitPublishingPublisher))) {
#line 1380 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		return;
#line 8875 "GalleryConnector.c"
	}
#line 1383 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp2_ = self->priv->session;
#line 1383 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (!publishing_rest_support_session_is_authenticated (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, PUBLISHING_REST_SUPPORT_TYPE_SESSION, PublishingRESTSupportSession))) {
#line 1384 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		return;
#line 8883 "GalleryConnector.c"
	}
#line 1386 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp3_ = publishing_gallery3_gallery_album_create_transaction_get_parameters (G_TYPE_CHECK_INSTANCE_TYPE (txn, PUBLISHING_GALLERY3_TYPE_GALLERY_ALBUM_CREATE_TRANSACTION) ? ((PublishingGallery3GalleryAlbumCreateTransaction*) txn) : NULL);
#line 1386 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp4_ = _tmp3_;
#line 1386 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp5_ = _publishing_gallery3_publishing_parameters_ref0 (_tmp4_);
#line 1386 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	new_params = _tmp5_;
#line 1388 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp6_ = new_params;
#line 1388 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp7_ = publishing_gallery3_gallery_album_create_transaction_get_new_album_path (G_TYPE_CHECK_INSTANCE_TYPE (txn, PUBLISHING_GALLERY3_TYPE_GALLERY_ALBUM_CREATE_TRANSACTION) ? ((PublishingGallery3GalleryAlbumCreateTransaction*) txn) : NULL);
#line 1388 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp8_ = _tmp7_;
#line 1388 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_publishing_parameters_set_album_path (_tmp6_, _tmp8_);
#line 1388 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (_tmp8_);
#line 1391 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp9_ = new_params;
#line 1391 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp10_ = publishing_gallery3_publishing_parameters_get_album_path (_tmp9_);
#line 1391 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp11_ = _tmp10_;
#line 1391 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_debug ("GalleryConnector.vala:1391: EVENT: user has created an album at \"%s\"" \
".", _tmp11_);
#line 1394 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp12_ = new_params;
#line 1394 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_gallery_publisher_do_publish (self, _tmp12_);
#line 1374 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_publishing_gallery3_publishing_parameters_unref0 (new_params);
#line 8917 "GalleryConnector.c"
}


static gpointer
_publishing_rest_support_batch_uploader_ref0 (gpointer self)
{
#line 1403 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return self ? publishing_rest_support_batch_uploader_ref (self) : NULL;
#line 8926 "GalleryConnector.c"
}


static void
publishing_gallery3_gallery_publisher_on_publish_error (PublishingGallery3GalleryPublisher* self,
                                                        PublishingRESTSupportBatchUploader* _uploader,
                                                        GError* err)
{
	PublishingGallery3Uploader* uploader = NULL;
	PublishingGallery3Uploader* _tmp0_;
	GError* g3_err = NULL;
	GError* _tmp1_;
	const gchar* _tmp2_;
	PublishingGallery3Uploader* _tmp3_;
	const gchar* _tmp4_;
	const gchar* _tmp5_;
	PublishingGallery3Uploader* _tmp6_;
	guint _tmp7_;
	guint _tmp8_;
	PublishingGallery3Uploader* _tmp9_;
	guint _tmp10_;
	PublishingGallery3Uploader* _tmp11_;
	guint _tmp12_;
	PublishingGallery3Uploader* _tmp13_;
	guint _tmp14_;
	guint _tmp15_;
	SpitPublishingPluginHost* _tmp32_;
	GError* _tmp33_;
#line 1397 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_GALLERY_PUBLISHER (self));
#line 1397 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_REST_SUPPORT_IS_BATCH_UPLOADER (_uploader));
#line 1400 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (!spit_publishing_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_PUBLISHER, SpitPublishingPublisher))) {
#line 1401 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		return;
#line 8963 "GalleryConnector.c"
	}
#line 1403 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = _publishing_rest_support_batch_uploader_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_uploader, PUBLISHING_GALLERY3_TYPE_UPLOADER) ? ((PublishingGallery3Uploader*) _uploader) : NULL);
#line 1403 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	uploader = _tmp0_;
#line 1404 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = g_error_copy (err);
#line 1404 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g3_err = _tmp1_;
#line 1406 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp2_ = err->message;
#line 1406 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp3_ = uploader;
#line 1406 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp4_ = publishing_gallery3_uploader_get_current_publishable_name (_tmp3_);
#line 1406 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp5_ = _tmp4_;
#line 1406 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp6_ = uploader;
#line 1406 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp7_ = publishing_gallery3_uploader_get_status_code (_tmp6_);
#line 1406 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp8_ = _tmp7_;
#line 1406 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_debug ("EVENT: uploader reports upload error = '%s' " "for file '%s' (code %d)", _tmp2_, _tmp5_, _tmp8_);
#line 1410 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp9_ = uploader;
#line 1410 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_parse_name ("upload-complete", PUBLISHING_REST_SUPPORT_TYPE_BATCH_UPLOADER, &_tmp10_, NULL, FALSE);
#line 1410 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_handlers_disconnect_matched (G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, PUBLISHING_REST_SUPPORT_TYPE_BATCH_UPLOADER, PublishingRESTSupportBatchUploader), G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp10_, 0, NULL, (GCallback) _publishing_gallery3_gallery_publisher_on_publish_complete_publishing_rest_support_batch_uploader_upload_complete, self);
#line 1411 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp11_ = uploader;
#line 1411 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_parse_name ("upload-error", PUBLISHING_REST_SUPPORT_TYPE_BATCH_UPLOADER, &_tmp12_, NULL, FALSE);
#line 1411 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_handlers_disconnect_matched (G_TYPE_CHECK_INSTANCE_CAST (_tmp11_, PUBLISHING_REST_SUPPORT_TYPE_BATCH_UPLOADER, PublishingRESTSupportBatchUploader), G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp12_, 0, NULL, (GCallback) _publishing_gallery3_gallery_publisher_on_publish_error_publishing_rest_support_batch_uploader_upload_error, self);
#line 1414 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp13_ = uploader;
#line 1414 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp14_ = publishing_gallery3_uploader_get_status_code (_tmp13_);
#line 1414 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp15_ = _tmp14_;
#line 1414 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (_tmp15_ == ((guint) 400)) {
#line 9009 "GalleryConnector.c"
		GError* _tmp16_;
		GError* _tmp17_;
		const gchar* _tmp18_;
		PublishingGallery3Uploader* _tmp19_;
		const gchar* _tmp20_;
		const gchar* _tmp21_;
		gchar* _tmp22_;
		gchar* _tmp23_;
		gchar* _tmp24_;
		PublishingGallery3Uploader* _tmp25_;
		SpitPublishingPublisherMediaType _tmp26_;
		SpitPublishingPublisherMediaType _tmp27_;
#line 1415 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp16_ = g3_err;
#line 1415 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp17_ = g3_err;
#line 1415 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp18_ = _tmp17_->message;
#line 1415 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp19_ = uploader;
#line 1415 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp20_ = publishing_gallery3_uploader_get_current_publishable_name (_tmp19_);
#line 1415 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp21_ = _tmp20_;
#line 1415 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp22_ = g_strdup_printf (PUBLISHING_GALLERY3_GALLERY_PUBLISHER_BAD_FILE_MSG, _tmp21_);
#line 1415 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp23_ = _tmp22_;
#line 1415 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp24_ = g_strconcat (_tmp18_, _tmp23_, NULL);
#line 1415 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_free0 (_tmp17_->message);
#line 1415 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp17_->message = _tmp24_;
#line 1415 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_free0 (_tmp23_);
#line 1419 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp25_ = uploader;
#line 1419 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp26_ = publishing_gallery3_uploader_get_current_publishable_type (_tmp25_);
#line 1419 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp27_ = _tmp26_;
#line 1419 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		if (_tmp27_ == SPIT_PUBLISHING_PUBLISHER_MEDIA_TYPE_VIDEO) {
#line 9054 "GalleryConnector.c"
			GError* _tmp28_;
			GError* _tmp29_;
			const gchar* _tmp30_;
			gchar* _tmp31_;
#line 1421 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp28_ = g3_err;
#line 1421 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp29_ = g3_err;
#line 1421 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp30_ = _tmp29_->message;
#line 1421 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp31_ = g_strconcat (_tmp30_, PUBLISHING_GALLERY3_GALLERY_PUBLISHER_BAD_MOVIE_MSG, NULL);
#line 1421 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_g_free0 (_tmp29_->message);
#line 1421 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp29_->message = _tmp31_;
#line 9071 "GalleryConnector.c"
		}
	}
#line 1423 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp32_ = self->priv->host;
#line 1423 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp33_ = g3_err;
#line 1423 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	spit_publishing_plugin_host_post_error (_tmp32_, _tmp33_);
#line 1397 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_error_free0 (g3_err);
#line 1397 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_publishing_rest_support_batch_uploader_unref0 (uploader);
#line 9084 "GalleryConnector.c"
}


static void
publishing_gallery3_gallery_publisher_on_upload_status_updated (PublishingGallery3GalleryPublisher* self,
                                                                gint file_number,
                                                                gdouble completed_fraction)
{
	SpitPublishingProgressCallback _tmp0_;
	void* _tmp0__target;
	SpitPublishingProgressCallback _tmp1_;
	void* _tmp1__target;
#line 1426 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_GALLERY_PUBLISHER (self));
#line 1429 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (!spit_publishing_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_PUBLISHER, SpitPublishingPublisher))) {
#line 1430 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		return;
#line 9103 "GalleryConnector.c"
	}
#line 1432 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_debug ("GalleryConnector.vala:1432: EVENT: uploader reports upload %.2f percen" \
"t complete.", 100.0 * completed_fraction);
#line 1435 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->progress_reporter;
#line 1435 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0__target = self->priv->progress_reporter_target;
#line 1435 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_vala_assert (_tmp0_ != NULL, "progress_reporter != null");
#line 1437 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = self->priv->progress_reporter;
#line 1437 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1__target = self->priv->progress_reporter_target;
#line 1437 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ (file_number, completed_fraction, _tmp1__target);
#line 9119 "GalleryConnector.c"
}


static void
publishing_gallery3_gallery_publisher_on_publish_complete (PublishingGallery3GalleryPublisher* self,
                                                           PublishingRESTSupportBatchUploader* uploader,
                                                           gint num_published)
{
	guint _tmp0_;
	guint _tmp1_;
	PublishingGallery3Session* _tmp2_;
#line 1441 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_GALLERY_PUBLISHER (self));
#line 1441 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_REST_SUPPORT_IS_BATCH_UPLOADER (uploader));
#line 1444 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_parse_name ("upload-complete", PUBLISHING_REST_SUPPORT_TYPE_BATCH_UPLOADER, &_tmp0_, NULL, FALSE);
#line 1444 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_handlers_disconnect_matched (uploader, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp0_, 0, NULL, (GCallback) _publishing_gallery3_gallery_publisher_on_publish_complete_publishing_rest_support_batch_uploader_upload_complete, self);
#line 1445 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_parse_name ("upload-error", PUBLISHING_REST_SUPPORT_TYPE_BATCH_UPLOADER, &_tmp1_, NULL, FALSE);
#line 1445 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_handlers_disconnect_matched (uploader, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _publishing_gallery3_gallery_publisher_on_publish_error_publishing_rest_support_batch_uploader_upload_error, self);
#line 1447 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (!spit_publishing_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_PUBLISHER, SpitPublishingPublisher))) {
#line 1448 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		return;
#line 9147 "GalleryConnector.c"
	}
#line 1451 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp2_ = self->priv->session;
#line 1451 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (!publishing_rest_support_session_is_authenticated (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, PUBLISHING_REST_SUPPORT_TYPE_SESSION, PublishingRESTSupportSession))) {
#line 1452 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		return;
#line 9155 "GalleryConnector.c"
	}
#line 1454 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_debug ("GalleryConnector.vala:1454: EVENT: publishing complete; %d items publi" \
"shed", num_published);
#line 1457 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_gallery_publisher_do_show_success_pane (self);
#line 9161 "GalleryConnector.c"
}


static void
publishing_gallery3_gallery_publisher_on_publishing_options_pane_logout (PublishingGallery3GalleryPublisher* self)
{
	PublishingGallery3PublishingOptionsPane* _tmp0_;
	guint _tmp1_;
	PublishingGallery3PublishingOptionsPane* _tmp2_;
	guint _tmp3_;
	PublishingGallery3Session* _tmp4_;
#line 1461 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_GALLERY_PUBLISHER (self));
#line 1462 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->publishing_options_pane;
#line 1462 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_parse_name ("publish", PUBLISHING_GALLERY3_TYPE_PUBLISHING_OPTIONS_PANE, &_tmp1_, NULL, FALSE);
#line 1462 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_handlers_disconnect_matched (_tmp0_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _publishing_gallery3_gallery_publisher_on_publishing_options_pane_publish_publishing_gallery3_publishing_options_pane_publish, self);
#line 1464 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp2_ = self->priv->publishing_options_pane;
#line 1464 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_parse_name ("logout", PUBLISHING_GALLERY3_TYPE_PUBLISHING_OPTIONS_PANE, &_tmp3_, NULL, FALSE);
#line 1464 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_handlers_disconnect_matched (_tmp2_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp3_, 0, NULL, (GCallback) _publishing_gallery3_gallery_publisher_on_publishing_options_pane_logout_publishing_gallery3_publishing_options_pane_logout, self);
#line 1467 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (!spit_publishing_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_PUBLISHER, SpitPublishingPublisher))) {
#line 1468 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		return;
#line 9191 "GalleryConnector.c"
	}
#line 1470 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_debug ("GalleryConnector.vala:1470: EVENT: user is attempting to log out.");
#line 1472 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp4_ = self->priv->session;
#line 1472 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_session_deauthenticate (_tmp4_);
#line 1473 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_gallery_publisher_do_show_service_welcome_pane (self);
#line 9201 "GalleryConnector.c"
}


static void
publishing_gallery3_gallery_publisher_on_publishing_options_pane_publish (PublishingGallery3GalleryPublisher* self,
                                                                          PublishingGallery3PublishingParameters* parameters)
{
	PublishingGallery3PublishingOptionsPane* _tmp0_;
	guint _tmp1_;
	PublishingGallery3PublishingOptionsPane* _tmp2_;
	guint _tmp3_;
#line 1476 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_GALLERY_PUBLISHER (self));
#line 1476 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_PUBLISHING_PARAMETERS (parameters));
#line 1477 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->publishing_options_pane;
#line 1477 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_parse_name ("publish", PUBLISHING_GALLERY3_TYPE_PUBLISHING_OPTIONS_PANE, &_tmp1_, NULL, FALSE);
#line 1477 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_handlers_disconnect_matched (_tmp0_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _publishing_gallery3_gallery_publisher_on_publishing_options_pane_publish_publishing_gallery3_publishing_options_pane_publish, self);
#line 1479 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp2_ = self->priv->publishing_options_pane;
#line 1479 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_parse_name ("logout", PUBLISHING_GALLERY3_TYPE_PUBLISHING_OPTIONS_PANE, &_tmp3_, NULL, FALSE);
#line 1479 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_handlers_disconnect_matched (_tmp2_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp3_, 0, NULL, (GCallback) _publishing_gallery3_gallery_publisher_on_publishing_options_pane_logout_publishing_gallery3_publishing_options_pane_logout, self);
#line 1482 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (!spit_publishing_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_PUBLISHER, SpitPublishingPublisher))) {
#line 1483 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		return;
#line 9233 "GalleryConnector.c"
	}
#line 1485 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_debug ("GalleryConnector.vala:1485: EVENT: user is attempting to publish somet" \
"hing.");
#line 1487 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (publishing_gallery3_publishing_parameters_is_to_new_album (parameters)) {
#line 9239 "GalleryConnector.c"
		const gchar* _tmp4_;
		const gchar* _tmp5_;
#line 1488 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp4_ = publishing_gallery3_publishing_parameters_get_album_name (parameters);
#line 1488 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp5_ = _tmp4_;
#line 1488 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_debug ("GalleryConnector.vala:1488: EVENT: must create new album \"%s\" first.", _tmp5_);
#line 1490 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		publishing_gallery3_gallery_publisher_do_create_album (self, parameters);
#line 9250 "GalleryConnector.c"
	} else {
#line 1493 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		publishing_gallery3_gallery_publisher_do_publish (self, parameters);
#line 9254 "GalleryConnector.c"
	}
}


static void
publishing_gallery3_gallery_publisher_class_init (PublishingGallery3GalleryPublisherClass * klass)
{
#line 800 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_gallery_publisher_parent_class = g_type_class_peek_parent (klass);
#line 800 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_type_class_add_private (klass, sizeof (PublishingGallery3GalleryPublisherPrivate));
#line 800 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	G_OBJECT_CLASS (klass)->finalize = publishing_gallery3_gallery_publisher_finalize;
#line 9268 "GalleryConnector.c"
}


static void
publishing_gallery3_gallery_publisher_spit_publishing_publisher_interface_init (SpitPublishingPublisherIface * iface)
{
#line 800 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_gallery_publisher_spit_publishing_publisher_parent_iface = g_type_interface_peek_parent (iface);
#line 800 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	iface->is_running = (gboolean (*) (SpitPublishingPublisher *)) publishing_gallery3_gallery_publisher_real_is_running;
#line 800 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	iface->get_service = (SpitPublishingService* (*) (SpitPublishingPublisher *)) publishing_gallery3_gallery_publisher_real_get_service;
#line 800 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	iface->start = (void (*) (SpitPublishingPublisher *)) publishing_gallery3_gallery_publisher_real_start;
#line 800 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	iface->stop = (void (*) (SpitPublishingPublisher *)) publishing_gallery3_gallery_publisher_real_stop;
#line 9285 "GalleryConnector.c"
}


static void
publishing_gallery3_gallery_publisher_instance_init (PublishingGallery3GalleryPublisher * self)
{
#line 800 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv = PUBLISHING_GALLERY3_GALLERY_PUBLISHER_GET_PRIVATE (self);
#line 804 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->host = NULL;
#line 805 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->progress_reporter = NULL;
#line 805 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->progress_reporter_target = self;
#line 805 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->progress_reporter_target_destroy_notify = NULL;
#line 806 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->service = NULL;
#line 807 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->session = NULL;
#line 808 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->running = FALSE;
#line 809 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->albums = NULL;
#line 809 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->albums_length1 = 0;
#line 809 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->_albums_size_ = self->priv->albums_length1;
#line 810 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->key = NULL;
#line 812 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->publishing_options_pane = NULL;
#line 9318 "GalleryConnector.c"
}


static void
publishing_gallery3_gallery_publisher_finalize (GObject * obj)
{
	PublishingGallery3GalleryPublisher * self;
#line 800 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_GALLERY3_TYPE_GALLERY_PUBLISHER, PublishingGallery3GalleryPublisher);
#line 805 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	(self->priv->progress_reporter_target_destroy_notify == NULL) ? NULL : (self->priv->progress_reporter_target_destroy_notify (self->priv->progress_reporter_target), NULL);
#line 805 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->progress_reporter = NULL;
#line 805 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->progress_reporter_target = NULL;
#line 805 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->progress_reporter_target_destroy_notify = NULL;
#line 807 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_publishing_rest_support_session_unref0 (self->priv->session);
#line 809 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->albums = (_vala_array_free (self->priv->albums, self->priv->albums_length1, (GDestroyNotify) publishing_gallery3_album_unref), NULL);
#line 810 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (self->priv->key);
#line 812 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_object_unref0 (self->priv->publishing_options_pane);
#line 800 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	G_OBJECT_CLASS (publishing_gallery3_gallery_publisher_parent_class)->finalize (obj);
#line 9346 "GalleryConnector.c"
}


GType
publishing_gallery3_gallery_publisher_get_type (void)
{
	static volatile gsize publishing_gallery3_gallery_publisher_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_gallery3_gallery_publisher_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingGallery3GalleryPublisherClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_gallery3_gallery_publisher_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingGallery3GalleryPublisher), 0, (GInstanceInitFunc) publishing_gallery3_gallery_publisher_instance_init, NULL };
		static const GInterfaceInfo spit_publishing_publisher_info = { (GInterfaceInitFunc) publishing_gallery3_gallery_publisher_spit_publishing_publisher_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType publishing_gallery3_gallery_publisher_type_id;
		publishing_gallery3_gallery_publisher_type_id = g_type_register_static (G_TYPE_OBJECT, "PublishingGallery3GalleryPublisher", &g_define_type_info, 0);
		g_type_add_interface_static (publishing_gallery3_gallery_publisher_type_id, SPIT_PUBLISHING_TYPE_PUBLISHER, &spit_publishing_publisher_info);
		g_once_init_leave (&publishing_gallery3_gallery_publisher_type_id__volatile, publishing_gallery3_gallery_publisher_type_id);
	}
	return publishing_gallery3_gallery_publisher_type_id__volatile;
}


static PublishingGallery3Album**
_vala_array_dup3 (PublishingGallery3Album** self,
                  int length)
{
	PublishingGallery3Album** result;
	int i;
#line 1527 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = g_new0 (PublishingGallery3Album*, length + 1);
#line 1527 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	for (i = 0; i < length; i++) {
#line 9376 "GalleryConnector.c"
		PublishingGallery3Album* _tmp0_;
#line 1527 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp0_ = _publishing_gallery3_album_ref0 (self[i]);
#line 1527 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		result[i] = _tmp0_;
#line 9382 "GalleryConnector.c"
	}
#line 1527 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 9386 "GalleryConnector.c"
}


static void
_publishing_gallery3_publishing_options_pane_on_use_existing_radio_clicked_gtk_button_clicked (GtkButton* _sender,
                                                                                               gpointer self)
{
#line 1556 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_publishing_options_pane_on_use_existing_radio_clicked ((PublishingGallery3PublishingOptionsPane*) self);
#line 9396 "GalleryConnector.c"
}


static void
_publishing_gallery3_publishing_options_pane_on_create_new_radio_clicked_gtk_button_clicked (GtkButton* _sender,
                                                                                             gpointer self)
{
#line 1557 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_publishing_options_pane_on_create_new_radio_clicked ((PublishingGallery3PublishingOptionsPane*) self);
#line 9406 "GalleryConnector.c"
}


static void
_publishing_gallery3_publishing_options_pane_on_new_album_entry_changed_gtk_editable_changed (GtkEditable* _sender,
                                                                                              gpointer self)
{
#line 1558 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_publishing_options_pane_on_new_album_entry_changed ((PublishingGallery3PublishingOptionsPane*) self);
#line 9416 "GalleryConnector.c"
}


static void
_publishing_gallery3_publishing_options_pane_on_scaling_constraint_changed_gtk_combo_box_changed (GtkComboBox* _sender,
                                                                                                  gpointer self)
{
#line 1559 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_publishing_options_pane_on_scaling_constraint_changed ((PublishingGallery3PublishingOptionsPane*) self);
#line 9426 "GalleryConnector.c"
}


static void
_publishing_gallery3_publishing_options_pane_on_pixels_changed_gtk_editable_changed (GtkEditable* _sender,
                                                                                     gpointer self)
{
#line 1560 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_publishing_options_pane_on_pixels_changed ((PublishingGallery3PublishingOptionsPane*) self);
#line 9436 "GalleryConnector.c"
}


static void
_publishing_gallery3_publishing_options_pane_on_logout_clicked_gtk_button_clicked (GtkButton* _sender,
                                                                                   gpointer self)
{
#line 1561 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_publishing_options_pane_on_logout_clicked ((PublishingGallery3PublishingOptionsPane*) self);
#line 9446 "GalleryConnector.c"
}


static void
_publishing_gallery3_publishing_options_pane_on_publish_clicked_gtk_button_clicked (GtkButton* _sender,
                                                                                    gpointer self)
{
#line 1562 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_publishing_options_pane_on_publish_clicked ((PublishingGallery3PublishingOptionsPane*) self);
#line 9456 "GalleryConnector.c"
}


PublishingGallery3PublishingOptionsPane*
publishing_gallery3_publishing_options_pane_construct (GType object_type,
                                                       SpitPublishingPluginHost* host,
                                                       const gchar* url,
                                                       const gchar* username,
                                                       PublishingGallery3Album** albums,
                                                       int albums_length1,
                                                       GtkBuilder* builder,
                                                       gboolean strip_metadata,
                                                       gint scaling_id,
                                                       gint scaling_pixels)
{
	PublishingGallery3PublishingOptionsPane * self = NULL;
	PublishingGallery3Album** _tmp0_;
	gint _tmp0__length1;
	GtkBuilder* _tmp1_;
	GSList* _tmp2_;
	GSList* _tmp3_;
	GObject* _tmp4_;
	GtkGrid* _tmp5_;
	GObject* _tmp6_;
	GtkLabel* _tmp7_;
	GObject* _tmp8_;
	GtkRadioButton* _tmp9_;
	GObject* _tmp10_;
	GtkComboBoxText* _tmp11_;
	GObject* _tmp12_;
	GtkComboBoxText* _tmp13_;
	GObject* _tmp14_;
	GtkEntry* _tmp15_;
	GObject* _tmp16_;
	GtkRadioButton* _tmp17_;
	GObject* _tmp18_;
	GtkEntry* _tmp19_;
	GtkBuilder* _tmp20_;
	GObject* _tmp21_;
	GtkCheckButton* _tmp22_;
	GObject* _tmp23_;
	GtkButton* _tmp24_;
	GObject* _tmp25_;
	GtkButton* _tmp26_;
	GtkLabel* _tmp27_;
	gchar* _tmp28_;
	gchar* _tmp29_;
	GtkCheckButton* _tmp30_;
	GtkComboBoxText* _tmp31_;
	GtkEntry* _tmp32_;
	gchar* _tmp33_;
	gchar* _tmp34_;
	GtkRadioButton* _tmp35_;
	GtkRadioButton* _tmp36_;
	GtkEntry* _tmp37_;
	GtkComboBoxText* _tmp38_;
	GtkEntry* _tmp39_;
	GtkButton* _tmp40_;
	GtkButton* _tmp41_;
#line 1523 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (SPIT_PUBLISHING_IS_PLUGIN_HOST (host), NULL);
#line 1523 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (url != NULL, NULL);
#line 1523 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (username != NULL, NULL);
#line 1523 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (GTK_IS_BUILDER (builder), NULL);
#line 1523 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = (PublishingGallery3PublishingOptionsPane*) g_object_new (object_type, NULL);
#line 1527 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = (albums != NULL) ? _vala_array_dup3 (albums, albums_length1) : ((gpointer) albums);
#line 1527 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0__length1 = albums_length1;
#line 1527 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->albums = (_vala_array_free (self->priv->albums, self->priv->albums_length1, (GDestroyNotify) publishing_gallery3_album_unref), NULL);
#line 1527 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->albums = _tmp0_;
#line 1527 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->albums_length1 = _tmp0__length1;
#line 1527 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->_albums_size_ = self->priv->albums_length1;
#line 1528 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->host = host;
#line 1530 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = _g_object_ref0 (builder);
#line 1530 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_object_unref0 (self->priv->builder);
#line 1530 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->builder = _tmp1_;
#line 1531 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_vala_assert (NULL != builder, "null != builder");
#line 1532 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp2_ = gtk_builder_get_objects (builder);
#line 1532 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp3_ = _tmp2_;
#line 1532 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_vala_assert (g_slist_length (_tmp3_) > ((guint) 0), "builder.get_objects().length() > 0");
#line 1532 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_slist_free0 (_tmp3_);
#line 1535 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp4_ = gtk_builder_get_object (builder, "pane_widget");
#line 1535 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp5_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp4_, gtk_grid_get_type ()) ? ((GtkGrid*) _tmp4_) : NULL);
#line 1535 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_object_unref0 (self->priv->pane_widget);
#line 1535 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->pane_widget = _tmp5_;
#line 1536 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp6_ = gtk_builder_get_object (builder, "title_label");
#line 1536 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp7_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp6_, gtk_label_get_type ()) ? ((GtkLabel*) _tmp6_) : NULL);
#line 1536 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_object_unref0 (self->priv->title_label);
#line 1536 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->title_label = _tmp7_;
#line 1537 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp8_ = gtk_builder_get_object (builder, "publish_to_existing_radio");
#line 1537 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp9_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp8_, gtk_radio_button_get_type ()) ? ((GtkRadioButton*) _tmp8_) : NULL);
#line 1537 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_object_unref0 (self->priv->use_existing_radio);
#line 1537 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->use_existing_radio = _tmp9_;
#line 1538 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp10_ = gtk_builder_get_object (builder, "existing_albums_combo");
#line 1538 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp11_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp10_, gtk_combo_box_text_get_type ()) ? ((GtkComboBoxText*) _tmp10_) : NULL);
#line 1538 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_object_unref0 (self->priv->existing_albums_combo);
#line 1538 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->existing_albums_combo = _tmp11_;
#line 1539 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp12_ = gtk_builder_get_object (builder, "scaling_constraint_combo");
#line 1539 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp13_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp12_, gtk_combo_box_text_get_type ()) ? ((GtkComboBoxText*) _tmp12_) : NULL);
#line 1539 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_object_unref0 (self->priv->scaling_combo);
#line 1539 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->scaling_combo = _tmp13_;
#line 1540 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp14_ = gtk_builder_get_object (builder, "major_axis_pixels");
#line 1540 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp15_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp14_, gtk_entry_get_type ()) ? ((GtkEntry*) _tmp14_) : NULL);
#line 1540 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_object_unref0 (self->priv->pixels);
#line 1540 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->pixels = _tmp15_;
#line 1541 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp16_ = gtk_builder_get_object (builder, "publish_new_radio");
#line 1541 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp17_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp16_, gtk_radio_button_get_type ()) ? ((GtkRadioButton*) _tmp16_) : NULL);
#line 1541 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_object_unref0 (self->priv->create_new_radio);
#line 1541 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->create_new_radio = _tmp17_;
#line 1542 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp18_ = gtk_builder_get_object (builder, "new_album_name");
#line 1542 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp19_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp18_, gtk_entry_get_type ()) ? ((GtkEntry*) _tmp18_) : NULL);
#line 1542 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_object_unref0 (self->priv->new_album_entry);
#line 1542 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->new_album_entry = _tmp19_;
#line 1543 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp20_ = self->priv->builder;
#line 1543 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp21_ = gtk_builder_get_object (_tmp20_, "strip_metadata_check");
#line 1543 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp22_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp21_, gtk_check_button_get_type ()) ? ((GtkCheckButton*) _tmp21_) : NULL);
#line 1543 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_object_unref0 (self->priv->strip_metadata_check);
#line 1543 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->strip_metadata_check = _tmp22_;
#line 1544 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp23_ = gtk_builder_get_object (builder, "publish_button");
#line 1544 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp24_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp23_, gtk_button_get_type ()) ? ((GtkButton*) _tmp23_) : NULL);
#line 1544 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_object_unref0 (self->priv->publish_button);
#line 1544 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->publish_button = _tmp24_;
#line 1545 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp25_ = gtk_builder_get_object (builder, "logout_button");
#line 1545 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp26_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp25_, gtk_button_get_type ()) ? ((GtkButton*) _tmp25_) : NULL);
#line 1545 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_object_unref0 (self->priv->logout_button);
#line 1545 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->logout_button = _tmp26_;
#line 1549 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp27_ = self->priv->title_label;
#line 1549 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp28_ = g_strdup_printf (_ ("Publishing to %s as %s."), url, username);
#line 1549 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp29_ = _tmp28_;
#line 1549 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	gtk_label_set_label (_tmp27_, _tmp29_);
#line 1549 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (_tmp29_);
#line 1551 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp30_ = self->priv->strip_metadata_check;
#line 1551 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	gtk_toggle_button_set_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp30_, gtk_toggle_button_get_type (), GtkToggleButton), strip_metadata);
#line 1552 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp31_ = self->priv->scaling_combo;
#line 1552 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	gtk_combo_box_set_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp31_, gtk_combo_box_get_type (), GtkComboBox), scaling_id);
#line 1553 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp32_ = self->priv->pixels;
#line 1553 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp33_ = g_strdup_printf ("%i", scaling_pixels);
#line 1553 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp34_ = _tmp33_;
#line 1553 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	gtk_entry_set_text (_tmp32_, _tmp34_);
#line 1553 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (_tmp34_);
#line 1556 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp35_ = self->priv->use_existing_radio;
#line 1556 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp35_, gtk_button_get_type (), GtkButton), "clicked", (GCallback) _publishing_gallery3_publishing_options_pane_on_use_existing_radio_clicked_gtk_button_clicked, self, 0);
#line 1557 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp36_ = self->priv->create_new_radio;
#line 1557 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp36_, gtk_button_get_type (), GtkButton), "clicked", (GCallback) _publishing_gallery3_publishing_options_pane_on_create_new_radio_clicked_gtk_button_clicked, self, 0);
#line 1558 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp37_ = self->priv->new_album_entry;
#line 1558 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp37_, gtk_editable_get_type (), GtkEditable), "changed", (GCallback) _publishing_gallery3_publishing_options_pane_on_new_album_entry_changed_gtk_editable_changed, self, 0);
#line 1559 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp38_ = self->priv->scaling_combo;
#line 1559 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp38_, gtk_combo_box_get_type (), GtkComboBox), "changed", (GCallback) _publishing_gallery3_publishing_options_pane_on_scaling_constraint_changed_gtk_combo_box_changed, self, 0);
#line 1560 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp39_ = self->priv->pixels;
#line 1560 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp39_, gtk_editable_get_type (), GtkEditable), "changed", (GCallback) _publishing_gallery3_publishing_options_pane_on_pixels_changed_gtk_editable_changed, self, 0);
#line 1561 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp40_ = self->priv->logout_button;
#line 1561 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_connect_object (_tmp40_, "clicked", (GCallback) _publishing_gallery3_publishing_options_pane_on_logout_clicked_gtk_button_clicked, self, 0);
#line 1562 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp41_ = self->priv->publish_button;
#line 1562 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_connect_object (_tmp41_, "clicked", (GCallback) _publishing_gallery3_publishing_options_pane_on_publish_clicked_gtk_button_clicked, self, 0);
#line 1523 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return self;
#line 9704 "GalleryConnector.c"
}


PublishingGallery3PublishingOptionsPane*
publishing_gallery3_publishing_options_pane_new (SpitPublishingPluginHost* host,
                                                 const gchar* url,
                                                 const gchar* username,
                                                 PublishingGallery3Album** albums,
                                                 int albums_length1,
                                                 GtkBuilder* builder,
                                                 gboolean strip_metadata,
                                                 gint scaling_id,
                                                 gint scaling_pixels)
{
#line 1523 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return publishing_gallery3_publishing_options_pane_construct (PUBLISHING_GALLERY3_TYPE_PUBLISHING_OPTIONS_PANE, host, url, username, albums, albums_length1, builder, strip_metadata, scaling_id, scaling_pixels);
#line 9721 "GalleryConnector.c"
}


static void
publishing_gallery3_publishing_options_pane_on_publish_clicked (PublishingGallery3PublishingOptionsPane* self)
{
	gchar* album_name = NULL;
	gint _tmp0_ = 0;
	GtkComboBoxText* _tmp1_;
	gint photo_major_axis_size = 0;
	PublishingGallery3PublishingParameters* param = NULL;
	GtkRadioButton* _tmp4_;
	PublishingGallery3PublishingParameters* _tmp29_;
	gint _tmp30_;
	PublishingGallery3PublishingParameters* _tmp31_;
	GtkCheckButton* _tmp32_;
	PublishingGallery3PublishingParameters* _tmp33_;
#line 1565 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_PUBLISHING_OPTIONS_PANE (self));
#line 1568 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = self->priv->scaling_combo;
#line 1568 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (gtk_combo_box_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, gtk_combo_box_get_type (), GtkComboBox)) == 1) {
#line 9745 "GalleryConnector.c"
		GtkEntry* _tmp2_;
		const gchar* _tmp3_;
#line 1569 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp2_ = self->priv->pixels;
#line 1569 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp3_ = gtk_entry_get_text (_tmp2_);
#line 1569 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp0_ = atoi (_tmp3_);
#line 9754 "GalleryConnector.c"
	} else {
#line 1569 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp0_ = -1;
#line 9758 "GalleryConnector.c"
	}
#line 1567 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	photo_major_axis_size = _tmp0_;
#line 1572 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp4_ = self->priv->create_new_radio;
#line 1572 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (gtk_toggle_button_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp4_, gtk_toggle_button_get_type (), GtkToggleButton))) {
#line 9766 "GalleryConnector.c"
		GtkEntry* _tmp5_;
		const gchar* _tmp6_;
		gchar* _tmp7_;
		SpitPublishingPluginHost* _tmp8_;
		const gchar* _tmp9_;
		const gchar* _tmp10_;
		PublishingGallery3PublishingParameters* _tmp11_;
		const gchar* _tmp12_;
#line 1573 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp5_ = self->priv->new_album_entry;
#line 1573 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp6_ = gtk_entry_get_text (_tmp5_);
#line 1573 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp7_ = g_strdup (_tmp6_);
#line 1573 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_free0 (album_name);
#line 1573 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		album_name = _tmp7_;
#line 1574 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp8_ = self->priv->host;
#line 1574 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp9_ = album_name;
#line 1574 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		spit_host_interface_set_config_string (G_TYPE_CHECK_INSTANCE_CAST (_tmp8_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), PUBLISHING_GALLERY3_PUBLISHING_OPTIONS_PANE_LAST_ALBUM_CONFIG_KEY, _tmp9_);
#line 1575 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp10_ = album_name;
#line 1575 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp11_ = publishing_gallery3_publishing_parameters_new_to_new_album (_tmp10_);
#line 1575 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_publishing_gallery3_publishing_parameters_unref0 (param);
#line 1575 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		param = _tmp11_;
#line 1577 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp12_ = album_name;
#line 1577 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_debug ("GalleryConnector.vala:1577: Trying to publish to \"%s\"", _tmp12_);
#line 9803 "GalleryConnector.c"
	} else {
		PublishingGallery3Album** _tmp13_;
		gint _tmp13__length1;
		GtkComboBoxText* _tmp14_;
		PublishingGallery3Album* _tmp15_;
		const gchar* _tmp16_;
		const gchar* _tmp17_;
		gchar* _tmp18_;
		SpitPublishingPluginHost* _tmp19_;
		const gchar* _tmp20_;
		gchar* album_path = NULL;
		PublishingGallery3Album** _tmp21_;
		gint _tmp21__length1;
		GtkComboBoxText* _tmp22_;
		PublishingGallery3Album* _tmp23_;
		const gchar* _tmp24_;
		const gchar* _tmp25_;
		gchar* _tmp26_;
		const gchar* _tmp27_;
		PublishingGallery3PublishingParameters* _tmp28_;
#line 1579 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp13_ = self->priv->albums;
#line 1579 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp13__length1 = self->priv->albums_length1;
#line 1579 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp14_ = self->priv->existing_albums_combo;
#line 1579 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp15_ = _tmp13_[gtk_combo_box_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp14_, gtk_combo_box_get_type (), GtkComboBox))];
#line 1579 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp16_ = publishing_gallery3_album_get_title (_tmp15_);
#line 1579 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp17_ = _tmp16_;
#line 1579 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp18_ = g_strdup (_tmp17_);
#line 1579 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_free0 (album_name);
#line 1579 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		album_name = _tmp18_;
#line 1581 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp19_ = self->priv->host;
#line 1581 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp20_ = album_name;
#line 1581 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		spit_host_interface_set_config_string (G_TYPE_CHECK_INSTANCE_CAST (_tmp19_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), PUBLISHING_GALLERY3_PUBLISHING_OPTIONS_PANE_LAST_ALBUM_CONFIG_KEY, _tmp20_);
#line 1582 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp21_ = self->priv->albums;
#line 1582 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp21__length1 = self->priv->albums_length1;
#line 1582 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp22_ = self->priv->existing_albums_combo;
#line 1582 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp23_ = _tmp21_[gtk_combo_box_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp22_, gtk_combo_box_get_type (), GtkComboBox))];
#line 1582 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp24_ = publishing_gallery3_album_get_path (_tmp23_);
#line 1582 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp25_ = _tmp24_;
#line 1582 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp26_ = g_strdup (_tmp25_);
#line 1582 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		album_path = _tmp26_;
#line 1584 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp27_ = album_path;
#line 1584 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp28_ = publishing_gallery3_publishing_parameters_new_to_existing_album (_tmp27_);
#line 1584 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_publishing_gallery3_publishing_parameters_unref0 (param);
#line 1584 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		param = _tmp28_;
#line 1572 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_free0 (album_path);
#line 9874 "GalleryConnector.c"
	}
#line 1588 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp29_ = param;
#line 1588 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp30_ = photo_major_axis_size;
#line 1588 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_publishing_parameters_set_photo_major_axis_size (_tmp29_, _tmp30_);
#line 1589 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp31_ = param;
#line 1589 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp32_ = self->priv->strip_metadata_check;
#line 1589 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_publishing_parameters_set_strip_metadata (_tmp31_, gtk_toggle_button_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp32_, gtk_toggle_button_get_type (), GtkToggleButton)));
#line 1591 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp33_ = param;
#line 1591 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_emit (self, publishing_gallery3_publishing_options_pane_signals[PUBLISHING_GALLERY3_PUBLISHING_OPTIONS_PANE_PUBLISH_SIGNAL], 0, _tmp33_);
#line 1565 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_publishing_gallery3_publishing_parameters_unref0 (param);
#line 1565 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (album_name);
#line 9896 "GalleryConnector.c"
}


static void
publishing_gallery3_publishing_options_pane_on_use_existing_radio_clicked (PublishingGallery3PublishingOptionsPane* self)
{
	GtkComboBoxText* _tmp0_;
	GtkEntry* _tmp1_;
	GtkComboBoxText* _tmp2_;
#line 1594 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_PUBLISHING_OPTIONS_PANE (self));
#line 1595 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->existing_albums_combo;
#line 1595 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, gtk_widget_get_type (), GtkWidget), TRUE);
#line 1596 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = self->priv->new_album_entry;
#line 1596 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, gtk_widget_get_type (), GtkWidget), FALSE);
#line 1597 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp2_ = self->priv->existing_albums_combo;
#line 1597 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	gtk_widget_grab_focus (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, gtk_widget_get_type (), GtkWidget));
#line 1598 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_publishing_options_pane_update_publish_button_sensitivity (self);
#line 9922 "GalleryConnector.c"
}


static void
publishing_gallery3_publishing_options_pane_on_create_new_radio_clicked (PublishingGallery3PublishingOptionsPane* self)
{
	GtkEntry* _tmp0_;
	GtkComboBoxText* _tmp1_;
	GtkEntry* _tmp2_;
#line 1601 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_PUBLISHING_OPTIONS_PANE (self));
#line 1602 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->new_album_entry;
#line 1602 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, gtk_widget_get_type (), GtkWidget), TRUE);
#line 1603 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = self->priv->existing_albums_combo;
#line 1603 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, gtk_widget_get_type (), GtkWidget), FALSE);
#line 1604 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp2_ = self->priv->new_album_entry;
#line 1604 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	gtk_widget_grab_focus (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, gtk_widget_get_type (), GtkWidget));
#line 1605 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_publishing_options_pane_update_publish_button_sensitivity (self);
#line 9948 "GalleryConnector.c"
}


static void
publishing_gallery3_publishing_options_pane_on_logout_clicked (PublishingGallery3PublishingOptionsPane* self)
{
#line 1608 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_PUBLISHING_OPTIONS_PANE (self));
#line 1609 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_emit (self, publishing_gallery3_publishing_options_pane_signals[PUBLISHING_GALLERY3_PUBLISHING_OPTIONS_PANE_LOGOUT_SIGNAL], 0);
#line 9959 "GalleryConnector.c"
}


static gchar*
string_strip (const gchar* self)
{
	gchar* result = NULL;
	gchar* _result_ = NULL;
	gchar* _tmp0_;
	const gchar* _tmp1_;
#line 1248 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, NULL);
#line 1249 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	_tmp0_ = g_strdup (self);
#line 1249 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	_result_ = _tmp0_;
#line 1250 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	_tmp1_ = _result_;
#line 1250 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	g_strstrip (_tmp1_);
#line 1251 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	result = _result_;
#line 1251 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	return result;
#line 9984 "GalleryConnector.c"
}


static void
publishing_gallery3_publishing_options_pane_update_publish_button_sensitivity (PublishingGallery3PublishingOptionsPane* self)
{
	gchar* album_name = NULL;
	GtkEntry* _tmp0_;
	const gchar* _tmp1_;
	gchar* _tmp2_;
	gboolean _tmp3_ = FALSE;
	const gchar* _tmp4_;
	gchar* _tmp5_;
	gchar* _tmp6_;
	gboolean _tmp7_;
	GtkButton* _tmp9_;
#line 1612 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_PUBLISHING_OPTIONS_PANE (self));
#line 1613 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->new_album_entry;
#line 1613 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = gtk_entry_get_text (_tmp0_);
#line 1613 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp2_ = g_strdup (_tmp1_);
#line 1613 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	album_name = _tmp2_;
#line 1614 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp4_ = album_name;
#line 1614 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp5_ = string_strip (_tmp4_);
#line 1614 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp6_ = _tmp5_;
#line 1614 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp7_ = g_strcmp0 (_tmp6_, "") == 0;
#line 1614 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (_tmp6_);
#line 1614 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (_tmp7_) {
#line 10023 "GalleryConnector.c"
		GtkRadioButton* _tmp8_;
#line 1615 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp8_ = self->priv->create_new_radio;
#line 1615 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp3_ = gtk_toggle_button_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp8_, gtk_toggle_button_get_type (), GtkToggleButton));
#line 10029 "GalleryConnector.c"
	} else {
#line 1614 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp3_ = FALSE;
#line 10033 "GalleryConnector.c"
	}
#line 1614 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp9_ = self->priv->publish_button;
#line 1614 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, gtk_widget_get_type (), GtkWidget), !_tmp3_);
#line 1612 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (album_name);
#line 10041 "GalleryConnector.c"
}


static void
publishing_gallery3_publishing_options_pane_on_new_album_entry_changed (PublishingGallery3PublishingOptionsPane* self)
{
#line 1618 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_PUBLISHING_OPTIONS_PANE (self));
#line 1619 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_publishing_options_pane_update_publish_button_sensitivity (self);
#line 10052 "GalleryConnector.c"
}


static void
publishing_gallery3_publishing_options_pane_update_pixel_entry_sensitivity (PublishingGallery3PublishingOptionsPane* self)
{
	GtkEntry* _tmp0_;
	GtkComboBoxText* _tmp1_;
#line 1622 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_PUBLISHING_OPTIONS_PANE (self));
#line 1623 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->pixels;
#line 1623 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = self->priv->scaling_combo;
#line 1623 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, gtk_widget_get_type (), GtkWidget), gtk_combo_box_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, gtk_combo_box_get_type (), GtkComboBox)) == 1);
#line 10069 "GalleryConnector.c"
}


static void
publishing_gallery3_publishing_options_pane_on_scaling_constraint_changed (PublishingGallery3PublishingOptionsPane* self)
{
#line 1626 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_PUBLISHING_OPTIONS_PANE (self));
#line 1627 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_publishing_options_pane_update_pixel_entry_sensitivity (self);
#line 10080 "GalleryConnector.c"
}


static glong
string_strnlen (gchar* str,
                glong maxlen)
{
	glong result = 0L;
	gchar* end = NULL;
	gchar* _tmp0_;
	gchar* _tmp1_;
#line 1336 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	_tmp0_ = memchr (str, 0, (gsize) maxlen);
#line 1336 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	end = _tmp0_;
#line 1337 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	_tmp1_ = end;
#line 1337 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	if (_tmp1_ == NULL) {
#line 1338 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		result = maxlen;
#line 1338 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		return result;
#line 10104 "GalleryConnector.c"
	} else {
		gchar* _tmp2_;
#line 1340 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		_tmp2_ = end;
#line 1340 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		result = (glong) (_tmp2_ - str);
#line 1340 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		return result;
#line 10113 "GalleryConnector.c"
	}
}


static gchar*
string_substring (const gchar* self,
                  glong offset,
                  glong len)
{
	gchar* result = NULL;
	glong string_length = 0L;
	gboolean _tmp0_ = FALSE;
	glong _tmp6_;
	gchar* _tmp7_;
#line 1347 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, NULL);
#line 1349 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	if (offset >= ((glong) 0)) {
#line 1349 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		_tmp0_ = len >= ((glong) 0);
#line 10134 "GalleryConnector.c"
	} else {
#line 1349 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		_tmp0_ = FALSE;
#line 10138 "GalleryConnector.c"
	}
#line 1349 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	if (_tmp0_) {
#line 1351 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		string_length = string_strnlen ((gchar*) self, offset + len);
#line 10144 "GalleryConnector.c"
	} else {
		gint _tmp1_;
		gint _tmp2_;
#line 1353 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		_tmp1_ = strlen (self);
#line 1353 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		_tmp2_ = _tmp1_;
#line 1353 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		string_length = (glong) _tmp2_;
#line 10154 "GalleryConnector.c"
	}
#line 1356 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	if (offset < ((glong) 0)) {
#line 10158 "GalleryConnector.c"
		glong _tmp3_;
#line 1357 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		_tmp3_ = string_length;
#line 1357 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		offset = _tmp3_ + offset;
#line 1358 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		g_return_val_if_fail (offset >= ((glong) 0), NULL);
#line 10166 "GalleryConnector.c"
	} else {
		glong _tmp4_;
#line 1360 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		_tmp4_ = string_length;
#line 1360 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		g_return_val_if_fail (offset <= _tmp4_, NULL);
#line 10173 "GalleryConnector.c"
	}
#line 1362 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	if (len < ((glong) 0)) {
#line 10177 "GalleryConnector.c"
		glong _tmp5_;
#line 1363 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		_tmp5_ = string_length;
#line 1363 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		len = _tmp5_ - offset;
#line 10183 "GalleryConnector.c"
	}
#line 1365 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	_tmp6_ = string_length;
#line 1365 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	g_return_val_if_fail ((offset + len) <= _tmp6_, NULL);
#line 1366 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	_tmp7_ = g_strndup (((gchar*) self) + offset, (gsize) len);
#line 1366 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	result = _tmp7_;
#line 1366 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	return result;
#line 10195 "GalleryConnector.c"
}


static void
publishing_gallery3_publishing_options_pane_on_pixels_changed (PublishingGallery3PublishingOptionsPane* self)
{
	gchar* orig_text = NULL;
	GtkEntry* _tmp0_;
	const gchar* _tmp1_;
	gchar* _tmp2_;
	gchar last_char = '\0';
	const gchar* _tmp3_;
	const gchar* _tmp4_;
	gint _tmp5_;
	gint _tmp6_;
	const gchar* _tmp7_;
	gint _tmp8_;
	gint _tmp9_;
#line 1630 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_PUBLISHING_OPTIONS_PANE (self));
#line 1631 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->pixels;
#line 1631 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = gtk_entry_get_text (_tmp0_);
#line 1631 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp2_ = g_strdup (_tmp1_);
#line 1631 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	orig_text = _tmp2_;
#line 1632 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp3_ = orig_text;
#line 1632 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp4_ = orig_text;
#line 1632 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp5_ = strlen (_tmp4_);
#line 1632 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp6_ = _tmp5_;
#line 1632 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	last_char = string_get (_tmp3_, (glong) (_tmp6_ - 1));
#line 1634 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp7_ = orig_text;
#line 1634 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp8_ = strlen (_tmp7_);
#line 1634 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp9_ = _tmp8_;
#line 1634 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (_tmp9_ > 0) {
#line 10242 "GalleryConnector.c"
		gchar _tmp10_;
#line 1635 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp10_ = last_char;
#line 1635 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		if (!g_ascii_isdigit (_tmp10_)) {
#line 10248 "GalleryConnector.c"
			GtkEntry* _tmp11_;
			const gchar* _tmp12_;
			const gchar* _tmp13_;
			gint _tmp14_;
			gint _tmp15_;
			gchar* _tmp16_;
			gchar* _tmp17_;
#line 1636 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp11_ = self->priv->pixels;
#line 1636 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp12_ = orig_text;
#line 1636 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp13_ = orig_text;
#line 1636 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp14_ = strlen (_tmp13_);
#line 1636 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp15_ = _tmp14_;
#line 1636 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp16_ = string_substring (_tmp12_, (glong) 0, (glong) (_tmp15_ - 1));
#line 1636 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp17_ = _tmp16_;
#line 1636 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			gtk_entry_set_text (_tmp11_, _tmp17_);
#line 1636 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_g_free0 (_tmp17_);
#line 10274 "GalleryConnector.c"
		}
	}
#line 1630 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (orig_text);
#line 10279 "GalleryConnector.c"
}


void
publishing_gallery3_publishing_options_pane_installed (PublishingGallery3PublishingOptionsPane* self)
{
	gint default_album_id = 0;
	gchar* last_album = NULL;
	SpitPublishingPluginHost* _tmp0_;
	gchar* _tmp1_;
	PublishingGallery3Album** _tmp27_;
	gint _tmp27__length1;
#line 1641 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_PUBLISHING_OPTIONS_PANE (self));
#line 1642 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	default_album_id = -1;
#line 1643 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->host;
#line 1643 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = spit_host_interface_get_config_string (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), PUBLISHING_GALLERY3_PUBLISHING_OPTIONS_PANE_LAST_ALBUM_CONFIG_KEY, "");
#line 1643 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	last_album = _tmp1_;
#line 10302 "GalleryConnector.c"
	{
		gint i = 0;
#line 1645 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		i = 0;
#line 10307 "GalleryConnector.c"
		{
			gboolean _tmp2_ = FALSE;
#line 1645 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp2_ = TRUE;
#line 1645 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			while (TRUE) {
#line 10314 "GalleryConnector.c"
				gint _tmp4_;
				PublishingGallery3Album** _tmp5_;
				gint _tmp5__length1;
				GtkComboBoxText* _tmp6_;
				PublishingGallery3Album** _tmp7_;
				gint _tmp7__length1;
				gint _tmp8_;
				PublishingGallery3Album* _tmp9_;
				const gchar* _tmp10_;
				const gchar* _tmp11_;
				gboolean _tmp12_ = FALSE;
				PublishingGallery3Album** _tmp13_;
				gint _tmp13__length1;
				gint _tmp14_;
				PublishingGallery3Album* _tmp15_;
				const gchar* _tmp16_;
				const gchar* _tmp17_;
				const gchar* _tmp18_;
#line 1645 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				if (!_tmp2_) {
#line 10335 "GalleryConnector.c"
					gint _tmp3_;
#line 1645 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
					_tmp3_ = i;
#line 1645 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
					i = _tmp3_ + 1;
#line 10341 "GalleryConnector.c"
				}
#line 1645 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp2_ = FALSE;
#line 1645 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp4_ = i;
#line 1645 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp5_ = self->priv->albums;
#line 1645 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp5__length1 = self->priv->albums_length1;
#line 1645 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				if (!(_tmp4_ <= (_tmp5__length1 - 1))) {
#line 1645 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
					break;
#line 10355 "GalleryConnector.c"
				}
#line 1646 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp6_ = self->priv->existing_albums_combo;
#line 1646 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp7_ = self->priv->albums;
#line 1646 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp7__length1 = self->priv->albums_length1;
#line 1646 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp8_ = i;
#line 1646 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp9_ = _tmp7_[_tmp8_];
#line 1646 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp10_ = publishing_gallery3_album_get_title (_tmp9_);
#line 1646 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp11_ = _tmp10_;
#line 1646 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				gtk_combo_box_text_append_text (_tmp6_, _tmp11_);
#line 1647 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp13_ = self->priv->albums;
#line 1647 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp13__length1 = self->priv->albums_length1;
#line 1647 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp14_ = i;
#line 1647 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp15_ = _tmp13_[_tmp14_];
#line 1647 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp16_ = publishing_gallery3_album_get_title (_tmp15_);
#line 1647 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp17_ = _tmp16_;
#line 1647 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				_tmp18_ = last_album;
#line 1647 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				if (g_strcmp0 (_tmp17_, _tmp18_) == 0) {
#line 1647 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
					_tmp12_ = TRUE;
#line 10391 "GalleryConnector.c"
				} else {
					gboolean _tmp19_ = FALSE;
					PublishingGallery3Album** _tmp20_;
					gint _tmp20__length1;
					gint _tmp21_;
					PublishingGallery3Album* _tmp22_;
					const gchar* _tmp23_;
					const gchar* _tmp24_;
#line 1648 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
					_tmp20_ = self->priv->albums;
#line 1648 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
					_tmp20__length1 = self->priv->albums_length1;
#line 1648 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
					_tmp21_ = i;
#line 1648 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
					_tmp22_ = _tmp20_[_tmp21_];
#line 1648 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
					_tmp23_ = publishing_gallery3_album_get_title (_tmp22_);
#line 1648 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
					_tmp24_ = _tmp23_;
#line 1648 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
					if (g_strcmp0 (PUBLISHING_GALLERY3_PUBLISHING_OPTIONS_PANE_DEFAULT_ALBUM_NAME, _tmp24_) == 0) {
#line 10414 "GalleryConnector.c"
						gint _tmp25_;
#line 1649 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
						_tmp25_ = default_album_id;
#line 1649 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
						_tmp19_ = -1 == _tmp25_;
#line 10420 "GalleryConnector.c"
					} else {
#line 1648 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
						_tmp19_ = FALSE;
#line 10424 "GalleryConnector.c"
					}
#line 1648 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
					_tmp12_ = _tmp19_;
#line 10428 "GalleryConnector.c"
				}
#line 1647 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
				if (_tmp12_) {
#line 10432 "GalleryConnector.c"
					gint _tmp26_;
#line 1650 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
					_tmp26_ = i;
#line 1650 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
					default_album_id = _tmp26_;
#line 10438 "GalleryConnector.c"
				}
			}
		}
	}
#line 1653 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp27_ = self->priv->albums;
#line 1653 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp27__length1 = self->priv->albums_length1;
#line 1653 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (_tmp27__length1 == 0) {
#line 10449 "GalleryConnector.c"
		GtkComboBoxText* _tmp28_;
		GtkRadioButton* _tmp29_;
		GtkRadioButton* _tmp30_;
		GtkEntry* _tmp31_;
		GtkEntry* _tmp32_;
#line 1654 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp28_ = self->priv->existing_albums_combo;
#line 1654 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp28_, gtk_widget_get_type (), GtkWidget), FALSE);
#line 1655 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp29_ = self->priv->use_existing_radio;
#line 1655 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp29_, gtk_widget_get_type (), GtkWidget), FALSE);
#line 1656 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp30_ = self->priv->create_new_radio;
#line 1656 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		gtk_toggle_button_set_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp30_, gtk_toggle_button_get_type (), GtkToggleButton), TRUE);
#line 1657 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp31_ = self->priv->new_album_entry;
#line 1657 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		gtk_widget_grab_focus (G_TYPE_CHECK_INSTANCE_CAST (_tmp31_, gtk_widget_get_type (), GtkWidget));
#line 1658 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp32_ = self->priv->new_album_entry;
#line 1658 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		gtk_entry_set_text (_tmp32_, PUBLISHING_GALLERY3_PUBLISHING_OPTIONS_PANE_DEFAULT_ALBUM_NAME);
#line 10475 "GalleryConnector.c"
	} else {
		gint _tmp33_;
#line 1660 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp33_ = default_album_id;
#line 1660 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		if (_tmp33_ >= 0) {
#line 10482 "GalleryConnector.c"
			GtkRadioButton* _tmp34_;
			GtkComboBoxText* _tmp35_;
			gint _tmp36_;
			GtkEntry* _tmp37_;
#line 1661 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp34_ = self->priv->use_existing_radio;
#line 1661 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			gtk_toggle_button_set_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp34_, gtk_toggle_button_get_type (), GtkToggleButton), TRUE);
#line 1662 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp35_ = self->priv->existing_albums_combo;
#line 1662 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp36_ = default_album_id;
#line 1662 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			gtk_combo_box_set_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp35_, gtk_combo_box_get_type (), GtkComboBox), _tmp36_);
#line 1663 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp37_ = self->priv->new_album_entry;
#line 1663 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp37_, gtk_widget_get_type (), GtkWidget), FALSE);
#line 10501 "GalleryConnector.c"
		} else {
			GtkRadioButton* _tmp38_;
			GtkComboBoxText* _tmp39_;
			GtkEntry* _tmp40_;
			GtkEntry* _tmp41_;
#line 1665 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp38_ = self->priv->create_new_radio;
#line 1665 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			gtk_toggle_button_set_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp38_, gtk_toggle_button_get_type (), GtkToggleButton), TRUE);
#line 1666 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp39_ = self->priv->existing_albums_combo;
#line 1666 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			gtk_combo_box_set_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp39_, gtk_combo_box_get_type (), GtkComboBox), 0);
#line 1667 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp40_ = self->priv->new_album_entry;
#line 1667 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			gtk_entry_set_text (_tmp40_, PUBLISHING_GALLERY3_PUBLISHING_OPTIONS_PANE_DEFAULT_ALBUM_NAME);
#line 1668 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp41_ = self->priv->new_album_entry;
#line 1668 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			gtk_widget_grab_focus (G_TYPE_CHECK_INSTANCE_CAST (_tmp41_, gtk_widget_get_type (), GtkWidget));
#line 10523 "GalleryConnector.c"
		}
	}
#line 1671 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_publishing_options_pane_update_publish_button_sensitivity (self);
#line 1672 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_publishing_options_pane_update_pixel_entry_sensitivity (self);
#line 1641 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (last_album);
#line 10532 "GalleryConnector.c"
}


static GtkWidget*
publishing_gallery3_publishing_options_pane_real_get_widget (SpitPublishingDialogPane* base)
{
	PublishingGallery3PublishingOptionsPane * self;
	GtkWidget* result = NULL;
	GtkGrid* _tmp0_;
	GtkWidget* _tmp1_;
#line 1675 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_GALLERY3_TYPE_PUBLISHING_OPTIONS_PANE, PublishingGallery3PublishingOptionsPane);
#line 1676 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->pane_widget;
#line 1676 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, gtk_widget_get_type (), GtkWidget));
#line 1676 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = _tmp1_;
#line 1676 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 10553 "GalleryConnector.c"
}


static SpitPublishingDialogPaneGeometryOptions
publishing_gallery3_publishing_options_pane_real_get_preferred_geometry (SpitPublishingDialogPane* base)
{
	PublishingGallery3PublishingOptionsPane * self;
	SpitPublishingDialogPaneGeometryOptions result = 0;
#line 1679 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_GALLERY3_TYPE_PUBLISHING_OPTIONS_PANE, PublishingGallery3PublishingOptionsPane);
#line 1680 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = SPIT_PUBLISHING_DIALOG_PANE_GEOMETRY_OPTIONS_NONE;
#line 1680 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 10568 "GalleryConnector.c"
}


static void
publishing_gallery3_publishing_options_pane_real_on_pane_installed (SpitPublishingDialogPane* base)
{
	PublishingGallery3PublishingOptionsPane * self;
#line 1683 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_GALLERY3_TYPE_PUBLISHING_OPTIONS_PANE, PublishingGallery3PublishingOptionsPane);
#line 1684 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_publishing_options_pane_installed (self);
#line 10580 "GalleryConnector.c"
}


static void
publishing_gallery3_publishing_options_pane_real_on_pane_uninstalled (SpitPublishingDialogPane* base)
{
	PublishingGallery3PublishingOptionsPane * self;
#line 1687 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_GALLERY3_TYPE_PUBLISHING_OPTIONS_PANE, PublishingGallery3PublishingOptionsPane);
#line 10590 "GalleryConnector.c"
}


static void
g_cclosure_user_marshal_VOID__PUBLISHING_GALLERY3_PUBLISHING_PARAMETERS (GClosure * closure,
                                                                         GValue * return_value,
                                                                         guint n_param_values,
                                                                         const GValue * param_values,
                                                                         gpointer invocation_hint,
                                                                         gpointer marshal_data)
{
	typedef void (*GMarshalFunc_VOID__PUBLISHING_GALLERY3_PUBLISHING_PARAMETERS) (gpointer data1, gpointer arg_1, gpointer data2);
	register GMarshalFunc_VOID__PUBLISHING_GALLERY3_PUBLISHING_PARAMETERS callback;
	register GCClosure * cc;
	register gpointer data1;
	register gpointer data2;
	cc = (GCClosure *) closure;
#line 1499 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (n_param_values == 2);
#line 1499 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (G_CCLOSURE_SWAP_DATA (closure)) {
#line 1499 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		data1 = closure->data;
#line 1499 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		data2 = param_values->data[0].v_pointer;
#line 10616 "GalleryConnector.c"
	} else {
#line 1499 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		data1 = param_values->data[0].v_pointer;
#line 1499 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		data2 = closure->data;
#line 10622 "GalleryConnector.c"
	}
#line 1499 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	callback = (GMarshalFunc_VOID__PUBLISHING_GALLERY3_PUBLISHING_PARAMETERS) (marshal_data ? marshal_data : cc->callback);
#line 1499 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	callback (data1, publishing_gallery3_value_get_publishing_parameters (param_values + 1), data2);
#line 10628 "GalleryConnector.c"
}


static void
publishing_gallery3_publishing_options_pane_class_init (PublishingGallery3PublishingOptionsPaneClass * klass)
{
#line 1499 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_publishing_options_pane_parent_class = g_type_class_peek_parent (klass);
#line 1499 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_type_class_add_private (klass, sizeof (PublishingGallery3PublishingOptionsPanePrivate));
#line 1499 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	G_OBJECT_CLASS (klass)->finalize = publishing_gallery3_publishing_options_pane_finalize;
#line 1499 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_publishing_options_pane_signals[PUBLISHING_GALLERY3_PUBLISHING_OPTIONS_PANE_PUBLISH_SIGNAL] = g_signal_new ("publish", PUBLISHING_GALLERY3_TYPE_PUBLISHING_OPTIONS_PANE, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_user_marshal_VOID__PUBLISHING_GALLERY3_PUBLISHING_PARAMETERS, G_TYPE_NONE, 1, PUBLISHING_GALLERY3_TYPE_PUBLISHING_PARAMETERS);
#line 1499 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_publishing_options_pane_signals[PUBLISHING_GALLERY3_PUBLISHING_OPTIONS_PANE_LOGOUT_SIGNAL] = g_signal_new ("logout", PUBLISHING_GALLERY3_TYPE_PUBLISHING_OPTIONS_PANE, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
#line 10645 "GalleryConnector.c"
}


static void
publishing_gallery3_publishing_options_pane_spit_publishing_dialog_pane_interface_init (SpitPublishingDialogPaneIface * iface)
{
#line 1499 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_publishing_options_pane_spit_publishing_dialog_pane_parent_iface = g_type_interface_peek_parent (iface);
#line 1499 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	iface->get_widget = (GtkWidget* (*) (SpitPublishingDialogPane *)) publishing_gallery3_publishing_options_pane_real_get_widget;
#line 1499 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	iface->get_preferred_geometry = (SpitPublishingDialogPaneGeometryOptions (*) (SpitPublishingDialogPane *)) publishing_gallery3_publishing_options_pane_real_get_preferred_geometry;
#line 1499 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	iface->on_pane_installed = (void (*) (SpitPublishingDialogPane *)) publishing_gallery3_publishing_options_pane_real_on_pane_installed;
#line 1499 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	iface->on_pane_uninstalled = (void (*) (SpitPublishingDialogPane *)) publishing_gallery3_publishing_options_pane_real_on_pane_uninstalled;
#line 10662 "GalleryConnector.c"
}


static void
publishing_gallery3_publishing_options_pane_instance_init (PublishingGallery3PublishingOptionsPane * self)
{
#line 1499 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv = PUBLISHING_GALLERY3_PUBLISHING_OPTIONS_PANE_GET_PRIVATE (self);
#line 1503 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->builder = NULL;
#line 1505 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->pane_widget = NULL;
#line 1506 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->title_label = NULL;
#line 1507 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->use_existing_radio = NULL;
#line 1508 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->existing_albums_combo = NULL;
#line 1509 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->create_new_radio = NULL;
#line 1510 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->new_album_entry = NULL;
#line 1511 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->scaling_combo = NULL;
#line 1512 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->pixels = NULL;
#line 1513 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->strip_metadata_check = NULL;
#line 1514 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->publish_button = NULL;
#line 1515 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->logout_button = NULL;
#line 10695 "GalleryConnector.c"
}


static void
publishing_gallery3_publishing_options_pane_finalize (GObject * obj)
{
	PublishingGallery3PublishingOptionsPane * self;
#line 1499 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_GALLERY3_TYPE_PUBLISHING_OPTIONS_PANE, PublishingGallery3PublishingOptionsPane);
#line 1503 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_object_unref0 (self->priv->builder);
#line 1505 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_object_unref0 (self->priv->pane_widget);
#line 1506 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_object_unref0 (self->priv->title_label);
#line 1507 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_object_unref0 (self->priv->use_existing_radio);
#line 1508 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_object_unref0 (self->priv->existing_albums_combo);
#line 1509 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_object_unref0 (self->priv->create_new_radio);
#line 1510 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_object_unref0 (self->priv->new_album_entry);
#line 1511 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_object_unref0 (self->priv->scaling_combo);
#line 1512 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_object_unref0 (self->priv->pixels);
#line 1513 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_object_unref0 (self->priv->strip_metadata_check);
#line 1514 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_object_unref0 (self->priv->publish_button);
#line 1515 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_object_unref0 (self->priv->logout_button);
#line 1517 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->albums = (_vala_array_free (self->priv->albums, self->priv->albums_length1, (GDestroyNotify) publishing_gallery3_album_unref), NULL);
#line 1499 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	G_OBJECT_CLASS (publishing_gallery3_publishing_options_pane_parent_class)->finalize (obj);
#line 10733 "GalleryConnector.c"
}


GType
publishing_gallery3_publishing_options_pane_get_type (void)
{
	static volatile gsize publishing_gallery3_publishing_options_pane_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_gallery3_publishing_options_pane_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingGallery3PublishingOptionsPaneClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_gallery3_publishing_options_pane_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingGallery3PublishingOptionsPane), 0, (GInstanceInitFunc) publishing_gallery3_publishing_options_pane_instance_init, NULL };
		static const GInterfaceInfo spit_publishing_dialog_pane_info = { (GInterfaceInitFunc) publishing_gallery3_publishing_options_pane_spit_publishing_dialog_pane_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType publishing_gallery3_publishing_options_pane_type_id;
		publishing_gallery3_publishing_options_pane_type_id = g_type_register_static (G_TYPE_OBJECT, "PublishingGallery3PublishingOptionsPane", &g_define_type_info, 0);
		g_type_add_interface_static (publishing_gallery3_publishing_options_pane_type_id, SPIT_PUBLISHING_TYPE_DIALOG_PANE, &spit_publishing_dialog_pane_info);
		g_once_init_leave (&publishing_gallery3_publishing_options_pane_type_id__volatile, publishing_gallery3_publishing_options_pane_type_id);
	}
	return publishing_gallery3_publishing_options_pane_type_id__volatile;
}


static PublishingGallery3PublishingParameters*
publishing_gallery3_publishing_parameters_construct (GType object_type)
{
	PublishingGallery3PublishingParameters* self = NULL;
#line 1710 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = (PublishingGallery3PublishingParameters*) g_type_create_instance (object_type);
#line 1710 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return self;
#line 10761 "GalleryConnector.c"
}


static PublishingGallery3PublishingParameters*
publishing_gallery3_publishing_parameters_new (void)
{
#line 1710 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return publishing_gallery3_publishing_parameters_construct (PUBLISHING_GALLERY3_TYPE_PUBLISHING_PARAMETERS);
#line 10770 "GalleryConnector.c"
}


static gchar*
string_delimit (const gchar* self,
                const gchar* delimiters,
                gchar new_delimiter)
{
	gchar* result = NULL;
	gchar* _result_ = NULL;
	gchar* _tmp0_;
	const gchar* _tmp1_;
#line 1256 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, NULL);
#line 1256 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	g_return_val_if_fail (delimiters != NULL, NULL);
#line 1257 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	_tmp0_ = g_strdup (self);
#line 1257 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	_result_ = _tmp0_;
#line 1258 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	_tmp1_ = _result_;
#line 1258 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	g_strdelimit (_tmp1_, delimiters, new_delimiter);
#line 1259 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	result = _result_;
#line 1259 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	return result;
#line 10799 "GalleryConnector.c"
}


PublishingGallery3PublishingParameters*
publishing_gallery3_publishing_parameters_construct_to_new_album (GType object_type,
                                                                  const gchar* album_title)
{
	PublishingGallery3PublishingParameters* self = NULL;
	gchar* _tmp0_;
	gchar* _tmp1_;
#line 1713 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (album_title != NULL, NULL);
#line 1713 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = (PublishingGallery3PublishingParameters*) g_type_create_instance (object_type);
#line 1714 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = string_delimit (album_title, " ", '-');
#line 1714 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = _tmp0_;
#line 1714 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_publishing_parameters_set_album_name (self, _tmp1_);
#line 1714 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (_tmp1_);
#line 1716 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_publishing_parameters_set_album_title (self, album_title);
#line 1713 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return self;
#line 10826 "GalleryConnector.c"
}


PublishingGallery3PublishingParameters*
publishing_gallery3_publishing_parameters_new_to_new_album (const gchar* album_title)
{
#line 1713 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return publishing_gallery3_publishing_parameters_construct_to_new_album (PUBLISHING_GALLERY3_TYPE_PUBLISHING_PARAMETERS, album_title);
#line 10835 "GalleryConnector.c"
}


PublishingGallery3PublishingParameters*
publishing_gallery3_publishing_parameters_construct_to_existing_album (GType object_type,
                                                                       const gchar* album_path)
{
	PublishingGallery3PublishingParameters* self = NULL;
#line 1719 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (album_path != NULL, NULL);
#line 1719 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = (PublishingGallery3PublishingParameters*) g_type_create_instance (object_type);
#line 1720 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_publishing_parameters_set_album_path (self, album_path);
#line 1719 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return self;
#line 10852 "GalleryConnector.c"
}


PublishingGallery3PublishingParameters*
publishing_gallery3_publishing_parameters_new_to_existing_album (const gchar* album_path)
{
#line 1719 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return publishing_gallery3_publishing_parameters_construct_to_existing_album (PUBLISHING_GALLERY3_TYPE_PUBLISHING_PARAMETERS, album_path);
#line 10861 "GalleryConnector.c"
}


gboolean
publishing_gallery3_publishing_parameters_is_to_new_album (PublishingGallery3PublishingParameters* self)
{
	gboolean result = FALSE;
	const gchar* _tmp0_;
#line 1723 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (PUBLISHING_GALLERY3_IS_PUBLISHING_PARAMETERS (self), FALSE);
#line 1724 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->_album_name;
#line 1724 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = g_strcmp0 (_tmp0_, "") != 0;
#line 1724 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 10878 "GalleryConnector.c"
}


const gchar*
publishing_gallery3_publishing_parameters_get_album_title (PublishingGallery3PublishingParameters* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 1698 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (PUBLISHING_GALLERY3_IS_PUBLISHING_PARAMETERS (self), NULL);
#line 1699 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_vala_assert (publishing_gallery3_publishing_parameters_is_to_new_album (self), "is_to_new_album()");
#line 1700 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->_album_title;
#line 1700 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = _tmp0_;
#line 1700 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 10897 "GalleryConnector.c"
}


static void
publishing_gallery3_publishing_parameters_set_album_title (PublishingGallery3PublishingParameters* self,
                                                           const gchar* value)
{
	gchar* _tmp0_;
#line 1702 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_PUBLISHING_PARAMETERS (self));
#line 1702 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = g_strdup (value);
#line 1702 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (self->priv->_album_title);
#line 1702 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->_album_title = _tmp0_;
#line 10914 "GalleryConnector.c"
}


const gchar*
publishing_gallery3_publishing_parameters_get_album_name (PublishingGallery3PublishingParameters* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 1704 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (PUBLISHING_GALLERY3_IS_PUBLISHING_PARAMETERS (self), NULL);
#line 1704 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->_album_name;
#line 1704 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = _tmp0_;
#line 1704 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 10931 "GalleryConnector.c"
}


static void
publishing_gallery3_publishing_parameters_set_album_name (PublishingGallery3PublishingParameters* self,
                                                          const gchar* value)
{
	gchar* _tmp0_;
#line 1704 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_PUBLISHING_PARAMETERS (self));
#line 1704 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = g_strdup (value);
#line 1704 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (self->priv->_album_name);
#line 1704 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->_album_name = _tmp0_;
#line 10948 "GalleryConnector.c"
}


const gchar*
publishing_gallery3_publishing_parameters_get_album_path (PublishingGallery3PublishingParameters* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 1705 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (PUBLISHING_GALLERY3_IS_PUBLISHING_PARAMETERS (self), NULL);
#line 1705 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->_album_path;
#line 1705 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = _tmp0_;
#line 1705 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 10965 "GalleryConnector.c"
}


void
publishing_gallery3_publishing_parameters_set_album_path (PublishingGallery3PublishingParameters* self,
                                                          const gchar* value)
{
	gchar* _tmp0_;
#line 1705 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_PUBLISHING_PARAMETERS (self));
#line 1705 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = g_strdup (value);
#line 1705 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (self->priv->_album_path);
#line 1705 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->_album_path = _tmp0_;
#line 10982 "GalleryConnector.c"
}


const gchar*
publishing_gallery3_publishing_parameters_get_entity_title (PublishingGallery3PublishingParameters* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 1706 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (PUBLISHING_GALLERY3_IS_PUBLISHING_PARAMETERS (self), NULL);
#line 1706 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->_entity_title;
#line 1706 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = _tmp0_;
#line 1706 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 10999 "GalleryConnector.c"
}


static void
publishing_gallery3_publishing_parameters_set_entity_title (PublishingGallery3PublishingParameters* self,
                                                            const gchar* value)
{
	gchar* _tmp0_;
#line 1706 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_PUBLISHING_PARAMETERS (self));
#line 1706 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = g_strdup (value);
#line 1706 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (self->priv->_entity_title);
#line 1706 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->_entity_title = _tmp0_;
#line 11016 "GalleryConnector.c"
}


gint
publishing_gallery3_publishing_parameters_get_photo_major_axis_size (PublishingGallery3PublishingParameters* self)
{
	gint result;
	gint _tmp0_;
#line 1707 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (PUBLISHING_GALLERY3_IS_PUBLISHING_PARAMETERS (self), 0);
#line 1707 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->_photo_major_axis_size;
#line 1707 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = _tmp0_;
#line 1707 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 11033 "GalleryConnector.c"
}


void
publishing_gallery3_publishing_parameters_set_photo_major_axis_size (PublishingGallery3PublishingParameters* self,
                                                                     gint value)
{
#line 1707 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_PUBLISHING_PARAMETERS (self));
#line 1707 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->_photo_major_axis_size = value;
#line 11045 "GalleryConnector.c"
}


gboolean
publishing_gallery3_publishing_parameters_get_strip_metadata (PublishingGallery3PublishingParameters* self)
{
	gboolean result;
	gboolean _tmp0_;
#line 1708 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (PUBLISHING_GALLERY3_IS_PUBLISHING_PARAMETERS (self), FALSE);
#line 1708 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->_strip_metadata;
#line 1708 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = _tmp0_;
#line 1708 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 11062 "GalleryConnector.c"
}


void
publishing_gallery3_publishing_parameters_set_strip_metadata (PublishingGallery3PublishingParameters* self,
                                                              gboolean value)
{
#line 1708 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_PUBLISHING_PARAMETERS (self));
#line 1708 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->_strip_metadata = value;
#line 11074 "GalleryConnector.c"
}


static void
publishing_gallery3_value_publishing_parameters_init (GValue* value)
{
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	value->data[0].v_pointer = NULL;
#line 11083 "GalleryConnector.c"
}


static void
publishing_gallery3_value_publishing_parameters_free_value (GValue* value)
{
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (value->data[0].v_pointer) {
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		publishing_gallery3_publishing_parameters_unref (value->data[0].v_pointer);
#line 11094 "GalleryConnector.c"
	}
}


static void
publishing_gallery3_value_publishing_parameters_copy_value (const GValue* src_value,
                                                            GValue* dest_value)
{
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (src_value->data[0].v_pointer) {
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		dest_value->data[0].v_pointer = publishing_gallery3_publishing_parameters_ref (src_value->data[0].v_pointer);
#line 11107 "GalleryConnector.c"
	} else {
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		dest_value->data[0].v_pointer = NULL;
#line 11111 "GalleryConnector.c"
	}
}


static gpointer
publishing_gallery3_value_publishing_parameters_peek_pointer (const GValue* value)
{
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return value->data[0].v_pointer;
#line 11121 "GalleryConnector.c"
}


static gchar*
publishing_gallery3_value_publishing_parameters_collect_value (GValue* value,
                                                               guint n_collect_values,
                                                               GTypeCValue* collect_values,
                                                               guint collect_flags)
{
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (collect_values[0].v_pointer) {
#line 11133 "GalleryConnector.c"
		PublishingGallery3PublishingParameters * object;
		object = collect_values[0].v_pointer;
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		if (object->parent_instance.g_class == NULL) {
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 11140 "GalleryConnector.c"
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 11144 "GalleryConnector.c"
		}
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		value->data[0].v_pointer = publishing_gallery3_publishing_parameters_ref (object);
#line 11148 "GalleryConnector.c"
	} else {
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		value->data[0].v_pointer = NULL;
#line 11152 "GalleryConnector.c"
	}
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return NULL;
#line 11156 "GalleryConnector.c"
}


static gchar*
publishing_gallery3_value_publishing_parameters_lcopy_value (const GValue* value,
                                                             guint n_collect_values,
                                                             GTypeCValue* collect_values,
                                                             guint collect_flags)
{
	PublishingGallery3PublishingParameters ** object_p;
	object_p = collect_values[0].v_pointer;
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (!object_p) {
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
#line 11172 "GalleryConnector.c"
	}
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (!value->data[0].v_pointer) {
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		*object_p = NULL;
#line 11178 "GalleryConnector.c"
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		*object_p = value->data[0].v_pointer;
#line 11182 "GalleryConnector.c"
	} else {
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		*object_p = publishing_gallery3_publishing_parameters_ref (value->data[0].v_pointer);
#line 11186 "GalleryConnector.c"
	}
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return NULL;
#line 11190 "GalleryConnector.c"
}


GParamSpec*
publishing_gallery3_param_spec_publishing_parameters (const gchar* name,
                                                      const gchar* nick,
                                                      const gchar* blurb,
                                                      GType object_type,
                                                      GParamFlags flags)
{
	PublishingGallery3ParamSpecPublishingParameters* spec;
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (g_type_is_a (object_type, PUBLISHING_GALLERY3_TYPE_PUBLISHING_PARAMETERS), NULL);
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	G_PARAM_SPEC (spec)->value_type = object_type;
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return G_PARAM_SPEC (spec);
#line 11210 "GalleryConnector.c"
}


gpointer
publishing_gallery3_value_get_publishing_parameters (const GValue* value)
{
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_GALLERY3_TYPE_PUBLISHING_PARAMETERS), NULL);
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return value->data[0].v_pointer;
#line 11221 "GalleryConnector.c"
}


void
publishing_gallery3_value_set_publishing_parameters (GValue* value,
                                                     gpointer v_object)
{
	PublishingGallery3PublishingParameters * old;
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_GALLERY3_TYPE_PUBLISHING_PARAMETERS));
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	old = value->data[0].v_pointer;
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (v_object) {
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, PUBLISHING_GALLERY3_TYPE_PUBLISHING_PARAMETERS));
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		value->data[0].v_pointer = v_object;
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		publishing_gallery3_publishing_parameters_ref (value->data[0].v_pointer);
#line 11244 "GalleryConnector.c"
	} else {
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		value->data[0].v_pointer = NULL;
#line 11248 "GalleryConnector.c"
	}
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (old) {
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		publishing_gallery3_publishing_parameters_unref (old);
#line 11254 "GalleryConnector.c"
	}
}


void
publishing_gallery3_value_take_publishing_parameters (GValue* value,
                                                      gpointer v_object)
{
	PublishingGallery3PublishingParameters * old;
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_GALLERY3_TYPE_PUBLISHING_PARAMETERS));
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	old = value->data[0].v_pointer;
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (v_object) {
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, PUBLISHING_GALLERY3_TYPE_PUBLISHING_PARAMETERS));
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		value->data[0].v_pointer = v_object;
#line 11276 "GalleryConnector.c"
	} else {
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		value->data[0].v_pointer = NULL;
#line 11280 "GalleryConnector.c"
	}
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (old) {
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		publishing_gallery3_publishing_parameters_unref (old);
#line 11286 "GalleryConnector.c"
	}
}


static void
publishing_gallery3_publishing_parameters_class_init (PublishingGallery3PublishingParametersClass * klass)
{
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_publishing_parameters_parent_class = g_type_class_peek_parent (klass);
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	((PublishingGallery3PublishingParametersClass *) klass)->finalize = publishing_gallery3_publishing_parameters_finalize;
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_type_class_add_private (klass, sizeof (PublishingGallery3PublishingParametersPrivate));
#line 11300 "GalleryConnector.c"
}


static void
publishing_gallery3_publishing_parameters_instance_init (PublishingGallery3PublishingParameters * self)
{
	gchar* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv = PUBLISHING_GALLERY3_PUBLISHING_PARAMETERS_GET_PRIVATE (self);
#line 1694 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = g_strdup ("");
#line 1694 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->_album_title = _tmp0_;
#line 1704 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = g_strdup ("");
#line 1704 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->_album_name = _tmp1_;
#line 1705 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp2_ = g_strdup ("");
#line 1705 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->_album_path = _tmp2_;
#line 1706 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp3_ = g_strdup ("");
#line 1706 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->_entity_title = _tmp3_;
#line 1707 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->_photo_major_axis_size = -1;
#line 1708 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->_strip_metadata = FALSE;
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->ref_count = 1;
#line 11335 "GalleryConnector.c"
}


static void
publishing_gallery3_publishing_parameters_finalize (PublishingGallery3PublishingParameters * obj)
{
	PublishingGallery3PublishingParameters * self;
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_GALLERY3_TYPE_PUBLISHING_PARAMETERS, PublishingGallery3PublishingParameters);
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_handlers_destroy (self);
#line 1694 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (self->priv->_album_title);
#line 1704 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (self->priv->_album_name);
#line 1705 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (self->priv->_album_path);
#line 1706 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (self->priv->_entity_title);
#line 11355 "GalleryConnector.c"
}


GType
publishing_gallery3_publishing_parameters_get_type (void)
{
	static volatile gsize publishing_gallery3_publishing_parameters_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_gallery3_publishing_parameters_type_id__volatile)) {
		static const GTypeValueTable g_define_type_value_table = { publishing_gallery3_value_publishing_parameters_init, publishing_gallery3_value_publishing_parameters_free_value, publishing_gallery3_value_publishing_parameters_copy_value, publishing_gallery3_value_publishing_parameters_peek_pointer, "p", publishing_gallery3_value_publishing_parameters_collect_value, "p", publishing_gallery3_value_publishing_parameters_lcopy_value };
		static const GTypeInfo g_define_type_info = { sizeof (PublishingGallery3PublishingParametersClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_gallery3_publishing_parameters_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingGallery3PublishingParameters), 0, (GInstanceInitFunc) publishing_gallery3_publishing_parameters_instance_init, &g_define_type_value_table };
		static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
		GType publishing_gallery3_publishing_parameters_type_id;
		publishing_gallery3_publishing_parameters_type_id = g_type_register_fundamental (g_type_fundamental_next (), "PublishingGallery3PublishingParameters", &g_define_type_info, &g_define_type_fundamental_info, 0);
		g_once_init_leave (&publishing_gallery3_publishing_parameters_type_id__volatile, publishing_gallery3_publishing_parameters_type_id);
	}
	return publishing_gallery3_publishing_parameters_type_id__volatile;
}


gpointer
publishing_gallery3_publishing_parameters_ref (gpointer instance)
{
	PublishingGallery3PublishingParameters * self;
	self = instance;
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_atomic_int_inc (&self->ref_count);
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return instance;
#line 11384 "GalleryConnector.c"
}


void
publishing_gallery3_publishing_parameters_unref (gpointer instance)
{
	PublishingGallery3PublishingParameters * self;
	self = instance;
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		PUBLISHING_GALLERY3_PUBLISHING_PARAMETERS_GET_CLASS (self)->finalize (self);
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_type_free_instance ((GTypeInstance *) self);
#line 11399 "GalleryConnector.c"
	}
}


gchar*
publishing_gallery3_credentials_pane_mode_to_string (PublishingGallery3CredentialsPaneMode self)
{
	gchar* result = NULL;
#line 1735 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	switch (self) {
#line 1735 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		case PUBLISHING_GALLERY3_CREDENTIALS_PANE_MODE_INTRO:
#line 11412 "GalleryConnector.c"
		{
			gchar* _tmp0_;
#line 1737 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp0_ = g_strdup ("INTRO");
#line 1737 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			result = _tmp0_;
#line 1737 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			return result;
#line 11421 "GalleryConnector.c"
		}
#line 1735 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		case PUBLISHING_GALLERY3_CREDENTIALS_PANE_MODE_FAILED_RETRY:
#line 11425 "GalleryConnector.c"
		{
			gchar* _tmp1_;
#line 1740 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp1_ = g_strdup ("FAILED_RETRY");
#line 1740 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			result = _tmp1_;
#line 1740 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			return result;
#line 11434 "GalleryConnector.c"
		}
#line 1735 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		case PUBLISHING_GALLERY3_CREDENTIALS_PANE_MODE_NOT_GALLERY_URL:
#line 11438 "GalleryConnector.c"
		{
			gchar* _tmp2_;
#line 1743 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp2_ = g_strdup ("NOT_GALLERY_URL");
#line 1743 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			result = _tmp2_;
#line 1743 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			return result;
#line 11447 "GalleryConnector.c"
		}
		default:
		{
#line 1746 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			g_error ("GalleryConnector.vala:1746: unrecognized CredentialsPane.Mode enumerat" \
"ion value");
#line 11453 "GalleryConnector.c"
		}
	}
}


GType
publishing_gallery3_credentials_pane_mode_get_type (void)
{
	static volatile gsize publishing_gallery3_credentials_pane_mode_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_gallery3_credentials_pane_mode_type_id__volatile)) {
		static const GEnumValue values[] = {{PUBLISHING_GALLERY3_CREDENTIALS_PANE_MODE_INTRO, "PUBLISHING_GALLERY3_CREDENTIALS_PANE_MODE_INTRO", "intro"}, {PUBLISHING_GALLERY3_CREDENTIALS_PANE_MODE_FAILED_RETRY, "PUBLISHING_GALLERY3_CREDENTIALS_PANE_MODE_FAILED_RETRY", "failed-retry"}, {PUBLISHING_GALLERY3_CREDENTIALS_PANE_MODE_NOT_GALLERY_URL, "PUBLISHING_GALLERY3_CREDENTIALS_PANE_MODE_NOT_GALLERY_URL", "not-gallery-url"}, {0, NULL, NULL}};
		GType publishing_gallery3_credentials_pane_mode_type_id;
		publishing_gallery3_credentials_pane_mode_type_id = g_enum_register_static ("PublishingGallery3CredentialsPaneMode", values);
		g_once_init_leave (&publishing_gallery3_credentials_pane_mode_type_id__volatile, publishing_gallery3_credentials_pane_mode_type_id);
	}
	return publishing_gallery3_credentials_pane_mode_type_id__volatile;
}


PublishingGallery3CredentialsPane*
publishing_gallery3_credentials_pane_construct (GType object_type,
                                                SpitPublishingPluginHost* host,
                                                PublishingGallery3CredentialsPaneMode mode,
                                                const gchar* url,
                                                const gchar* username,
                                                const gchar* key)
{
	PublishingGallery3CredentialsPane * self = NULL;
	GtkBuilder* builder = NULL;
	GtkBuilder* _tmp0_;
	GtkBuilder* _tmp8_;
	PublishingGallery3CredentialsGrid* _tmp9_;
	PublishingGallery3CredentialsGrid* _tmp10_;
	GtkGrid* _tmp11_;
	GtkGrid* _tmp12_;
	GtkWidget* _tmp13_;
	GError * _inner_error_ = NULL;
#line 1758 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (SPIT_PUBLISHING_IS_PLUGIN_HOST (host), NULL);
#line 1758 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = (PublishingGallery3CredentialsPane*) g_object_new (object_type, NULL);
#line 1763 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = gtk_builder_new ();
#line 1763 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	builder = _tmp0_;
#line 11499 "GalleryConnector.c"
	{
		GtkBuilder* _tmp1_;
#line 1766 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp1_ = builder;
#line 1766 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		gtk_builder_add_from_resource (_tmp1_, PLUGIN_RESOURCE_PATH "/gallery3_authentication_pane.ui", &_inner_error_);
#line 1766 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 11508 "GalleryConnector.c"
			goto __catch15_g_error;
		}
	}
	goto __finally15;
	__catch15_g_error:
	{
		GError* e = NULL;
		GError* _tmp2_;
		const gchar* _tmp3_;
		gchar* _tmp4_;
		gchar* _tmp5_;
		GError* _tmp6_;
		GError* _tmp7_;
#line 1765 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		e = _inner_error_;
#line 1765 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_inner_error_ = NULL;
#line 1770 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp2_ = e;
#line 1770 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp3_ = _tmp2_->message;
#line 1770 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_warning ("GalleryConnector.vala:1770: Could not parse UI file! Error: %s.", _tmp3_);
#line 1771 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp4_ = g_strdup_printf (_ ("A file required for publishing is unavailable. Publishing to %s can’t " \
"continue."), PUBLISHING_GALLERY3_SERVICE_NAME);
#line 1771 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp5_ = _tmp4_;
#line 1771 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp6_ = g_error_new_literal (SPIT_PUBLISHING_PUBLISHING_ERROR, SPIT_PUBLISHING_PUBLISHING_ERROR_LOCAL_FILE_ERROR, _tmp5_);
#line 1771 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp7_ = _tmp6_;
#line 1771 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		spit_publishing_plugin_host_post_error (host, _tmp7_);
#line 1771 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_error_free0 (_tmp7_);
#line 1771 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_free0 (_tmp5_);
#line 1778 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_error_free0 (e);
#line 1778 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_object_unref0 (builder);
#line 1778 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		return self;
#line 11552 "GalleryConnector.c"
	}
	__finally15:
#line 1765 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1765 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_object_unref0 (builder);
#line 1765 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1765 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_clear_error (&_inner_error_);
#line 1765 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		return NULL;
#line 11565 "GalleryConnector.c"
	}
#line 1781 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp8_ = builder;
#line 1781 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp9_ = publishing_gallery3_credentials_grid_new (host, mode, url, username, key, _tmp8_);
#line 1781 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_object_unref0 (self->priv->frame);
#line 1781 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->frame = _tmp9_;
#line 1782 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp10_ = self->priv->frame;
#line 1782 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp11_ = publishing_gallery3_credentials_grid_get_pane_widget (_tmp10_);
#line 1782 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp12_ = _tmp11_;
#line 1782 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp13_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp12_, gtk_widget_get_type ()) ? ((GtkWidget*) _tmp12_) : NULL);
#line 1782 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_object_unref0 (self->priv->grid_widget);
#line 1782 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->grid_widget = _tmp13_;
#line 1758 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_object_unref0 (builder);
#line 1758 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return self;
#line 11591 "GalleryConnector.c"
}


PublishingGallery3CredentialsPane*
publishing_gallery3_credentials_pane_new (SpitPublishingPluginHost* host,
                                          PublishingGallery3CredentialsPaneMode mode,
                                          const gchar* url,
                                          const gchar* username,
                                          const gchar* key)
{
#line 1758 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return publishing_gallery3_credentials_pane_construct (PUBLISHING_GALLERY3_TYPE_CREDENTIALS_PANE, host, mode, url, username, key);
#line 11604 "GalleryConnector.c"
}


void
publishing_gallery3_credentials_pane_notify_go_back (PublishingGallery3CredentialsPane* self)
{
#line 1785 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_CREDENTIALS_PANE (self));
#line 1786 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_emit (self, publishing_gallery3_credentials_pane_signals[PUBLISHING_GALLERY3_CREDENTIALS_PANE_GO_BACK_SIGNAL], 0);
#line 11615 "GalleryConnector.c"
}


void
publishing_gallery3_credentials_pane_notify_login (PublishingGallery3CredentialsPane* self,
                                                   const gchar* url,
                                                   const gchar* uname,
                                                   const gchar* password,
                                                   const gchar* key)
{
#line 1789 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_CREDENTIALS_PANE (self));
#line 1789 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (url != NULL);
#line 1789 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (uname != NULL);
#line 1789 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (password != NULL);
#line 1789 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (key != NULL);
#line 1791 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_emit (self, publishing_gallery3_credentials_pane_signals[PUBLISHING_GALLERY3_CREDENTIALS_PANE_LOGIN_SIGNAL], 0, url, uname, password, key);
#line 11638 "GalleryConnector.c"
}


static GtkWidget*
publishing_gallery3_credentials_pane_real_get_widget (SpitPublishingDialogPane* base)
{
	PublishingGallery3CredentialsPane * self;
	GtkWidget* result = NULL;
	GtkWidget* _tmp0_;
	GtkWidget* _tmp1_;
	GtkWidget* _tmp2_;
#line 1794 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_GALLERY3_TYPE_CREDENTIALS_PANE, PublishingGallery3CredentialsPane);
#line 1795 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->grid_widget;
#line 1795 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_vala_assert (NULL != _tmp0_, "null != grid_widget");
#line 1796 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = self->priv->grid_widget;
#line 1796 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 1796 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = _tmp2_;
#line 1796 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 11664 "GalleryConnector.c"
}


static SpitPublishingDialogPaneGeometryOptions
publishing_gallery3_credentials_pane_real_get_preferred_geometry (SpitPublishingDialogPane* base)
{
	PublishingGallery3CredentialsPane * self;
	SpitPublishingDialogPaneGeometryOptions result = 0;
#line 1799 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_GALLERY3_TYPE_CREDENTIALS_PANE, PublishingGallery3CredentialsPane);
#line 1800 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = SPIT_PUBLISHING_DIALOG_PANE_GEOMETRY_OPTIONS_NONE;
#line 1800 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 11679 "GalleryConnector.c"
}


static void
_publishing_gallery3_credentials_pane_notify_go_back_publishing_gallery3_credentials_grid_go_back (PublishingGallery3CredentialsGrid* _sender,
                                                                                                   gpointer self)
{
#line 1804 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_credentials_pane_notify_go_back ((PublishingGallery3CredentialsPane*) self);
#line 11689 "GalleryConnector.c"
}


static void
_publishing_gallery3_credentials_pane_notify_login_publishing_gallery3_credentials_grid_login (PublishingGallery3CredentialsGrid* _sender,
                                                                                               const gchar* url,
                                                                                               const gchar* username,
                                                                                               const gchar* password,
                                                                                               const gchar* key,
                                                                                               gpointer self)
{
#line 1805 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_credentials_pane_notify_login ((PublishingGallery3CredentialsPane*) self, url, username, password, key);
#line 11703 "GalleryConnector.c"
}


static void
publishing_gallery3_credentials_pane_real_on_pane_installed (SpitPublishingDialogPane* base)
{
	PublishingGallery3CredentialsPane * self;
	PublishingGallery3CredentialsGrid* _tmp0_;
	PublishingGallery3CredentialsGrid* _tmp1_;
	PublishingGallery3CredentialsGrid* _tmp2_;
#line 1803 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_GALLERY3_TYPE_CREDENTIALS_PANE, PublishingGallery3CredentialsPane);
#line 1804 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->frame;
#line 1804 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_connect_object (_tmp0_, "go-back", (GCallback) _publishing_gallery3_credentials_pane_notify_go_back_publishing_gallery3_credentials_grid_go_back, self, 0);
#line 1805 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = self->priv->frame;
#line 1805 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_connect_object (_tmp1_, "login", (GCallback) _publishing_gallery3_credentials_pane_notify_login_publishing_gallery3_credentials_grid_login, self, 0);
#line 1807 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp2_ = self->priv->frame;
#line 1807 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_credentials_grid_installed (_tmp2_);
#line 11728 "GalleryConnector.c"
}


static void
publishing_gallery3_credentials_pane_real_on_pane_uninstalled (SpitPublishingDialogPane* base)
{
	PublishingGallery3CredentialsPane * self;
	PublishingGallery3CredentialsGrid* _tmp0_;
	guint _tmp1_;
	PublishingGallery3CredentialsGrid* _tmp2_;
	guint _tmp3_;
#line 1810 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_GALLERY3_TYPE_CREDENTIALS_PANE, PublishingGallery3CredentialsPane);
#line 1811 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->frame;
#line 1811 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_parse_name ("go-back", PUBLISHING_GALLERY3_TYPE_CREDENTIALS_GRID, &_tmp1_, NULL, FALSE);
#line 1811 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_handlers_disconnect_matched (_tmp0_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _publishing_gallery3_credentials_pane_notify_go_back_publishing_gallery3_credentials_grid_go_back, self);
#line 1812 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp2_ = self->priv->frame;
#line 1812 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_parse_name ("login", PUBLISHING_GALLERY3_TYPE_CREDENTIALS_GRID, &_tmp3_, NULL, FALSE);
#line 1812 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_handlers_disconnect_matched (_tmp2_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp3_, 0, NULL, (GCallback) _publishing_gallery3_credentials_pane_notify_login_publishing_gallery3_credentials_grid_login, self);
#line 11754 "GalleryConnector.c"
}


static void
g_cclosure_user_marshal_VOID__STRING_STRING_STRING_STRING (GClosure * closure,
                                                           GValue * return_value,
                                                           guint n_param_values,
                                                           const GValue * param_values,
                                                           gpointer invocation_hint,
                                                           gpointer marshal_data)
{
	typedef void (*GMarshalFunc_VOID__STRING_STRING_STRING_STRING) (gpointer data1, const char* arg_1, const char* arg_2, const char* arg_3, const char* arg_4, gpointer data2);
	register GMarshalFunc_VOID__STRING_STRING_STRING_STRING callback;
	register GCClosure * cc;
	register gpointer data1;
	register gpointer data2;
	cc = (GCClosure *) closure;
#line 1728 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (n_param_values == 5);
#line 1728 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (G_CCLOSURE_SWAP_DATA (closure)) {
#line 1728 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		data1 = closure->data;
#line 1728 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		data2 = param_values->data[0].v_pointer;
#line 11780 "GalleryConnector.c"
	} else {
#line 1728 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		data1 = param_values->data[0].v_pointer;
#line 1728 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		data2 = closure->data;
#line 11786 "GalleryConnector.c"
	}
#line 1728 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	callback = (GMarshalFunc_VOID__STRING_STRING_STRING_STRING) (marshal_data ? marshal_data : cc->callback);
#line 1728 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	callback (data1, g_value_get_string (param_values + 1), g_value_get_string (param_values + 2), g_value_get_string (param_values + 3), g_value_get_string (param_values + 4), data2);
#line 11792 "GalleryConnector.c"
}


static void
publishing_gallery3_credentials_pane_class_init (PublishingGallery3CredentialsPaneClass * klass)
{
#line 1728 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_credentials_pane_parent_class = g_type_class_peek_parent (klass);
#line 1728 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_type_class_add_private (klass, sizeof (PublishingGallery3CredentialsPanePrivate));
#line 1728 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	G_OBJECT_CLASS (klass)->finalize = publishing_gallery3_credentials_pane_finalize;
#line 1728 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_credentials_pane_signals[PUBLISHING_GALLERY3_CREDENTIALS_PANE_GO_BACK_SIGNAL] = g_signal_new ("go-back", PUBLISHING_GALLERY3_TYPE_CREDENTIALS_PANE, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
#line 1728 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_credentials_pane_signals[PUBLISHING_GALLERY3_CREDENTIALS_PANE_LOGIN_SIGNAL] = g_signal_new ("login", PUBLISHING_GALLERY3_TYPE_CREDENTIALS_PANE, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_user_marshal_VOID__STRING_STRING_STRING_STRING, G_TYPE_NONE, 4, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING);
#line 11809 "GalleryConnector.c"
}


static void
publishing_gallery3_credentials_pane_spit_publishing_dialog_pane_interface_init (SpitPublishingDialogPaneIface * iface)
{
#line 1728 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_credentials_pane_spit_publishing_dialog_pane_parent_iface = g_type_interface_peek_parent (iface);
#line 1728 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	iface->get_widget = (GtkWidget* (*) (SpitPublishingDialogPane *)) publishing_gallery3_credentials_pane_real_get_widget;
#line 1728 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	iface->get_preferred_geometry = (SpitPublishingDialogPaneGeometryOptions (*) (SpitPublishingDialogPane *)) publishing_gallery3_credentials_pane_real_get_preferred_geometry;
#line 1728 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	iface->on_pane_installed = (void (*) (SpitPublishingDialogPane *)) publishing_gallery3_credentials_pane_real_on_pane_installed;
#line 1728 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	iface->on_pane_uninstalled = (void (*) (SpitPublishingDialogPane *)) publishing_gallery3_credentials_pane_real_on_pane_uninstalled;
#line 11826 "GalleryConnector.c"
}


static void
publishing_gallery3_credentials_pane_instance_init (PublishingGallery3CredentialsPane * self)
{
#line 1728 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv = PUBLISHING_GALLERY3_CREDENTIALS_PANE_GET_PRIVATE (self);
#line 1751 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->frame = NULL;
#line 1752 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->grid_widget = NULL;
#line 11839 "GalleryConnector.c"
}


static void
publishing_gallery3_credentials_pane_finalize (GObject * obj)
{
	PublishingGallery3CredentialsPane * self;
#line 1728 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_GALLERY3_TYPE_CREDENTIALS_PANE, PublishingGallery3CredentialsPane);
#line 1751 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_object_unref0 (self->priv->frame);
#line 1752 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_object_unref0 (self->priv->grid_widget);
#line 1728 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	G_OBJECT_CLASS (publishing_gallery3_credentials_pane_parent_class)->finalize (obj);
#line 11855 "GalleryConnector.c"
}


GType
publishing_gallery3_credentials_pane_get_type (void)
{
	static volatile gsize publishing_gallery3_credentials_pane_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_gallery3_credentials_pane_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingGallery3CredentialsPaneClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_gallery3_credentials_pane_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingGallery3CredentialsPane), 0, (GInstanceInitFunc) publishing_gallery3_credentials_pane_instance_init, NULL };
		static const GInterfaceInfo spit_publishing_dialog_pane_info = { (GInterfaceInitFunc) publishing_gallery3_credentials_pane_spit_publishing_dialog_pane_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType publishing_gallery3_credentials_pane_type_id;
		publishing_gallery3_credentials_pane_type_id = g_type_register_static (G_TYPE_OBJECT, "PublishingGallery3CredentialsPane", &g_define_type_info, 0);
		g_type_add_interface_static (publishing_gallery3_credentials_pane_type_id, SPIT_PUBLISHING_TYPE_DIALOG_PANE, &spit_publishing_dialog_pane_info);
		g_once_init_leave (&publishing_gallery3_credentials_pane_type_id__volatile, publishing_gallery3_credentials_pane_type_id);
	}
	return publishing_gallery3_credentials_pane_type_id__volatile;
}


static void
_publishing_gallery3_credentials_grid_on_url_or_username_changed_gtk_editable_changed (GtkEditable* _sender,
                                                                                       gpointer self)
{
#line 1890 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_credentials_grid_on_url_or_username_changed ((PublishingGallery3CredentialsGrid*) self);
#line 11881 "GalleryConnector.c"
}


static void
_publishing_gallery3_credentials_grid_on_go_back_button_clicked_gtk_button_clicked (GtkButton* _sender,
                                                                                    gpointer self)
{
#line 1906 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_credentials_grid_on_go_back_button_clicked ((PublishingGallery3CredentialsGrid*) self);
#line 11891 "GalleryConnector.c"
}


static void
_publishing_gallery3_credentials_grid_on_login_button_clicked_gtk_button_clicked (GtkButton* _sender,
                                                                                  gpointer self)
{
#line 1907 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_credentials_grid_on_login_button_clicked ((PublishingGallery3CredentialsGrid*) self);
#line 11901 "GalleryConnector.c"
}


PublishingGallery3CredentialsGrid*
publishing_gallery3_credentials_grid_construct (GType object_type,
                                                SpitPublishingPluginHost* host,
                                                PublishingGallery3CredentialsPaneMode mode,
                                                const gchar* url,
                                                const gchar* username,
                                                const gchar* key,
                                                GtkBuilder* builder)
{
	PublishingGallery3CredentialsGrid * self = NULL;
	gchar* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	GtkBuilder* _tmp3_;
	GSList* _tmp4_;
	GSList* _tmp5_;
	GObject* _tmp6_;
	GObject* _tmp7_;
	GtkLabel* _tmp8_;
	GObject* _tmp9_;
	GtkEntry* _tmp10_;
	GObject* _tmp11_;
	GtkEntry* _tmp12_;
	GObject* _tmp13_;
	GtkEntry* _tmp14_;
	GObject* _tmp15_;
	GtkEntry* _tmp16_;
	GObject* _tmp17_;
	GtkButton* _tmp18_;
	GObject* _tmp19_;
	GtkButton* _tmp20_;
	GtkEntry* _tmp30_;
	GtkEntry* _tmp33_;
	GtkEntry* _tmp36_;
	GtkButton* _tmp37_;
	GtkButton* _tmp38_;
	gboolean _tmp39_ = FALSE;
	GtkButton* _tmp40_;
#line 1840 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (SPIT_PUBLISHING_IS_PLUGIN_HOST (host), NULL);
#line 1840 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (GTK_IS_BUILDER (builder), NULL);
#line 1840 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = (PublishingGallery3CredentialsGrid*) g_object_new (object_type, NULL);
#line 1845 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->host = host;
#line 1846 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = g_strdup (url);
#line 1846 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (self->priv->url);
#line 1846 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->url = _tmp0_;
#line 1847 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = g_strdup (key);
#line 1847 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (self->priv->key);
#line 1847 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->key = _tmp1_;
#line 1848 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp2_ = g_strdup (username);
#line 1848 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (self->priv->username);
#line 1848 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->username = _tmp2_;
#line 1850 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp3_ = _g_object_ref0 (builder);
#line 1850 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_object_unref0 (self->priv->builder);
#line 1850 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->builder = _tmp3_;
#line 1851 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_vala_assert (builder != NULL, "builder != null");
#line 1852 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp4_ = gtk_builder_get_objects (builder);
#line 1852 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp5_ = _tmp4_;
#line 1852 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_vala_assert (g_slist_length (_tmp5_) > ((guint) 0), "builder.get_objects().length() > 0");
#line 1852 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_slist_free0 (_tmp5_);
#line 1855 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp6_ = gtk_builder_get_object (builder, "gallery3_auth_pane_widget");
#line 1855 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_credentials_grid_set_pane_widget (self, G_TYPE_CHECK_INSTANCE_TYPE (_tmp6_, gtk_grid_get_type ()) ? ((GtkGrid*) _tmp6_) : NULL);
#line 1856 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp7_ = gtk_builder_get_object (builder, "intro_message_label");
#line 1856 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp8_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp7_, gtk_label_get_type ()) ? ((GtkLabel*) _tmp7_) : NULL);
#line 1856 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_object_unref0 (self->priv->intro_message_label);
#line 1856 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->intro_message_label = _tmp8_;
#line 1857 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp9_ = gtk_builder_get_object (builder, "url_entry");
#line 1857 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp10_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp9_, gtk_entry_get_type ()) ? ((GtkEntry*) _tmp9_) : NULL);
#line 1857 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_object_unref0 (self->priv->url_entry);
#line 1857 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->url_entry = _tmp10_;
#line 1858 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp11_ = gtk_builder_get_object (builder, "username_entry");
#line 1858 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp12_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp11_, gtk_entry_get_type ()) ? ((GtkEntry*) _tmp11_) : NULL);
#line 1858 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_object_unref0 (self->priv->username_entry);
#line 1858 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->username_entry = _tmp12_;
#line 1859 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp13_ = gtk_builder_get_object (builder, "key_entry");
#line 1859 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp14_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp13_, gtk_entry_get_type ()) ? ((GtkEntry*) _tmp13_) : NULL);
#line 1859 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_object_unref0 (self->priv->key_entry);
#line 1859 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->key_entry = _tmp14_;
#line 1860 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp15_ = gtk_builder_get_object (builder, "password_entry");
#line 1860 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp16_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp15_, gtk_entry_get_type ()) ? ((GtkEntry*) _tmp15_) : NULL);
#line 1860 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_object_unref0 (self->priv->password_entry);
#line 1860 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->password_entry = _tmp16_;
#line 1861 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp17_ = gtk_builder_get_object (builder, "go_back_button");
#line 1861 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp18_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp17_, gtk_button_get_type ()) ? ((GtkButton*) _tmp17_) : NULL);
#line 1861 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_object_unref0 (self->priv->go_back_button);
#line 1861 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->go_back_button = _tmp18_;
#line 1862 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp19_ = gtk_builder_get_object (builder, "login_button");
#line 1862 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp20_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp19_, gtk_button_get_type ()) ? ((GtkButton*) _tmp19_) : NULL);
#line 1862 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_object_unref0 (self->priv->login_button);
#line 1862 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->login_button = _tmp20_;
#line 1865 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	switch (mode) {
#line 1865 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		case PUBLISHING_GALLERY3_CREDENTIALS_PANE_MODE_INTRO:
#line 12049 "GalleryConnector.c"
		{
			GtkLabel* _tmp21_;
#line 1867 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp21_ = self->priv->intro_message_label;
#line 1867 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			gtk_label_set_markup (_tmp21_, PUBLISHING_GALLERY3_CREDENTIALS_GRID_INTRO_MESSAGE);
#line 1868 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			break;
#line 12058 "GalleryConnector.c"
		}
#line 1865 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		case PUBLISHING_GALLERY3_CREDENTIALS_PANE_MODE_FAILED_RETRY:
#line 12062 "GalleryConnector.c"
		{
			GtkLabel* _tmp22_;
			gchar* _tmp23_;
			gchar* _tmp24_;
#line 1871 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp22_ = self->priv->intro_message_label;
#line 1871 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp23_ = g_strdup_printf ("<b>%s</b>\n\n%s", _ ("Unrecognized User"), PUBLISHING_GALLERY3_CREDENTIALS_GRID_FAILED_RETRY_MESSAGE);
#line 1871 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp24_ = _tmp23_;
#line 1871 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			gtk_label_set_markup (_tmp22_, _tmp24_);
#line 1871 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_g_free0 (_tmp24_);
#line 1873 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			break;
#line 12079 "GalleryConnector.c"
		}
#line 1865 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		case PUBLISHING_GALLERY3_CREDENTIALS_PANE_MODE_NOT_GALLERY_URL:
#line 12083 "GalleryConnector.c"
		{
			GtkLabel* _tmp25_;
			gchar* _tmp26_;
			gchar* _tmp27_;
#line 1876 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp25_ = self->priv->intro_message_label;
#line 1876 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp26_ = g_strdup_printf ("<b>%s</b>\n\n%s", _ (PUBLISHING_GALLERY3_SERVICE_NAME " Site Not Found"), PUBLISHING_GALLERY3_CREDENTIALS_GRID_NOT_GALLERY_URL_MESSAGE);
#line 1876 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_tmp27_ = _tmp26_;
#line 1876 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			gtk_label_set_markup (_tmp25_, _tmp27_);
#line 1876 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			_g_free0 (_tmp27_);
#line 1879 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			break;
#line 12100 "GalleryConnector.c"
		}
		default:
		{
#line 1882 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
			g_error ("GalleryConnector.vala:1882: Invalid CredentialsPane mode");
#line 12106 "GalleryConnector.c"
		}
	}
#line 1886 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (url != NULL) {
#line 12111 "GalleryConnector.c"
		GtkEntry* _tmp28_;
		GtkEntry* _tmp29_;
#line 1887 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp28_ = self->priv->url_entry;
#line 1887 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		gtk_entry_set_text (_tmp28_, url);
#line 1888 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp29_ = self->priv->username_entry;
#line 1888 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		gtk_widget_grab_focus (G_TYPE_CHECK_INSTANCE_CAST (_tmp29_, gtk_widget_get_type (), GtkWidget));
#line 12122 "GalleryConnector.c"
	}
#line 1890 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp30_ = self->priv->url_entry;
#line 1890 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp30_, gtk_editable_get_type (), GtkEditable), "changed", (GCallback) _publishing_gallery3_credentials_grid_on_url_or_username_changed_gtk_editable_changed, self, 0);
#line 1892 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (username != NULL) {
#line 12130 "GalleryConnector.c"
		GtkEntry* _tmp31_;
		GtkEntry* _tmp32_;
#line 1893 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp31_ = self->priv->username_entry;
#line 1893 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		gtk_entry_set_text (_tmp31_, username);
#line 1894 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp32_ = self->priv->password_entry;
#line 1894 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		gtk_widget_grab_focus (G_TYPE_CHECK_INSTANCE_CAST (_tmp32_, gtk_widget_get_type (), GtkWidget));
#line 12141 "GalleryConnector.c"
	}
#line 1896 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp33_ = self->priv->username_entry;
#line 1896 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp33_, gtk_editable_get_type (), GtkEditable), "changed", (GCallback) _publishing_gallery3_credentials_grid_on_url_or_username_changed_gtk_editable_changed, self, 0);
#line 1899 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (key != NULL) {
#line 12149 "GalleryConnector.c"
		GtkEntry* _tmp34_;
		GtkEntry* _tmp35_;
#line 1900 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp34_ = self->priv->key_entry;
#line 1900 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		gtk_entry_set_text (_tmp34_, key);
#line 1901 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp35_ = self->priv->key_entry;
#line 1901 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		gtk_widget_grab_focus (G_TYPE_CHECK_INSTANCE_CAST (_tmp35_, gtk_widget_get_type (), GtkWidget));
#line 12160 "GalleryConnector.c"
	}
#line 1903 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp36_ = self->priv->key_entry;
#line 1903 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp36_, gtk_editable_get_type (), GtkEditable), "changed", (GCallback) _publishing_gallery3_credentials_grid_on_url_or_username_changed_gtk_editable_changed, self, 0);
#line 1906 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp37_ = self->priv->go_back_button;
#line 1906 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_connect_object (_tmp37_, "clicked", (GCallback) _publishing_gallery3_credentials_grid_on_go_back_button_clicked_gtk_button_clicked, self, 0);
#line 1907 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp38_ = self->priv->login_button;
#line 1907 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_connect_object (_tmp38_, "clicked", (GCallback) _publishing_gallery3_credentials_grid_on_login_button_clicked_gtk_button_clicked, self, 0);
#line 1908 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (url != NULL) {
#line 1908 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp39_ = username != NULL;
#line 12178 "GalleryConnector.c"
	} else {
#line 1908 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp39_ = FALSE;
#line 12182 "GalleryConnector.c"
	}
#line 1908 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp40_ = self->priv->login_button;
#line 1908 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp40_, gtk_widget_get_type (), GtkWidget), _tmp39_);
#line 1840 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return self;
#line 12190 "GalleryConnector.c"
}


PublishingGallery3CredentialsGrid*
publishing_gallery3_credentials_grid_new (SpitPublishingPluginHost* host,
                                          PublishingGallery3CredentialsPaneMode mode,
                                          const gchar* url,
                                          const gchar* username,
                                          const gchar* key,
                                          GtkBuilder* builder)
{
#line 1840 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return publishing_gallery3_credentials_grid_construct (PUBLISHING_GALLERY3_TYPE_CREDENTIALS_GRID, host, mode, url, username, key, builder);
#line 12204 "GalleryConnector.c"
}


static void
publishing_gallery3_credentials_grid_on_login_button_clicked (PublishingGallery3CredentialsGrid* self)
{
	GtkEntry* _tmp0_;
	const gchar* _tmp1_;
	GtkEntry* _tmp2_;
	const gchar* _tmp3_;
	GtkEntry* _tmp4_;
	const gchar* _tmp5_;
	GtkEntry* _tmp6_;
	const gchar* _tmp7_;
#line 1911 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_CREDENTIALS_GRID (self));
#line 1912 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->url_entry;
#line 1912 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = gtk_entry_get_text (_tmp0_);
#line 1912 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp2_ = self->priv->username_entry;
#line 1912 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp3_ = gtk_entry_get_text (_tmp2_);
#line 1912 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp4_ = self->priv->password_entry;
#line 1912 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp5_ = gtk_entry_get_text (_tmp4_);
#line 1912 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp6_ = self->priv->key_entry;
#line 1912 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp7_ = gtk_entry_get_text (_tmp6_);
#line 1912 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_emit (self, publishing_gallery3_credentials_grid_signals[PUBLISHING_GALLERY3_CREDENTIALS_GRID_LOGIN_SIGNAL], 0, _tmp1_, _tmp3_, _tmp5_, _tmp7_);
#line 12239 "GalleryConnector.c"
}


static void
publishing_gallery3_credentials_grid_on_go_back_button_clicked (PublishingGallery3CredentialsGrid* self)
{
#line 1916 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_CREDENTIALS_GRID (self));
#line 1917 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_signal_emit (self, publishing_gallery3_credentials_grid_signals[PUBLISHING_GALLERY3_CREDENTIALS_GRID_GO_BACK_SIGNAL], 0);
#line 12250 "GalleryConnector.c"
}


static void
publishing_gallery3_credentials_grid_on_url_or_username_changed (PublishingGallery3CredentialsGrid* self)
{
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_ = FALSE;
	GtkEntry* _tmp2_;
	const gchar* _tmp3_;
	GtkButton* _tmp8_;
#line 1920 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_CREDENTIALS_GRID (self));
#line 1922 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp2_ = self->priv->url_entry;
#line 1922 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp3_ = gtk_entry_get_text (_tmp2_);
#line 1922 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (g_strcmp0 (_tmp3_, "") != 0) {
#line 12270 "GalleryConnector.c"
		GtkEntry* _tmp4_;
		const gchar* _tmp5_;
#line 1923 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp4_ = self->priv->username_entry;
#line 1923 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp5_ = gtk_entry_get_text (_tmp4_);
#line 1923 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp1_ = g_strcmp0 (_tmp5_, "") != 0;
#line 12279 "GalleryConnector.c"
	} else {
#line 1922 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp1_ = FALSE;
#line 12283 "GalleryConnector.c"
	}
#line 1922 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (_tmp1_) {
#line 1922 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp0_ = TRUE;
#line 12289 "GalleryConnector.c"
	} else {
		GtkEntry* _tmp6_;
		const gchar* _tmp7_;
#line 1924 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp6_ = self->priv->key_entry;
#line 1924 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp7_ = gtk_entry_get_text (_tmp6_);
#line 1924 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp0_ = g_strcmp0 (_tmp7_, "") != 0;
#line 12299 "GalleryConnector.c"
	}
#line 1921 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp8_ = self->priv->login_button;
#line 1921 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp8_, gtk_widget_get_type (), GtkWidget), _tmp0_);
#line 12305 "GalleryConnector.c"
}


void
publishing_gallery3_credentials_grid_installed (PublishingGallery3CredentialsGrid* self)
{
	SpitPublishingPluginHost* _tmp0_;
	SpitPublishingPluginHost* _tmp1_;
	GtkButton* _tmp2_;
#line 1927 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_CREDENTIALS_GRID (self));
#line 1928 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->host;
#line 1928 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	spit_publishing_plugin_host_set_service_locked (_tmp0_, FALSE);
#line 1931 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = self->priv->host;
#line 1931 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp2_ = self->priv->login_button;
#line 1931 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	spit_publishing_plugin_host_set_dialog_default_widget (_tmp1_, G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, gtk_widget_get_type (), GtkWidget));
#line 12327 "GalleryConnector.c"
}


GtkGrid*
publishing_gallery3_credentials_grid_get_pane_widget (PublishingGallery3CredentialsGrid* self)
{
	GtkGrid* result;
	GtkGrid* _tmp0_;
#line 1821 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (PUBLISHING_GALLERY3_IS_CREDENTIALS_GRID (self), NULL);
#line 1821 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->_pane_widget;
#line 1821 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = _tmp0_;
#line 1821 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 12344 "GalleryConnector.c"
}


static void
publishing_gallery3_credentials_grid_set_pane_widget (PublishingGallery3CredentialsGrid* self,
                                                      GtkGrid* value)
{
#line 1821 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_CREDENTIALS_GRID (self));
#line 1821 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (publishing_gallery3_credentials_grid_get_pane_widget (self) != value) {
#line 12356 "GalleryConnector.c"
		GtkGrid* _tmp0_;
#line 1821 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_tmp0_ = _g_object_ref0 (value);
#line 1821 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		_g_object_unref0 (self->priv->_pane_widget);
#line 1821 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		self->priv->_pane_widget = _tmp0_;
#line 1821 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_object_notify_by_pspec ((GObject *) self, publishing_gallery3_credentials_grid_properties[PUBLISHING_GALLERY3_CREDENTIALS_GRID_PANE_WIDGET_PROPERTY]);
#line 12366 "GalleryConnector.c"
	}
}


static void
publishing_gallery3_credentials_grid_class_init (PublishingGallery3CredentialsGridClass * klass)
{
#line 1816 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_credentials_grid_parent_class = g_type_class_peek_parent (klass);
#line 1816 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_type_class_add_private (klass, sizeof (PublishingGallery3CredentialsGridPrivate));
#line 1816 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_publishing_gallery3_credentials_grid_get_property;
#line 1816 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_publishing_gallery3_credentials_grid_set_property;
#line 1816 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	G_OBJECT_CLASS (klass)->finalize = publishing_gallery3_credentials_grid_finalize;
#line 1816 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), PUBLISHING_GALLERY3_CREDENTIALS_GRID_PANE_WIDGET_PROPERTY, publishing_gallery3_credentials_grid_properties[PUBLISHING_GALLERY3_CREDENTIALS_GRID_PANE_WIDGET_PROPERTY] = g_param_spec_object ("pane-widget", "pane-widget", "pane-widget", gtk_grid_get_type (), G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
#line 1816 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_credentials_grid_signals[PUBLISHING_GALLERY3_CREDENTIALS_GRID_GO_BACK_SIGNAL] = g_signal_new ("go-back", PUBLISHING_GALLERY3_TYPE_CREDENTIALS_GRID, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
#line 1816 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_credentials_grid_signals[PUBLISHING_GALLERY3_CREDENTIALS_GRID_LOGIN_SIGNAL] = g_signal_new ("login", PUBLISHING_GALLERY3_TYPE_CREDENTIALS_GRID, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_user_marshal_VOID__STRING_STRING_STRING_STRING, G_TYPE_NONE, 4, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING);
#line 12390 "GalleryConnector.c"
}


static void
publishing_gallery3_credentials_grid_instance_init (PublishingGallery3CredentialsGrid * self)
{
#line 1816 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv = PUBLISHING_GALLERY3_CREDENTIALS_GRID_GET_PRIVATE (self);
#line 1821 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->_pane_widget = NULL;
#line 1823 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->host = NULL;
#line 1824 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->builder = NULL;
#line 1825 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->intro_message_label = NULL;
#line 1826 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->url_entry = NULL;
#line 1827 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->username_entry = NULL;
#line 1828 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->password_entry = NULL;
#line 1829 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->key_entry = NULL;
#line 1830 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->login_button = NULL;
#line 1831 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->go_back_button = NULL;
#line 1832 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->url = NULL;
#line 1833 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->username = NULL;
#line 1834 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->key = NULL;
#line 12425 "GalleryConnector.c"
}


static void
publishing_gallery3_credentials_grid_finalize (GObject * obj)
{
	PublishingGallery3CredentialsGrid * self;
#line 1816 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_GALLERY3_TYPE_CREDENTIALS_GRID, PublishingGallery3CredentialsGrid);
#line 1821 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_object_unref0 (self->priv->_pane_widget);
#line 1824 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_object_unref0 (self->priv->builder);
#line 1825 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_object_unref0 (self->priv->intro_message_label);
#line 1826 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_object_unref0 (self->priv->url_entry);
#line 1827 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_object_unref0 (self->priv->username_entry);
#line 1828 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_object_unref0 (self->priv->password_entry);
#line 1829 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_object_unref0 (self->priv->key_entry);
#line 1830 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_object_unref0 (self->priv->login_button);
#line 1831 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_object_unref0 (self->priv->go_back_button);
#line 1832 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (self->priv->url);
#line 1833 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (self->priv->username);
#line 1834 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (self->priv->key);
#line 1816 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	G_OBJECT_CLASS (publishing_gallery3_credentials_grid_parent_class)->finalize (obj);
#line 12461 "GalleryConnector.c"
}


GType
publishing_gallery3_credentials_grid_get_type (void)
{
	static volatile gsize publishing_gallery3_credentials_grid_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_gallery3_credentials_grid_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingGallery3CredentialsGridClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_gallery3_credentials_grid_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingGallery3CredentialsGrid), 0, (GInstanceInitFunc) publishing_gallery3_credentials_grid_instance_init, NULL };
		GType publishing_gallery3_credentials_grid_type_id;
		publishing_gallery3_credentials_grid_type_id = g_type_register_static (G_TYPE_OBJECT, "PublishingGallery3CredentialsGrid", &g_define_type_info, 0);
		g_once_init_leave (&publishing_gallery3_credentials_grid_type_id__volatile, publishing_gallery3_credentials_grid_type_id);
	}
	return publishing_gallery3_credentials_grid_type_id__volatile;
}


static void
_vala_publishing_gallery3_credentials_grid_get_property (GObject * object,
                                                         guint property_id,
                                                         GValue * value,
                                                         GParamSpec * pspec)
{
	PublishingGallery3CredentialsGrid * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, PUBLISHING_GALLERY3_TYPE_CREDENTIALS_GRID, PublishingGallery3CredentialsGrid);
#line 1816 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	switch (property_id) {
#line 1816 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		case PUBLISHING_GALLERY3_CREDENTIALS_GRID_PANE_WIDGET_PROPERTY:
#line 1816 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_value_set_object (value, publishing_gallery3_credentials_grid_get_pane_widget (self));
#line 1816 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		break;
#line 12495 "GalleryConnector.c"
		default:
#line 1816 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 1816 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		break;
#line 12501 "GalleryConnector.c"
	}
}


static void
_vala_publishing_gallery3_credentials_grid_set_property (GObject * object,
                                                         guint property_id,
                                                         const GValue * value,
                                                         GParamSpec * pspec)
{
	PublishingGallery3CredentialsGrid * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, PUBLISHING_GALLERY3_TYPE_CREDENTIALS_GRID, PublishingGallery3CredentialsGrid);
#line 1816 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	switch (property_id) {
#line 1816 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		case PUBLISHING_GALLERY3_CREDENTIALS_GRID_PANE_WIDGET_PROPERTY:
#line 1816 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		publishing_gallery3_credentials_grid_set_pane_widget (self, g_value_get_object (value));
#line 1816 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		break;
#line 12522 "GalleryConnector.c"
		default:
#line 1816 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 1816 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		break;
#line 12528 "GalleryConnector.c"
	}
}


PublishingGallery3Session*
publishing_gallery3_session_construct (GType object_type)
{
	PublishingGallery3Session* self = NULL;
#line 1942 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = (PublishingGallery3Session*) publishing_rest_support_session_construct (object_type, NULL);
#line 1942 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return self;
#line 12541 "GalleryConnector.c"
}


PublishingGallery3Session*
publishing_gallery3_session_new (void)
{
#line 1942 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return publishing_gallery3_session_construct (PUBLISHING_GALLERY3_TYPE_SESSION);
#line 12550 "GalleryConnector.c"
}


static gboolean
publishing_gallery3_session_real_is_authenticated (PublishingRESTSupportSession* base)
{
	PublishingGallery3Session * self;
	gboolean result = FALSE;
	const gchar* _tmp0_;
#line 1945 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_GALLERY3_TYPE_SESSION, PublishingGallery3Session);
#line 1946 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->_key;
#line 1946 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = NULL != _tmp0_;
#line 1946 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 12568 "GalleryConnector.c"
}


void
publishing_gallery3_session_authenticate (PublishingGallery3Session* self,
                                          const gchar* gallery_url,
                                          const gchar* username,
                                          const gchar* key)
{
#line 1949 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_SESSION (self));
#line 1949 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (gallery_url != NULL);
#line 1949 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (username != NULL);
#line 1949 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (key != NULL);
#line 1950 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_session_set_url (self, gallery_url);
#line 1951 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_session_set_username (self, username);
#line 1952 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_session_set_key (self, key);
#line 1954 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_rest_support_session_notify_authenticated (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_SESSION, PublishingRESTSupportSession));
#line 12594 "GalleryConnector.c"
}


void
publishing_gallery3_session_deauthenticate (PublishingGallery3Session* self)
{
#line 1957 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_SESSION (self));
#line 1958 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_session_set_url (self, NULL);
#line 1959 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_session_set_username (self, NULL);
#line 1960 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_session_set_key (self, NULL);
#line 12609 "GalleryConnector.c"
}


const gchar*
publishing_gallery3_session_get_url (PublishingGallery3Session* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 1938 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (PUBLISHING_GALLERY3_IS_SESSION (self), NULL);
#line 1938 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->_url;
#line 1938 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = _tmp0_;
#line 1938 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 12626 "GalleryConnector.c"
}


static void
publishing_gallery3_session_set_url (PublishingGallery3Session* self,
                                     const gchar* value)
{
	gchar* _tmp0_;
#line 1938 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_SESSION (self));
#line 1938 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = g_strdup (value);
#line 1938 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (self->priv->_url);
#line 1938 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->_url = _tmp0_;
#line 12643 "GalleryConnector.c"
}


const gchar*
publishing_gallery3_session_get_username (PublishingGallery3Session* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 1939 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (PUBLISHING_GALLERY3_IS_SESSION (self), NULL);
#line 1939 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->_username;
#line 1939 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = _tmp0_;
#line 1939 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 12660 "GalleryConnector.c"
}


static void
publishing_gallery3_session_set_username (PublishingGallery3Session* self,
                                          const gchar* value)
{
	gchar* _tmp0_;
#line 1939 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_SESSION (self));
#line 1939 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = g_strdup (value);
#line 1939 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (self->priv->_username);
#line 1939 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->_username = _tmp0_;
#line 12677 "GalleryConnector.c"
}


const gchar*
publishing_gallery3_session_get_key (PublishingGallery3Session* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 1940 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (PUBLISHING_GALLERY3_IS_SESSION (self), NULL);
#line 1940 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->_key;
#line 1940 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = _tmp0_;
#line 1940 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 12694 "GalleryConnector.c"
}


static void
publishing_gallery3_session_set_key (PublishingGallery3Session* self,
                                     const gchar* value)
{
	gchar* _tmp0_;
#line 1940 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_if_fail (PUBLISHING_GALLERY3_IS_SESSION (self));
#line 1940 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = g_strdup (value);
#line 1940 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (self->priv->_key);
#line 1940 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->_key = _tmp0_;
#line 12711 "GalleryConnector.c"
}


static void
publishing_gallery3_session_class_init (PublishingGallery3SessionClass * klass)
{
#line 1935 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_session_parent_class = g_type_class_peek_parent (klass);
#line 1935 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	((PublishingRESTSupportSessionClass *) klass)->finalize = publishing_gallery3_session_finalize;
#line 1935 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_type_class_add_private (klass, sizeof (PublishingGallery3SessionPrivate));
#line 1935 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	((PublishingRESTSupportSessionClass *) klass)->is_authenticated = (gboolean (*) (PublishingRESTSupportSession *)) publishing_gallery3_session_real_is_authenticated;
#line 12726 "GalleryConnector.c"
}


static void
publishing_gallery3_session_instance_init (PublishingGallery3Session * self)
{
#line 1935 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv = PUBLISHING_GALLERY3_SESSION_GET_PRIVATE (self);
#line 1938 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->_url = NULL;
#line 1939 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->_username = NULL;
#line 1940 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->_key = NULL;
#line 12741 "GalleryConnector.c"
}


static void
publishing_gallery3_session_finalize (PublishingRESTSupportSession * obj)
{
	PublishingGallery3Session * self;
#line 1935 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_GALLERY3_TYPE_SESSION, PublishingGallery3Session);
#line 1938 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (self->priv->_url);
#line 1939 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (self->priv->_username);
#line 1940 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (self->priv->_key);
#line 1935 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	PUBLISHING_REST_SUPPORT_SESSION_CLASS (publishing_gallery3_session_parent_class)->finalize (obj);
#line 12759 "GalleryConnector.c"
}


GType
publishing_gallery3_session_get_type (void)
{
	static volatile gsize publishing_gallery3_session_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_gallery3_session_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingGallery3SessionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_gallery3_session_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingGallery3Session), 0, (GInstanceInitFunc) publishing_gallery3_session_instance_init, NULL };
		GType publishing_gallery3_session_type_id;
		publishing_gallery3_session_type_id = g_type_register_static (PUBLISHING_REST_SUPPORT_TYPE_SESSION, "PublishingGallery3Session", &g_define_type_info, 0);
		g_once_init_leave (&publishing_gallery3_session_type_id__volatile, publishing_gallery3_session_type_id);
	}
	return publishing_gallery3_session_type_id__volatile;
}


PublishingGallery3Uploader*
publishing_gallery3_uploader_construct (GType object_type,
                                        PublishingGallery3Session* session,
                                        SpitPublishingPublishable** publishables,
                                        int publishables_length1,
                                        PublishingGallery3PublishingParameters* parameters)
{
	PublishingGallery3Uploader* self = NULL;
	PublishingGallery3PublishingParameters* _tmp0_;
#line 1990 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (PUBLISHING_GALLERY3_IS_SESSION (session), NULL);
#line 1990 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (PUBLISHING_GALLERY3_IS_PUBLISHING_PARAMETERS (parameters), NULL);
#line 1994 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = (PublishingGallery3Uploader*) publishing_rest_support_batch_uploader_construct (object_type, G_TYPE_CHECK_INSTANCE_CAST (session, PUBLISHING_REST_SUPPORT_TYPE_SESSION, PublishingRESTSupportSession), publishables, publishables_length1);
#line 1996 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = _publishing_gallery3_publishing_parameters_ref0 (parameters);
#line 1996 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_publishing_gallery3_publishing_parameters_unref0 (self->priv->parameters);
#line 1996 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->parameters = _tmp0_;
#line 1990 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return self;
#line 12800 "GalleryConnector.c"
}


PublishingGallery3Uploader*
publishing_gallery3_uploader_new (PublishingGallery3Session* session,
                                  SpitPublishingPublishable** publishables,
                                  int publishables_length1,
                                  PublishingGallery3PublishingParameters* parameters)
{
#line 1990 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return publishing_gallery3_uploader_construct (PUBLISHING_GALLERY3_TYPE_UPLOADER, session, publishables, publishables_length1, parameters);
#line 12812 "GalleryConnector.c"
}


static gpointer
_publishing_rest_support_transaction_ref0 (gpointer self)
{
#line 2011 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return self ? publishing_rest_support_transaction_ref (self) : NULL;
#line 12821 "GalleryConnector.c"
}


static PublishingRESTSupportTransaction*
publishing_gallery3_uploader_real_create_transaction (PublishingRESTSupportBatchUploader* base,
                                                      SpitPublishingPublishable* publishable)
{
	PublishingGallery3Uploader * self;
	PublishingRESTSupportTransaction* result = NULL;
	SpitPublishingPublishable* p = NULL;
	SpitPublishingPublishable* _tmp0_;
	gchar* _tmp1_;
	PublishingRESTSupportSession* _tmp2_;
	PublishingGallery3Session* _tmp3_;
	PublishingGallery3PublishingParameters* _tmp4_;
	PublishingGallery3GalleryUploadTransaction* _tmp5_;
	PublishingRESTSupportTransaction* _tmp6_;
	PublishingRESTSupportTransaction* _tmp7_;
#line 2000 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_GALLERY3_TYPE_UPLOADER, PublishingGallery3Uploader);
#line 2000 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (SPIT_PUBLISHING_IS_PUBLISHABLE (publishable), NULL);
#line 2003 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = publishing_rest_support_batch_uploader_get_current_publishable (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_BATCH_UPLOADER, PublishingRESTSupportBatchUploader));
#line 2003 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	p = _tmp0_;
#line 2004 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = spit_publishing_publishable_get_param_string (p, SPIT_PUBLISHING_PUBLISHABLE_PARAM_STRING_BASENAME);
#line 2004 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (self->priv->_current_publishable_name);
#line 2004 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->_current_publishable_name = _tmp1_;
#line 2006 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->_current_media_type = spit_publishing_publishable_get_media_type (p);
#line 2008 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp2_ = publishing_rest_support_batch_uploader_get_session (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_BATCH_UPLOADER, PublishingRESTSupportBatchUploader));
#line 2008 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp3_ = G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, PUBLISHING_GALLERY3_TYPE_SESSION, PublishingGallery3Session);
#line 2008 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp4_ = self->priv->parameters;
#line 2008 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp5_ = publishing_gallery3_gallery_upload_transaction_new (_tmp3_, _tmp4_, p);
#line 2008 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_publishing_rest_support_transaction_unref0 (self->priv->_current_transaction);
#line 2008 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv->_current_transaction = G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction);
#line 2008 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_publishing_rest_support_session_unref0 (_tmp3_);
#line 2011 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp6_ = self->priv->_current_transaction;
#line 2011 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp7_ = _publishing_rest_support_transaction_ref0 (_tmp6_);
#line 2011 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = _tmp7_;
#line 2011 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_object_unref0 (p);
#line 2011 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 12880 "GalleryConnector.c"
}


const gchar*
publishing_gallery3_uploader_get_current_publishable_name (PublishingGallery3Uploader* self)
{
	const gchar* result;
	const gchar* _tmp0_;
#line 1974 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (PUBLISHING_GALLERY3_IS_UPLOADER (self), NULL);
#line 1975 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->_current_publishable_name;
#line 1975 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = _tmp0_;
#line 1975 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 12897 "GalleryConnector.c"
}


guint
publishing_gallery3_uploader_get_status_code (PublishingGallery3Uploader* self)
{
	guint result;
	PublishingRESTSupportTransaction* _tmp0_;
#line 1979 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (PUBLISHING_GALLERY3_IS_UPLOADER (self), 0U);
#line 1980 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->_current_transaction;
#line 1980 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = publishing_rest_support_transaction_get_status_code (_tmp0_);
#line 1980 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 12914 "GalleryConnector.c"
}


SpitPublishingPublisherMediaType
publishing_gallery3_uploader_get_current_publishable_type (PublishingGallery3Uploader* self)
{
	SpitPublishingPublisherMediaType result;
	SpitPublishingPublisherMediaType _tmp0_;
#line 1985 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (PUBLISHING_GALLERY3_IS_UPLOADER (self), 0);
#line 1986 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = self->priv->_current_media_type;
#line 1986 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = _tmp0_;
#line 1986 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 12931 "GalleryConnector.c"
}


static void
publishing_gallery3_uploader_class_init (PublishingGallery3UploaderClass * klass)
{
#line 1965 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	publishing_gallery3_uploader_parent_class = g_type_class_peek_parent (klass);
#line 1965 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	((PublishingRESTSupportBatchUploaderClass *) klass)->finalize = publishing_gallery3_uploader_finalize;
#line 1965 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_type_class_add_private (klass, sizeof (PublishingGallery3UploaderPrivate));
#line 1965 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	((PublishingRESTSupportBatchUploaderClass *) klass)->create_transaction = (PublishingRESTSupportTransaction* (*) (PublishingRESTSupportBatchUploader *, SpitPublishingPublishable*)) publishing_gallery3_uploader_real_create_transaction;
#line 12946 "GalleryConnector.c"
}


static void
publishing_gallery3_uploader_instance_init (PublishingGallery3Uploader * self)
{
#line 1965 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self->priv = PUBLISHING_GALLERY3_UPLOADER_GET_PRIVATE (self);
#line 12955 "GalleryConnector.c"
}


static void
publishing_gallery3_uploader_finalize (PublishingRESTSupportBatchUploader * obj)
{
	PublishingGallery3Uploader * self;
#line 1965 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_GALLERY3_TYPE_UPLOADER, PublishingGallery3Uploader);
#line 1967 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_publishing_gallery3_publishing_parameters_unref0 (self->priv->parameters);
#line 1968 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_g_free0 (self->priv->_current_publishable_name);
#line 1970 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_publishing_rest_support_transaction_unref0 (self->priv->_current_transaction);
#line 1965 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	PUBLISHING_REST_SUPPORT_BATCH_UPLOADER_CLASS (publishing_gallery3_uploader_parent_class)->finalize (obj);
#line 12973 "GalleryConnector.c"
}


GType
publishing_gallery3_uploader_get_type (void)
{
	static volatile gsize publishing_gallery3_uploader_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_gallery3_uploader_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingGallery3UploaderClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_gallery3_uploader_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingGallery3Uploader), 0, (GInstanceInitFunc) publishing_gallery3_uploader_instance_init, NULL };
		GType publishing_gallery3_uploader_type_id;
		publishing_gallery3_uploader_type_id = g_type_register_static (PUBLISHING_REST_SUPPORT_TYPE_BATCH_UPLOADER, "PublishingGallery3Uploader", &g_define_type_info, 0);
		g_once_init_leave (&publishing_gallery3_uploader_type_id__volatile, publishing_gallery3_uploader_type_id);
	}
	return publishing_gallery3_uploader_type_id__volatile;
}


static gint
string_last_index_of (const gchar* self,
                      const gchar* needle,
                      gint start_index)
{
	gint result = 0;
	gchar* _result_ = NULL;
	gchar* _tmp0_;
	gchar* _tmp1_;
#line 1035 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, 0);
#line 1035 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	g_return_val_if_fail (needle != NULL, 0);
#line 1036 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	_tmp0_ = g_strrstr (((gchar*) self) + start_index, (gchar*) needle);
#line 1036 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	_result_ = _tmp0_;
#line 1038 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	_tmp1_ = _result_;
#line 1038 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	if (_tmp1_ != NULL) {
#line 13012 "GalleryConnector.c"
		gchar* _tmp2_;
#line 1039 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		_tmp2_ = _result_;
#line 1039 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		result = (gint) (_tmp2_ - ((gchar*) self));
#line 1039 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		return result;
#line 13020 "GalleryConnector.c"
	} else {
#line 1041 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		result = -1;
#line 1041 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		return result;
#line 13026 "GalleryConnector.c"
	}
}


gchar*
publishing_gallery3_strip_session_url (const gchar* url)
{
	gchar* result = NULL;
	gint item_loc = 0;
	gint _tmp0_;
	gint _tmp1_;
	gchar* _tmp2_;
#line 2017 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_return_val_if_fail (url != NULL, NULL);
#line 2020 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	g_debug ("GalleryConnector.vala:2020: Searching for \"%s\" in \"%s\"", PUBLISHING_GALLERY3_REST_PATH, url);
#line 2022 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	item_loc = string_last_index_of (url, PUBLISHING_GALLERY3_REST_PATH, 0);
#line 2025 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	if (-1 == item_loc) {
#line 2026 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
		g_error ("Did not find \"%s\" in the base of the new item " "URL \"%s\"", PUBLISHING_GALLERY3_REST_PATH, url);
#line 13049 "GalleryConnector.c"
	}
#line 2029 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp0_ = strlen (PUBLISHING_GALLERY3_REST_PATH);
#line 2029 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp1_ = _tmp0_;
#line 2029 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	_tmp2_ = string_substring (url, (glong) (item_loc + _tmp1_), (glong) -1);
#line 2029 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	result = _tmp2_;
#line 2029 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/GalleryConnector.vala"
	return result;
#line 13061 "GalleryConnector.c"
}


static void
_vala_array_destroy (gpointer array,
                     gint array_length,
                     GDestroyNotify destroy_func)
{
	if ((array != NULL) && (destroy_func != NULL)) {
		int i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}


static void
_vala_array_free (gpointer array,
                  gint array_length,
                  GDestroyNotify destroy_func)
{
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}



