/* RajcePublishing.c generated by valac 0.40.4, the Vala compiler
 * generated from RajcePublishing.vala, do not modify */

/* Copyright 2014 rajce.net
 *
 * This software is licensed under the GNU Lesser General Public License
 * (version 2.1 or later).  See the COPYING file in this distribution.
 */


#include <glib.h>
#include <glib-object.h>
#include <shotwell-plugin-dev-1.0.h>
#include <gdk-pixbuf/gdk-pixbuf.h>
#include <stdlib.h>
#include <string.h>
#include <gio/gio.h>
#include "shotwell-plugin-common.h"
#include <glib/gi18n-lib.h>
#include <gtk/gtk.h>
#include <libxml/tree.h>
#include <gee.h>
#include <float.h>
#include <math.h>
#include <libxml/parser.h>
#include <libsoup/soup.h>
#include <gobject/gvaluecollector.h>


#define TYPE_RAJCE_SERVICE (rajce_service_get_type ())
#define RAJCE_SERVICE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_RAJCE_SERVICE, RajceService))
#define RAJCE_SERVICE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_RAJCE_SERVICE, RajceServiceClass))
#define IS_RAJCE_SERVICE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_RAJCE_SERVICE))
#define IS_RAJCE_SERVICE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_RAJCE_SERVICE))
#define RAJCE_SERVICE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_RAJCE_SERVICE, RajceServiceClass))

typedef struct _RajceService RajceService;
typedef struct _RajceServiceClass RajceServiceClass;
typedef struct _RajceServicePrivate RajceServicePrivate;
enum  {
	RAJCE_SERVICE_0_PROPERTY,
	RAJCE_SERVICE_NUM_PROPERTIES
};
static GParamSpec* rajce_service_properties[RAJCE_SERVICE_NUM_PROPERTIES];
#define _g_free0(var) (var = (g_free (var), NULL))

#define PUBLISHING_RAJCE_TYPE_RAJCE_PUBLISHER (publishing_rajce_rajce_publisher_get_type ())
#define PUBLISHING_RAJCE_RAJCE_PUBLISHER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_RAJCE_TYPE_RAJCE_PUBLISHER, PublishingRajceRajcePublisher))
#define PUBLISHING_RAJCE_RAJCE_PUBLISHER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_RAJCE_TYPE_RAJCE_PUBLISHER, PublishingRajceRajcePublisherClass))
#define PUBLISHING_RAJCE_IS_RAJCE_PUBLISHER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_RAJCE_TYPE_RAJCE_PUBLISHER))
#define PUBLISHING_RAJCE_IS_RAJCE_PUBLISHER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_RAJCE_TYPE_RAJCE_PUBLISHER))
#define PUBLISHING_RAJCE_RAJCE_PUBLISHER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_RAJCE_TYPE_RAJCE_PUBLISHER, PublishingRajceRajcePublisherClass))

typedef struct _PublishingRajceRajcePublisher PublishingRajceRajcePublisher;
typedef struct _PublishingRajceRajcePublisherClass PublishingRajceRajcePublisherClass;
typedef struct _PublishingRajceRajcePublisherPrivate PublishingRajceRajcePublisherPrivate;

#define PUBLISHING_RAJCE_TYPE_SESSION (publishing_rajce_session_get_type ())
#define PUBLISHING_RAJCE_SESSION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_RAJCE_TYPE_SESSION, PublishingRajceSession))
#define PUBLISHING_RAJCE_SESSION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_RAJCE_TYPE_SESSION, PublishingRajceSessionClass))
#define PUBLISHING_RAJCE_IS_SESSION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_RAJCE_TYPE_SESSION))
#define PUBLISHING_RAJCE_IS_SESSION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_RAJCE_TYPE_SESSION))
#define PUBLISHING_RAJCE_SESSION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_RAJCE_TYPE_SESSION, PublishingRajceSessionClass))

typedef struct _PublishingRajceSession PublishingRajceSession;
typedef struct _PublishingRajceSessionClass PublishingRajceSessionClass;

#define PUBLISHING_RAJCE_TYPE_ALBUM (publishing_rajce_album_get_type ())
#define PUBLISHING_RAJCE_ALBUM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_RAJCE_TYPE_ALBUM, PublishingRajceAlbum))
#define PUBLISHING_RAJCE_ALBUM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_RAJCE_TYPE_ALBUM, PublishingRajceAlbumClass))
#define PUBLISHING_RAJCE_IS_ALBUM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_RAJCE_TYPE_ALBUM))
#define PUBLISHING_RAJCE_IS_ALBUM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_RAJCE_TYPE_ALBUM))
#define PUBLISHING_RAJCE_ALBUM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_RAJCE_TYPE_ALBUM, PublishingRajceAlbumClass))

typedef struct _PublishingRajceAlbum PublishingRajceAlbum;
typedef struct _PublishingRajceAlbumClass PublishingRajceAlbumClass;

#define PUBLISHING_RAJCE_TYPE_PUBLISHING_PARAMETERS (publishing_rajce_publishing_parameters_get_type ())
#define PUBLISHING_RAJCE_PUBLISHING_PARAMETERS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_RAJCE_TYPE_PUBLISHING_PARAMETERS, PublishingRajcePublishingParameters))
#define PUBLISHING_RAJCE_PUBLISHING_PARAMETERS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_RAJCE_TYPE_PUBLISHING_PARAMETERS, PublishingRajcePublishingParametersClass))
#define PUBLISHING_RAJCE_IS_PUBLISHING_PARAMETERS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_RAJCE_TYPE_PUBLISHING_PARAMETERS))
#define PUBLISHING_RAJCE_IS_PUBLISHING_PARAMETERS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_RAJCE_TYPE_PUBLISHING_PARAMETERS))
#define PUBLISHING_RAJCE_PUBLISHING_PARAMETERS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_RAJCE_TYPE_PUBLISHING_PARAMETERS, PublishingRajcePublishingParametersClass))

typedef struct _PublishingRajcePublishingParameters PublishingRajcePublishingParameters;
typedef struct _PublishingRajcePublishingParametersClass PublishingRajcePublishingParametersClass;
enum  {
	PUBLISHING_RAJCE_RAJCE_PUBLISHER_0_PROPERTY,
	PUBLISHING_RAJCE_RAJCE_PUBLISHER_NUM_PROPERTIES
};
static GParamSpec* publishing_rajce_rajce_publisher_properties[PUBLISHING_RAJCE_RAJCE_PUBLISHER_NUM_PROPERTIES];
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _publishing_rest_support_session_unref0(var) ((var == NULL) ? NULL : (var = (publishing_rest_support_session_unref (var), NULL)))
#define _publishing_rajce_publishing_parameters_unref0(var) ((var == NULL) ? NULL : (var = (publishing_rajce_publishing_parameters_unref (var), NULL)))

#define PUBLISHING_RAJCE_AUTHENTICATION_PANE_TYPE_MODE (publishing_rajce_authentication_pane_mode_get_type ())

#define PUBLISHING_RAJCE_TYPE_AUTHENTICATION_PANE (publishing_rajce_authentication_pane_get_type ())
#define PUBLISHING_RAJCE_AUTHENTICATION_PANE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_RAJCE_TYPE_AUTHENTICATION_PANE, PublishingRajceAuthenticationPane))
#define PUBLISHING_RAJCE_AUTHENTICATION_PANE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_RAJCE_TYPE_AUTHENTICATION_PANE, PublishingRajceAuthenticationPaneClass))
#define PUBLISHING_RAJCE_IS_AUTHENTICATION_PANE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_RAJCE_TYPE_AUTHENTICATION_PANE))
#define PUBLISHING_RAJCE_IS_AUTHENTICATION_PANE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_RAJCE_TYPE_AUTHENTICATION_PANE))
#define PUBLISHING_RAJCE_AUTHENTICATION_PANE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_RAJCE_TYPE_AUTHENTICATION_PANE, PublishingRajceAuthenticationPaneClass))

typedef struct _PublishingRajceAuthenticationPane PublishingRajceAuthenticationPane;
typedef struct _PublishingRajceAuthenticationPaneClass PublishingRajceAuthenticationPaneClass;

#define PUBLISHING_RAJCE_TYPE_TRANSACTION (publishing_rajce_transaction_get_type ())
#define PUBLISHING_RAJCE_TRANSACTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_RAJCE_TYPE_TRANSACTION, PublishingRajceTransaction))
#define PUBLISHING_RAJCE_TRANSACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_RAJCE_TYPE_TRANSACTION, PublishingRajceTransactionClass))
#define PUBLISHING_RAJCE_IS_TRANSACTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_RAJCE_TYPE_TRANSACTION))
#define PUBLISHING_RAJCE_IS_TRANSACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_RAJCE_TYPE_TRANSACTION))
#define PUBLISHING_RAJCE_TRANSACTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_RAJCE_TYPE_TRANSACTION, PublishingRajceTransactionClass))

typedef struct _PublishingRajceTransaction PublishingRajceTransaction;
typedef struct _PublishingRajceTransactionClass PublishingRajceTransactionClass;

#define PUBLISHING_RAJCE_TYPE_SESSION_LOGIN_TRANSACTION (publishing_rajce_session_login_transaction_get_type ())
#define PUBLISHING_RAJCE_SESSION_LOGIN_TRANSACTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_RAJCE_TYPE_SESSION_LOGIN_TRANSACTION, PublishingRajceSessionLoginTransaction))
#define PUBLISHING_RAJCE_SESSION_LOGIN_TRANSACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_RAJCE_TYPE_SESSION_LOGIN_TRANSACTION, PublishingRajceSessionLoginTransactionClass))
#define PUBLISHING_RAJCE_IS_SESSION_LOGIN_TRANSACTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_RAJCE_TYPE_SESSION_LOGIN_TRANSACTION))
#define PUBLISHING_RAJCE_IS_SESSION_LOGIN_TRANSACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_RAJCE_TYPE_SESSION_LOGIN_TRANSACTION))
#define PUBLISHING_RAJCE_SESSION_LOGIN_TRANSACTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_RAJCE_TYPE_SESSION_LOGIN_TRANSACTION, PublishingRajceSessionLoginTransactionClass))

typedef struct _PublishingRajceSessionLoginTransaction PublishingRajceSessionLoginTransaction;
typedef struct _PublishingRajceSessionLoginTransactionClass PublishingRajceSessionLoginTransactionClass;
#define _publishing_rest_support_transaction_unref0(var) ((var == NULL) ? NULL : (var = (publishing_rest_support_transaction_unref (var), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
#define _publishing_rest_support_xml_document_unref0(var) ((var == NULL) ? NULL : (var = (publishing_rest_support_xml_document_unref (var), NULL)))

#define PUBLISHING_RAJCE_TYPE_GET_ALBUMS_TRANSACTION (publishing_rajce_get_albums_transaction_get_type ())
#define PUBLISHING_RAJCE_GET_ALBUMS_TRANSACTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_RAJCE_TYPE_GET_ALBUMS_TRANSACTION, PublishingRajceGetAlbumsTransaction))
#define PUBLISHING_RAJCE_GET_ALBUMS_TRANSACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_RAJCE_TYPE_GET_ALBUMS_TRANSACTION, PublishingRajceGetAlbumsTransactionClass))
#define PUBLISHING_RAJCE_IS_GET_ALBUMS_TRANSACTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_RAJCE_TYPE_GET_ALBUMS_TRANSACTION))
#define PUBLISHING_RAJCE_IS_GET_ALBUMS_TRANSACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_RAJCE_TYPE_GET_ALBUMS_TRANSACTION))
#define PUBLISHING_RAJCE_GET_ALBUMS_TRANSACTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_RAJCE_TYPE_GET_ALBUMS_TRANSACTION, PublishingRajceGetAlbumsTransactionClass))

typedef struct _PublishingRajceGetAlbumsTransaction PublishingRajceGetAlbumsTransaction;
typedef struct _PublishingRajceGetAlbumsTransactionClass PublishingRajceGetAlbumsTransactionClass;
#define _publishing_rajce_album_unref0(var) ((var == NULL) ? NULL : (var = (publishing_rajce_album_unref (var), NULL)))

#define PUBLISHING_RAJCE_TYPE_PUBLISHING_OPTIONS_PANE (publishing_rajce_publishing_options_pane_get_type ())
#define PUBLISHING_RAJCE_PUBLISHING_OPTIONS_PANE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_RAJCE_TYPE_PUBLISHING_OPTIONS_PANE, PublishingRajcePublishingOptionsPane))
#define PUBLISHING_RAJCE_PUBLISHING_OPTIONS_PANE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_RAJCE_TYPE_PUBLISHING_OPTIONS_PANE, PublishingRajcePublishingOptionsPaneClass))
#define PUBLISHING_RAJCE_IS_PUBLISHING_OPTIONS_PANE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_RAJCE_TYPE_PUBLISHING_OPTIONS_PANE))
#define PUBLISHING_RAJCE_IS_PUBLISHING_OPTIONS_PANE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_RAJCE_TYPE_PUBLISHING_OPTIONS_PANE))
#define PUBLISHING_RAJCE_PUBLISHING_OPTIONS_PANE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_RAJCE_TYPE_PUBLISHING_OPTIONS_PANE, PublishingRajcePublishingOptionsPaneClass))

typedef struct _PublishingRajcePublishingOptionsPane PublishingRajcePublishingOptionsPane;
typedef struct _PublishingRajcePublishingOptionsPaneClass PublishingRajcePublishingOptionsPaneClass;
typedef struct _PublishingRajcePublishingParametersPrivate PublishingRajcePublishingParametersPrivate;

#define PUBLISHING_RAJCE_TYPE_CREATE_ALBUM_TRANSACTION (publishing_rajce_create_album_transaction_get_type ())
#define PUBLISHING_RAJCE_CREATE_ALBUM_TRANSACTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_RAJCE_TYPE_CREATE_ALBUM_TRANSACTION, PublishingRajceCreateAlbumTransaction))
#define PUBLISHING_RAJCE_CREATE_ALBUM_TRANSACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_RAJCE_TYPE_CREATE_ALBUM_TRANSACTION, PublishingRajceCreateAlbumTransactionClass))
#define PUBLISHING_RAJCE_IS_CREATE_ALBUM_TRANSACTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_RAJCE_TYPE_CREATE_ALBUM_TRANSACTION))
#define PUBLISHING_RAJCE_IS_CREATE_ALBUM_TRANSACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_RAJCE_TYPE_CREATE_ALBUM_TRANSACTION))
#define PUBLISHING_RAJCE_CREATE_ALBUM_TRANSACTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_RAJCE_TYPE_CREATE_ALBUM_TRANSACTION, PublishingRajceCreateAlbumTransactionClass))

typedef struct _PublishingRajceCreateAlbumTransaction PublishingRajceCreateAlbumTransaction;
typedef struct _PublishingRajceCreateAlbumTransactionClass PublishingRajceCreateAlbumTransactionClass;

#define PUBLISHING_RAJCE_TYPE_OPEN_ALBUM_TRANSACTION (publishing_rajce_open_album_transaction_get_type ())
#define PUBLISHING_RAJCE_OPEN_ALBUM_TRANSACTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_RAJCE_TYPE_OPEN_ALBUM_TRANSACTION, PublishingRajceOpenAlbumTransaction))
#define PUBLISHING_RAJCE_OPEN_ALBUM_TRANSACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_RAJCE_TYPE_OPEN_ALBUM_TRANSACTION, PublishingRajceOpenAlbumTransactionClass))
#define PUBLISHING_RAJCE_IS_OPEN_ALBUM_TRANSACTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_RAJCE_TYPE_OPEN_ALBUM_TRANSACTION))
#define PUBLISHING_RAJCE_IS_OPEN_ALBUM_TRANSACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_RAJCE_TYPE_OPEN_ALBUM_TRANSACTION))
#define PUBLISHING_RAJCE_OPEN_ALBUM_TRANSACTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_RAJCE_TYPE_OPEN_ALBUM_TRANSACTION, PublishingRajceOpenAlbumTransactionClass))

typedef struct _PublishingRajceOpenAlbumTransaction PublishingRajceOpenAlbumTransaction;
typedef struct _PublishingRajceOpenAlbumTransactionClass PublishingRajceOpenAlbumTransactionClass;

#define PUBLISHING_RAJCE_TYPE_UPLOADER (publishing_rajce_uploader_get_type ())
#define PUBLISHING_RAJCE_UPLOADER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_RAJCE_TYPE_UPLOADER, PublishingRajceUploader))
#define PUBLISHING_RAJCE_UPLOADER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_RAJCE_TYPE_UPLOADER, PublishingRajceUploaderClass))
#define PUBLISHING_RAJCE_IS_UPLOADER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_RAJCE_TYPE_UPLOADER))
#define PUBLISHING_RAJCE_IS_UPLOADER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_RAJCE_TYPE_UPLOADER))
#define PUBLISHING_RAJCE_UPLOADER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_RAJCE_TYPE_UPLOADER, PublishingRajceUploaderClass))

typedef struct _PublishingRajceUploader PublishingRajceUploader;
typedef struct _PublishingRajceUploaderClass PublishingRajceUploaderClass;
#define _publishing_rest_support_batch_uploader_unref0(var) ((var == NULL) ? NULL : (var = (publishing_rest_support_batch_uploader_unref (var), NULL)))

#define PUBLISHING_RAJCE_TYPE_GET_ALBUM_URL_TRANSACTION (publishing_rajce_get_album_url_transaction_get_type ())
#define PUBLISHING_RAJCE_GET_ALBUM_URL_TRANSACTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_RAJCE_TYPE_GET_ALBUM_URL_TRANSACTION, PublishingRajceGetAlbumUrlTransaction))
#define PUBLISHING_RAJCE_GET_ALBUM_URL_TRANSACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_RAJCE_TYPE_GET_ALBUM_URL_TRANSACTION, PublishingRajceGetAlbumUrlTransactionClass))
#define PUBLISHING_RAJCE_IS_GET_ALBUM_URL_TRANSACTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_RAJCE_TYPE_GET_ALBUM_URL_TRANSACTION))
#define PUBLISHING_RAJCE_IS_GET_ALBUM_URL_TRANSACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_RAJCE_TYPE_GET_ALBUM_URL_TRANSACTION))
#define PUBLISHING_RAJCE_GET_ALBUM_URL_TRANSACTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_RAJCE_TYPE_GET_ALBUM_URL_TRANSACTION, PublishingRajceGetAlbumUrlTransactionClass))

typedef struct _PublishingRajceGetAlbumUrlTransaction PublishingRajceGetAlbumUrlTransaction;
typedef struct _PublishingRajceGetAlbumUrlTransactionClass PublishingRajceGetAlbumUrlTransactionClass;

#define PUBLISHING_RAJCE_TYPE_CLOSE_ALBUM_TRANSACTION (publishing_rajce_close_album_transaction_get_type ())
#define PUBLISHING_RAJCE_CLOSE_ALBUM_TRANSACTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_RAJCE_TYPE_CLOSE_ALBUM_TRANSACTION, PublishingRajceCloseAlbumTransaction))
#define PUBLISHING_RAJCE_CLOSE_ALBUM_TRANSACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_RAJCE_TYPE_CLOSE_ALBUM_TRANSACTION, PublishingRajceCloseAlbumTransactionClass))
#define PUBLISHING_RAJCE_IS_CLOSE_ALBUM_TRANSACTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_RAJCE_TYPE_CLOSE_ALBUM_TRANSACTION))
#define PUBLISHING_RAJCE_IS_CLOSE_ALBUM_TRANSACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_RAJCE_TYPE_CLOSE_ALBUM_TRANSACTION))
#define PUBLISHING_RAJCE_CLOSE_ALBUM_TRANSACTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_RAJCE_TYPE_CLOSE_ALBUM_TRANSACTION, PublishingRajceCloseAlbumTransactionClass))

typedef struct _PublishingRajceCloseAlbumTransaction PublishingRajceCloseAlbumTransaction;
typedef struct _PublishingRajceCloseAlbumTransactionClass PublishingRajceCloseAlbumTransactionClass;
typedef struct _PublishingRajceAlbumPrivate PublishingRajceAlbumPrivate;
typedef struct _PublishingRajceParamSpecAlbum PublishingRajceParamSpecAlbum;
typedef struct _PublishingRajceUploaderPrivate PublishingRajceUploaderPrivate;

#define PUBLISHING_RAJCE_TYPE_ADD_PHOTO_TRANSACTION (publishing_rajce_add_photo_transaction_get_type ())
#define PUBLISHING_RAJCE_ADD_PHOTO_TRANSACTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_RAJCE_TYPE_ADD_PHOTO_TRANSACTION, PublishingRajceAddPhotoTransaction))
#define PUBLISHING_RAJCE_ADD_PHOTO_TRANSACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_RAJCE_TYPE_ADD_PHOTO_TRANSACTION, PublishingRajceAddPhotoTransactionClass))
#define PUBLISHING_RAJCE_IS_ADD_PHOTO_TRANSACTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_RAJCE_TYPE_ADD_PHOTO_TRANSACTION))
#define PUBLISHING_RAJCE_IS_ADD_PHOTO_TRANSACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_RAJCE_TYPE_ADD_PHOTO_TRANSACTION))
#define PUBLISHING_RAJCE_ADD_PHOTO_TRANSACTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_RAJCE_TYPE_ADD_PHOTO_TRANSACTION, PublishingRajceAddPhotoTransactionClass))

typedef struct _PublishingRajceAddPhotoTransaction PublishingRajceAddPhotoTransaction;
typedef struct _PublishingRajceAddPhotoTransactionClass PublishingRajceAddPhotoTransactionClass;
typedef struct _PublishingRajceAuthenticationPanePrivate PublishingRajceAuthenticationPanePrivate;
enum  {
	PUBLISHING_RAJCE_AUTHENTICATION_PANE_0_PROPERTY,
	PUBLISHING_RAJCE_AUTHENTICATION_PANE_NUM_PROPERTIES
};
static GParamSpec* publishing_rajce_authentication_pane_properties[PUBLISHING_RAJCE_AUTHENTICATION_PANE_NUM_PROPERTIES];
enum  {
	PUBLISHING_RAJCE_AUTHENTICATION_PANE_LOGIN_SIGNAL,
	PUBLISHING_RAJCE_AUTHENTICATION_PANE_NUM_SIGNALS
};
static guint publishing_rajce_authentication_pane_signals[PUBLISHING_RAJCE_AUTHENTICATION_PANE_NUM_SIGNALS] = {0};
typedef struct _PublishingRajcePublishingOptionsPanePrivate PublishingRajcePublishingOptionsPanePrivate;
enum  {
	PUBLISHING_RAJCE_PUBLISHING_OPTIONS_PANE_0_PROPERTY,
	PUBLISHING_RAJCE_PUBLISHING_OPTIONS_PANE_NUM_PROPERTIES
};
static GParamSpec* publishing_rajce_publishing_options_pane_properties[PUBLISHING_RAJCE_PUBLISHING_OPTIONS_PANE_NUM_PROPERTIES];
enum  {
	PUBLISHING_RAJCE_PUBLISHING_OPTIONS_PANE_PUBLISH_SIGNAL,
	PUBLISHING_RAJCE_PUBLISHING_OPTIONS_PANE_LOGOUT_SIGNAL,
	PUBLISHING_RAJCE_PUBLISHING_OPTIONS_PANE_NUM_SIGNALS
};
static guint publishing_rajce_publishing_options_pane_signals[PUBLISHING_RAJCE_PUBLISHING_OPTIONS_PANE_NUM_SIGNALS] = {0};
typedef struct _PublishingRajceParamSpecPublishingParameters PublishingRajceParamSpecPublishingParameters;
typedef struct _PublishingRajceSessionPrivate PublishingRajceSessionPrivate;

#define PUBLISHING_RAJCE_TYPE_ARG_ITEM (publishing_rajce_arg_item_get_type ())
#define PUBLISHING_RAJCE_ARG_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_RAJCE_TYPE_ARG_ITEM, PublishingRajceArgItem))
#define PUBLISHING_RAJCE_ARG_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_RAJCE_TYPE_ARG_ITEM, PublishingRajceArgItemClass))
#define PUBLISHING_RAJCE_IS_ARG_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_RAJCE_TYPE_ARG_ITEM))
#define PUBLISHING_RAJCE_IS_ARG_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_RAJCE_TYPE_ARG_ITEM))
#define PUBLISHING_RAJCE_ARG_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_RAJCE_TYPE_ARG_ITEM, PublishingRajceArgItemClass))

typedef struct _PublishingRajceArgItem PublishingRajceArgItem;
typedef struct _PublishingRajceArgItemClass PublishingRajceArgItemClass;
typedef struct _PublishingRajceArgItemPrivate PublishingRajceArgItemPrivate;
#define _publishing_rajce_arg_item_unref0(var) ((var == NULL) ? NULL : (var = (publishing_rajce_arg_item_unref (var), NULL)))
typedef struct _PublishingRajceParamSpecArgItem PublishingRajceParamSpecArgItem;

#define PUBLISHING_RAJCE_TYPE_LIVE_API_REQUEST (publishing_rajce_live_api_request_get_type ())
#define PUBLISHING_RAJCE_LIVE_API_REQUEST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_RAJCE_TYPE_LIVE_API_REQUEST, PublishingRajceLiveApiRequest))
#define PUBLISHING_RAJCE_LIVE_API_REQUEST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_RAJCE_TYPE_LIVE_API_REQUEST, PublishingRajceLiveApiRequestClass))
#define PUBLISHING_RAJCE_IS_LIVE_API_REQUEST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_RAJCE_TYPE_LIVE_API_REQUEST))
#define PUBLISHING_RAJCE_IS_LIVE_API_REQUEST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_RAJCE_TYPE_LIVE_API_REQUEST))
#define PUBLISHING_RAJCE_LIVE_API_REQUEST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_RAJCE_TYPE_LIVE_API_REQUEST, PublishingRajceLiveApiRequestClass))

typedef struct _PublishingRajceLiveApiRequest PublishingRajceLiveApiRequest;
typedef struct _PublishingRajceLiveApiRequestClass PublishingRajceLiveApiRequestClass;
typedef struct _PublishingRajceLiveApiRequestPrivate PublishingRajceLiveApiRequestPrivate;
typedef struct _PublishingRajceParamSpecLiveApiRequest PublishingRajceParamSpecLiveApiRequest;
typedef struct _PublishingRajceTransactionPrivate PublishingRajceTransactionPrivate;
typedef struct _PublishingRajceSessionLoginTransactionPrivate PublishingRajceSessionLoginTransactionPrivate;
#define _publishing_rajce_live_api_request_unref0(var) ((var == NULL) ? NULL : (var = (publishing_rajce_live_api_request_unref (var), NULL)))
typedef struct _PublishingRajceGetAlbumsTransactionPrivate PublishingRajceGetAlbumsTransactionPrivate;
typedef struct _PublishingRajceCreateAlbumTransactionPrivate PublishingRajceCreateAlbumTransactionPrivate;
typedef struct _PublishingRajceOpenAlbumTransactionPrivate PublishingRajceOpenAlbumTransactionPrivate;
typedef struct _PublishingRajceGetAlbumUrlTransactionPrivate PublishingRajceGetAlbumUrlTransactionPrivate;
typedef struct _PublishingRajceCloseAlbumTransactionPrivate PublishingRajceCloseAlbumTransactionPrivate;

#define PUBLISHING_RAJCE_TYPE_GET_CATEGORIES_TRANSACTION (publishing_rajce_get_categories_transaction_get_type ())
#define PUBLISHING_RAJCE_GET_CATEGORIES_TRANSACTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_RAJCE_TYPE_GET_CATEGORIES_TRANSACTION, PublishingRajceGetCategoriesTransaction))
#define PUBLISHING_RAJCE_GET_CATEGORIES_TRANSACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_RAJCE_TYPE_GET_CATEGORIES_TRANSACTION, PublishingRajceGetCategoriesTransactionClass))
#define PUBLISHING_RAJCE_IS_GET_CATEGORIES_TRANSACTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_RAJCE_TYPE_GET_CATEGORIES_TRANSACTION))
#define PUBLISHING_RAJCE_IS_GET_CATEGORIES_TRANSACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_RAJCE_TYPE_GET_CATEGORIES_TRANSACTION))
#define PUBLISHING_RAJCE_GET_CATEGORIES_TRANSACTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_RAJCE_TYPE_GET_CATEGORIES_TRANSACTION, PublishingRajceGetCategoriesTransactionClass))

typedef struct _PublishingRajceGetCategoriesTransaction PublishingRajceGetCategoriesTransaction;
typedef struct _PublishingRajceGetCategoriesTransactionClass PublishingRajceGetCategoriesTransactionClass;
typedef struct _PublishingRajceGetCategoriesTransactionPrivate PublishingRajceGetCategoriesTransactionPrivate;
typedef struct _PublishingRajceAddPhotoTransactionPrivate PublishingRajceAddPhotoTransactionPrivate;
#define _g_hash_table_unref0(var) ((var == NULL) ? NULL : (var = (g_hash_table_unref (var), NULL)))
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);
#define _vala_return_if_fail(expr, msg) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return; }
#define _vala_return_val_if_fail(expr, msg, val) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return val; }
#define _vala_warn_if_fail(expr, msg) if G_LIKELY (expr) ; else g_warn_message (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _RajceService {
	GObject parent_instance;
	RajceServicePrivate * priv;
};

struct _RajceServiceClass {
	GObjectClass parent_class;
};

struct _PublishingRajceRajcePublisher {
	GObject parent_instance;
	PublishingRajceRajcePublisherPrivate * priv;
};

struct _PublishingRajceRajcePublisherClass {
	GObjectClass parent_class;
};

struct _PublishingRajceRajcePublisherPrivate {
	SpitPublishingPluginHost* host;
	SpitPublishingProgressCallback progress_reporter;
	gpointer progress_reporter_target;
	GDestroyNotify progress_reporter_target_destroy_notify;
	SpitPublishingService* service;
	gboolean running;
	PublishingRajceSession* session;
	PublishingRajceAlbum** albums;
	gint albums_length1;
	gint _albums_size_;
	PublishingRajcePublishingParameters* parameters;
	SpitPublishingPublisherMediaType media_type;
};

typedef enum  {
	PUBLISHING_RAJCE_AUTHENTICATION_PANE_MODE_INTRO,
	PUBLISHING_RAJCE_AUTHENTICATION_PANE_MODE_FAILED_RETRY_USER
} PublishingRajceAuthenticationPaneMode;

struct _PublishingRajcePublishingParameters {
	GTypeInstance parent_instance;
	volatile int ref_count;
	PublishingRajcePublishingParametersPrivate * priv;
	gchar* album_name;
	gboolean* album_hidden;
	gint* album_id;
};

struct _PublishingRajcePublishingParametersClass {
	GTypeClass parent_class;
	void (*finalize) (PublishingRajcePublishingParameters *self);
};

struct _PublishingRajceAlbum {
	GTypeInstance parent_instance;
	volatile int ref_count;
	PublishingRajceAlbumPrivate * priv;
	gint id;
	gchar* albumName;
	gchar* url;
	gchar* thumbUrl;
	gchar* createDate;
	gchar* updateDate;
	gboolean hidden;
	gboolean secure;
	gint photoCount;
};

struct _PublishingRajceAlbumClass {
	GTypeClass parent_class;
	void (*finalize) (PublishingRajceAlbum *self);
};

struct _PublishingRajceParamSpecAlbum {
	GParamSpec parent_instance;
};

struct _PublishingRajceUploader {
	PublishingRESTSupportBatchUploader parent_instance;
	PublishingRajceUploaderPrivate * priv;
};

struct _PublishingRajceUploaderClass {
	PublishingRESTSupportBatchUploaderClass parent_class;
};

struct _PublishingRajceUploaderPrivate {
	PublishingRajcePublishingParameters* parameters;
	gchar* url;
};

struct _PublishingRajceAuthenticationPane {
	GObject parent_instance;
	PublishingRajceAuthenticationPanePrivate * priv;
};

struct _PublishingRajceAuthenticationPaneClass {
	GObjectClass parent_class;
};

struct _PublishingRajceAuthenticationPanePrivate {
	GtkBox* pane_widget;
	GtkBuilder* builder;
	GtkEntry* username_entry;
	GtkEntry* password_entry;
	GtkCheckButton* remember_checkbutton;
	GtkButton* login_button;
	gboolean crypt;
};

struct _PublishingRajcePublishingOptionsPane {
	GObject parent_instance;
	PublishingRajcePublishingOptionsPanePrivate * priv;
};

struct _PublishingRajcePublishingOptionsPaneClass {
	GObjectClass parent_class;
};

struct _PublishingRajcePublishingOptionsPanePrivate {
	PublishingRajceRajcePublisher* publisher;
	PublishingRajceAlbum** albums;
	gint albums_length1;
	gint _albums_size_;
	gchar* username;
	GtkBuilder* builder;
	GtkBox* pane_widget;
	GtkLabel* login_identity_label;
	GtkLabel* publish_to_label;
	GtkRadioButton* use_existing_radio;
	GtkComboBoxText* existing_albums_combo;
	GtkRadioButton* create_new_radio;
	GtkEntry* new_album_entry;
	GtkCheckButton* hide_check;
	GtkCheckButton* show_check;
	GtkButton* publish_button;
	GtkButton* logout_button;
};

struct _PublishingRajceParamSpecPublishingParameters {
	GParamSpec parent_instance;
};

struct _PublishingRajceSession {
	PublishingRESTSupportSession parent_instance;
	PublishingRajceSessionPrivate * priv;
};

struct _PublishingRajceSessionClass {
	PublishingRESTSupportSessionClass parent_class;
};

struct _PublishingRajceSessionPrivate {
	gchar* usertoken;
	gchar* albumtoken;
	gchar* albumticket;
	gchar* username;
	gint* userid;
	gint* maxsize;
	gint* quality;
};

struct _PublishingRajceArgItem {
	GTypeInstance parent_instance;
	volatile int ref_count;
	PublishingRajceArgItemPrivate * priv;
	gchar* key;
	gchar* val;
	PublishingRajceArgItem** children;
	gint children_length1;
	gint _children_size_;
};

struct _PublishingRajceArgItemClass {
	GTypeClass parent_class;
	void (*finalize) (PublishingRajceArgItem *self);
};

struct _PublishingRajceParamSpecArgItem {
	GParamSpec parent_instance;
};

struct _PublishingRajceLiveApiRequest {
	GTypeInstance parent_instance;
	volatile int ref_count;
	PublishingRajceLiveApiRequestPrivate * priv;
};

struct _PublishingRajceLiveApiRequestClass {
	GTypeClass parent_class;
	void (*finalize) (PublishingRajceLiveApiRequest *self);
};

struct _PublishingRajceLiveApiRequestPrivate {
	PublishingRajceArgItem** _params;
	gint _params_length1;
	gint __params_size_;
	gchar* _cmd;
};

struct _PublishingRajceParamSpecLiveApiRequest {
	GParamSpec parent_instance;
};

struct _PublishingRajceTransaction {
	PublishingRESTSupportTransaction parent_instance;
	PublishingRajceTransactionPrivate * priv;
};

struct _PublishingRajceTransactionClass {
	PublishingRESTSupportTransactionClass parent_class;
};

struct _PublishingRajceSessionLoginTransaction {
	PublishingRajceTransaction parent_instance;
	PublishingRajceSessionLoginTransactionPrivate * priv;
};

struct _PublishingRajceSessionLoginTransactionClass {
	PublishingRajceTransactionClass parent_class;
};

struct _PublishingRajceGetAlbumsTransaction {
	PublishingRajceTransaction parent_instance;
	PublishingRajceGetAlbumsTransactionPrivate * priv;
};

struct _PublishingRajceGetAlbumsTransactionClass {
	PublishingRajceTransactionClass parent_class;
};

struct _PublishingRajceCreateAlbumTransaction {
	PublishingRajceTransaction parent_instance;
	PublishingRajceCreateAlbumTransactionPrivate * priv;
};

struct _PublishingRajceCreateAlbumTransactionClass {
	PublishingRajceTransactionClass parent_class;
};

struct _PublishingRajceOpenAlbumTransaction {
	PublishingRajceTransaction parent_instance;
	PublishingRajceOpenAlbumTransactionPrivate * priv;
};

struct _PublishingRajceOpenAlbumTransactionClass {
	PublishingRajceTransactionClass parent_class;
};

struct _PublishingRajceGetAlbumUrlTransaction {
	PublishingRajceTransaction parent_instance;
	PublishingRajceGetAlbumUrlTransactionPrivate * priv;
};

struct _PublishingRajceGetAlbumUrlTransactionClass {
	PublishingRajceTransactionClass parent_class;
};

struct _PublishingRajceCloseAlbumTransaction {
	PublishingRajceTransaction parent_instance;
	PublishingRajceCloseAlbumTransactionPrivate * priv;
};

struct _PublishingRajceCloseAlbumTransactionClass {
	PublishingRajceTransactionClass parent_class;
};

struct _PublishingRajceGetCategoriesTransaction {
	PublishingRajceTransaction parent_instance;
	PublishingRajceGetCategoriesTransactionPrivate * priv;
};

struct _PublishingRajceGetCategoriesTransactionClass {
	PublishingRajceTransactionClass parent_class;
};

struct _PublishingRajceAddPhotoTransaction {
	PublishingRESTSupportUploadTransaction parent_instance;
	PublishingRajceAddPhotoTransactionPrivate * priv;
};

struct _PublishingRajceAddPhotoTransactionClass {
	PublishingRESTSupportUploadTransactionClass parent_class;
};

struct _PublishingRajceAddPhotoTransactionPrivate {
	PublishingRajcePublishingParameters* parameters;
};


static gpointer rajce_service_parent_class = NULL;
static GdkPixbuf** rajce_service_icon_pixbuf_set;
static gint rajce_service_icon_pixbuf_set_length1;
static GdkPixbuf** rajce_service_icon_pixbuf_set = NULL;
static gint rajce_service_icon_pixbuf_set_length1 = 0;
static gint _rajce_service_icon_pixbuf_set_size_ = 0;
static SpitPluggableIface * rajce_service_spit_pluggable_parent_iface = NULL;
static SpitPublishingServiceIface * rajce_service_spit_publishing_service_parent_iface = NULL;
static gpointer publishing_rajce_rajce_publisher_parent_class = NULL;
static SpitPublishingPublisherIface * publishing_rajce_rajce_publisher_spit_publishing_publisher_parent_iface = NULL;
static gpointer publishing_rajce_album_parent_class = NULL;
static gpointer publishing_rajce_uploader_parent_class = NULL;
static gpointer publishing_rajce_authentication_pane_parent_class = NULL;
static gchar* publishing_rajce_authentication_pane_INTRO_MESSAGE;
static gchar* publishing_rajce_authentication_pane_INTRO_MESSAGE = NULL;
static gchar* publishing_rajce_authentication_pane_FAILED_RETRY_USER_MESSAGE;
static gchar* publishing_rajce_authentication_pane_FAILED_RETRY_USER_MESSAGE = NULL;
static SpitPublishingDialogPaneIface * publishing_rajce_authentication_pane_spit_publishing_dialog_pane_parent_iface = NULL;
static gpointer publishing_rajce_publishing_options_pane_parent_class = NULL;
static SpitPublishingDialogPaneIface * publishing_rajce_publishing_options_pane_spit_publishing_dialog_pane_parent_iface = NULL;
static gpointer publishing_rajce_publishing_parameters_parent_class = NULL;
static gpointer publishing_rajce_session_parent_class = NULL;
static gpointer publishing_rajce_arg_item_parent_class = NULL;
static gpointer publishing_rajce_live_api_request_parent_class = NULL;
static gpointer publishing_rajce_transaction_parent_class = NULL;
static gpointer publishing_rajce_session_login_transaction_parent_class = NULL;
static gpointer publishing_rajce_get_albums_transaction_parent_class = NULL;
static gpointer publishing_rajce_create_album_transaction_parent_class = NULL;
static gpointer publishing_rajce_open_album_transaction_parent_class = NULL;
static gpointer publishing_rajce_get_album_url_transaction_parent_class = NULL;
static gpointer publishing_rajce_close_album_transaction_parent_class = NULL;
static gpointer publishing_rajce_get_categories_transaction_parent_class = NULL;
static gpointer publishing_rajce_add_photo_transaction_parent_class = NULL;

GType rajce_service_get_type (void) G_GNUC_CONST;
#define RAJCE_SERVICE_ICON_FILENAME "rajce.png"
RajceService* rajce_service_new (GFile* resource_directory);
RajceService* rajce_service_construct (GType object_type,
                                       GFile* resource_directory);
static gint rajce_service_real_get_pluggable_interface (SpitPluggable* base,
                                                 gint min_host_interface,
                                                 gint max_host_interface);
static const gchar* rajce_service_real_get_id (SpitPluggable* base);
static const gchar* rajce_service_real_get_pluggable_name (SpitPluggable* base);
static void rajce_service_real_get_info (SpitPluggable* base,
                                  SpitPluggableInfo* info);
static GdkPixbuf** _vala_array_dup4 (GdkPixbuf** self,
                              int length);
static SpitPublishingPublisher* rajce_service_real_create_publisher (SpitPublishingService* base,
                                                              SpitPublishingPluginHost* host);
PublishingRajceRajcePublisher* publishing_rajce_rajce_publisher_new (SpitPublishingService* service,
                                                                     SpitPublishingPluginHost* host);
PublishingRajceRajcePublisher* publishing_rajce_rajce_publisher_construct (GType object_type,
                                                                           SpitPublishingService* service,
                                                                           SpitPublishingPluginHost* host);
GType publishing_rajce_rajce_publisher_get_type (void) G_GNUC_CONST;
static SpitPublishingPublisherMediaType rajce_service_real_get_supported_media (SpitPublishingService* base);
static void rajce_service_real_activation (SpitPluggable* base,
                                    gboolean enabled);
static void rajce_service_finalize (GObject * obj);
GType publishing_rajce_session_get_type (void) G_GNUC_CONST;
gpointer publishing_rajce_album_ref (gpointer instance);
void publishing_rajce_album_unref (gpointer instance);
GParamSpec* publishing_rajce_param_spec_album (const gchar* name,
                                               const gchar* nick,
                                               const gchar* blurb,
                                               GType object_type,
                                               GParamFlags flags);
void publishing_rajce_value_set_album (GValue* value,
                                       gpointer v_object);
void publishing_rajce_value_take_album (GValue* value,
                                        gpointer v_object);
gpointer publishing_rajce_value_get_album (const GValue* value);
GType publishing_rajce_album_get_type (void) G_GNUC_CONST;
gpointer publishing_rajce_publishing_parameters_ref (gpointer instance);
void publishing_rajce_publishing_parameters_unref (gpointer instance);
GParamSpec* publishing_rajce_param_spec_publishing_parameters (const gchar* name,
                                                               const gchar* nick,
                                                               const gchar* blurb,
                                                               GType object_type,
                                                               GParamFlags flags);
void publishing_rajce_value_set_publishing_parameters (GValue* value,
                                                       gpointer v_object);
void publishing_rajce_value_take_publishing_parameters (GValue* value,
                                                        gpointer v_object);
gpointer publishing_rajce_value_get_publishing_parameters (const GValue* value);
GType publishing_rajce_publishing_parameters_get_type (void) G_GNUC_CONST;
#define PUBLISHING_RAJCE_RAJCE_PUBLISHER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PUBLISHING_RAJCE_TYPE_RAJCE_PUBLISHER, PublishingRajceRajcePublisherPrivate))
PublishingRajceSession* publishing_rajce_session_new (void);
PublishingRajceSession* publishing_rajce_session_construct (GType object_type);
static gchar* publishing_rajce_rajce_publisher_get_rajce_url (PublishingRajceRajcePublisher* self);
static SpitPublishingService* publishing_rajce_rajce_publisher_real_get_service (SpitPublishingPublisher* base);
SpitPublishingPluginHost* publishing_rajce_rajce_publisher_get_host (PublishingRajceRajcePublisher* self);
static gboolean publishing_rajce_rajce_publisher_real_is_running (SpitPublishingPublisher* base);
static void publishing_rajce_rajce_publisher_real_start (SpitPublishingPublisher* base);
static void publishing_rajce_rajce_publisher_do_fetch_albums (PublishingRajceRajcePublisher* self);
gchar* publishing_rajce_rajce_publisher_get_username (PublishingRajceRajcePublisher* self);
gchar* publishing_rajce_rajce_publisher_get_token (PublishingRajceRajcePublisher* self);
gboolean publishing_rajce_rajce_publisher_get_remember (PublishingRajceRajcePublisher* self);
static gboolean* _bool_dup (gboolean* self);
static void publishing_rajce_rajce_publisher_do_network_login (PublishingRajceRajcePublisher* self,
                                                        const gchar* username,
                                                        const gchar* token,
                                                        gboolean remember);
GType publishing_rajce_authentication_pane_mode_get_type (void) G_GNUC_CONST;
static void publishing_rajce_rajce_publisher_do_show_authentication_pane (PublishingRajceRajcePublisher* self,
                                                                   PublishingRajceAuthenticationPaneMode mode);
static void publishing_rajce_rajce_publisher_real_stop (SpitPublishingPublisher* base);
gchar* publishing_rajce_rajce_publisher_get_url (PublishingRajceRajcePublisher* self);
static void publishing_rajce_rajce_publisher_set_username (PublishingRajceRajcePublisher* self,
                                                    const gchar* username);
static void publishing_rajce_rajce_publisher_set_token (PublishingRajceRajcePublisher* self,
                                                 const gchar* token);
static void publishing_rajce_rajce_publisher_set_remember (PublishingRajceRajcePublisher* self,
                                                    gboolean remember);
gboolean publishing_rajce_rajce_publisher_get_hide_album (PublishingRajceRajcePublisher* self);
void publishing_rajce_rajce_publisher_set_hide_album (PublishingRajceRajcePublisher* self,
                                                      gboolean hide_album);
gboolean publishing_rajce_rajce_publisher_get_show_album (PublishingRajceRajcePublisher* self);
void publishing_rajce_rajce_publisher_set_show_album (PublishingRajceRajcePublisher* self,
                                                      gboolean show_album);
GType publishing_rajce_authentication_pane_get_type (void) G_GNUC_CONST;
PublishingRajceAuthenticationPane* publishing_rajce_authentication_pane_new (PublishingRajceRajcePublisher* publisher,
                                                                             PublishingRajceAuthenticationPaneMode mode);
PublishingRajceAuthenticationPane* publishing_rajce_authentication_pane_construct (GType object_type,
                                                                                   PublishingRajceRajcePublisher* publisher,
                                                                                   PublishingRajceAuthenticationPaneMode mode);
static void publishing_rajce_rajce_publisher_on_authentication_pane_login_clicked (PublishingRajceRajcePublisher* self,
                                                                            const gchar* username,
                                                                            const gchar* token,
                                                                            gboolean remember);
static void _publishing_rajce_rajce_publisher_on_authentication_pane_login_clicked_publishing_rajce_authentication_pane_login (PublishingRajceAuthenticationPane* _sender,
                                                                                                                        const gchar* user,
                                                                                                                        const gchar* token,
                                                                                                                        gboolean remember,
                                                                                                                        gpointer self);
GtkWidget* publishing_rajce_authentication_pane_get_default_widget (PublishingRajceAuthenticationPane* self);
GType publishing_rajce_transaction_get_type (void) G_GNUC_CONST;
GType publishing_rajce_session_login_transaction_get_type (void) G_GNUC_CONST;
PublishingRajceSessionLoginTransaction* publishing_rajce_session_login_transaction_new (PublishingRajceSession* session,
                                                                                        const gchar* url,
                                                                                        const gchar* username,
                                                                                        const gchar* token);
PublishingRajceSessionLoginTransaction* publishing_rajce_session_login_transaction_construct (GType object_type,
                                                                                              PublishingRajceSession* session,
                                                                                              const gchar* url,
                                                                                              const gchar* username,
                                                                                              const gchar* token);
static void publishing_rajce_rajce_publisher_on_login_network_error (PublishingRajceRajcePublisher* self,
                                                              PublishingRESTSupportTransaction* bad_txn,
                                                              GError* err);
static void _publishing_rajce_rajce_publisher_on_login_network_error_publishing_rest_support_transaction_network_error (PublishingRESTSupportTransaction* _sender,
                                                                                                                 GError* err,
                                                                                                                 gpointer self);
static void publishing_rajce_rajce_publisher_on_login_network_complete (PublishingRajceRajcePublisher* self,
                                                                 PublishingRESTSupportTransaction* txn);
static void _publishing_rajce_rajce_publisher_on_login_network_complete_publishing_rest_support_transaction_completed (PublishingRESTSupportTransaction* _sender,
                                                                                                                gpointer self);
static void publishing_rajce_rajce_publisher_do_show_error (PublishingRajceRajcePublisher* self,
                                                     GError* e);
gchar* publishing_rajce_transaction_validate_xml (PublishingRESTSupportXmlDocument* doc);
static gchar* _publishing_rajce_transaction_validate_xml_publishing_rest_support_xml_document_check_for_error_response (PublishingRESTSupportXmlDocument* doc,
                                                                                                                 gpointer self);
void publishing_rajce_session_authenticate (PublishingRajceSession* self,
                                            const gchar* token,
                                            const gchar* name,
                                            gint id,
                                            gint maxsize,
                                            gint quality);
GType publishing_rajce_get_albums_transaction_get_type (void) G_GNUC_CONST;
PublishingRajceGetAlbumsTransaction* publishing_rajce_get_albums_transaction_new (PublishingRajceSession* session,
                                                                                  const gchar* url);
PublishingRajceGetAlbumsTransaction* publishing_rajce_get_albums_transaction_construct (GType object_type,
                                                                                        PublishingRajceSession* session,
                                                                                        const gchar* url);
static void publishing_rajce_rajce_publisher_on_albums_fetch_error (PublishingRajceRajcePublisher* self,
                                                             PublishingRESTSupportTransaction* bad_txn,
                                                             GError* err);
static void _publishing_rajce_rajce_publisher_on_albums_fetch_error_publishing_rest_support_transaction_network_error (PublishingRESTSupportTransaction* _sender,
                                                                                                                GError* err,
                                                                                                                gpointer self);
static void publishing_rajce_rajce_publisher_on_albums_fetch_complete (PublishingRajceRajcePublisher* self,
                                                                PublishingRESTSupportTransaction* txn);
static void _publishing_rajce_rajce_publisher_on_albums_fetch_complete_publishing_rest_support_transaction_completed (PublishingRESTSupportTransaction* _sender,
                                                                                                               gpointer self);
PublishingRajceAlbum* publishing_rajce_album_new (gint id,
                                                  const gchar* albumName,
                                                  const gchar* url,
                                                  const gchar* thumbUrl,
                                                  const gchar* createDate,
                                                  const gchar* updateDate,
                                                  gboolean hidden,
                                                  gboolean secure,
                                                  gint photoCount);
PublishingRajceAlbum* publishing_rajce_album_construct (GType object_type,
                                                        gint id,
                                                        const gchar* albumName,
                                                        const gchar* url,
                                                        const gchar* thumbUrl,
                                                        const gchar* createDate,
                                                        const gchar* updateDate,
                                                        gboolean hidden,
                                                        gboolean secure,
                                                        gint photoCount);
gint publishing_rajce_album_compare_albums (PublishingRajceAlbum* a,
                                            PublishingRajceAlbum* b);
static gint _publishing_rajce_album_compare_albums_gcompare_data_func (gconstpointer a,
                                                                gconstpointer b,
                                                                gpointer self);
void publishing_rajce_session_set_usertoken (PublishingRajceSession* self,
                                             const gchar* usertoken);
static void publishing_rajce_rajce_publisher_do_show_publishing_options_pane (PublishingRajceRajcePublisher* self);
static void publishing_rajce_rajce_publisher_on_network_error (PublishingRajceRajcePublisher* self,
                                                        PublishingRESTSupportTransaction* bad_txn,
                                                        GError* err);
GType publishing_rajce_publishing_options_pane_get_type (void) G_GNUC_CONST;
gchar* publishing_rajce_session_get_username (PublishingRajceSession* self);
PublishingRajcePublishingOptionsPane* publishing_rajce_publishing_options_pane_new (PublishingRajceRajcePublisher* publisher,
                                                                                    const gchar* username,
                                                                                    PublishingRajceAlbum** albums,
                                                                                    int albums_length1);
PublishingRajcePublishingOptionsPane* publishing_rajce_publishing_options_pane_construct (GType object_type,
                                                                                          PublishingRajceRajcePublisher* publisher,
                                                                                          const gchar* username,
                                                                                          PublishingRajceAlbum** albums,
                                                                                          int albums_length1);
static void publishing_rajce_rajce_publisher_on_publishing_options_pane_logout_clicked (PublishingRajceRajcePublisher* self);
static void _publishing_rajce_rajce_publisher_on_publishing_options_pane_logout_clicked_publishing_rajce_publishing_options_pane_logout (PublishingRajcePublishingOptionsPane* _sender,
                                                                                                                                  gpointer self);
static void publishing_rajce_rajce_publisher_on_publishing_options_pane_publish_clicked (PublishingRajceRajcePublisher* self,
                                                                                  PublishingRajcePublishingParameters* parameters);
static void _publishing_rajce_rajce_publisher_on_publishing_options_pane_publish_clicked_publishing_rajce_publishing_options_pane_publish (PublishingRajcePublishingOptionsPane* _sender,
                                                                                                                                    PublishingRajcePublishingParameters* parameters,
                                                                                                                                    gpointer self);
GtkWidget* publishing_rajce_publishing_options_pane_get_default_widget (PublishingRajcePublishingOptionsPane* self);
void publishing_rajce_session_deauthenticate (PublishingRajceSession* self);
static void publishing_rajce_rajce_publisher_do_begin_upload (PublishingRajceRajcePublisher* self);
static gboolean _int_equal (const gint * s1,
                     const gint * s2);
GType publishing_rajce_create_album_transaction_get_type (void) G_GNUC_CONST;
PublishingRajceCreateAlbumTransaction* publishing_rajce_create_album_transaction_new (PublishingRajceSession* session,
                                                                                      const gchar* url,
                                                                                      const gchar* albumName,
                                                                                      gboolean hidden);
PublishingRajceCreateAlbumTransaction* publishing_rajce_create_album_transaction_construct (GType object_type,
                                                                                            PublishingRajceSession* session,
                                                                                            const gchar* url,
                                                                                            const gchar* albumName,
                                                                                            gboolean hidden);
static void publishing_rajce_rajce_publisher_on_create_album_error (PublishingRajceRajcePublisher* self,
                                                             PublishingRESTSupportTransaction* bad_txn,
                                                             GError* err);
static void _publishing_rajce_rajce_publisher_on_create_album_error_publishing_rest_support_transaction_network_error (PublishingRESTSupportTransaction* _sender,
                                                                                                                GError* err,
                                                                                                                gpointer self);
static void publishing_rajce_rajce_publisher_on_create_album_complete (PublishingRajceRajcePublisher* self,
                                                                PublishingRESTSupportTransaction* txn);
static void _publishing_rajce_rajce_publisher_on_create_album_complete_publishing_rest_support_transaction_completed (PublishingRESTSupportTransaction* _sender,
                                                                                                               gpointer self);
GType publishing_rajce_open_album_transaction_get_type (void) G_GNUC_CONST;
PublishingRajceOpenAlbumTransaction* publishing_rajce_open_album_transaction_new (PublishingRajceSession* session,
                                                                                  const gchar* url,
                                                                                  gint albumID);
PublishingRajceOpenAlbumTransaction* publishing_rajce_open_album_transaction_construct (GType object_type,
                                                                                        PublishingRajceSession* session,
                                                                                        const gchar* url,
                                                                                        gint albumID);
static void publishing_rajce_rajce_publisher_on_open_album_error (PublishingRajceRajcePublisher* self,
                                                           PublishingRESTSupportTransaction* bad_txn,
                                                           GError* err);
static void _publishing_rajce_rajce_publisher_on_open_album_error_publishing_rest_support_transaction_network_error (PublishingRESTSupportTransaction* _sender,
                                                                                                              GError* err,
                                                                                                              gpointer self);
static void publishing_rajce_rajce_publisher_on_open_album_complete (PublishingRajceRajcePublisher* self,
                                                              PublishingRESTSupportTransaction* txn);
static void _publishing_rajce_rajce_publisher_on_open_album_complete_publishing_rest_support_transaction_completed (PublishingRESTSupportTransaction* _sender,
                                                                                                             gpointer self);
static gint* _int_dup (gint* self);
void publishing_rajce_session_set_albumtoken (PublishingRajceSession* self,
                                              const gchar* albumtoken);
static void publishing_rajce_rajce_publisher_do_upload_photos (PublishingRajceRajcePublisher* self);
gint publishing_rajce_session_get_maxsize (PublishingRajceSession* self);
GType publishing_rajce_uploader_get_type (void) G_GNUC_CONST;
PublishingRajceUploader* publishing_rajce_uploader_new (PublishingRajceSession* session,
                                                        const gchar* url,
                                                        SpitPublishingPublishable** publishables,
                                                        int publishables_length1,
                                                        PublishingRajcePublishingParameters* parameters);
PublishingRajceUploader* publishing_rajce_uploader_construct (GType object_type,
                                                              PublishingRajceSession* session,
                                                              const gchar* url,
                                                              SpitPublishingPublishable** publishables,
                                                              int publishables_length1,
                                                              PublishingRajcePublishingParameters* parameters);
static void publishing_rajce_rajce_publisher_on_upload_photos_complete (PublishingRajceRajcePublisher* self,
                                                                 PublishingRESTSupportBatchUploader* uploader,
                                                                 gint num_published);
static void _publishing_rajce_rajce_publisher_on_upload_photos_complete_publishing_rest_support_batch_uploader_upload_complete (PublishingRESTSupportBatchUploader* _sender,
                                                                                                                         gint num_photos_published,
                                                                                                                         gpointer self);
static void publishing_rajce_rajce_publisher_on_upload_photos_error (PublishingRajceRajcePublisher* self,
                                                              PublishingRESTSupportBatchUploader* uploader,
                                                              GError* err);
static void _publishing_rajce_rajce_publisher_on_upload_photos_error_publishing_rest_support_batch_uploader_upload_error (PublishingRESTSupportBatchUploader* _sender,
                                                                                                                   GError* err,
                                                                                                                   gpointer self);
static void publishing_rajce_rajce_publisher_on_upload_photos_status_updated (PublishingRajceRajcePublisher* self,
                                                                       gint file_number,
                                                                       gdouble completed_fraction);
static void _publishing_rajce_rajce_publisher_on_upload_photos_status_updated_spit_publishing_progress_callback (gint file_number,
                                                                                                          gdouble fraction_complete,
                                                                                                          gpointer self);
static void publishing_rajce_rajce_publisher_do_end_upload (PublishingRajceRajcePublisher* self);
static void publishing_rajce_rajce_publisher_do_get_album_url (PublishingRajceRajcePublisher* self);
static void publishing_rajce_rajce_publisher_do_close_album (PublishingRajceRajcePublisher* self);
GType publishing_rajce_get_album_url_transaction_get_type (void) G_GNUC_CONST;
PublishingRajceGetAlbumUrlTransaction* publishing_rajce_get_album_url_transaction_new (PublishingRajceSession* session,
                                                                                       const gchar* url);
PublishingRajceGetAlbumUrlTransaction* publishing_rajce_get_album_url_transaction_construct (GType object_type,
                                                                                             PublishingRajceSession* session,
                                                                                             const gchar* url);
static void publishing_rajce_rajce_publisher_on_get_album_url_error (PublishingRajceRajcePublisher* self,
                                                              PublishingRESTSupportTransaction* bad_txn,
                                                              GError* err);
static void _publishing_rajce_rajce_publisher_on_get_album_url_error_publishing_rest_support_transaction_network_error (PublishingRESTSupportTransaction* _sender,
                                                                                                                 GError* err,
                                                                                                                 gpointer self);
static void publishing_rajce_rajce_publisher_on_get_album_url_complete (PublishingRajceRajcePublisher* self,
                                                                 PublishingRESTSupportTransaction* txn);
static void _publishing_rajce_rajce_publisher_on_get_album_url_complete_publishing_rest_support_transaction_completed (PublishingRESTSupportTransaction* _sender,
                                                                                                                gpointer self);
void publishing_rajce_session_set_albumticket (PublishingRajceSession* self,
                                               const gchar* albumticket);
GType publishing_rajce_close_album_transaction_get_type (void) G_GNUC_CONST;
PublishingRajceCloseAlbumTransaction* publishing_rajce_close_album_transaction_new (PublishingRajceSession* session,
                                                                                    const gchar* url);
PublishingRajceCloseAlbumTransaction* publishing_rajce_close_album_transaction_construct (GType object_type,
                                                                                          PublishingRajceSession* session,
                                                                                          const gchar* url);
static void publishing_rajce_rajce_publisher_on_close_album_error (PublishingRajceRajcePublisher* self,
                                                            PublishingRESTSupportTransaction* bad_txn,
                                                            GError* err);
static void _publishing_rajce_rajce_publisher_on_close_album_error_publishing_rest_support_transaction_network_error (PublishingRESTSupportTransaction* _sender,
                                                                                                               GError* err,
                                                                                                               gpointer self);
static void publishing_rajce_rajce_publisher_on_close_album_complete (PublishingRajceRajcePublisher* self,
                                                               PublishingRESTSupportTransaction* txn);
static void _publishing_rajce_rajce_publisher_on_close_album_complete_publishing_rest_support_transaction_completed (PublishingRESTSupportTransaction* _sender,
                                                                                                              gpointer self);
static void publishing_rajce_rajce_publisher_do_show_success_pane (PublishingRajceRajcePublisher* self);
gchar* publishing_rajce_session_get_albumticket (PublishingRajceSession* self);
static void publishing_rajce_rajce_publisher_do_show_error_message (PublishingRajceRajcePublisher* self,
                                                             const gchar* message);
static void publishing_rajce_rajce_publisher_finalize (GObject * obj);
static void publishing_rajce_album_finalize (PublishingRajceAlbum * obj);
#define PUBLISHING_RAJCE_UPLOADER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PUBLISHING_RAJCE_TYPE_UPLOADER, PublishingRajceUploaderPrivate))
static PublishingRESTSupportTransaction* publishing_rajce_uploader_real_create_transaction (PublishingRESTSupportBatchUploader* base,
                                                                                     SpitPublishingPublishable* publishable);
PublishingRajceAddPhotoTransaction* publishing_rajce_add_photo_transaction_new (PublishingRajceSession* session,
                                                                                const gchar* url,
                                                                                PublishingRajcePublishingParameters* parameters,
                                                                                SpitPublishingPublishable* publishable);
PublishingRajceAddPhotoTransaction* publishing_rajce_add_photo_transaction_construct (GType object_type,
                                                                                      PublishingRajceSession* session,
                                                                                      const gchar* url,
                                                                                      PublishingRajcePublishingParameters* parameters,
                                                                                      SpitPublishingPublishable* publishable);
GType publishing_rajce_add_photo_transaction_get_type (void) G_GNUC_CONST;
static void publishing_rajce_uploader_finalize (PublishingRESTSupportBatchUploader * obj);
#define PUBLISHING_RAJCE_AUTHENTICATION_PANE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PUBLISHING_RAJCE_TYPE_AUTHENTICATION_PANE, PublishingRajceAuthenticationPanePrivate))
static void publishing_rajce_authentication_pane_on_user_changed (PublishingRajceAuthenticationPane* self);
static void _publishing_rajce_authentication_pane_on_user_changed_gtk_editable_changed (GtkEditable* _sender,
                                                                                 gpointer self);
static void publishing_rajce_authentication_pane_on_password_changed (PublishingRajceAuthenticationPane* self);
static void _publishing_rajce_authentication_pane_on_password_changed_gtk_editable_changed (GtkEditable* _sender,
                                                                                     gpointer self);
static void publishing_rajce_authentication_pane_on_login_button_clicked (PublishingRajceAuthenticationPane* self);
static void _publishing_rajce_authentication_pane_on_login_button_clicked_gtk_button_clicked (GtkButton* _sender,
                                                                                       gpointer self);
static void publishing_rajce_authentication_pane_update_login_button_sensitivity (PublishingRajceAuthenticationPane* self);
static GtkWidget* publishing_rajce_authentication_pane_real_get_widget (SpitPublishingDialogPane* base);
static SpitPublishingDialogPaneGeometryOptions publishing_rajce_authentication_pane_real_get_preferred_geometry (SpitPublishingDialogPane* base);
static void publishing_rajce_authentication_pane_real_on_pane_installed (SpitPublishingDialogPane* base);
static void publishing_rajce_authentication_pane_real_on_pane_uninstalled (SpitPublishingDialogPane* base);
static void g_cclosure_user_marshal_VOID__STRING_STRING_BOOLEAN (GClosure * closure,
                                                          GValue * return_value,
                                                          guint n_param_values,
                                                          const GValue * param_values,
                                                          gpointer invocation_hint,
                                                          gpointer marshal_data);
static void publishing_rajce_authentication_pane_finalize (GObject * obj);
#define PUBLISHING_RAJCE_PUBLISHING_OPTIONS_PANE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PUBLISHING_RAJCE_TYPE_PUBLISHING_OPTIONS_PANE, PublishingRajcePublishingOptionsPanePrivate))
static PublishingRajceAlbum** _vala_array_dup5 (PublishingRajceAlbum** self,
                                         int length);
static void publishing_rajce_publishing_options_pane_on_use_existing_radio_clicked (PublishingRajcePublishingOptionsPane* self);
static void _publishing_rajce_publishing_options_pane_on_use_existing_radio_clicked_gtk_button_clicked (GtkButton* _sender,
                                                                                                 gpointer self);
static void publishing_rajce_publishing_options_pane_on_create_new_radio_clicked (PublishingRajcePublishingOptionsPane* self);
static void _publishing_rajce_publishing_options_pane_on_create_new_radio_clicked_gtk_button_clicked (GtkButton* _sender,
                                                                                               gpointer self);
static void publishing_rajce_publishing_options_pane_on_new_album_entry_changed (PublishingRajcePublishingOptionsPane* self);
static void _publishing_rajce_publishing_options_pane_on_new_album_entry_changed_gtk_editable_changed (GtkEditable* _sender,
                                                                                                gpointer self);
static void publishing_rajce_publishing_options_pane_on_logout_clicked (PublishingRajcePublishingOptionsPane* self);
static void _publishing_rajce_publishing_options_pane_on_logout_clicked_gtk_button_clicked (GtkButton* _sender,
                                                                                     gpointer self);
static void publishing_rajce_publishing_options_pane_on_publish_clicked (PublishingRajcePublishingOptionsPane* self);
static void _publishing_rajce_publishing_options_pane_on_publish_clicked_gtk_button_clicked (GtkButton* _sender,
                                                                                      gpointer self);
PublishingRajcePublishingParameters* publishing_rajce_publishing_parameters_new_to_new_album (const gchar* album_name,
                                                                                              gboolean album_hidden);
PublishingRajcePublishingParameters* publishing_rajce_publishing_parameters_construct_to_new_album (GType object_type,
                                                                                                    const gchar* album_name,
                                                                                                    gboolean album_hidden);
PublishingRajcePublishingParameters* publishing_rajce_publishing_parameters_new_to_existing_album (const gchar* album_name,
                                                                                                   gint album_id);
PublishingRajcePublishingParameters* publishing_rajce_publishing_parameters_construct_to_existing_album (GType object_type,
                                                                                                         const gchar* album_name,
                                                                                                         gint album_id);
static void publishing_rajce_publishing_options_pane_update_publish_button_sensitivity (PublishingRajcePublishingOptionsPane* self);
void publishing_rajce_publishing_options_pane_installed (PublishingRajcePublishingOptionsPane* self);
void publishing_rajce_publishing_options_pane_notify_publish (PublishingRajcePublishingOptionsPane* self,
                                                              PublishingRajcePublishingParameters* parameters);
void publishing_rajce_publishing_options_pane_notify_logout (PublishingRajcePublishingOptionsPane* self);
static GtkWidget* publishing_rajce_publishing_options_pane_real_get_widget (SpitPublishingDialogPane* base);
static SpitPublishingDialogPaneGeometryOptions publishing_rajce_publishing_options_pane_real_get_preferred_geometry (SpitPublishingDialogPane* base);
static void publishing_rajce_publishing_options_pane_real_on_pane_installed (SpitPublishingDialogPane* base);
static void _publishing_rajce_publishing_options_pane_notify_publish_publishing_rajce_publishing_options_pane_publish (PublishingRajcePublishingOptionsPane* _sender,
                                                                                                                PublishingRajcePublishingParameters* parameters,
                                                                                                                gpointer self);
static void _publishing_rajce_publishing_options_pane_notify_logout_publishing_rajce_publishing_options_pane_logout (PublishingRajcePublishingOptionsPane* _sender,
                                                                                                              gpointer self);
static void publishing_rajce_publishing_options_pane_real_on_pane_uninstalled (SpitPublishingDialogPane* base);
static void g_cclosure_user_marshal_VOID__PUBLISHING_RAJCE_PUBLISHING_PARAMETERS (GClosure * closure,
                                                                           GValue * return_value,
                                                                           guint n_param_values,
                                                                           const GValue * param_values,
                                                                           gpointer invocation_hint,
                                                                           gpointer marshal_data);
static void publishing_rajce_publishing_options_pane_finalize (GObject * obj);
static PublishingRajcePublishingParameters* publishing_rajce_publishing_parameters_new (void);
static PublishingRajcePublishingParameters* publishing_rajce_publishing_parameters_construct (GType object_type);
static void publishing_rajce_publishing_parameters_finalize (PublishingRajcePublishingParameters * obj);
#define PUBLISHING_RAJCE_SESSION_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PUBLISHING_RAJCE_TYPE_SESSION, PublishingRajceSessionPrivate))
static gboolean publishing_rajce_session_real_is_authenticated (PublishingRESTSupportSession* base);
gchar* publishing_rajce_session_get_usertoken (PublishingRajceSession* self);
gchar* publishing_rajce_session_get_albumtoken (PublishingRajceSession* self);
static void publishing_rajce_session_finalize (PublishingRESTSupportSession * obj);
gpointer publishing_rajce_arg_item_ref (gpointer instance);
void publishing_rajce_arg_item_unref (gpointer instance);
GParamSpec* publishing_rajce_param_spec_arg_item (const gchar* name,
                                                  const gchar* nick,
                                                  const gchar* blurb,
                                                  GType object_type,
                                                  GParamFlags flags);
void publishing_rajce_value_set_arg_item (GValue* value,
                                          gpointer v_object);
void publishing_rajce_value_take_arg_item (GValue* value,
                                           gpointer v_object);
gpointer publishing_rajce_value_get_arg_item (const GValue* value);
GType publishing_rajce_arg_item_get_type (void) G_GNUC_CONST;
PublishingRajceArgItem* publishing_rajce_arg_item_new (const gchar* k,
                                                       const gchar* v);
PublishingRajceArgItem* publishing_rajce_arg_item_construct (GType object_type,
                                                             const gchar* k,
                                                             const gchar* v);
void publishing_rajce_arg_item_AddChild (PublishingRajceArgItem* self,
                                         PublishingRajceArgItem* child);
static void _vala_array_add6 (PublishingRajceArgItem** * array,
                       int* length,
                       int* size,
                       PublishingRajceArgItem* value);
void publishing_rajce_arg_item_AddChildren (PublishingRajceArgItem* self,
                                            PublishingRajceArgItem** newchildren,
                                            int newchildren_length1);
static void publishing_rajce_arg_item_finalize (PublishingRajceArgItem * obj);
gpointer publishing_rajce_live_api_request_ref (gpointer instance);
void publishing_rajce_live_api_request_unref (gpointer instance);
GParamSpec* publishing_rajce_param_spec_live_api_request (const gchar* name,
                                                          const gchar* nick,
                                                          const gchar* blurb,
                                                          GType object_type,
                                                          GParamFlags flags);
void publishing_rajce_value_set_live_api_request (GValue* value,
                                                  gpointer v_object);
void publishing_rajce_value_take_live_api_request (GValue* value,
                                                   gpointer v_object);
gpointer publishing_rajce_value_get_live_api_request (const GValue* value);
GType publishing_rajce_live_api_request_get_type (void) G_GNUC_CONST;
#define PUBLISHING_RAJCE_LIVE_API_REQUEST_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PUBLISHING_RAJCE_TYPE_LIVE_API_REQUEST, PublishingRajceLiveApiRequestPrivate))
PublishingRajceLiveApiRequest* publishing_rajce_live_api_request_new (const gchar* cmd);
PublishingRajceLiveApiRequest* publishing_rajce_live_api_request_construct (GType object_type,
                                                                            const gchar* cmd);
void publishing_rajce_live_api_request_AddParam (PublishingRajceLiveApiRequest* self,
                                                 const gchar* name,
                                                 const gchar* val);
static void _vala_array_add7 (PublishingRajceArgItem** * array,
                       int* length,
                       int* size,
                       PublishingRajceArgItem* value);
void publishing_rajce_live_api_request_AddParamBool (PublishingRajceLiveApiRequest* self,
                                                     const gchar* name,
                                                     gboolean val);
void publishing_rajce_live_api_request_AddParamInt (PublishingRajceLiveApiRequest* self,
                                                    const gchar* name,
                                                    gint val);
void publishing_rajce_live_api_request_AddParamNode (PublishingRajceLiveApiRequest* self,
                                                     const gchar* name,
                                                     PublishingRajceArgItem** val,
                                                     int val_length1);
static void _vala_array_add8 (PublishingRajceArgItem** * array,
                       int* length,
                       int* size,
                       PublishingRajceArgItem* value);
gchar* publishing_rajce_live_api_request_Params2XmlString (PublishingRajceLiveApiRequest* self,
                                                           gboolean urlencode);
static void publishing_rajce_live_api_request_WriteParam (xmlNode* node,
                                                   PublishingRajceArgItem* arg);
static void publishing_rajce_live_api_request_finalize (PublishingRajceLiveApiRequest * obj);
PublishingRajceTransaction* publishing_rajce_transaction_new (PublishingRajceSession* session);
PublishingRajceTransaction* publishing_rajce_transaction_construct (GType object_type,
                                                                    PublishingRajceSession* session);
static void _vala_array_add9 (PublishingRajceArgItem** * array,
                       int* length,
                       int* size,
                       PublishingRajceArgItem* value);
static void _vala_array_add10 (PublishingRajceArgItem** * array,
                        int* length,
                        int* size,
                        PublishingRajceArgItem* value);
static void _vala_array_add11 (PublishingRajceArgItem** * array,
                        int* length,
                        int* size,
                        PublishingRajceArgItem* value);
static void _vala_array_add12 (PublishingRajceArgItem** * array,
                        int* length,
                        int* size,
                        PublishingRajceArgItem* value);
static void _vala_array_add13 (PublishingRajceArgItem** * array,
                        int* length,
                        int* size,
                        PublishingRajceArgItem* value);
GType publishing_rajce_get_categories_transaction_get_type (void) G_GNUC_CONST;
PublishingRajceGetCategoriesTransaction* publishing_rajce_get_categories_transaction_new (PublishingRajceSession* session,
                                                                                          const gchar* url);
PublishingRajceGetCategoriesTransaction* publishing_rajce_get_categories_transaction_construct (GType object_type,
                                                                                                PublishingRajceSession* session,
                                                                                                const gchar* url);
#define PUBLISHING_RAJCE_ADD_PHOTO_TRANSACTION_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PUBLISHING_RAJCE_TYPE_ADD_PHOTO_TRANSACTION, PublishingRajceAddPhotoTransactionPrivate))
static void _g_free0_ (gpointer var);
static void publishing_rajce_add_photo_transaction_finalize (PublishingRESTSupportTransaction * obj);
static void _vala_array_destroy (gpointer array,
                          gint array_length,
                          GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array,
                       gint array_length,
                       GDestroyNotify destroy_func);


RajceService*
rajce_service_construct (GType object_type,
                         GFile* resource_directory)
{
	RajceService * self = NULL;
	GdkPixbuf** _tmp0_;
	gint _tmp0__length1;
#line 13 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_val_if_fail (G_IS_FILE (resource_directory), NULL);
#line 13 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self = (RajceService*) g_object_new (object_type, NULL);
#line 15 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp0_ = rajce_service_icon_pixbuf_set;
#line 15 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp0__length1 = rajce_service_icon_pixbuf_set_length1;
#line 15 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	if (_tmp0_ == NULL) {
#line 1158 "RajcePublishing.c"
		gint _tmp1_;
		GdkPixbuf** _tmp2_;
#line 16 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp2_ = resources_load_from_resource (PLUGIN_RESOURCE_PATH "/" RAJCE_SERVICE_ICON_FILENAME, &_tmp1_);
#line 16 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		rajce_service_icon_pixbuf_set = (_vala_array_free (rajce_service_icon_pixbuf_set, rajce_service_icon_pixbuf_set_length1, (GDestroyNotify) g_object_unref), NULL);
#line 16 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		rajce_service_icon_pixbuf_set = _tmp2_;
#line 16 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		rajce_service_icon_pixbuf_set_length1 = _tmp1_;
#line 16 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_rajce_service_icon_pixbuf_set_size_ = rajce_service_icon_pixbuf_set_length1;
#line 1171 "RajcePublishing.c"
	}
#line 13 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	return self;
#line 1175 "RajcePublishing.c"
}


RajceService*
rajce_service_new (GFile* resource_directory)
{
#line 13 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	return rajce_service_construct (TYPE_RAJCE_SERVICE, resource_directory);
#line 1184 "RajcePublishing.c"
}


static gint
rajce_service_real_get_pluggable_interface (SpitPluggable* base,
                                            gint min_host_interface,
                                            gint max_host_interface)
{
	RajceService * self;
	gint result = 0;
#line 21 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_RAJCE_SERVICE, RajceService);
#line 23 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	result = spit_negotiate_interfaces (min_host_interface, max_host_interface, SPIT_PUBLISHING_CURRENT_INTERFACE);
#line 23 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	return result;
#line 1201 "RajcePublishing.c"
}


static const gchar*
rajce_service_real_get_id (SpitPluggable* base)
{
	RajceService * self;
	const gchar* result = NULL;
#line 27 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_RAJCE_SERVICE, RajceService);
#line 29 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	result = "org.yorba.shotwell.publishing.rajce";
#line 29 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	return result;
#line 1216 "RajcePublishing.c"
}


static const gchar*
rajce_service_real_get_pluggable_name (SpitPluggable* base)
{
	RajceService * self;
	const gchar* result = NULL;
#line 32 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_RAJCE_SERVICE, RajceService);
#line 34 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	result = "Rajce";
#line 34 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	return result;
#line 1231 "RajcePublishing.c"
}


static gpointer
_g_object_ref0 (gpointer self)
{
#line 47 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	return self ? g_object_ref (self) : NULL;
#line 1240 "RajcePublishing.c"
}


static GdkPixbuf**
_vala_array_dup4 (GdkPixbuf** self,
                  int length)
{
	GdkPixbuf** result;
	int i;
#line 47 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	result = g_new0 (GdkPixbuf*, length + 1);
#line 47 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	for (i = 0; i < length; i++) {
#line 1254 "RajcePublishing.c"
		GdkPixbuf* _tmp0_;
#line 47 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp0_ = _g_object_ref0 (self[i]);
#line 47 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		result[i] = _tmp0_;
#line 1260 "RajcePublishing.c"
	}
#line 47 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	return result;
#line 1264 "RajcePublishing.c"
}


static void
rajce_service_real_get_info (SpitPluggable* base,
                             SpitPluggableInfo* info)
{
	RajceService * self;
	gchar* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	gchar* _tmp4_;
	gchar* _tmp5_;
	gchar* _tmp6_;
	GdkPixbuf** _tmp7_;
	gint _tmp7__length1;
	GdkPixbuf** _tmp8_;
	gint _tmp8__length1;
#line 37 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_RAJCE_SERVICE, RajceService);
#line 37 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_if_fail (info != NULL);
#line 39 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp0_ = g_strdup ("rajce.net developers");
#line 39 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_free0 ((*info).authors);
#line 39 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	(*info).authors = _tmp0_;
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp1_ = g_strdup (_ ("Copyright © 2013 rajce.net"));
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_free0 ((*info).copyright);
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	(*info).copyright = _tmp1_;
#line 41 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp2_ = g_strdup (RESOURCES_TRANSLATORS);
#line 41 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_free0 ((*info).translators);
#line 41 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	(*info).translators = _tmp2_;
#line 42 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp3_ = g_strdup (_VERSION);
#line 42 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_free0 ((*info).version);
#line 42 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	(*info).version = _tmp3_;
#line 43 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp4_ = g_strdup (RESOURCES_WEBSITE_NAME);
#line 43 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_free0 ((*info).website_name);
#line 43 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	(*info).website_name = _tmp4_;
#line 44 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp5_ = g_strdup (RESOURCES_WEBSITE_URL);
#line 44 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_free0 ((*info).website_url);
#line 44 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	(*info).website_url = _tmp5_;
#line 45 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	(*info).is_license_wordwrapped = FALSE;
#line 46 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp6_ = g_strdup (RESOURCES_LICENSE);
#line 46 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_free0 ((*info).license);
#line 46 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	(*info).license = _tmp6_;
#line 47 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp7_ = rajce_service_icon_pixbuf_set;
#line 47 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp7__length1 = rajce_service_icon_pixbuf_set_length1;
#line 47 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp8_ = (_tmp7_ != NULL) ? _vala_array_dup4 (_tmp7_, _tmp7__length1) : ((gpointer) _tmp7_);
#line 47 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp8__length1 = _tmp7__length1;
#line 47 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	(*info).icons = (_vala_array_free ((*info).icons, (*info).icons_length1, (GDestroyNotify) g_object_unref), NULL);
#line 47 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	(*info).icons = _tmp8_;
#line 47 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	(*info).icons_length1 = _tmp8__length1;
#line 1346 "RajcePublishing.c"
}


static SpitPublishingPublisher*
rajce_service_real_create_publisher (SpitPublishingService* base,
                                     SpitPublishingPluginHost* host)
{
	RajceService * self;
	SpitPublishingPublisher* result = NULL;
	PublishingRajceRajcePublisher* _tmp0_;
#line 50 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_RAJCE_SERVICE, RajceService);
#line 50 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_val_if_fail (SPIT_PUBLISHING_IS_PLUGIN_HOST (host), NULL);
#line 52 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp0_ = publishing_rajce_rajce_publisher_new (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_SERVICE, SpitPublishingService), host);
#line 52 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	result = G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_PUBLISHING_TYPE_PUBLISHER, SpitPublishingPublisher);
#line 52 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	return result;
#line 1367 "RajcePublishing.c"
}


static SpitPublishingPublisherMediaType
rajce_service_real_get_supported_media (SpitPublishingService* base)
{
	RajceService * self;
	SpitPublishingPublisherMediaType result = 0;
#line 55 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_RAJCE_SERVICE, RajceService);
#line 57 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	result = SPIT_PUBLISHING_PUBLISHER_MEDIA_TYPE_PHOTO;
#line 57 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	return result;
#line 1382 "RajcePublishing.c"
}


static void
rajce_service_real_activation (SpitPluggable* base,
                               gboolean enabled)
{
	RajceService * self;
#line 60 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_RAJCE_SERVICE, RajceService);
#line 1393 "RajcePublishing.c"
}


static void
rajce_service_class_init (RajceServiceClass * klass)
{
#line 7 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	rajce_service_parent_class = g_type_class_peek_parent (klass);
#line 7 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	G_OBJECT_CLASS (klass)->finalize = rajce_service_finalize;
#line 1404 "RajcePublishing.c"
}


static void
rajce_service_spit_pluggable_interface_init (SpitPluggableIface * iface)
{
#line 7 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	rajce_service_spit_pluggable_parent_iface = g_type_interface_peek_parent (iface);
#line 7 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	iface->get_pluggable_interface = (gint (*) (SpitPluggable *, gint, gint)) rajce_service_real_get_pluggable_interface;
#line 7 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	iface->get_id = (const gchar* (*) (SpitPluggable *)) rajce_service_real_get_id;
#line 7 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	iface->get_pluggable_name = (const gchar* (*) (SpitPluggable *)) rajce_service_real_get_pluggable_name;
#line 7 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	iface->get_info = (void (*) (SpitPluggable *, SpitPluggableInfo*)) rajce_service_real_get_info;
#line 7 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	iface->activation = (void (*) (SpitPluggable *, gboolean)) rajce_service_real_activation;
#line 1423 "RajcePublishing.c"
}


static void
rajce_service_spit_publishing_service_interface_init (SpitPublishingServiceIface * iface)
{
#line 7 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	rajce_service_spit_publishing_service_parent_iface = g_type_interface_peek_parent (iface);
#line 7 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	iface->create_publisher = (SpitPublishingPublisher* (*) (SpitPublishingService *, SpitPublishingPluginHost*)) rajce_service_real_create_publisher;
#line 7 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	iface->get_supported_media = (SpitPublishingPublisherMediaType (*) (SpitPublishingService *)) rajce_service_real_get_supported_media;
#line 1436 "RajcePublishing.c"
}


static void
rajce_service_instance_init (RajceService * self)
{
}


static void
rajce_service_finalize (GObject * obj)
{
	RajceService * self;
#line 7 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_RAJCE_SERVICE, RajceService);
#line 7 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	G_OBJECT_CLASS (rajce_service_parent_class)->finalize (obj);
#line 1454 "RajcePublishing.c"
}


GType
rajce_service_get_type (void)
{
	static volatile gsize rajce_service_type_id__volatile = 0;
	if (g_once_init_enter (&rajce_service_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (RajceServiceClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) rajce_service_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (RajceService), 0, (GInstanceInitFunc) rajce_service_instance_init, NULL };
		static const GInterfaceInfo spit_pluggable_info = { (GInterfaceInitFunc) rajce_service_spit_pluggable_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		static const GInterfaceInfo spit_publishing_service_info = { (GInterfaceInitFunc) rajce_service_spit_publishing_service_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType rajce_service_type_id;
		rajce_service_type_id = g_type_register_static (G_TYPE_OBJECT, "RajceService", &g_define_type_info, 0);
		g_type_add_interface_static (rajce_service_type_id, SPIT_TYPE_PLUGGABLE, &spit_pluggable_info);
		g_type_add_interface_static (rajce_service_type_id, SPIT_PUBLISHING_TYPE_SERVICE, &spit_publishing_service_info);
		g_once_init_leave (&rajce_service_type_id__volatile, rajce_service_type_id);
	}
	return rajce_service_type_id__volatile;
}


PublishingRajceRajcePublisher*
publishing_rajce_rajce_publisher_construct (GType object_type,
                                            SpitPublishingService* service,
                                            SpitPublishingPluginHost* host)
{
	PublishingRajceRajcePublisher * self = NULL;
	SpitPublishingService* _tmp0_;
	SpitPublishingPluginHost* _tmp1_;
	PublishingRajceSession* _tmp2_;
	gint _tmp3_;
	SpitPublishingPublishable** _tmp4_;
#line 84 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_val_if_fail (SPIT_PUBLISHING_IS_SERVICE (service), NULL);
#line 84 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_val_if_fail (SPIT_PUBLISHING_IS_PLUGIN_HOST (host), NULL);
#line 84 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self = (PublishingRajceRajcePublisher*) g_object_new (object_type, NULL);
#line 86 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_debug ("RajcePublishing.vala:86: RajcePublisher created.");
#line 87 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp0_ = _g_object_ref0 (service);
#line 87 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_object_unref0 (self->priv->service);
#line 87 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self->priv->service = _tmp0_;
#line 88 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp1_ = _g_object_ref0 (host);
#line 88 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_object_unref0 (self->priv->host);
#line 88 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self->priv->host = _tmp1_;
#line 89 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp2_ = publishing_rajce_session_new ();
#line 89 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_publishing_rest_support_session_unref0 (self->priv->session);
#line 89 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self->priv->session = _tmp2_;
#line 91 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp4_ = spit_publishing_plugin_host_get_publishables (host, &_tmp3_);
#line 1515 "RajcePublishing.c"
	{
		SpitPublishingPublishable** p_collection = NULL;
		gint p_collection_length1 = 0;
		gint _p_collection_size_ = 0;
		gint p_it = 0;
#line 91 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		p_collection = _tmp4_;
#line 91 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		p_collection_length1 = _tmp3_;
#line 91 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		for (p_it = 0; p_it < _tmp3_; p_it = p_it + 1) {
#line 1527 "RajcePublishing.c"
			SpitPublishingPublishable* _tmp5_;
			SpitPublishingPublishable* p = NULL;
#line 91 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			_tmp5_ = _g_object_ref0 (p_collection[p_it]);
#line 91 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			p = _tmp5_;
#line 1534 "RajcePublishing.c"
			{
				SpitPublishingPublisherMediaType _tmp6_;
				SpitPublishingPublishable* _tmp7_;
#line 92 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
				_tmp6_ = self->priv->media_type;
#line 92 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
				_tmp7_ = p;
#line 92 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
				self->priv->media_type = _tmp6_ | spit_publishing_publishable_get_media_type (_tmp7_);
#line 91 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
				_g_object_unref0 (p);
#line 1546 "RajcePublishing.c"
			}
		}
#line 91 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		p_collection = (_vala_array_free (p_collection, p_collection_length1, (GDestroyNotify) g_object_unref), NULL);
#line 1551 "RajcePublishing.c"
	}
#line 84 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	return self;
#line 1555 "RajcePublishing.c"
}


PublishingRajceRajcePublisher*
publishing_rajce_rajce_publisher_new (SpitPublishingService* service,
                                      SpitPublishingPluginHost* host)
{
#line 84 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	return publishing_rajce_rajce_publisher_construct (PUBLISHING_RAJCE_TYPE_RAJCE_PUBLISHER, service, host);
#line 1565 "RajcePublishing.c"
}


static gchar*
publishing_rajce_rajce_publisher_get_rajce_url (PublishingRajceRajcePublisher* self)
{
	gchar* result = NULL;
	gchar* _tmp0_;
#line 95 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_val_if_fail (PUBLISHING_RAJCE_IS_RAJCE_PUBLISHER (self), NULL);
#line 97 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp0_ = g_strdup ("http://www.rajce.idnes.cz/liveAPI/index.php");
#line 97 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	result = _tmp0_;
#line 97 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	return result;
#line 1582 "RajcePublishing.c"
}


static SpitPublishingService*
publishing_rajce_rajce_publisher_real_get_service (SpitPublishingPublisher* base)
{
	PublishingRajceRajcePublisher * self;
	SpitPublishingService* result = NULL;
	SpitPublishingService* _tmp0_;
	SpitPublishingService* _tmp1_;
#line 102 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_RAJCE_TYPE_RAJCE_PUBLISHER, PublishingRajceRajcePublisher);
#line 102 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp0_ = self->priv->service;
#line 102 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 102 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	result = _tmp1_;
#line 102 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	return result;
#line 1603 "RajcePublishing.c"
}


SpitPublishingPluginHost*
publishing_rajce_rajce_publisher_get_host (PublishingRajceRajcePublisher* self)
{
	SpitPublishingPluginHost* result = NULL;
	SpitPublishingPluginHost* _tmp0_;
	SpitPublishingPluginHost* _tmp1_;
#line 103 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_val_if_fail (PUBLISHING_RAJCE_IS_RAJCE_PUBLISHER (self), NULL);
#line 103 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp0_ = self->priv->host;
#line 103 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 103 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	result = _tmp1_;
#line 103 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	return result;
#line 1623 "RajcePublishing.c"
}


static gboolean
publishing_rajce_rajce_publisher_real_is_running (SpitPublishingPublisher* base)
{
	PublishingRajceRajcePublisher * self;
	gboolean result = FALSE;
	gboolean _tmp0_;
#line 104 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_RAJCE_TYPE_RAJCE_PUBLISHER, PublishingRajceRajcePublisher);
#line 104 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp0_ = self->priv->running;
#line 104 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	result = _tmp0_;
#line 104 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	return result;
#line 1641 "RajcePublishing.c"
}


static gboolean*
_bool_dup (gboolean* self)
{
	gboolean* dup;
#line 124 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	dup = g_new0 (gboolean, 1);
#line 124 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	memcpy (dup, self, sizeof (gboolean));
#line 124 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	return dup;
#line 1655 "RajcePublishing.c"
}


static gpointer
__bool_dup0 (gpointer self)
{
#line 124 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	return self ? _bool_dup (self) : NULL;
#line 1664 "RajcePublishing.c"
}


static void
publishing_rajce_rajce_publisher_real_start (SpitPublishingPublisher* base)
{
	PublishingRajceRajcePublisher * self;
	PublishingRajceSession* _tmp0_;
#line 106 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_RAJCE_TYPE_RAJCE_PUBLISHER, PublishingRajceRajcePublisher);
#line 108 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	if (spit_publishing_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_PUBLISHER, SpitPublishingPublisher))) {
#line 109 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		return;
#line 1679 "RajcePublishing.c"
	}
#line 111 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_debug ("RajcePublishing.vala:111: RajcePublisher: start");
#line 112 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self->priv->running = TRUE;
#line 114 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp0_ = self->priv->session;
#line 114 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	if (publishing_rest_support_session_is_authenticated (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, PUBLISHING_REST_SUPPORT_TYPE_SESSION, PublishingRESTSupportSession))) {
#line 116 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		g_debug ("RajcePublishing.vala:116: RajcePublisher: session is authenticated.");
#line 117 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		publishing_rajce_rajce_publisher_do_fetch_albums (self);
#line 1693 "RajcePublishing.c"
	} else {
		gchar* persistent_username = NULL;
		gchar* _tmp1_;
		gchar* persistent_token = NULL;
		gchar* _tmp2_;
		gboolean* persistent_remember = NULL;
		gboolean _tmp3_;
		gboolean* _tmp4_;
		gboolean _tmp5_ = FALSE;
		const gchar* _tmp6_;
#line 121 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		g_debug ("RajcePublishing.vala:121: RajcePublisher: session is not authenticated" \
".");
#line 122 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp1_ = publishing_rajce_rajce_publisher_get_username (self);
#line 122 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		persistent_username = _tmp1_;
#line 123 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp2_ = publishing_rajce_rajce_publisher_get_token (self);
#line 123 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		persistent_token = _tmp2_;
#line 124 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp3_ = publishing_rajce_rajce_publisher_get_remember (self);
#line 124 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp4_ = __bool_dup0 (&_tmp3_);
#line 124 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		persistent_remember = _tmp4_;
#line 125 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp6_ = persistent_username;
#line 125 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		if (_tmp6_ != NULL) {
#line 1724 "RajcePublishing.c"
			const gchar* _tmp7_;
#line 125 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			_tmp7_ = persistent_token;
#line 125 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			_tmp5_ = _tmp7_ != NULL;
#line 1730 "RajcePublishing.c"
		} else {
#line 125 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			_tmp5_ = FALSE;
#line 1734 "RajcePublishing.c"
		}
#line 125 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		if (_tmp5_) {
#line 1738 "RajcePublishing.c"
			const gchar* _tmp8_;
			const gchar* _tmp9_;
			gboolean* _tmp10_;
#line 126 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			_tmp8_ = persistent_username;
#line 126 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			_tmp9_ = persistent_token;
#line 126 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			_tmp10_ = persistent_remember;
#line 126 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			publishing_rajce_rajce_publisher_do_network_login (self, _tmp8_, _tmp9_, *_tmp10_);
#line 1750 "RajcePublishing.c"
		} else {
#line 128 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			publishing_rajce_rajce_publisher_do_show_authentication_pane (self, PUBLISHING_RAJCE_AUTHENTICATION_PANE_MODE_INTRO);
#line 1754 "RajcePublishing.c"
		}
#line 114 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_g_free0 (persistent_remember);
#line 114 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_g_free0 (persistent_token);
#line 114 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_g_free0 (persistent_username);
#line 1762 "RajcePublishing.c"
	}
}


static void
publishing_rajce_rajce_publisher_real_stop (SpitPublishingPublisher* base)
{
	PublishingRajceRajcePublisher * self;
#line 132 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_RAJCE_TYPE_RAJCE_PUBLISHER, PublishingRajceRajcePublisher);
#line 134 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_debug ("RajcePublishing.vala:134: RajcePublisher: stop");
#line 135 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self->priv->running = FALSE;
#line 1777 "RajcePublishing.c"
}


gchar*
publishing_rajce_rajce_publisher_get_url (PublishingRajceRajcePublisher* self)
{
	gchar* result = NULL;
	gchar* _tmp0_;
#line 140 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_val_if_fail (PUBLISHING_RAJCE_IS_RAJCE_PUBLISHER (self), NULL);
#line 140 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp0_ = publishing_rajce_rajce_publisher_get_rajce_url (self);
#line 140 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	result = _tmp0_;
#line 140 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	return result;
#line 1794 "RajcePublishing.c"
}


gchar*
publishing_rajce_rajce_publisher_get_username (PublishingRajceRajcePublisher* self)
{
	gchar* result = NULL;
	SpitPublishingPluginHost* _tmp0_;
	gchar* _tmp1_;
#line 141 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_val_if_fail (PUBLISHING_RAJCE_IS_RAJCE_PUBLISHER (self), NULL);
#line 141 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp0_ = self->priv->host;
#line 141 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp1_ = spit_host_interface_get_config_string (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), "username", NULL);
#line 141 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	result = _tmp1_;
#line 141 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	return result;
#line 1814 "RajcePublishing.c"
}


static void
publishing_rajce_rajce_publisher_set_username (PublishingRajceRajcePublisher* self,
                                               const gchar* username)
{
	SpitPublishingPluginHost* _tmp0_;
#line 142 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_if_fail (PUBLISHING_RAJCE_IS_RAJCE_PUBLISHER (self));
#line 142 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_if_fail (username != NULL);
#line 142 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp0_ = self->priv->host;
#line 142 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	spit_host_interface_set_config_string (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), "username", username);
#line 1831 "RajcePublishing.c"
}


gchar*
publishing_rajce_rajce_publisher_get_token (PublishingRajceRajcePublisher* self)
{
	gchar* result = NULL;
	SpitPublishingPluginHost* _tmp0_;
	gchar* _tmp1_;
#line 143 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_val_if_fail (PUBLISHING_RAJCE_IS_RAJCE_PUBLISHER (self), NULL);
#line 143 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp0_ = self->priv->host;
#line 143 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp1_ = spit_host_interface_get_config_string (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), "token", NULL);
#line 143 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	result = _tmp1_;
#line 143 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	return result;
#line 1851 "RajcePublishing.c"
}


static void
publishing_rajce_rajce_publisher_set_token (PublishingRajceRajcePublisher* self,
                                            const gchar* token)
{
	SpitPublishingPluginHost* _tmp0_;
#line 144 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_if_fail (PUBLISHING_RAJCE_IS_RAJCE_PUBLISHER (self));
#line 144 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp0_ = self->priv->host;
#line 144 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	spit_host_interface_set_config_string (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), "token", token);
#line 1866 "RajcePublishing.c"
}


gboolean
publishing_rajce_rajce_publisher_get_remember (PublishingRajceRajcePublisher* self)
{
	gboolean result = FALSE;
	SpitPublishingPluginHost* _tmp0_;
#line 147 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_val_if_fail (PUBLISHING_RAJCE_IS_RAJCE_PUBLISHER (self), FALSE);
#line 147 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp0_ = self->priv->host;
#line 147 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	result = spit_host_interface_get_config_bool (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), "remember", FALSE);
#line 147 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	return result;
#line 1883 "RajcePublishing.c"
}


static void
publishing_rajce_rajce_publisher_set_remember (PublishingRajceRajcePublisher* self,
                                               gboolean remember)
{
	SpitPublishingPluginHost* _tmp0_;
#line 148 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_if_fail (PUBLISHING_RAJCE_IS_RAJCE_PUBLISHER (self));
#line 148 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp0_ = self->priv->host;
#line 148 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	spit_host_interface_set_config_bool (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), "remember", remember);
#line 1898 "RajcePublishing.c"
}


gboolean
publishing_rajce_rajce_publisher_get_hide_album (PublishingRajceRajcePublisher* self)
{
	gboolean result = FALSE;
	SpitPublishingPluginHost* _tmp0_;
#line 149 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_val_if_fail (PUBLISHING_RAJCE_IS_RAJCE_PUBLISHER (self), FALSE);
#line 149 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp0_ = self->priv->host;
#line 149 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	result = spit_host_interface_get_config_bool (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), "hide-album", FALSE);
#line 149 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	return result;
#line 1915 "RajcePublishing.c"
}


void
publishing_rajce_rajce_publisher_set_hide_album (PublishingRajceRajcePublisher* self,
                                                 gboolean hide_album)
{
	SpitPublishingPluginHost* _tmp0_;
#line 150 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_if_fail (PUBLISHING_RAJCE_IS_RAJCE_PUBLISHER (self));
#line 150 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp0_ = self->priv->host;
#line 150 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	spit_host_interface_set_config_bool (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), "hide-album", hide_album);
#line 1930 "RajcePublishing.c"
}


gboolean
publishing_rajce_rajce_publisher_get_show_album (PublishingRajceRajcePublisher* self)
{
	gboolean result = FALSE;
	SpitPublishingPluginHost* _tmp0_;
#line 151 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_val_if_fail (PUBLISHING_RAJCE_IS_RAJCE_PUBLISHER (self), FALSE);
#line 151 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp0_ = self->priv->host;
#line 151 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	result = spit_host_interface_get_config_bool (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), "show-album", TRUE);
#line 151 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	return result;
#line 1947 "RajcePublishing.c"
}


void
publishing_rajce_rajce_publisher_set_show_album (PublishingRajceRajcePublisher* self,
                                                 gboolean show_album)
{
	SpitPublishingPluginHost* _tmp0_;
#line 152 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_if_fail (PUBLISHING_RAJCE_IS_RAJCE_PUBLISHER (self));
#line 152 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp0_ = self->priv->host;
#line 152 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	spit_host_interface_set_config_bool (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), "show-album", show_album);
#line 1962 "RajcePublishing.c"
}


/**
     * Action that shows the authentication pane.
     */
static void
_publishing_rajce_rajce_publisher_on_authentication_pane_login_clicked_publishing_rajce_authentication_pane_login (PublishingRajceAuthenticationPane* _sender,
                                                                                                                   const gchar* user,
                                                                                                                   const gchar* token,
                                                                                                                   gboolean remember,
                                                                                                                   gpointer self)
{
#line 167 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rajce_rajce_publisher_on_authentication_pane_login_clicked ((PublishingRajceRajcePublisher*) self, user, token, remember);
#line 1978 "RajcePublishing.c"
}


static void
publishing_rajce_rajce_publisher_do_show_authentication_pane (PublishingRajceRajcePublisher* self,
                                                              PublishingRajceAuthenticationPaneMode mode)
{
	SpitPublishingPluginHost* _tmp0_;
	PublishingRajceAuthenticationPane* authentication_pane = NULL;
	PublishingRajceAuthenticationPane* _tmp1_;
	SpitPublishingPluginHost* _tmp2_;
	SpitPublishingPluginHost* _tmp3_;
	GtkWidget* _tmp4_;
	GtkWidget* _tmp5_;
#line 161 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_if_fail (PUBLISHING_RAJCE_IS_RAJCE_PUBLISHER (self));
#line 163 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_debug ("RajcePublishing.vala:163: ACTION: installing authentication pane");
#line 165 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp0_ = self->priv->host;
#line 165 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	spit_publishing_plugin_host_set_service_locked (_tmp0_, FALSE);
#line 166 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp1_ = publishing_rajce_authentication_pane_new (self, mode);
#line 166 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	authentication_pane = _tmp1_;
#line 167 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_signal_connect_object (authentication_pane, "login", (GCallback) _publishing_rajce_rajce_publisher_on_authentication_pane_login_clicked_publishing_rajce_authentication_pane_login, self, 0);
#line 168 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp2_ = self->priv->host;
#line 168 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	spit_publishing_plugin_host_install_dialog_pane (_tmp2_, G_TYPE_CHECK_INSTANCE_CAST (authentication_pane, SPIT_PUBLISHING_TYPE_DIALOG_PANE, SpitPublishingDialogPane), SPIT_PUBLISHING_PLUGIN_HOST_BUTTON_MODE_CLOSE);
#line 169 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp3_ = self->priv->host;
#line 169 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp4_ = publishing_rajce_authentication_pane_get_default_widget (authentication_pane);
#line 169 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp5_ = _tmp4_;
#line 169 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	spit_publishing_plugin_host_set_dialog_default_widget (_tmp3_, _tmp5_);
#line 169 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_object_unref0 (_tmp5_);
#line 161 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_object_unref0 (authentication_pane);
#line 2023 "RajcePublishing.c"
}


/**
     * Event triggered when the login button in the authentication panel is clicked.
     */
static void
publishing_rajce_rajce_publisher_on_authentication_pane_login_clicked (PublishingRajceRajcePublisher* self,
                                                                       const gchar* username,
                                                                       const gchar* token,
                                                                       gboolean remember)
{
	gboolean _tmp0_;
#line 175 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_if_fail (PUBLISHING_RAJCE_IS_RAJCE_PUBLISHER (self));
#line 175 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_if_fail (username != NULL);
#line 175 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_if_fail (token != NULL);
#line 177 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_debug ("RajcePublishing.vala:177: EVENT: on_authentication_pane_login_clicked");
#line 178 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp0_ = self->priv->running;
#line 178 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	if (!_tmp0_) {
#line 179 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		return;
#line 2051 "RajcePublishing.c"
	}
#line 180 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rajce_rajce_publisher_do_network_login (self, username, token, remember);
#line 2055 "RajcePublishing.c"
}


/**
     * Action to perform a network login to a Rajce service.
     */
static void
_publishing_rajce_rajce_publisher_on_login_network_error_publishing_rest_support_transaction_network_error (PublishingRESTSupportTransaction* _sender,
                                                                                                            GError* err,
                                                                                                            gpointer self)
{
#line 195 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rajce_rajce_publisher_on_login_network_error ((PublishingRajceRajcePublisher*) self, _sender, err);
#line 2069 "RajcePublishing.c"
}


static void
_publishing_rajce_rajce_publisher_on_login_network_complete_publishing_rest_support_transaction_completed (PublishingRESTSupportTransaction* _sender,
                                                                                                           gpointer self)
{
#line 196 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rajce_rajce_publisher_on_login_network_complete ((PublishingRajceRajcePublisher*) self, _sender);
#line 2079 "RajcePublishing.c"
}


static void
publishing_rajce_rajce_publisher_do_network_login (PublishingRajceRajcePublisher* self,
                                                   const gchar* username,
                                                   const gchar* token,
                                                   gboolean remember)
{
	SpitPublishingPluginHost* _tmp0_;
	SpitPublishingPluginHost* _tmp1_;
	const gchar* _tmp2_ = NULL;
	PublishingRajceSessionLoginTransaction* login_trans = NULL;
	PublishingRajceSession* _tmp3_;
	gchar* _tmp4_;
	gchar* _tmp5_;
	PublishingRajceSessionLoginTransaction* _tmp6_;
	PublishingRajceSessionLoginTransaction* _tmp7_;
	GError * _inner_error_ = NULL;
#line 186 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_if_fail (PUBLISHING_RAJCE_IS_RAJCE_PUBLISHER (self));
#line 186 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_if_fail (username != NULL);
#line 186 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_if_fail (token != NULL);
#line 188 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_debug ("RajcePublishing.vala:188: ACTION: logging in");
#line 189 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp0_ = self->priv->host;
#line 189 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	spit_publishing_plugin_host_set_service_locked (_tmp0_, TRUE);
#line 190 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp1_ = self->priv->host;
#line 190 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	spit_publishing_plugin_host_install_login_wait_pane (_tmp1_);
#line 191 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rajce_rajce_publisher_set_remember (self, remember);
#line 192 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rajce_rajce_publisher_set_username (self, username);
#line 193 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	if (remember) {
#line 193 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp2_ = token;
#line 2123 "RajcePublishing.c"
	} else {
#line 193 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp2_ = NULL;
#line 2127 "RajcePublishing.c"
	}
#line 193 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rajce_rajce_publisher_set_token (self, _tmp2_);
#line 194 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp3_ = self->priv->session;
#line 194 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp4_ = publishing_rajce_rajce_publisher_get_url (self);
#line 194 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp5_ = _tmp4_;
#line 194 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp6_ = publishing_rajce_session_login_transaction_new (_tmp3_, _tmp5_, username, token);
#line 194 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp7_ = _tmp6_;
#line 194 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_free0 (_tmp5_);
#line 194 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	login_trans = _tmp7_;
#line 195 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (login_trans, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "network-error", (GCallback) _publishing_rajce_rajce_publisher_on_login_network_error_publishing_rest_support_transaction_network_error, self, 0);
#line 196 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (login_trans, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "completed", (GCallback) _publishing_rajce_rajce_publisher_on_login_network_complete_publishing_rest_support_transaction_completed, self, 0);
#line 2149 "RajcePublishing.c"
	{
#line 199 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		publishing_rest_support_transaction_execute (G_TYPE_CHECK_INSTANCE_CAST (login_trans, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), &_inner_error_);
#line 199 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 199 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 2157 "RajcePublishing.c"
				goto __catch16_spit_publishing_publishing_error;
			}
#line 199 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			_publishing_rest_support_transaction_unref0 (login_trans);
#line 199 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 199 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			g_clear_error (&_inner_error_);
#line 199 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			return;
#line 2168 "RajcePublishing.c"
		}
	}
	goto __finally16;
	__catch16_spit_publishing_publishing_error:
	{
		GError* err = NULL;
		GError* _tmp8_;
#line 197 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		err = _inner_error_;
#line 197 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_inner_error_ = NULL;
#line 203 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		g_debug ("RajcePublishing.vala:203: ERROR: do_network_login");
#line 204 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp8_ = err;
#line 204 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		publishing_rajce_rajce_publisher_do_show_error (self, _tmp8_);
#line 197 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_g_error_free0 (err);
#line 2188 "RajcePublishing.c"
	}
	__finally16:
#line 197 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 197 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_publishing_rest_support_transaction_unref0 (login_trans);
#line 197 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 197 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		g_clear_error (&_inner_error_);
#line 197 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		return;
#line 2201 "RajcePublishing.c"
	}
#line 186 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_publishing_rest_support_transaction_unref0 (login_trans);
#line 2205 "RajcePublishing.c"
}


/**
     * Event triggered when the network login action is complete and successful.
     */
static gchar*
_publishing_rajce_transaction_validate_xml_publishing_rest_support_xml_document_check_for_error_response (PublishingRESTSupportXmlDocument* doc,
                                                                                                          gpointer self)
{
	gchar* result;
	result = publishing_rajce_transaction_validate_xml (doc);
#line 219 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	return result;
#line 2220 "RajcePublishing.c"
}


static void
publishing_rajce_rajce_publisher_on_login_network_complete (PublishingRajceRajcePublisher* self,
                                                            PublishingRESTSupportTransaction* txn)
{
	guint _tmp0_;
	guint _tmp1_;
	GError * _inner_error_ = NULL;
#line 211 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_if_fail (PUBLISHING_RAJCE_IS_RAJCE_PUBLISHER (self));
#line 211 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_if_fail (PUBLISHING_REST_SUPPORT_IS_TRANSACTION (txn));
#line 213 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_debug ("RajcePublishing.vala:213: EVENT: on_login_network_complete");
#line 214 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_signal_parse_name ("completed", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp0_, NULL, FALSE);
#line 214 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_signal_handlers_disconnect_matched (txn, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp0_, 0, NULL, (GCallback) _publishing_rajce_rajce_publisher_on_login_network_complete_publishing_rest_support_transaction_completed, self);
#line 215 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_signal_parse_name ("network-error", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp1_, NULL, FALSE);
#line 215 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_signal_handlers_disconnect_matched (txn, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _publishing_rajce_rajce_publisher_on_login_network_error_publishing_rest_support_transaction_network_error, self);
#line 2245 "RajcePublishing.c"
	{
		PublishingRESTSupportXmlDocument* doc = NULL;
		gchar* _tmp2_;
		gchar* _tmp3_;
		PublishingRESTSupportXmlDocument* _tmp4_;
		PublishingRESTSupportXmlDocument* _tmp5_;
		xmlNode* response = NULL;
		PublishingRESTSupportXmlDocument* _tmp6_;
		xmlNode* _tmp7_;
		xmlNode* sessionToken = NULL;
		PublishingRESTSupportXmlDocument* _tmp8_;
		xmlNode* _tmp9_;
		xmlNode* _tmp10_;
		xmlNode* maxWidth = NULL;
		PublishingRESTSupportXmlDocument* _tmp11_;
		xmlNode* _tmp12_;
		xmlNode* _tmp13_;
		xmlNode* maxHeight = NULL;
		PublishingRESTSupportXmlDocument* _tmp14_;
		xmlNode* _tmp15_;
		xmlNode* _tmp16_;
		xmlNode* quality = NULL;
		PublishingRESTSupportXmlDocument* _tmp17_;
		xmlNode* _tmp18_;
		xmlNode* _tmp19_;
		xmlNode* nick = NULL;
		PublishingRESTSupportXmlDocument* _tmp20_;
		xmlNode* _tmp21_;
		xmlNode* _tmp22_;
		gint maxW = 0;
		xmlNode* _tmp23_;
		gchar* _tmp24_;
		gchar* _tmp25_;
		gint _tmp26_;
		gint maxH = 0;
		xmlNode* _tmp27_;
		gchar* _tmp28_;
		gchar* _tmp29_;
		gint _tmp30_;
		gint _tmp31_;
		gint _tmp32_;
		PublishingRajceSession* _tmp34_;
		xmlNode* _tmp35_;
		gchar* _tmp36_;
		gchar* _tmp37_;
		xmlNode* _tmp38_;
		gchar* _tmp39_;
		gchar* _tmp40_;
		gint _tmp41_;
		xmlNode* _tmp42_;
		gchar* _tmp43_;
		gchar* _tmp44_;
#line 219 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp2_ = publishing_rest_support_transaction_get_response (txn);
#line 219 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp3_ = _tmp2_;
#line 219 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp4_ = publishing_rest_support_xml_document_parse_string (_tmp3_, _publishing_rajce_transaction_validate_xml_publishing_rest_support_xml_document_check_for_error_response, NULL, &_inner_error_);
#line 219 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp5_ = _tmp4_;
#line 219 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_g_free0 (_tmp3_);
#line 219 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		doc = _tmp5_;
#line 219 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 219 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 2314 "RajcePublishing.c"
				goto __catch17_spit_publishing_publishing_error;
			}
#line 219 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 219 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			g_clear_error (&_inner_error_);
#line 219 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			return;
#line 2323 "RajcePublishing.c"
		}
#line 220 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp6_ = doc;
#line 220 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp7_ = publishing_rest_support_xml_document_get_root_node (_tmp6_);
#line 220 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		response = _tmp7_;
#line 221 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp8_ = doc;
#line 221 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp9_ = response;
#line 221 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp10_ = publishing_rest_support_xml_document_get_named_child (_tmp8_, _tmp9_, "sessionToken", &_inner_error_);
#line 221 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		sessionToken = _tmp10_;
#line 221 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 221 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			_publishing_rest_support_xml_document_unref0 (doc);
#line 221 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 2345 "RajcePublishing.c"
				goto __catch17_spit_publishing_publishing_error;
			}
#line 221 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			_publishing_rest_support_xml_document_unref0 (doc);
#line 221 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 221 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			g_clear_error (&_inner_error_);
#line 221 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			return;
#line 2356 "RajcePublishing.c"
		}
#line 222 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp11_ = doc;
#line 222 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp12_ = response;
#line 222 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp13_ = publishing_rest_support_xml_document_get_named_child (_tmp11_, _tmp12_, "maxWidth", &_inner_error_);
#line 222 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		maxWidth = _tmp13_;
#line 222 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 222 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			_publishing_rest_support_xml_document_unref0 (doc);
#line 222 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 2372 "RajcePublishing.c"
				goto __catch17_spit_publishing_publishing_error;
			}
#line 222 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			_publishing_rest_support_xml_document_unref0 (doc);
#line 222 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 222 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			g_clear_error (&_inner_error_);
#line 222 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			return;
#line 2383 "RajcePublishing.c"
		}
#line 223 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp14_ = doc;
#line 223 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp15_ = response;
#line 223 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp16_ = publishing_rest_support_xml_document_get_named_child (_tmp14_, _tmp15_, "maxHeight", &_inner_error_);
#line 223 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		maxHeight = _tmp16_;
#line 223 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 223 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			_publishing_rest_support_xml_document_unref0 (doc);
#line 223 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 2399 "RajcePublishing.c"
				goto __catch17_spit_publishing_publishing_error;
			}
#line 223 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			_publishing_rest_support_xml_document_unref0 (doc);
#line 223 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 223 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			g_clear_error (&_inner_error_);
#line 223 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			return;
#line 2410 "RajcePublishing.c"
		}
#line 224 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp17_ = doc;
#line 224 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp18_ = response;
#line 224 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp19_ = publishing_rest_support_xml_document_get_named_child (_tmp17_, _tmp18_, "quality", &_inner_error_);
#line 224 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		quality = _tmp19_;
#line 224 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 224 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			_publishing_rest_support_xml_document_unref0 (doc);
#line 224 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 2426 "RajcePublishing.c"
				goto __catch17_spit_publishing_publishing_error;
			}
#line 224 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			_publishing_rest_support_xml_document_unref0 (doc);
#line 224 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 224 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			g_clear_error (&_inner_error_);
#line 224 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			return;
#line 2437 "RajcePublishing.c"
		}
#line 225 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp20_ = doc;
#line 225 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp21_ = response;
#line 225 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp22_ = publishing_rest_support_xml_document_get_named_child (_tmp20_, _tmp21_, "nick", &_inner_error_);
#line 225 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		nick = _tmp22_;
#line 225 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 225 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			_publishing_rest_support_xml_document_unref0 (doc);
#line 225 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 2453 "RajcePublishing.c"
				goto __catch17_spit_publishing_publishing_error;
			}
#line 225 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			_publishing_rest_support_xml_document_unref0 (doc);
#line 225 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 225 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			g_clear_error (&_inner_error_);
#line 225 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			return;
#line 2464 "RajcePublishing.c"
		}
#line 226 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp23_ = maxWidth;
#line 226 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp24_ = (gchar*) xmlNodeGetContent (_tmp23_);
#line 226 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp25_ = _tmp24_;
#line 226 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp26_ = atoi (_tmp25_);
#line 226 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_g_free0 (_tmp25_);
#line 226 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		maxW = _tmp26_;
#line 227 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp27_ = maxHeight;
#line 227 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp28_ = (gchar*) xmlNodeGetContent (_tmp27_);
#line 227 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp29_ = _tmp28_;
#line 227 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp30_ = atoi (_tmp29_);
#line 227 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_g_free0 (_tmp29_);
#line 227 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		maxH = _tmp30_;
#line 228 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp31_ = maxW;
#line 228 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp32_ = maxH;
#line 228 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		if (_tmp31_ > _tmp32_) {
#line 2496 "RajcePublishing.c"
			gint _tmp33_;
#line 230 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			_tmp33_ = maxW;
#line 230 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			maxH = _tmp33_;
#line 2502 "RajcePublishing.c"
		}
#line 232 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp34_ = self->priv->session;
#line 232 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp35_ = sessionToken;
#line 232 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp36_ = (gchar*) xmlNodeGetContent (_tmp35_);
#line 232 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp37_ = _tmp36_;
#line 232 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp38_ = nick;
#line 232 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp39_ = (gchar*) xmlNodeGetContent (_tmp38_);
#line 232 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp40_ = _tmp39_;
#line 232 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp41_ = maxH;
#line 232 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp42_ = quality;
#line 232 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp43_ = (gchar*) xmlNodeGetContent (_tmp42_);
#line 232 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp44_ = _tmp43_;
#line 232 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		publishing_rajce_session_authenticate (_tmp34_, _tmp37_, _tmp40_, 0, _tmp41_, atoi (_tmp44_));
#line 232 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_g_free0 (_tmp44_);
#line 232 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_g_free0 (_tmp40_);
#line 232 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_g_free0 (_tmp37_);
#line 217 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_publishing_rest_support_xml_document_unref0 (doc);
#line 2536 "RajcePublishing.c"
	}
	goto __finally17;
	__catch17_spit_publishing_publishing_error:
	{
		GError* err = NULL;
		gint code_int = 0;
		GError* _tmp45_;
		const gchar* _tmp46_;
		gint _tmp47_;
#line 217 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		err = _inner_error_;
#line 217 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_inner_error_ = NULL;
#line 236 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp45_ = err;
#line 236 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp46_ = _tmp45_->message;
#line 236 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		code_int = atoi (_tmp46_);
#line 237 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp47_ = code_int;
#line 237 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		if (_tmp47_ == 999) {
#line 239 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			g_debug ("RajcePublishing.vala:239: ERROR: on_login_network_complete, code 999");
#line 240 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			publishing_rajce_rajce_publisher_do_show_authentication_pane (self, PUBLISHING_RAJCE_AUTHENTICATION_PANE_MODE_FAILED_RETRY_USER);
#line 2564 "RajcePublishing.c"
		} else {
			GError* _tmp48_;
#line 244 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			g_debug ("RajcePublishing.vala:244: ERROR: on_login_network_complete");
#line 245 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			_tmp48_ = err;
#line 245 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			publishing_rajce_rajce_publisher_do_show_error (self, _tmp48_);
#line 2573 "RajcePublishing.c"
		}
#line 247 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_g_error_free0 (err);
#line 247 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		return;
#line 2579 "RajcePublishing.c"
	}
	__finally17:
#line 217 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 217 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 217 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		g_clear_error (&_inner_error_);
#line 217 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		return;
#line 2590 "RajcePublishing.c"
	}
#line 249 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rajce_rajce_publisher_do_fetch_albums (self);
#line 2594 "RajcePublishing.c"
}


/**
     * Event triggered when a network login action fails due to a network error.
     */
static void
publishing_rajce_rajce_publisher_on_login_network_error (PublishingRajceRajcePublisher* self,
                                                         PublishingRESTSupportTransaction* bad_txn,
                                                         GError* err)
{
	guint _tmp0_;
	guint _tmp1_;
#line 255 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_if_fail (PUBLISHING_RAJCE_IS_RAJCE_PUBLISHER (self));
#line 255 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_if_fail (PUBLISHING_REST_SUPPORT_IS_TRANSACTION (bad_txn));
#line 257 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_debug ("RajcePublishing.vala:257: EVENT: on_login_network_error");
#line 258 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_signal_parse_name ("completed", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp0_, NULL, FALSE);
#line 258 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_signal_handlers_disconnect_matched (bad_txn, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp0_, 0, NULL, (GCallback) _publishing_rajce_rajce_publisher_on_login_network_complete_publishing_rest_support_transaction_completed, self);
#line 259 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_signal_parse_name ("network-error", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp1_, NULL, FALSE);
#line 259 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_signal_handlers_disconnect_matched (bad_txn, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _publishing_rajce_rajce_publisher_on_login_network_error_publishing_rest_support_transaction_network_error, self);
#line 260 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rajce_rajce_publisher_do_show_authentication_pane (self, PUBLISHING_RAJCE_AUTHENTICATION_PANE_MODE_FAILED_RETRY_USER);
#line 2624 "RajcePublishing.c"
}


/**
     * Action that fetches all user albums from the Rajce.
     */
static void
_publishing_rajce_rajce_publisher_on_albums_fetch_error_publishing_rest_support_transaction_network_error (PublishingRESTSupportTransaction* _sender,
                                                                                                           GError* err,
                                                                                                           gpointer self)
{
#line 273 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rajce_rajce_publisher_on_albums_fetch_error ((PublishingRajceRajcePublisher*) self, _sender, err);
#line 2638 "RajcePublishing.c"
}


static void
_publishing_rajce_rajce_publisher_on_albums_fetch_complete_publishing_rest_support_transaction_completed (PublishingRESTSupportTransaction* _sender,
                                                                                                          gpointer self)
{
#line 274 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rajce_rajce_publisher_on_albums_fetch_complete ((PublishingRajceRajcePublisher*) self, _sender);
#line 2648 "RajcePublishing.c"
}


static void
publishing_rajce_rajce_publisher_do_fetch_albums (PublishingRajceRajcePublisher* self)
{
	SpitPublishingPluginHost* _tmp0_;
	SpitPublishingPluginHost* _tmp1_;
	PublishingRajceGetAlbumsTransaction* get_albums_trans = NULL;
	PublishingRajceSession* _tmp2_;
	gchar* _tmp3_;
	gchar* _tmp4_;
	PublishingRajceGetAlbumsTransaction* _tmp5_;
	PublishingRajceGetAlbumsTransaction* _tmp6_;
	GError * _inner_error_ = NULL;
#line 266 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_if_fail (PUBLISHING_RAJCE_IS_RAJCE_PUBLISHER (self));
#line 268 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_debug ("RajcePublishing.vala:268: ACTION: fetching albums");
#line 269 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp0_ = self->priv->host;
#line 269 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	spit_publishing_plugin_host_set_service_locked (_tmp0_, TRUE);
#line 270 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp1_ = self->priv->host;
#line 270 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	spit_publishing_plugin_host_install_account_fetch_wait_pane (_tmp1_);
#line 272 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp2_ = self->priv->session;
#line 272 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp3_ = publishing_rajce_rajce_publisher_get_url (self);
#line 272 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp4_ = _tmp3_;
#line 272 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp5_ = publishing_rajce_get_albums_transaction_new (_tmp2_, _tmp4_);
#line 272 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp6_ = _tmp5_;
#line 272 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_free0 (_tmp4_);
#line 272 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	get_albums_trans = _tmp6_;
#line 273 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (get_albums_trans, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "network-error", (GCallback) _publishing_rajce_rajce_publisher_on_albums_fetch_error_publishing_rest_support_transaction_network_error, self, 0);
#line 274 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (get_albums_trans, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "completed", (GCallback) _publishing_rajce_rajce_publisher_on_albums_fetch_complete_publishing_rest_support_transaction_completed, self, 0);
#line 2694 "RajcePublishing.c"
	{
#line 278 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		publishing_rest_support_transaction_execute (G_TYPE_CHECK_INSTANCE_CAST (get_albums_trans, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), &_inner_error_);
#line 278 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 278 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 2702 "RajcePublishing.c"
				goto __catch18_spit_publishing_publishing_error;
			}
#line 278 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			_publishing_rest_support_transaction_unref0 (get_albums_trans);
#line 278 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 278 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			g_clear_error (&_inner_error_);
#line 278 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			return;
#line 2713 "RajcePublishing.c"
		}
	}
	goto __finally18;
	__catch18_spit_publishing_publishing_error:
	{
		GError* err = NULL;
		GError* _tmp7_;
#line 276 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		err = _inner_error_;
#line 276 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_inner_error_ = NULL;
#line 282 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		g_debug ("RajcePublishing.vala:282: ERROR: do_fetch_albums");
#line 283 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp7_ = err;
#line 283 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		publishing_rajce_rajce_publisher_do_show_error (self, _tmp7_);
#line 276 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_g_error_free0 (err);
#line 2733 "RajcePublishing.c"
	}
	__finally18:
#line 276 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 276 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_publishing_rest_support_transaction_unref0 (get_albums_trans);
#line 276 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 276 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		g_clear_error (&_inner_error_);
#line 276 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		return;
#line 2746 "RajcePublishing.c"
	}
#line 266 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_publishing_rest_support_transaction_unref0 (get_albums_trans);
#line 2750 "RajcePublishing.c"
}


/**
     * Event triggered when the fetch albums action completes successfully.
     */
static gint
_publishing_rajce_album_compare_albums_gcompare_data_func (gconstpointer a,
                                                           gconstpointer b,
                                                           gpointer self)
{
	gint result;
	result = publishing_rajce_album_compare_albums ((PublishingRajceAlbum*) a, (PublishingRajceAlbum*) b);
#line 320 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	return result;
#line 2766 "RajcePublishing.c"
}


static void
publishing_rajce_rajce_publisher_on_albums_fetch_complete (PublishingRajceRajcePublisher* self,
                                                           PublishingRESTSupportTransaction* txn)
{
	guint _tmp0_;
	guint _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	PublishingRajceAlbum** _tmp4_;
	gint _tmp4__length1;
	GeeArrayList* list = NULL;
	GeeArrayList* _tmp5_;
	GError * _inner_error_ = NULL;
#line 290 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_if_fail (PUBLISHING_RAJCE_IS_RAJCE_PUBLISHER (self));
#line 290 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_if_fail (PUBLISHING_REST_SUPPORT_IS_TRANSACTION (txn));
#line 292 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_debug ("RajcePublishing.vala:292: EVENT: on_albums_fetch_complete");
#line 293 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_signal_parse_name ("completed", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp0_, NULL, FALSE);
#line 293 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_signal_handlers_disconnect_matched (txn, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp0_, 0, NULL, (GCallback) _publishing_rajce_rajce_publisher_on_albums_fetch_complete_publishing_rest_support_transaction_completed, self);
#line 294 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_signal_parse_name ("network-error", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp1_, NULL, FALSE);
#line 294 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_signal_handlers_disconnect_matched (txn, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _publishing_rajce_rajce_publisher_on_albums_fetch_error_publishing_rest_support_transaction_network_error, self);
#line 295 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp2_ = publishing_rest_support_transaction_get_response (txn);
#line 295 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp3_ = _tmp2_;
#line 295 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_debug ("RajcePublishing.vala:295: RajcePlugin: list of albums: %s", _tmp3_);
#line 295 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_free0 (_tmp3_);
#line 296 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp4_ = self->priv->albums;
#line 296 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp4__length1 = self->priv->albums_length1;
#line 296 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	if (_tmp4_ != NULL) {
#line 298 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		self->priv->albums = (_vala_array_free (self->priv->albums, self->priv->albums_length1, (GDestroyNotify) publishing_rajce_album_unref), NULL);
#line 298 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		self->priv->albums = NULL;
#line 298 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		self->priv->albums_length1 = 0;
#line 298 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		self->priv->_albums_size_ = self->priv->albums_length1;
#line 2819 "RajcePublishing.c"
	}
#line 300 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp5_ = gee_array_list_new (PUBLISHING_RAJCE_TYPE_ALBUM, (GBoxedCopyFunc) publishing_rajce_album_ref, (GDestroyNotify) publishing_rajce_album_unref, NULL, NULL, NULL);
#line 300 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	list = _tmp5_;
#line 2825 "RajcePublishing.c"
	{
		PublishingRESTSupportXmlDocument* doc = NULL;
		gchar* _tmp6_;
		gchar* _tmp7_;
		PublishingRESTSupportXmlDocument* _tmp8_;
		PublishingRESTSupportXmlDocument* _tmp9_;
		xmlNode* response = NULL;
		PublishingRESTSupportXmlDocument* _tmp10_;
		xmlNode* _tmp11_;
		xmlNode* sessionToken = NULL;
		PublishingRESTSupportXmlDocument* _tmp12_;
		xmlNode* _tmp13_;
		xmlNode* _tmp14_;
		xmlNode* nodealbums = NULL;
		PublishingRESTSupportXmlDocument* _tmp15_;
		xmlNode* _tmp16_;
		xmlNode* _tmp17_;
		GeeArrayList* _tmp88_;
		GeeArrayList* _tmp89_;
		gint _tmp90_;
		gpointer* _tmp91_;
		PublishingRajceSession* _tmp92_;
		xmlNode* _tmp93_;
		gchar* _tmp94_;
		gchar* _tmp95_;
#line 303 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp6_ = publishing_rest_support_transaction_get_response (txn);
#line 303 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp7_ = _tmp6_;
#line 303 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp8_ = publishing_rest_support_xml_document_parse_string (_tmp7_, _publishing_rajce_transaction_validate_xml_publishing_rest_support_xml_document_check_for_error_response, NULL, &_inner_error_);
#line 303 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp9_ = _tmp8_;
#line 303 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_g_free0 (_tmp7_);
#line 303 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		doc = _tmp9_;
#line 303 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 303 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 2867 "RajcePublishing.c"
				goto __catch19_spit_publishing_publishing_error;
			}
#line 303 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			_g_object_unref0 (list);
#line 303 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 303 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			g_clear_error (&_inner_error_);
#line 303 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			return;
#line 2878 "RajcePublishing.c"
		}
#line 304 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp10_ = doc;
#line 304 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp11_ = publishing_rest_support_xml_document_get_root_node (_tmp10_);
#line 304 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		response = _tmp11_;
#line 305 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp12_ = doc;
#line 305 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp13_ = response;
#line 305 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp14_ = publishing_rest_support_xml_document_get_named_child (_tmp12_, _tmp13_, "sessionToken", &_inner_error_);
#line 305 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		sessionToken = _tmp14_;
#line 305 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 305 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			_publishing_rest_support_xml_document_unref0 (doc);
#line 305 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 2900 "RajcePublishing.c"
				goto __catch19_spit_publishing_publishing_error;
			}
#line 305 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			_publishing_rest_support_xml_document_unref0 (doc);
#line 305 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			_g_object_unref0 (list);
#line 305 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 305 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			g_clear_error (&_inner_error_);
#line 305 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			return;
#line 2913 "RajcePublishing.c"
		}
#line 306 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp15_ = doc;
#line 306 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp16_ = response;
#line 306 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp17_ = publishing_rest_support_xml_document_get_named_child (_tmp15_, _tmp16_, "albums", &_inner_error_);
#line 306 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		nodealbums = _tmp17_;
#line 306 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 306 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			_publishing_rest_support_xml_document_unref0 (doc);
#line 306 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 2929 "RajcePublishing.c"
				goto __catch19_spit_publishing_publishing_error;
			}
#line 306 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			_publishing_rest_support_xml_document_unref0 (doc);
#line 306 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			_g_object_unref0 (list);
#line 306 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 306 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			g_clear_error (&_inner_error_);
#line 306 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			return;
#line 2942 "RajcePublishing.c"
		}
		{
			xmlNode* album = NULL;
			xmlNode* _tmp18_;
			xmlNode* _tmp19_;
#line 307 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			_tmp18_ = nodealbums;
#line 307 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			_tmp19_ = _tmp18_->children;
#line 307 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			album = _tmp19_;
#line 2954 "RajcePublishing.c"
			{
				gboolean _tmp20_ = FALSE;
#line 307 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
				_tmp20_ = TRUE;
#line 307 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
				while (TRUE) {
#line 2961 "RajcePublishing.c"
					xmlNode* _tmp23_;
					gint id = 0;
					xmlNode* _tmp24_;
					gchar* _tmp25_;
					gchar* _tmp26_;
					gint _tmp27_;
					xmlNode* _tmp28_ = NULL;
					PublishingRESTSupportXmlDocument* _tmp29_;
					xmlNode* _tmp30_;
					xmlNode* _tmp31_;
					gchar* albumName = NULL;
					gchar* _tmp32_;
					xmlNode* _tmp33_ = NULL;
					PublishingRESTSupportXmlDocument* _tmp34_;
					xmlNode* _tmp35_;
					xmlNode* _tmp36_;
					gchar* url = NULL;
					gchar* _tmp37_;
					xmlNode* _tmp38_ = NULL;
					PublishingRESTSupportXmlDocument* _tmp39_;
					xmlNode* _tmp40_;
					xmlNode* _tmp41_;
					gchar* thumbUrl = NULL;
					gchar* _tmp42_;
					xmlNode* _tmp43_ = NULL;
					PublishingRESTSupportXmlDocument* _tmp44_;
					xmlNode* _tmp45_;
					xmlNode* _tmp46_;
					gchar* createDate = NULL;
					gchar* _tmp47_;
					xmlNode* _tmp48_ = NULL;
					PublishingRESTSupportXmlDocument* _tmp49_;
					xmlNode* _tmp50_;
					xmlNode* _tmp51_;
					gchar* updateDate = NULL;
					gchar* _tmp52_;
					gboolean _tmp53_ = FALSE;
					xmlNode* _tmp54_ = NULL;
					PublishingRESTSupportXmlDocument* _tmp55_;
					xmlNode* _tmp56_;
					xmlNode* _tmp57_;
					gchar* _tmp58_;
					gchar* _tmp59_;
					gboolean _tmp60_;
					gboolean hidden = FALSE;
					gboolean _tmp61_ = FALSE;
					xmlNode* _tmp62_ = NULL;
					PublishingRESTSupportXmlDocument* _tmp63_;
					xmlNode* _tmp64_;
					xmlNode* _tmp65_;
					gchar* _tmp66_;
					gchar* _tmp67_;
					gboolean _tmp68_;
					gboolean secure = FALSE;
					xmlNode* _tmp69_ = NULL;
					PublishingRESTSupportXmlDocument* _tmp70_;
					xmlNode* _tmp71_;
					xmlNode* _tmp72_;
					gint photoCount = 0;
					gchar* _tmp73_;
					gchar* _tmp74_;
					gint _tmp75_;
					GeeArrayList* _tmp76_;
					gint _tmp77_;
					const gchar* _tmp78_;
					const gchar* _tmp79_;
					const gchar* _tmp80_;
					const gchar* _tmp81_;
					const gchar* _tmp82_;
					gboolean _tmp83_;
					gboolean _tmp84_;
					gint _tmp85_;
					PublishingRajceAlbum* _tmp86_;
					PublishingRajceAlbum* _tmp87_;
#line 307 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
					if (!_tmp20_) {
#line 3038 "RajcePublishing.c"
						xmlNode* _tmp21_;
						xmlNode* _tmp22_;
#line 307 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						_tmp21_ = album;
#line 307 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						_tmp22_ = _tmp21_->next;
#line 307 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						album = _tmp22_;
#line 3047 "RajcePublishing.c"
					}
#line 307 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
					_tmp20_ = FALSE;
#line 307 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
					_tmp23_ = album;
#line 307 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
					if (!(_tmp23_ != NULL)) {
#line 307 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						break;
#line 3057 "RajcePublishing.c"
					}
#line 309 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
					_tmp24_ = album;
#line 309 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
					_tmp25_ = (gchar*) xmlGetProp (_tmp24_, (xmlChar*) "id");
#line 309 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
					_tmp26_ = _tmp25_;
#line 309 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
					_tmp27_ = atoi (_tmp26_);
#line 309 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
					_g_free0 (_tmp26_);
#line 309 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
					id = _tmp27_;
#line 310 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
					_tmp29_ = doc;
#line 310 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
					_tmp30_ = album;
#line 310 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
					_tmp31_ = publishing_rest_support_xml_document_get_named_child (_tmp29_, _tmp30_, "albumName", &_inner_error_);
#line 310 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
					_tmp28_ = _tmp31_;
#line 310 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
					if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 310 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						_publishing_rest_support_xml_document_unref0 (doc);
#line 310 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 3085 "RajcePublishing.c"
							goto __catch19_spit_publishing_publishing_error;
						}
#line 310 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						_publishing_rest_support_xml_document_unref0 (doc);
#line 310 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						_g_object_unref0 (list);
#line 310 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 310 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						g_clear_error (&_inner_error_);
#line 310 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						return;
#line 3098 "RajcePublishing.c"
					}
#line 310 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
					_tmp32_ = (gchar*) xmlNodeGetContent (_tmp28_);
#line 310 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
					albumName = _tmp32_;
#line 311 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
					_tmp34_ = doc;
#line 311 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
					_tmp35_ = album;
#line 311 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
					_tmp36_ = publishing_rest_support_xml_document_get_named_child (_tmp34_, _tmp35_, "url", &_inner_error_);
#line 311 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
					_tmp33_ = _tmp36_;
#line 311 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
					if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 311 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						_g_free0 (albumName);
#line 311 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						_publishing_rest_support_xml_document_unref0 (doc);
#line 311 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 3120 "RajcePublishing.c"
							goto __catch19_spit_publishing_publishing_error;
						}
#line 311 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						_g_free0 (albumName);
#line 311 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						_publishing_rest_support_xml_document_unref0 (doc);
#line 311 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						_g_object_unref0 (list);
#line 311 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 311 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						g_clear_error (&_inner_error_);
#line 311 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						return;
#line 3135 "RajcePublishing.c"
					}
#line 311 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
					_tmp37_ = (gchar*) xmlNodeGetContent (_tmp33_);
#line 311 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
					url = _tmp37_;
#line 312 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
					_tmp39_ = doc;
#line 312 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
					_tmp40_ = album;
#line 312 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
					_tmp41_ = publishing_rest_support_xml_document_get_named_child (_tmp39_, _tmp40_, "thumbUrl", &_inner_error_);
#line 312 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
					_tmp38_ = _tmp41_;
#line 312 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
					if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 312 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						_g_free0 (url);
#line 312 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						_g_free0 (albumName);
#line 312 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						_publishing_rest_support_xml_document_unref0 (doc);
#line 312 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 3159 "RajcePublishing.c"
							goto __catch19_spit_publishing_publishing_error;
						}
#line 312 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						_g_free0 (url);
#line 312 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						_g_free0 (albumName);
#line 312 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						_publishing_rest_support_xml_document_unref0 (doc);
#line 312 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						_g_object_unref0 (list);
#line 312 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 312 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						g_clear_error (&_inner_error_);
#line 312 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						return;
#line 3176 "RajcePublishing.c"
					}
#line 312 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
					_tmp42_ = (gchar*) xmlNodeGetContent (_tmp38_);
#line 312 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
					thumbUrl = _tmp42_;
#line 313 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
					_tmp44_ = doc;
#line 313 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
					_tmp45_ = album;
#line 313 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
					_tmp46_ = publishing_rest_support_xml_document_get_named_child (_tmp44_, _tmp45_, "createDate", &_inner_error_);
#line 313 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
					_tmp43_ = _tmp46_;
#line 313 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
					if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 313 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						_g_free0 (thumbUrl);
#line 313 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						_g_free0 (url);
#line 313 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						_g_free0 (albumName);
#line 313 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						_publishing_rest_support_xml_document_unref0 (doc);
#line 313 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 3202 "RajcePublishing.c"
							goto __catch19_spit_publishing_publishing_error;
						}
#line 313 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						_g_free0 (thumbUrl);
#line 313 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						_g_free0 (url);
#line 313 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						_g_free0 (albumName);
#line 313 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						_publishing_rest_support_xml_document_unref0 (doc);
#line 313 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						_g_object_unref0 (list);
#line 313 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 313 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						g_clear_error (&_inner_error_);
#line 313 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						return;
#line 3221 "RajcePublishing.c"
					}
#line 313 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
					_tmp47_ = (gchar*) xmlNodeGetContent (_tmp43_);
#line 313 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
					createDate = _tmp47_;
#line 314 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
					_tmp49_ = doc;
#line 314 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
					_tmp50_ = album;
#line 314 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
					_tmp51_ = publishing_rest_support_xml_document_get_named_child (_tmp49_, _tmp50_, "updateDate", &_inner_error_);
#line 314 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
					_tmp48_ = _tmp51_;
#line 314 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
					if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 314 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						_g_free0 (createDate);
#line 314 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						_g_free0 (thumbUrl);
#line 314 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						_g_free0 (url);
#line 314 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						_g_free0 (albumName);
#line 314 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						_publishing_rest_support_xml_document_unref0 (doc);
#line 314 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 3249 "RajcePublishing.c"
							goto __catch19_spit_publishing_publishing_error;
						}
#line 314 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						_g_free0 (createDate);
#line 314 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						_g_free0 (thumbUrl);
#line 314 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						_g_free0 (url);
#line 314 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						_g_free0 (albumName);
#line 314 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						_publishing_rest_support_xml_document_unref0 (doc);
#line 314 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						_g_object_unref0 (list);
#line 314 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 314 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						g_clear_error (&_inner_error_);
#line 314 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						return;
#line 3270 "RajcePublishing.c"
					}
#line 314 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
					_tmp52_ = (gchar*) xmlNodeGetContent (_tmp48_);
#line 314 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
					updateDate = _tmp52_;
#line 315 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
					_tmp55_ = doc;
#line 315 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
					_tmp56_ = album;
#line 315 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
					_tmp57_ = publishing_rest_support_xml_document_get_named_child (_tmp55_, _tmp56_, "hidden", &_inner_error_);
#line 315 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
					_tmp54_ = _tmp57_;
#line 315 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
					if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 315 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						_g_free0 (updateDate);
#line 315 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						_g_free0 (createDate);
#line 315 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						_g_free0 (thumbUrl);
#line 315 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						_g_free0 (url);
#line 315 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						_g_free0 (albumName);
#line 315 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						_publishing_rest_support_xml_document_unref0 (doc);
#line 315 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 3300 "RajcePublishing.c"
							goto __catch19_spit_publishing_publishing_error;
						}
#line 315 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						_g_free0 (updateDate);
#line 315 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						_g_free0 (createDate);
#line 315 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						_g_free0 (thumbUrl);
#line 315 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						_g_free0 (url);
#line 315 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						_g_free0 (albumName);
#line 315 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						_publishing_rest_support_xml_document_unref0 (doc);
#line 315 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						_g_object_unref0 (list);
#line 315 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 315 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						g_clear_error (&_inner_error_);
#line 315 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						return;
#line 3323 "RajcePublishing.c"
					}
#line 315 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
					_tmp58_ = (gchar*) xmlNodeGetContent (_tmp54_);
#line 315 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
					_tmp59_ = _tmp58_;
#line 315 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
					_tmp60_ = atoi (_tmp59_) > 0;
#line 315 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
					_g_free0 (_tmp59_);
#line 315 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
					if (_tmp60_) {
#line 315 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						_tmp53_ = TRUE;
#line 3337 "RajcePublishing.c"
					} else {
#line 315 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						_tmp53_ = FALSE;
#line 3341 "RajcePublishing.c"
					}
#line 315 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
					hidden = _tmp53_;
#line 316 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
					_tmp63_ = doc;
#line 316 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
					_tmp64_ = album;
#line 316 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
					_tmp65_ = publishing_rest_support_xml_document_get_named_child (_tmp63_, _tmp64_, "secure", &_inner_error_);
#line 316 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
					_tmp62_ = _tmp65_;
#line 316 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
					if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 316 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						_g_free0 (updateDate);
#line 316 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						_g_free0 (createDate);
#line 316 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						_g_free0 (thumbUrl);
#line 316 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						_g_free0 (url);
#line 316 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						_g_free0 (albumName);
#line 316 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						_publishing_rest_support_xml_document_unref0 (doc);
#line 316 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 3369 "RajcePublishing.c"
							goto __catch19_spit_publishing_publishing_error;
						}
#line 316 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						_g_free0 (updateDate);
#line 316 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						_g_free0 (createDate);
#line 316 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						_g_free0 (thumbUrl);
#line 316 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						_g_free0 (url);
#line 316 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						_g_free0 (albumName);
#line 316 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						_publishing_rest_support_xml_document_unref0 (doc);
#line 316 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						_g_object_unref0 (list);
#line 316 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 316 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						g_clear_error (&_inner_error_);
#line 316 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						return;
#line 3392 "RajcePublishing.c"
					}
#line 316 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
					_tmp66_ = (gchar*) xmlNodeGetContent (_tmp62_);
#line 316 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
					_tmp67_ = _tmp66_;
#line 316 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
					_tmp68_ = atoi (_tmp67_) > 0;
#line 316 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
					_g_free0 (_tmp67_);
#line 316 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
					if (_tmp68_) {
#line 316 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						_tmp61_ = TRUE;
#line 3406 "RajcePublishing.c"
					} else {
#line 316 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						_tmp61_ = FALSE;
#line 3410 "RajcePublishing.c"
					}
#line 316 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
					secure = _tmp61_;
#line 317 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
					_tmp70_ = doc;
#line 317 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
					_tmp71_ = album;
#line 317 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
					_tmp72_ = publishing_rest_support_xml_document_get_named_child (_tmp70_, _tmp71_, "photoCount", &_inner_error_);
#line 317 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
					_tmp69_ = _tmp72_;
#line 317 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
					if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 317 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						_g_free0 (updateDate);
#line 317 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						_g_free0 (createDate);
#line 317 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						_g_free0 (thumbUrl);
#line 317 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						_g_free0 (url);
#line 317 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						_g_free0 (albumName);
#line 317 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						_publishing_rest_support_xml_document_unref0 (doc);
#line 317 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 3438 "RajcePublishing.c"
							goto __catch19_spit_publishing_publishing_error;
						}
#line 317 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						_g_free0 (updateDate);
#line 317 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						_g_free0 (createDate);
#line 317 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						_g_free0 (thumbUrl);
#line 317 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						_g_free0 (url);
#line 317 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						_g_free0 (albumName);
#line 317 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						_publishing_rest_support_xml_document_unref0 (doc);
#line 317 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						_g_object_unref0 (list);
#line 317 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 317 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						g_clear_error (&_inner_error_);
#line 317 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						return;
#line 3461 "RajcePublishing.c"
					}
#line 317 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
					_tmp73_ = (gchar*) xmlNodeGetContent (_tmp69_);
#line 317 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
					_tmp74_ = _tmp73_;
#line 317 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
					_tmp75_ = atoi (_tmp74_);
#line 317 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
					_g_free0 (_tmp74_);
#line 317 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
					photoCount = _tmp75_;
#line 318 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
					_tmp76_ = list;
#line 318 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
					_tmp77_ = id;
#line 318 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
					_tmp78_ = albumName;
#line 318 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
					_tmp79_ = url;
#line 318 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
					_tmp80_ = thumbUrl;
#line 318 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
					_tmp81_ = createDate;
#line 318 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
					_tmp82_ = updateDate;
#line 318 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
					_tmp83_ = hidden;
#line 318 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
					_tmp84_ = secure;
#line 318 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
					_tmp85_ = photoCount;
#line 318 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
					_tmp86_ = publishing_rajce_album_new (_tmp77_, _tmp78_, _tmp79_, _tmp80_, _tmp81_, _tmp82_, _tmp83_, _tmp84_, _tmp85_);
#line 318 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
					_tmp87_ = _tmp86_;
#line 318 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
					gee_abstract_list_insert (G_TYPE_CHECK_INSTANCE_CAST (_tmp76_, GEE_TYPE_ABSTRACT_LIST, GeeAbstractList), 0, _tmp87_);
#line 318 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
					_publishing_rajce_album_unref0 (_tmp87_);
#line 307 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
					_g_free0 (updateDate);
#line 307 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
					_g_free0 (createDate);
#line 307 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
					_g_free0 (thumbUrl);
#line 307 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
					_g_free0 (url);
#line 307 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
					_g_free0 (albumName);
#line 3511 "RajcePublishing.c"
				}
			}
		}
#line 320 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp88_ = list;
#line 320 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		gee_list_sort (G_TYPE_CHECK_INSTANCE_CAST (_tmp88_, GEE_TYPE_LIST, GeeList), _publishing_rajce_album_compare_albums_gcompare_data_func, NULL, NULL);
#line 321 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp89_ = list;
#line 321 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp91_ = gee_collection_to_array (G_TYPE_CHECK_INSTANCE_CAST (_tmp89_, GEE_TYPE_COLLECTION, GeeCollection), &_tmp90_);
#line 321 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		self->priv->albums = (_vala_array_free (self->priv->albums, self->priv->albums_length1, (GDestroyNotify) publishing_rajce_album_unref), NULL);
#line 321 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		self->priv->albums = _tmp91_;
#line 321 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		self->priv->albums_length1 = _tmp90_;
#line 321 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		self->priv->_albums_size_ = self->priv->albums_length1;
#line 322 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp92_ = self->priv->session;
#line 322 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp93_ = sessionToken;
#line 322 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp94_ = (gchar*) xmlNodeGetContent (_tmp93_);
#line 322 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp95_ = _tmp94_;
#line 322 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		publishing_rajce_session_set_usertoken (_tmp92_, _tmp95_);
#line 322 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_g_free0 (_tmp95_);
#line 301 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_publishing_rest_support_xml_document_unref0 (doc);
#line 3545 "RajcePublishing.c"
	}
	goto __finally19;
	__catch19_spit_publishing_publishing_error:
	{
		GError* err = NULL;
		GError* _tmp96_;
#line 301 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		err = _inner_error_;
#line 301 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_inner_error_ = NULL;
#line 326 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		g_debug ("RajcePublishing.vala:326: ERROR: on_albums_fetch_complete");
#line 327 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp96_ = err;
#line 327 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		publishing_rajce_rajce_publisher_do_show_error (self, _tmp96_);
#line 328 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_g_error_free0 (err);
#line 328 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_g_object_unref0 (list);
#line 328 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		return;
#line 3568 "RajcePublishing.c"
	}
	__finally19:
#line 301 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 301 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_g_object_unref0 (list);
#line 301 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 301 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		g_clear_error (&_inner_error_);
#line 301 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		return;
#line 3581 "RajcePublishing.c"
	}
#line 330 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rajce_rajce_publisher_do_show_publishing_options_pane (self);
#line 290 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_object_unref0 (list);
#line 3587 "RajcePublishing.c"
}


/**
     * Event triggered when the fetch albums transaction fails due to a network error.
     */
static void
publishing_rajce_rajce_publisher_on_albums_fetch_error (PublishingRajceRajcePublisher* self,
                                                        PublishingRESTSupportTransaction* bad_txn,
                                                        GError* err)
{
	guint _tmp0_;
	guint _tmp1_;
#line 336 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_if_fail (PUBLISHING_RAJCE_IS_RAJCE_PUBLISHER (self));
#line 336 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_if_fail (PUBLISHING_REST_SUPPORT_IS_TRANSACTION (bad_txn));
#line 338 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_debug ("RajcePublishing.vala:338: EVENT: on_albums_fetch_error");
#line 339 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_signal_parse_name ("completed", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp0_, NULL, FALSE);
#line 339 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_signal_handlers_disconnect_matched (bad_txn, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp0_, 0, NULL, (GCallback) _publishing_rajce_rajce_publisher_on_albums_fetch_complete_publishing_rest_support_transaction_completed, self);
#line 340 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_signal_parse_name ("network-error", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp1_, NULL, FALSE);
#line 340 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_signal_handlers_disconnect_matched (bad_txn, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _publishing_rajce_rajce_publisher_on_albums_fetch_error_publishing_rest_support_transaction_network_error, self);
#line 341 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rajce_rajce_publisher_on_network_error (self, bad_txn, err);
#line 3617 "RajcePublishing.c"
}


/**
     * Action that shows the publishing options pane.
     */
static void
_publishing_rajce_rajce_publisher_on_publishing_options_pane_logout_clicked_publishing_rajce_publishing_options_pane_logout (PublishingRajcePublishingOptionsPane* _sender,
                                                                                                                             gpointer self)
{
#line 352 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rajce_rajce_publisher_on_publishing_options_pane_logout_clicked ((PublishingRajceRajcePublisher*) self);
#line 3630 "RajcePublishing.c"
}


static void
_publishing_rajce_rajce_publisher_on_publishing_options_pane_publish_clicked_publishing_rajce_publishing_options_pane_publish (PublishingRajcePublishingOptionsPane* _sender,
                                                                                                                               PublishingRajcePublishingParameters* parameters,
                                                                                                                               gpointer self)
{
#line 353 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rajce_rajce_publisher_on_publishing_options_pane_publish_clicked ((PublishingRajceRajcePublisher*) self, parameters);
#line 3641 "RajcePublishing.c"
}


static void
publishing_rajce_rajce_publisher_do_show_publishing_options_pane (PublishingRajceRajcePublisher* self)
{
	SpitPublishingPluginHost* _tmp0_;
	PublishingRajcePublishingOptionsPane* opts_pane = NULL;
	PublishingRajceSession* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	PublishingRajceAlbum** _tmp4_;
	gint _tmp4__length1;
	PublishingRajcePublishingOptionsPane* _tmp5_;
	PublishingRajcePublishingOptionsPane* _tmp6_;
	SpitPublishingPluginHost* _tmp7_;
	SpitPublishingPluginHost* _tmp8_;
	GtkWidget* _tmp9_;
	GtkWidget* _tmp10_;
#line 347 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_if_fail (PUBLISHING_RAJCE_IS_RAJCE_PUBLISHER (self));
#line 349 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_debug ("RajcePublishing.vala:349: ACTION: installing publishing options pane");
#line 350 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp0_ = self->priv->host;
#line 350 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	spit_publishing_plugin_host_set_service_locked (_tmp0_, FALSE);
#line 351 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp1_ = self->priv->session;
#line 351 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp2_ = publishing_rajce_session_get_username (_tmp1_);
#line 351 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp3_ = _tmp2_;
#line 351 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp4_ = self->priv->albums;
#line 351 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp4__length1 = self->priv->albums_length1;
#line 351 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp5_ = publishing_rajce_publishing_options_pane_new (self, _tmp3_, _tmp4_, _tmp4__length1);
#line 351 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp6_ = _tmp5_;
#line 351 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_free0 (_tmp3_);
#line 351 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	opts_pane = _tmp6_;
#line 352 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_signal_connect_object (opts_pane, "logout", (GCallback) _publishing_rajce_rajce_publisher_on_publishing_options_pane_logout_clicked_publishing_rajce_publishing_options_pane_logout, self, 0);
#line 353 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_signal_connect_object (opts_pane, "publish", (GCallback) _publishing_rajce_rajce_publisher_on_publishing_options_pane_publish_clicked_publishing_rajce_publishing_options_pane_publish, self, 0);
#line 354 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp7_ = self->priv->host;
#line 354 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	spit_publishing_plugin_host_install_dialog_pane (_tmp7_, G_TYPE_CHECK_INSTANCE_CAST (opts_pane, SPIT_PUBLISHING_TYPE_DIALOG_PANE, SpitPublishingDialogPane), SPIT_PUBLISHING_PLUGIN_HOST_BUTTON_MODE_CLOSE);
#line 355 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp8_ = self->priv->host;
#line 355 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp9_ = publishing_rajce_publishing_options_pane_get_default_widget (opts_pane);
#line 355 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp10_ = _tmp9_;
#line 355 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	spit_publishing_plugin_host_set_dialog_default_widget (_tmp8_, _tmp10_);
#line 355 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_object_unref0 (_tmp10_);
#line 347 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_object_unref0 (opts_pane);
#line 3707 "RajcePublishing.c"
}


/**
     * Event triggered when the user clicks logout in the publishing options pane.
     */
static void
publishing_rajce_rajce_publisher_on_publishing_options_pane_logout_clicked (PublishingRajceRajcePublisher* self)
{
	PublishingRajceSession* _tmp0_;
#line 361 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_if_fail (PUBLISHING_RAJCE_IS_RAJCE_PUBLISHER (self));
#line 363 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_debug ("RajcePublishing.vala:363: EVENT: on_publishing_options_pane_logout_cli" \
"cked");
#line 364 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp0_ = self->priv->session;
#line 364 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rajce_session_deauthenticate (_tmp0_);
#line 365 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rajce_rajce_publisher_do_show_authentication_pane (self, PUBLISHING_RAJCE_AUTHENTICATION_PANE_MODE_INTRO);
#line 3728 "RajcePublishing.c"
}


/**
     * Event triggered when the user clicks publish in the publishing options pane.
     *
     * @param parameters the publishing parameters
     */
static gpointer
_publishing_rajce_publishing_parameters_ref0 (gpointer self)
{
#line 376 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	return self ? publishing_rajce_publishing_parameters_ref (self) : NULL;
#line 3742 "RajcePublishing.c"
}


static void
publishing_rajce_rajce_publisher_on_publishing_options_pane_publish_clicked (PublishingRajceRajcePublisher* self,
                                                                             PublishingRajcePublishingParameters* parameters)
{
	PublishingRajcePublishingParameters* _tmp0_;
#line 373 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_if_fail (PUBLISHING_RAJCE_IS_RAJCE_PUBLISHER (self));
#line 373 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_if_fail (PUBLISHING_RAJCE_IS_PUBLISHING_PARAMETERS (parameters));
#line 375 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_debug ("RajcePublishing.vala:375: EVENT: on_publishing_options_pane_publish_cl" \
"icked");
#line 376 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp0_ = _publishing_rajce_publishing_parameters_ref0 (parameters);
#line 376 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_publishing_rajce_publishing_parameters_unref0 (self->priv->parameters);
#line 376 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self->priv->parameters = _tmp0_;
#line 377 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rajce_rajce_publisher_do_begin_upload (self);
#line 3765 "RajcePublishing.c"
}


/**
     * Begin upload action: open existing album or create a new one
     */
static gboolean
_int_equal (const gint * s1,
            const gint * s2)
{
#line 386 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	if (s1 == s2) {
#line 386 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		return TRUE;
#line 3780 "RajcePublishing.c"
	}
#line 386 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	if (s1 == NULL) {
#line 386 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		return FALSE;
#line 3786 "RajcePublishing.c"
	}
#line 386 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	if (s2 == NULL) {
#line 386 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		return FALSE;
#line 3792 "RajcePublishing.c"
	}
#line 386 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	return (*s1) == (*s2);
#line 3796 "RajcePublishing.c"
}


static void
_publishing_rajce_rajce_publisher_on_create_album_error_publishing_rest_support_transaction_network_error (PublishingRESTSupportTransaction* _sender,
                                                                                                           GError* err,
                                                                                                           gpointer self)
{
#line 391 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rajce_rajce_publisher_on_create_album_error ((PublishingRajceRajcePublisher*) self, _sender, err);
#line 3807 "RajcePublishing.c"
}


static void
_publishing_rajce_rajce_publisher_on_create_album_complete_publishing_rest_support_transaction_completed (PublishingRESTSupportTransaction* _sender,
                                                                                                          gpointer self)
{
#line 392 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rajce_rajce_publisher_on_create_album_complete ((PublishingRajceRajcePublisher*) self, _sender);
#line 3817 "RajcePublishing.c"
}


static void
_publishing_rajce_rajce_publisher_on_open_album_error_publishing_rest_support_transaction_network_error (PublishingRESTSupportTransaction* _sender,
                                                                                                         GError* err,
                                                                                                         gpointer self)
{
#line 408 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rajce_rajce_publisher_on_open_album_error ((PublishingRajceRajcePublisher*) self, _sender, err);
#line 3828 "RajcePublishing.c"
}


static void
_publishing_rajce_rajce_publisher_on_open_album_complete_publishing_rest_support_transaction_completed (PublishingRESTSupportTransaction* _sender,
                                                                                                        gpointer self)
{
#line 409 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rajce_rajce_publisher_on_open_album_complete ((PublishingRajceRajcePublisher*) self, _sender);
#line 3838 "RajcePublishing.c"
}


static void
publishing_rajce_rajce_publisher_do_begin_upload (PublishingRajceRajcePublisher* self)
{
	SpitPublishingPluginHost* _tmp0_;
	PublishingRajcePublishingParameters* _tmp1_;
	gint* _tmp2_;
	gint _tmp3_;
	GError * _inner_error_ = NULL;
#line 383 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_if_fail (PUBLISHING_RAJCE_IS_RAJCE_PUBLISHER (self));
#line 385 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp0_ = self->priv->host;
#line 385 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	spit_publishing_plugin_host_set_service_locked (_tmp0_, TRUE);
#line 386 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp1_ = self->priv->parameters;
#line 386 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp2_ = _tmp1_->album_id;
#line 386 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp3_ = 0;
#line 386 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	if (_int_equal (_tmp2_, &_tmp3_) == TRUE) {
#line 3864 "RajcePublishing.c"
		PublishingRajceCreateAlbumTransaction* create_album_trans = NULL;
		PublishingRajceSession* _tmp4_;
		gchar* _tmp5_;
		gchar* _tmp6_;
		PublishingRajcePublishingParameters* _tmp7_;
		const gchar* _tmp8_;
		PublishingRajcePublishingParameters* _tmp9_;
		gboolean* _tmp10_;
		PublishingRajceCreateAlbumTransaction* _tmp11_;
		PublishingRajceCreateAlbumTransaction* _tmp12_;
		PublishingRajceCreateAlbumTransaction* _tmp13_;
		PublishingRajceCreateAlbumTransaction* _tmp14_;
#line 389 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		g_debug ("RajcePublishing.vala:389: ACTION: closing album");
#line 390 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp4_ = self->priv->session;
#line 390 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp5_ = publishing_rajce_rajce_publisher_get_url (self);
#line 390 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp6_ = _tmp5_;
#line 390 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp7_ = self->priv->parameters;
#line 390 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp8_ = _tmp7_->album_name;
#line 390 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp9_ = self->priv->parameters;
#line 390 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp10_ = _tmp9_->album_hidden;
#line 390 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp11_ = publishing_rajce_create_album_transaction_new (_tmp4_, _tmp6_, _tmp8_, *_tmp10_);
#line 390 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp12_ = _tmp11_;
#line 390 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_g_free0 (_tmp6_);
#line 390 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		create_album_trans = _tmp12_;
#line 391 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp13_ = create_album_trans;
#line 391 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp13_, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "network-error", (GCallback) _publishing_rajce_rajce_publisher_on_create_album_error_publishing_rest_support_transaction_network_error, self, 0);
#line 392 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp14_ = create_album_trans;
#line 392 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp14_, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "completed", (GCallback) _publishing_rajce_rajce_publisher_on_create_album_complete_publishing_rest_support_transaction_completed, self, 0);
#line 3909 "RajcePublishing.c"
		{
			PublishingRajceCreateAlbumTransaction* _tmp15_;
#line 395 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			_tmp15_ = create_album_trans;
#line 395 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			publishing_rest_support_transaction_execute (G_TYPE_CHECK_INSTANCE_CAST (_tmp15_, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), &_inner_error_);
#line 395 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 395 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
				if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 3920 "RajcePublishing.c"
					goto __catch20_spit_publishing_publishing_error;
				}
#line 395 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
				_publishing_rest_support_transaction_unref0 (create_album_trans);
#line 395 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
				g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 395 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
				g_clear_error (&_inner_error_);
#line 395 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
				return;
#line 3931 "RajcePublishing.c"
			}
		}
		goto __finally20;
		__catch20_spit_publishing_publishing_error:
		{
			GError* err = NULL;
			GError* _tmp16_;
#line 393 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			err = _inner_error_;
#line 393 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			_inner_error_ = NULL;
#line 399 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			g_debug ("RajcePublishing.vala:399: ERROR: create album");
#line 400 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			_tmp16_ = err;
#line 400 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			publishing_rajce_rajce_publisher_do_show_error (self, _tmp16_);
#line 393 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			_g_error_free0 (err);
#line 3951 "RajcePublishing.c"
		}
		__finally20:
#line 393 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 393 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			_publishing_rest_support_transaction_unref0 (create_album_trans);
#line 393 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 393 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			g_clear_error (&_inner_error_);
#line 393 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			return;
#line 3964 "RajcePublishing.c"
		}
#line 386 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_publishing_rest_support_transaction_unref0 (create_album_trans);
#line 3968 "RajcePublishing.c"
	} else {
		PublishingRajceOpenAlbumTransaction* open_album_trans = NULL;
		PublishingRajceSession* _tmp17_;
		gchar* _tmp18_;
		gchar* _tmp19_;
		PublishingRajcePublishingParameters* _tmp20_;
		gint* _tmp21_;
		PublishingRajceOpenAlbumTransaction* _tmp22_;
		PublishingRajceOpenAlbumTransaction* _tmp23_;
		PublishingRajceOpenAlbumTransaction* _tmp24_;
		PublishingRajceOpenAlbumTransaction* _tmp25_;
#line 406 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		g_debug ("RajcePublishing.vala:406: ACTION: opening album");
#line 407 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp17_ = self->priv->session;
#line 407 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp18_ = publishing_rajce_rajce_publisher_get_url (self);
#line 407 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp19_ = _tmp18_;
#line 407 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp20_ = self->priv->parameters;
#line 407 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp21_ = _tmp20_->album_id;
#line 407 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp22_ = publishing_rajce_open_album_transaction_new (_tmp17_, _tmp19_, *_tmp21_);
#line 407 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp23_ = _tmp22_;
#line 407 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_g_free0 (_tmp19_);
#line 407 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		open_album_trans = _tmp23_;
#line 408 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp24_ = open_album_trans;
#line 408 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp24_, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "network-error", (GCallback) _publishing_rajce_rajce_publisher_on_open_album_error_publishing_rest_support_transaction_network_error, self, 0);
#line 409 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp25_ = open_album_trans;
#line 409 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp25_, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "completed", (GCallback) _publishing_rajce_rajce_publisher_on_open_album_complete_publishing_rest_support_transaction_completed, self, 0);
#line 4008 "RajcePublishing.c"
		{
			PublishingRajceOpenAlbumTransaction* _tmp26_;
#line 412 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			_tmp26_ = open_album_trans;
#line 412 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			publishing_rest_support_transaction_execute (G_TYPE_CHECK_INSTANCE_CAST (_tmp26_, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), &_inner_error_);
#line 412 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 412 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
				if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 4019 "RajcePublishing.c"
					goto __catch21_spit_publishing_publishing_error;
				}
#line 412 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
				_publishing_rest_support_transaction_unref0 (open_album_trans);
#line 412 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
				g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 412 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
				g_clear_error (&_inner_error_);
#line 412 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
				return;
#line 4030 "RajcePublishing.c"
			}
		}
		goto __finally21;
		__catch21_spit_publishing_publishing_error:
		{
			GError* err = NULL;
			GError* _tmp27_;
#line 410 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			err = _inner_error_;
#line 410 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			_inner_error_ = NULL;
#line 416 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			g_debug ("RajcePublishing.vala:416: ERROR: open album");
#line 417 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			_tmp27_ = err;
#line 417 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			publishing_rajce_rajce_publisher_do_show_error (self, _tmp27_);
#line 410 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			_g_error_free0 (err);
#line 4050 "RajcePublishing.c"
		}
		__finally21:
#line 410 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 410 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			_publishing_rest_support_transaction_unref0 (open_album_trans);
#line 410 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 410 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			g_clear_error (&_inner_error_);
#line 410 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			return;
#line 4063 "RajcePublishing.c"
		}
#line 386 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_publishing_rest_support_transaction_unref0 (open_album_trans);
#line 4067 "RajcePublishing.c"
	}
}


/**
     * Event triggered when the create album completes successfully.
     */
static gint*
_int_dup (gint* self)
{
	gint* dup;
#line 437 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	dup = g_new0 (gint, 1);
#line 437 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	memcpy (dup, self, sizeof (gint));
#line 437 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	return dup;
#line 4085 "RajcePublishing.c"
}


static gpointer
__int_dup0 (gpointer self)
{
#line 437 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	return self ? _int_dup (self) : NULL;
#line 4094 "RajcePublishing.c"
}


static void
publishing_rajce_rajce_publisher_on_create_album_complete (PublishingRajceRajcePublisher* self,
                                                           PublishingRESTSupportTransaction* txn)
{
	guint _tmp0_;
	guint _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	GError * _inner_error_ = NULL;
#line 425 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_if_fail (PUBLISHING_RAJCE_IS_RAJCE_PUBLISHER (self));
#line 425 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_if_fail (PUBLISHING_REST_SUPPORT_IS_TRANSACTION (txn));
#line 427 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_debug ("RajcePublishing.vala:427: EVENT: on_create_album_complete");
#line 428 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_signal_parse_name ("completed", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp0_, NULL, FALSE);
#line 428 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_signal_handlers_disconnect_matched (txn, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp0_, 0, NULL, (GCallback) _publishing_rajce_rajce_publisher_on_create_album_complete_publishing_rest_support_transaction_completed, self);
#line 429 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_signal_parse_name ("network-error", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp1_, NULL, FALSE);
#line 429 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_signal_handlers_disconnect_matched (txn, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _publishing_rajce_rajce_publisher_on_create_album_error_publishing_rest_support_transaction_network_error, self);
#line 430 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp2_ = publishing_rest_support_transaction_get_response (txn);
#line 430 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp3_ = _tmp2_;
#line 430 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_debug ("RajcePublishing.vala:430: RajcePlugin: create album: %s", _tmp3_);
#line 430 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_free0 (_tmp3_);
#line 4129 "RajcePublishing.c"
	{
		PublishingRESTSupportXmlDocument* doc = NULL;
		gchar* _tmp4_;
		gchar* _tmp5_;
		PublishingRESTSupportXmlDocument* _tmp6_;
		PublishingRESTSupportXmlDocument* _tmp7_;
		xmlNode* response = NULL;
		PublishingRESTSupportXmlDocument* _tmp8_;
		xmlNode* _tmp9_;
		xmlNode* _tmp10_ = NULL;
		PublishingRESTSupportXmlDocument* _tmp11_;
		xmlNode* _tmp12_;
		xmlNode* _tmp13_;
		gchar* sessionToken = NULL;
		gchar* _tmp14_;
		xmlNode* _tmp15_ = NULL;
		PublishingRESTSupportXmlDocument* _tmp16_;
		xmlNode* _tmp17_;
		xmlNode* _tmp18_;
		gchar* albumToken = NULL;
		gchar* _tmp19_;
		xmlNode* _tmp20_ = NULL;
		PublishingRESTSupportXmlDocument* _tmp21_;
		xmlNode* _tmp22_;
		xmlNode* _tmp23_;
		PublishingRajcePublishingParameters* _tmp24_;
		gchar* _tmp25_;
		gchar* _tmp26_;
		gint _tmp27_;
		gint* _tmp28_;
		PublishingRajceSession* _tmp29_;
		const gchar* _tmp30_;
		PublishingRajceSession* _tmp31_;
		const gchar* _tmp32_;
#line 433 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp4_ = publishing_rest_support_transaction_get_response (txn);
#line 433 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp5_ = _tmp4_;
#line 433 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp6_ = publishing_rest_support_xml_document_parse_string (_tmp5_, _publishing_rajce_transaction_validate_xml_publishing_rest_support_xml_document_check_for_error_response, NULL, &_inner_error_);
#line 433 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp7_ = _tmp6_;
#line 433 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_g_free0 (_tmp5_);
#line 433 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		doc = _tmp7_;
#line 433 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 433 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 4180 "RajcePublishing.c"
				goto __catch22_spit_publishing_publishing_error;
			}
#line 433 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 433 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			g_clear_error (&_inner_error_);
#line 433 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			return;
#line 4189 "RajcePublishing.c"
		}
#line 434 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp8_ = doc;
#line 434 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp9_ = publishing_rest_support_xml_document_get_root_node (_tmp8_);
#line 434 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		response = _tmp9_;
#line 435 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp11_ = doc;
#line 435 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp12_ = response;
#line 435 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp13_ = publishing_rest_support_xml_document_get_named_child (_tmp11_, _tmp12_, "sessionToken", &_inner_error_);
#line 435 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp10_ = _tmp13_;
#line 435 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 435 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			_publishing_rest_support_xml_document_unref0 (doc);
#line 435 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 4211 "RajcePublishing.c"
				goto __catch22_spit_publishing_publishing_error;
			}
#line 435 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			_publishing_rest_support_xml_document_unref0 (doc);
#line 435 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 435 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			g_clear_error (&_inner_error_);
#line 435 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			return;
#line 4222 "RajcePublishing.c"
		}
#line 435 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp14_ = (gchar*) xmlNodeGetContent (_tmp10_);
#line 435 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		sessionToken = _tmp14_;
#line 436 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp16_ = doc;
#line 436 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp17_ = response;
#line 436 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp18_ = publishing_rest_support_xml_document_get_named_child (_tmp16_, _tmp17_, "albumToken", &_inner_error_);
#line 436 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp15_ = _tmp18_;
#line 436 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 436 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			_g_free0 (sessionToken);
#line 436 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			_publishing_rest_support_xml_document_unref0 (doc);
#line 436 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 4244 "RajcePublishing.c"
				goto __catch22_spit_publishing_publishing_error;
			}
#line 436 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			_g_free0 (sessionToken);
#line 436 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			_publishing_rest_support_xml_document_unref0 (doc);
#line 436 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 436 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			g_clear_error (&_inner_error_);
#line 436 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			return;
#line 4257 "RajcePublishing.c"
		}
#line 436 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp19_ = (gchar*) xmlNodeGetContent (_tmp15_);
#line 436 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		albumToken = _tmp19_;
#line 437 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp21_ = doc;
#line 437 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp22_ = response;
#line 437 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp23_ = publishing_rest_support_xml_document_get_named_child (_tmp21_, _tmp22_, "albumID", &_inner_error_);
#line 437 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp20_ = _tmp23_;
#line 437 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 437 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			_g_free0 (albumToken);
#line 437 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			_g_free0 (sessionToken);
#line 437 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			_publishing_rest_support_xml_document_unref0 (doc);
#line 437 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 4281 "RajcePublishing.c"
				goto __catch22_spit_publishing_publishing_error;
			}
#line 437 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			_g_free0 (albumToken);
#line 437 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			_g_free0 (sessionToken);
#line 437 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			_publishing_rest_support_xml_document_unref0 (doc);
#line 437 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 437 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			g_clear_error (&_inner_error_);
#line 437 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			return;
#line 4296 "RajcePublishing.c"
		}
#line 437 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp24_ = self->priv->parameters;
#line 437 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp25_ = (gchar*) xmlNodeGetContent (_tmp20_);
#line 437 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp26_ = _tmp25_;
#line 437 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp27_ = atoi (_tmp26_);
#line 437 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp28_ = __int_dup0 (&_tmp27_);
#line 437 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_g_free0 (_tmp24_->album_id);
#line 437 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp24_->album_id = _tmp28_;
#line 437 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_g_free0 (_tmp26_);
#line 438 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp29_ = self->priv->session;
#line 438 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp30_ = sessionToken;
#line 438 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		publishing_rajce_session_set_usertoken (_tmp29_, _tmp30_);
#line 439 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp31_ = self->priv->session;
#line 439 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp32_ = albumToken;
#line 439 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		publishing_rajce_session_set_albumtoken (_tmp31_, _tmp32_);
#line 431 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_g_free0 (albumToken);
#line 431 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_g_free0 (sessionToken);
#line 431 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_publishing_rest_support_xml_document_unref0 (doc);
#line 4332 "RajcePublishing.c"
	}
	goto __finally22;
	__catch22_spit_publishing_publishing_error:
	{
		GError* err = NULL;
		GError* _tmp33_;
#line 431 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		err = _inner_error_;
#line 431 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_inner_error_ = NULL;
#line 443 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		g_debug ("RajcePublishing.vala:443: ERROR: on_create_album_complete");
#line 444 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp33_ = err;
#line 444 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		publishing_rajce_rajce_publisher_do_show_error (self, _tmp33_);
#line 445 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_g_error_free0 (err);
#line 445 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		return;
#line 4353 "RajcePublishing.c"
	}
	__finally22:
#line 431 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 431 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 431 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		g_clear_error (&_inner_error_);
#line 431 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		return;
#line 4364 "RajcePublishing.c"
	}
#line 447 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rajce_rajce_publisher_do_upload_photos (self);
#line 4368 "RajcePublishing.c"
}


/**
     * Event triggered when the create album transaction fails due to a network error.
     */
static void
publishing_rajce_rajce_publisher_on_create_album_error (PublishingRajceRajcePublisher* self,
                                                        PublishingRESTSupportTransaction* bad_txn,
                                                        GError* err)
{
	guint _tmp0_;
	guint _tmp1_;
#line 453 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_if_fail (PUBLISHING_RAJCE_IS_RAJCE_PUBLISHER (self));
#line 453 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_if_fail (PUBLISHING_REST_SUPPORT_IS_TRANSACTION (bad_txn));
#line 455 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_debug ("RajcePublishing.vala:455: EVENT: on_create_album_error");
#line 456 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_signal_parse_name ("completed", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp0_, NULL, FALSE);
#line 456 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_signal_handlers_disconnect_matched (bad_txn, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp0_, 0, NULL, (GCallback) _publishing_rajce_rajce_publisher_on_create_album_complete_publishing_rest_support_transaction_completed, self);
#line 457 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_signal_parse_name ("network-error", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp1_, NULL, FALSE);
#line 457 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_signal_handlers_disconnect_matched (bad_txn, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _publishing_rajce_rajce_publisher_on_create_album_error_publishing_rest_support_transaction_network_error, self);
#line 458 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rajce_rajce_publisher_on_network_error (self, bad_txn, err);
#line 4398 "RajcePublishing.c"
}


/**
     * Event triggered when the open album completes successfully.
     */
static void
publishing_rajce_rajce_publisher_on_open_album_complete (PublishingRajceRajcePublisher* self,
                                                         PublishingRESTSupportTransaction* txn)
{
	guint _tmp0_;
	guint _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	GError * _inner_error_ = NULL;
#line 464 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_if_fail (PUBLISHING_RAJCE_IS_RAJCE_PUBLISHER (self));
#line 464 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_if_fail (PUBLISHING_REST_SUPPORT_IS_TRANSACTION (txn));
#line 466 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_debug ("RajcePublishing.vala:466: EVENT: on_open_album_complete");
#line 467 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_signal_parse_name ("completed", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp0_, NULL, FALSE);
#line 467 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_signal_handlers_disconnect_matched (txn, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp0_, 0, NULL, (GCallback) _publishing_rajce_rajce_publisher_on_open_album_complete_publishing_rest_support_transaction_completed, self);
#line 468 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_signal_parse_name ("network-error", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp1_, NULL, FALSE);
#line 468 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_signal_handlers_disconnect_matched (txn, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _publishing_rajce_rajce_publisher_on_open_album_error_publishing_rest_support_transaction_network_error, self);
#line 469 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp2_ = publishing_rest_support_transaction_get_response (txn);
#line 469 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp3_ = _tmp2_;
#line 469 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_debug ("RajcePublishing.vala:469: RajcePlugin: open album: %s", _tmp3_);
#line 469 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_free0 (_tmp3_);
#line 4436 "RajcePublishing.c"
	{
		PublishingRESTSupportXmlDocument* doc = NULL;
		gchar* _tmp4_;
		gchar* _tmp5_;
		PublishingRESTSupportXmlDocument* _tmp6_;
		PublishingRESTSupportXmlDocument* _tmp7_;
		xmlNode* response = NULL;
		PublishingRESTSupportXmlDocument* _tmp8_;
		xmlNode* _tmp9_;
		xmlNode* _tmp10_ = NULL;
		PublishingRESTSupportXmlDocument* _tmp11_;
		xmlNode* _tmp12_;
		xmlNode* _tmp13_;
		gchar* sessionToken = NULL;
		gchar* _tmp14_;
		xmlNode* _tmp15_ = NULL;
		PublishingRESTSupportXmlDocument* _tmp16_;
		xmlNode* _tmp17_;
		xmlNode* _tmp18_;
		gchar* albumToken = NULL;
		gchar* _tmp19_;
		PublishingRajceSession* _tmp20_;
		const gchar* _tmp21_;
		PublishingRajceSession* _tmp22_;
		const gchar* _tmp23_;
#line 472 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp4_ = publishing_rest_support_transaction_get_response (txn);
#line 472 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp5_ = _tmp4_;
#line 472 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp6_ = publishing_rest_support_xml_document_parse_string (_tmp5_, _publishing_rajce_transaction_validate_xml_publishing_rest_support_xml_document_check_for_error_response, NULL, &_inner_error_);
#line 472 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp7_ = _tmp6_;
#line 472 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_g_free0 (_tmp5_);
#line 472 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		doc = _tmp7_;
#line 472 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 472 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 4478 "RajcePublishing.c"
				goto __catch23_spit_publishing_publishing_error;
			}
#line 472 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 472 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			g_clear_error (&_inner_error_);
#line 472 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			return;
#line 4487 "RajcePublishing.c"
		}
#line 473 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp8_ = doc;
#line 473 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp9_ = publishing_rest_support_xml_document_get_root_node (_tmp8_);
#line 473 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		response = _tmp9_;
#line 474 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp11_ = doc;
#line 474 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp12_ = response;
#line 474 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp13_ = publishing_rest_support_xml_document_get_named_child (_tmp11_, _tmp12_, "sessionToken", &_inner_error_);
#line 474 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp10_ = _tmp13_;
#line 474 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 474 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			_publishing_rest_support_xml_document_unref0 (doc);
#line 474 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 4509 "RajcePublishing.c"
				goto __catch23_spit_publishing_publishing_error;
			}
#line 474 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			_publishing_rest_support_xml_document_unref0 (doc);
#line 474 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 474 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			g_clear_error (&_inner_error_);
#line 474 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			return;
#line 4520 "RajcePublishing.c"
		}
#line 474 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp14_ = (gchar*) xmlNodeGetContent (_tmp10_);
#line 474 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		sessionToken = _tmp14_;
#line 475 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp16_ = doc;
#line 475 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp17_ = response;
#line 475 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp18_ = publishing_rest_support_xml_document_get_named_child (_tmp16_, _tmp17_, "albumToken", &_inner_error_);
#line 475 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp15_ = _tmp18_;
#line 475 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 475 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			_g_free0 (sessionToken);
#line 475 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			_publishing_rest_support_xml_document_unref0 (doc);
#line 475 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 4542 "RajcePublishing.c"
				goto __catch23_spit_publishing_publishing_error;
			}
#line 475 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			_g_free0 (sessionToken);
#line 475 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			_publishing_rest_support_xml_document_unref0 (doc);
#line 475 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 475 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			g_clear_error (&_inner_error_);
#line 475 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			return;
#line 4555 "RajcePublishing.c"
		}
#line 475 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp19_ = (gchar*) xmlNodeGetContent (_tmp15_);
#line 475 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		albumToken = _tmp19_;
#line 476 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp20_ = self->priv->session;
#line 476 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp21_ = sessionToken;
#line 476 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		publishing_rajce_session_set_usertoken (_tmp20_, _tmp21_);
#line 477 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp22_ = self->priv->session;
#line 477 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp23_ = albumToken;
#line 477 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		publishing_rajce_session_set_albumtoken (_tmp22_, _tmp23_);
#line 470 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_g_free0 (albumToken);
#line 470 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_g_free0 (sessionToken);
#line 470 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_publishing_rest_support_xml_document_unref0 (doc);
#line 4579 "RajcePublishing.c"
	}
	goto __finally23;
	__catch23_spit_publishing_publishing_error:
	{
		GError* err = NULL;
		GError* _tmp24_;
#line 470 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		err = _inner_error_;
#line 470 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_inner_error_ = NULL;
#line 481 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		g_debug ("RajcePublishing.vala:481: ERROR: on_open_album_complete");
#line 482 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp24_ = err;
#line 482 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		publishing_rajce_rajce_publisher_do_show_error (self, _tmp24_);
#line 483 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_g_error_free0 (err);
#line 483 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		return;
#line 4600 "RajcePublishing.c"
	}
	__finally23:
#line 470 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 470 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 470 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		g_clear_error (&_inner_error_);
#line 470 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		return;
#line 4611 "RajcePublishing.c"
	}
#line 485 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rajce_rajce_publisher_do_upload_photos (self);
#line 4615 "RajcePublishing.c"
}


/**
     * Event triggered when the open album transaction fails due to a network error.
     */
static void
publishing_rajce_rajce_publisher_on_open_album_error (PublishingRajceRajcePublisher* self,
                                                      PublishingRESTSupportTransaction* bad_txn,
                                                      GError* err)
{
	guint _tmp0_;
	guint _tmp1_;
#line 491 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_if_fail (PUBLISHING_RAJCE_IS_RAJCE_PUBLISHER (self));
#line 491 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_if_fail (PUBLISHING_REST_SUPPORT_IS_TRANSACTION (bad_txn));
#line 493 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_debug ("RajcePublishing.vala:493: EVENT: on_open_album_error");
#line 494 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_signal_parse_name ("completed", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp0_, NULL, FALSE);
#line 494 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_signal_handlers_disconnect_matched (bad_txn, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp0_, 0, NULL, (GCallback) _publishing_rajce_rajce_publisher_on_open_album_complete_publishing_rest_support_transaction_completed, self);
#line 495 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_signal_parse_name ("network-error", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp1_, NULL, FALSE);
#line 495 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_signal_handlers_disconnect_matched (bad_txn, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _publishing_rajce_rajce_publisher_on_open_album_error_publishing_rest_support_transaction_network_error, self);
#line 496 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rajce_rajce_publisher_on_network_error (self, bad_txn, err);
#line 4645 "RajcePublishing.c"
}


/**
     * Upload photos: the key part of the plugin
     */
static void
_publishing_rajce_rajce_publisher_on_upload_photos_complete_publishing_rest_support_batch_uploader_upload_complete (PublishingRESTSupportBatchUploader* _sender,
                                                                                                                    gint num_photos_published,
                                                                                                                    gpointer self)
{
#line 509 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rajce_rajce_publisher_on_upload_photos_complete ((PublishingRajceRajcePublisher*) self, _sender, num_photos_published);
#line 4659 "RajcePublishing.c"
}


static void
_publishing_rajce_rajce_publisher_on_upload_photos_error_publishing_rest_support_batch_uploader_upload_error (PublishingRESTSupportBatchUploader* _sender,
                                                                                                              GError* err,
                                                                                                              gpointer self)
{
#line 510 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rajce_rajce_publisher_on_upload_photos_error ((PublishingRajceRajcePublisher*) self, _sender, err);
#line 4670 "RajcePublishing.c"
}


static void
_publishing_rajce_rajce_publisher_on_upload_photos_status_updated_spit_publishing_progress_callback (gint file_number,
                                                                                                     gdouble fraction_complete,
                                                                                                     gpointer self)
{
#line 511 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rajce_rajce_publisher_on_upload_photos_status_updated ((PublishingRajceRajcePublisher*) self, file_number, fraction_complete);
#line 4681 "RajcePublishing.c"
}


static void
publishing_rajce_rajce_publisher_do_upload_photos (PublishingRajceRajcePublisher* self)
{
	SpitPublishingPluginHost* _tmp0_;
	PublishingRajceSession* _tmp1_;
	void* _tmp2_;
	GDestroyNotify _tmp3_;
	SpitPublishingProgressCallback _tmp4_;
	SpitPublishingPublishable** publishables = NULL;
	SpitPublishingPluginHost* _tmp5_;
	gint _tmp6_;
	SpitPublishingPublishable** _tmp7_;
	gint publishables_length1;
	gint _publishables_size_;
	PublishingRajceUploader* uploader = NULL;
	PublishingRajceSession* _tmp8_;
	gchar* _tmp9_;
	gchar* _tmp10_;
	PublishingRajcePublishingParameters* _tmp11_;
	PublishingRajceUploader* _tmp12_;
	PublishingRajceUploader* _tmp13_;
#line 502 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_if_fail (PUBLISHING_RAJCE_IS_RAJCE_PUBLISHER (self));
#line 504 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_debug ("RajcePublishing.vala:504: ACTION: uploading photos");
#line 505 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp0_ = self->priv->host;
#line 505 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp1_ = self->priv->session;
#line 505 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp4_ = spit_publishing_plugin_host_serialize_publishables (_tmp0_, publishing_rajce_session_get_maxsize (_tmp1_), FALSE, &_tmp2_, &_tmp3_);
#line 505 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	(self->priv->progress_reporter_target_destroy_notify == NULL) ? NULL : (self->priv->progress_reporter_target_destroy_notify (self->priv->progress_reporter_target), NULL);
#line 505 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self->priv->progress_reporter = NULL;
#line 505 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self->priv->progress_reporter_target = NULL;
#line 505 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self->priv->progress_reporter_target_destroy_notify = NULL;
#line 505 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self->priv->progress_reporter = _tmp4_;
#line 505 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self->priv->progress_reporter_target = _tmp2_;
#line 505 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self->priv->progress_reporter_target_destroy_notify = _tmp3_;
#line 506 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp5_ = self->priv->host;
#line 506 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp7_ = spit_publishing_plugin_host_get_publishables (_tmp5_, &_tmp6_);
#line 506 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishables = _tmp7_;
#line 506 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishables_length1 = _tmp6_;
#line 506 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_publishables_size_ = publishables_length1;
#line 508 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp8_ = self->priv->session;
#line 508 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp9_ = publishing_rajce_rajce_publisher_get_url (self);
#line 508 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp10_ = _tmp9_;
#line 508 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp11_ = self->priv->parameters;
#line 508 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp12_ = publishing_rajce_uploader_new (_tmp8_, _tmp10_, publishables, publishables_length1, _tmp11_);
#line 508 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp13_ = _tmp12_;
#line 508 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_free0 (_tmp10_);
#line 508 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	uploader = _tmp13_;
#line 509 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (uploader, PUBLISHING_REST_SUPPORT_TYPE_BATCH_UPLOADER, PublishingRESTSupportBatchUploader), "upload-complete", (GCallback) _publishing_rajce_rajce_publisher_on_upload_photos_complete_publishing_rest_support_batch_uploader_upload_complete, self, 0);
#line 510 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (uploader, PUBLISHING_REST_SUPPORT_TYPE_BATCH_UPLOADER, PublishingRESTSupportBatchUploader), "upload-error", (GCallback) _publishing_rajce_rajce_publisher_on_upload_photos_error_publishing_rest_support_batch_uploader_upload_error, self, 0);
#line 511 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rest_support_batch_uploader_upload (G_TYPE_CHECK_INSTANCE_CAST (uploader, PUBLISHING_REST_SUPPORT_TYPE_BATCH_UPLOADER, PublishingRESTSupportBatchUploader), _publishing_rajce_rajce_publisher_on_upload_photos_status_updated_spit_publishing_progress_callback, self);
#line 502 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_publishing_rest_support_batch_uploader_unref0 (uploader);
#line 502 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishables = (_vala_array_free (publishables, publishables_length1, (GDestroyNotify) g_object_unref), NULL);
#line 4766 "RajcePublishing.c"
}


/**
     * Event triggered when the batch uploader reports that at least one of the
     * network transactions encapsulating uploads has completed successfully
     */
static void
publishing_rajce_rajce_publisher_on_upload_photos_complete (PublishingRajceRajcePublisher* self,
                                                            PublishingRESTSupportBatchUploader* uploader,
                                                            gint num_published)
{
	guint _tmp0_;
	guint _tmp1_;
#line 518 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_if_fail (PUBLISHING_RAJCE_IS_RAJCE_PUBLISHER (self));
#line 518 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_if_fail (PUBLISHING_REST_SUPPORT_IS_BATCH_UPLOADER (uploader));
#line 520 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_debug ("RajcePublishing.vala:520: EVENT: on_upload_photos_complete");
#line 521 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_signal_parse_name ("upload-complete", PUBLISHING_REST_SUPPORT_TYPE_BATCH_UPLOADER, &_tmp0_, NULL, FALSE);
#line 521 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_signal_handlers_disconnect_matched (uploader, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp0_, 0, NULL, (GCallback) _publishing_rajce_rajce_publisher_on_upload_photos_complete_publishing_rest_support_batch_uploader_upload_complete, self);
#line 522 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_signal_parse_name ("upload-error", PUBLISHING_REST_SUPPORT_TYPE_BATCH_UPLOADER, &_tmp1_, NULL, FALSE);
#line 522 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_signal_handlers_disconnect_matched (uploader, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _publishing_rajce_rajce_publisher_on_upload_photos_error_publishing_rest_support_batch_uploader_upload_error, self);
#line 525 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rajce_rajce_publisher_do_end_upload (self);
#line 4797 "RajcePublishing.c"
}


/**
     * Event triggered when the batch uploader reports that at least one of the
     * network transactions encapsulating uploads has caused a network error
     */
static void
publishing_rajce_rajce_publisher_on_upload_photos_error (PublishingRajceRajcePublisher* self,
                                                         PublishingRESTSupportBatchUploader* uploader,
                                                         GError* err)
{
	guint _tmp0_;
	guint _tmp1_;
#line 532 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_if_fail (PUBLISHING_RAJCE_IS_RAJCE_PUBLISHER (self));
#line 532 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_if_fail (PUBLISHING_REST_SUPPORT_IS_BATCH_UPLOADER (uploader));
#line 534 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_debug ("RajcePublishing.vala:534: EVENT: on_upload_photos_error");
#line 535 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_signal_parse_name ("upload-complete", PUBLISHING_REST_SUPPORT_TYPE_BATCH_UPLOADER, &_tmp0_, NULL, FALSE);
#line 535 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_signal_handlers_disconnect_matched (uploader, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp0_, 0, NULL, (GCallback) _publishing_rajce_rajce_publisher_on_upload_photos_complete_publishing_rest_support_batch_uploader_upload_complete, self);
#line 536 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_signal_parse_name ("upload-error", PUBLISHING_REST_SUPPORT_TYPE_BATCH_UPLOADER, &_tmp1_, NULL, FALSE);
#line 536 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_signal_handlers_disconnect_matched (uploader, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _publishing_rajce_rajce_publisher_on_upload_photos_error_publishing_rest_support_batch_uploader_upload_error, self);
#line 537 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rajce_rajce_publisher_do_show_error (self, err);
#line 4828 "RajcePublishing.c"
}


/**
     * Event triggered when upload progresses and the status needs to be updated.
     */
static void
publishing_rajce_rajce_publisher_on_upload_photos_status_updated (PublishingRajceRajcePublisher* self,
                                                                  gint file_number,
                                                                  gdouble completed_fraction)
{
#line 543 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_if_fail (PUBLISHING_RAJCE_IS_RAJCE_PUBLISHER (self));
#line 545 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	if (spit_publishing_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_PUBLISHER, SpitPublishingPublisher))) {
#line 4844 "RajcePublishing.c"
		SpitPublishingProgressCallback _tmp0_;
		void* _tmp0__target;
		SpitPublishingProgressCallback _tmp1_;
		void* _tmp1__target;
#line 547 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		g_debug ("RajcePublishing.vala:547: EVENT: uploader reports upload %.2f percent " \
"complete.", 100.0 * completed_fraction);
#line 548 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp0_ = self->priv->progress_reporter;
#line 548 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp0__target = self->priv->progress_reporter_target;
#line 548 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_vala_assert (_tmp0_ != NULL, "progress_reporter != null");
#line 549 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp1_ = self->priv->progress_reporter;
#line 549 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp1__target = self->priv->progress_reporter_target;
#line 549 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp1_ (file_number, completed_fraction, _tmp1__target);
#line 4863 "RajcePublishing.c"
	}
}


static void
publishing_rajce_rajce_publisher_do_end_upload (PublishingRajceRajcePublisher* self)
{
#line 553 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_if_fail (PUBLISHING_RAJCE_IS_RAJCE_PUBLISHER (self));
#line 555 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	if (publishing_rajce_rajce_publisher_get_show_album (self)) {
#line 557 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		publishing_rajce_rajce_publisher_do_get_album_url (self);
#line 4877 "RajcePublishing.c"
	} else {
#line 561 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		publishing_rajce_rajce_publisher_do_close_album (self);
#line 4881 "RajcePublishing.c"
	}
}


/**
     * End upload action: get album url
     */
static void
_publishing_rajce_rajce_publisher_on_get_album_url_error_publishing_rest_support_transaction_network_error (PublishingRESTSupportTransaction* _sender,
                                                                                                            GError* err,
                                                                                                            gpointer self)
{
#line 573 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rajce_rajce_publisher_on_get_album_url_error ((PublishingRajceRajcePublisher*) self, _sender, err);
#line 4896 "RajcePublishing.c"
}


static void
_publishing_rajce_rajce_publisher_on_get_album_url_complete_publishing_rest_support_transaction_completed (PublishingRESTSupportTransaction* _sender,
                                                                                                           gpointer self)
{
#line 574 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rajce_rajce_publisher_on_get_album_url_complete ((PublishingRajceRajcePublisher*) self, _sender);
#line 4906 "RajcePublishing.c"
}


static void
publishing_rajce_rajce_publisher_do_get_album_url (PublishingRajceRajcePublisher* self)
{
	SpitPublishingPluginHost* _tmp0_;
	PublishingRajceGetAlbumUrlTransaction* get_album_url_trans = NULL;
	PublishingRajceSession* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	PublishingRajceGetAlbumUrlTransaction* _tmp4_;
	PublishingRajceGetAlbumUrlTransaction* _tmp5_;
	GError * _inner_error_ = NULL;
#line 568 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_if_fail (PUBLISHING_RAJCE_IS_RAJCE_PUBLISHER (self));
#line 570 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_debug ("RajcePublishing.vala:570: ACTION: getting album URL");
#line 571 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp0_ = self->priv->host;
#line 571 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	spit_publishing_plugin_host_set_service_locked (_tmp0_, TRUE);
#line 572 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp1_ = self->priv->session;
#line 572 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp2_ = publishing_rajce_rajce_publisher_get_url (self);
#line 572 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp3_ = _tmp2_;
#line 572 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp4_ = publishing_rajce_get_album_url_transaction_new (_tmp1_, _tmp3_);
#line 572 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp5_ = _tmp4_;
#line 572 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_free0 (_tmp3_);
#line 572 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	get_album_url_trans = _tmp5_;
#line 573 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (get_album_url_trans, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "network-error", (GCallback) _publishing_rajce_rajce_publisher_on_get_album_url_error_publishing_rest_support_transaction_network_error, self, 0);
#line 574 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (get_album_url_trans, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "completed", (GCallback) _publishing_rajce_rajce_publisher_on_get_album_url_complete_publishing_rest_support_transaction_completed, self, 0);
#line 4947 "RajcePublishing.c"
	{
#line 577 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		publishing_rest_support_transaction_execute (G_TYPE_CHECK_INSTANCE_CAST (get_album_url_trans, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), &_inner_error_);
#line 577 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 577 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 4955 "RajcePublishing.c"
				goto __catch24_spit_publishing_publishing_error;
			}
#line 577 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			_publishing_rest_support_transaction_unref0 (get_album_url_trans);
#line 577 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 577 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			g_clear_error (&_inner_error_);
#line 577 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			return;
#line 4966 "RajcePublishing.c"
		}
	}
	goto __finally24;
	__catch24_spit_publishing_publishing_error:
	{
		GError* err = NULL;
		GError* _tmp6_;
#line 575 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		err = _inner_error_;
#line 575 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_inner_error_ = NULL;
#line 581 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		g_debug ("RajcePublishing.vala:581: ERROR: close album");
#line 582 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp6_ = err;
#line 582 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		publishing_rajce_rajce_publisher_do_show_error (self, _tmp6_);
#line 575 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_g_error_free0 (err);
#line 4986 "RajcePublishing.c"
	}
	__finally24:
#line 575 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 575 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_publishing_rest_support_transaction_unref0 (get_album_url_trans);
#line 575 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 575 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		g_clear_error (&_inner_error_);
#line 575 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		return;
#line 4999 "RajcePublishing.c"
	}
#line 568 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_publishing_rest_support_transaction_unref0 (get_album_url_trans);
#line 5003 "RajcePublishing.c"
}


/**
     * Event triggered when the get album url completes successfully.
     */
static void
publishing_rajce_rajce_publisher_on_get_album_url_complete (PublishingRajceRajcePublisher* self,
                                                            PublishingRESTSupportTransaction* txn)
{
	guint _tmp0_;
	guint _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	GError * _inner_error_ = NULL;
#line 589 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_if_fail (PUBLISHING_RAJCE_IS_RAJCE_PUBLISHER (self));
#line 589 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_if_fail (PUBLISHING_REST_SUPPORT_IS_TRANSACTION (txn));
#line 591 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_debug ("RajcePublishing.vala:591: EVENT: on_get_album_url_complete");
#line 592 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_signal_parse_name ("completed", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp0_, NULL, FALSE);
#line 592 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_signal_handlers_disconnect_matched (txn, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp0_, 0, NULL, (GCallback) _publishing_rajce_rajce_publisher_on_get_album_url_complete_publishing_rest_support_transaction_completed, self);
#line 593 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_signal_parse_name ("network-error", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp1_, NULL, FALSE);
#line 593 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_signal_handlers_disconnect_matched (txn, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _publishing_rajce_rajce_publisher_on_get_album_url_error_publishing_rest_support_transaction_network_error, self);
#line 594 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp2_ = publishing_rest_support_transaction_get_response (txn);
#line 594 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp3_ = _tmp2_;
#line 594 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_debug ("RajcePublishing.vala:594: RajcePlugin: get album url: %s", _tmp3_);
#line 594 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_free0 (_tmp3_);
#line 5041 "RajcePublishing.c"
	{
		PublishingRESTSupportXmlDocument* doc = NULL;
		gchar* _tmp4_;
		gchar* _tmp5_;
		PublishingRESTSupportXmlDocument* _tmp6_;
		PublishingRESTSupportXmlDocument* _tmp7_;
		xmlNode* response = NULL;
		PublishingRESTSupportXmlDocument* _tmp8_;
		xmlNode* _tmp9_;
		xmlNode* _tmp10_ = NULL;
		PublishingRESTSupportXmlDocument* _tmp11_;
		xmlNode* _tmp12_;
		xmlNode* _tmp13_;
		gchar* sessionToken = NULL;
		gchar* _tmp14_;
		xmlNode* _tmp15_ = NULL;
		PublishingRESTSupportXmlDocument* _tmp16_;
		xmlNode* _tmp17_;
		xmlNode* _tmp18_;
		gchar* url = NULL;
		gchar* _tmp19_;
		PublishingRajceSession* _tmp20_;
		const gchar* _tmp21_;
		PublishingRajceSession* _tmp22_;
		const gchar* _tmp23_;
#line 597 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp4_ = publishing_rest_support_transaction_get_response (txn);
#line 597 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp5_ = _tmp4_;
#line 597 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp6_ = publishing_rest_support_xml_document_parse_string (_tmp5_, _publishing_rajce_transaction_validate_xml_publishing_rest_support_xml_document_check_for_error_response, NULL, &_inner_error_);
#line 597 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp7_ = _tmp6_;
#line 597 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_g_free0 (_tmp5_);
#line 597 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		doc = _tmp7_;
#line 597 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 597 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 5083 "RajcePublishing.c"
				goto __catch25_spit_publishing_publishing_error;
			}
#line 597 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 597 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			g_clear_error (&_inner_error_);
#line 597 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			return;
#line 5092 "RajcePublishing.c"
		}
#line 598 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp8_ = doc;
#line 598 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp9_ = publishing_rest_support_xml_document_get_root_node (_tmp8_);
#line 598 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		response = _tmp9_;
#line 599 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp11_ = doc;
#line 599 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp12_ = response;
#line 599 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp13_ = publishing_rest_support_xml_document_get_named_child (_tmp11_, _tmp12_, "sessionToken", &_inner_error_);
#line 599 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp10_ = _tmp13_;
#line 599 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 599 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			_publishing_rest_support_xml_document_unref0 (doc);
#line 599 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 5114 "RajcePublishing.c"
				goto __catch25_spit_publishing_publishing_error;
			}
#line 599 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			_publishing_rest_support_xml_document_unref0 (doc);
#line 599 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 599 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			g_clear_error (&_inner_error_);
#line 599 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			return;
#line 5125 "RajcePublishing.c"
		}
#line 599 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp14_ = (gchar*) xmlNodeGetContent (_tmp10_);
#line 599 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		sessionToken = _tmp14_;
#line 600 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp16_ = doc;
#line 600 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp17_ = response;
#line 600 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp18_ = publishing_rest_support_xml_document_get_named_child (_tmp16_, _tmp17_, "url", &_inner_error_);
#line 600 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp15_ = _tmp18_;
#line 600 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 600 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			_g_free0 (sessionToken);
#line 600 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			_publishing_rest_support_xml_document_unref0 (doc);
#line 600 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 5147 "RajcePublishing.c"
				goto __catch25_spit_publishing_publishing_error;
			}
#line 600 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			_g_free0 (sessionToken);
#line 600 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			_publishing_rest_support_xml_document_unref0 (doc);
#line 600 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 600 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			g_clear_error (&_inner_error_);
#line 600 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			return;
#line 5160 "RajcePublishing.c"
		}
#line 600 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp19_ = (gchar*) xmlNodeGetContent (_tmp15_);
#line 600 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		url = _tmp19_;
#line 601 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp20_ = self->priv->session;
#line 601 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp21_ = sessionToken;
#line 601 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		publishing_rajce_session_set_usertoken (_tmp20_, _tmp21_);
#line 602 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp22_ = self->priv->session;
#line 602 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp23_ = url;
#line 602 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		publishing_rajce_session_set_albumticket (_tmp22_, _tmp23_);
#line 595 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_g_free0 (url);
#line 595 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_g_free0 (sessionToken);
#line 595 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_publishing_rest_support_xml_document_unref0 (doc);
#line 5184 "RajcePublishing.c"
	}
	goto __finally25;
	__catch25_spit_publishing_publishing_error:
	{
		GError* err = NULL;
#line 595 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		err = _inner_error_;
#line 595 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_inner_error_ = NULL;
#line 606 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		g_debug ("RajcePublishing.vala:606: ERROR: on_get_album_url_complete");
#line 595 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_g_error_free0 (err);
#line 5198 "RajcePublishing.c"
	}
	__finally25:
#line 595 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 595 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 595 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		g_clear_error (&_inner_error_);
#line 595 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		return;
#line 5209 "RajcePublishing.c"
	}
#line 611 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rajce_rajce_publisher_do_close_album (self);
#line 5213 "RajcePublishing.c"
}


/**
     * Event triggered when the get album url transaction fails due to a network error.
     */
static void
publishing_rajce_rajce_publisher_on_get_album_url_error (PublishingRajceRajcePublisher* self,
                                                         PublishingRESTSupportTransaction* bad_txn,
                                                         GError* err)
{
	guint _tmp0_;
	guint _tmp1_;
#line 617 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_if_fail (PUBLISHING_RAJCE_IS_RAJCE_PUBLISHER (self));
#line 617 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_if_fail (PUBLISHING_REST_SUPPORT_IS_TRANSACTION (bad_txn));
#line 619 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_debug ("RajcePublishing.vala:619: EVENT: on_get_album_url_error");
#line 620 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_signal_parse_name ("completed", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp0_, NULL, FALSE);
#line 620 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_signal_handlers_disconnect_matched (bad_txn, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp0_, 0, NULL, (GCallback) _publishing_rajce_rajce_publisher_on_get_album_url_complete_publishing_rest_support_transaction_completed, self);
#line 621 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_signal_parse_name ("network-error", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp1_, NULL, FALSE);
#line 621 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_signal_handlers_disconnect_matched (bad_txn, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _publishing_rajce_rajce_publisher_on_get_album_url_error_publishing_rest_support_transaction_network_error, self);
#line 624 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rajce_rajce_publisher_do_close_album (self);
#line 5243 "RajcePublishing.c"
}


/**
     * End upload action: close album
     */
static void
_publishing_rajce_rajce_publisher_on_close_album_error_publishing_rest_support_transaction_network_error (PublishingRESTSupportTransaction* _sender,
                                                                                                          GError* err,
                                                                                                          gpointer self)
{
#line 636 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rajce_rajce_publisher_on_close_album_error ((PublishingRajceRajcePublisher*) self, _sender, err);
#line 5257 "RajcePublishing.c"
}


static void
_publishing_rajce_rajce_publisher_on_close_album_complete_publishing_rest_support_transaction_completed (PublishingRESTSupportTransaction* _sender,
                                                                                                         gpointer self)
{
#line 637 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rajce_rajce_publisher_on_close_album_complete ((PublishingRajceRajcePublisher*) self, _sender);
#line 5267 "RajcePublishing.c"
}


static void
publishing_rajce_rajce_publisher_do_close_album (PublishingRajceRajcePublisher* self)
{
	SpitPublishingPluginHost* _tmp0_;
	PublishingRajceCloseAlbumTransaction* close_album_trans = NULL;
	PublishingRajceSession* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	PublishingRajceCloseAlbumTransaction* _tmp4_;
	PublishingRajceCloseAlbumTransaction* _tmp5_;
	GError * _inner_error_ = NULL;
#line 631 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_if_fail (PUBLISHING_RAJCE_IS_RAJCE_PUBLISHER (self));
#line 633 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_debug ("RajcePublishing.vala:633: ACTION: closing album");
#line 634 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp0_ = self->priv->host;
#line 634 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	spit_publishing_plugin_host_set_service_locked (_tmp0_, TRUE);
#line 635 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp1_ = self->priv->session;
#line 635 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp2_ = publishing_rajce_rajce_publisher_get_url (self);
#line 635 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp3_ = _tmp2_;
#line 635 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp4_ = publishing_rajce_close_album_transaction_new (_tmp1_, _tmp3_);
#line 635 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp5_ = _tmp4_;
#line 635 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_free0 (_tmp3_);
#line 635 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	close_album_trans = _tmp5_;
#line 636 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (close_album_trans, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "network-error", (GCallback) _publishing_rajce_rajce_publisher_on_close_album_error_publishing_rest_support_transaction_network_error, self, 0);
#line 637 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (close_album_trans, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "completed", (GCallback) _publishing_rajce_rajce_publisher_on_close_album_complete_publishing_rest_support_transaction_completed, self, 0);
#line 5308 "RajcePublishing.c"
	{
#line 640 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		publishing_rest_support_transaction_execute (G_TYPE_CHECK_INSTANCE_CAST (close_album_trans, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), &_inner_error_);
#line 640 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 640 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 5316 "RajcePublishing.c"
				goto __catch26_spit_publishing_publishing_error;
			}
#line 640 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			_publishing_rest_support_transaction_unref0 (close_album_trans);
#line 640 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 640 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			g_clear_error (&_inner_error_);
#line 640 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			return;
#line 5327 "RajcePublishing.c"
		}
	}
	goto __finally26;
	__catch26_spit_publishing_publishing_error:
	{
		GError* err = NULL;
		GError* _tmp6_;
#line 638 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		err = _inner_error_;
#line 638 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_inner_error_ = NULL;
#line 644 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		g_debug ("RajcePublishing.vala:644: ERROR: close album");
#line 645 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp6_ = err;
#line 645 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		publishing_rajce_rajce_publisher_do_show_error (self, _tmp6_);
#line 638 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_g_error_free0 (err);
#line 5347 "RajcePublishing.c"
	}
	__finally26:
#line 638 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 638 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_publishing_rest_support_transaction_unref0 (close_album_trans);
#line 638 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 638 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		g_clear_error (&_inner_error_);
#line 638 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		return;
#line 5360 "RajcePublishing.c"
	}
#line 631 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_publishing_rest_support_transaction_unref0 (close_album_trans);
#line 5364 "RajcePublishing.c"
}


/**
     * Event triggered when the close album completes successfully.
     */
static void
publishing_rajce_rajce_publisher_on_close_album_complete (PublishingRajceRajcePublisher* self,
                                                          PublishingRESTSupportTransaction* txn)
{
	guint _tmp0_;
	guint _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	GError * _inner_error_ = NULL;
#line 652 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_if_fail (PUBLISHING_RAJCE_IS_RAJCE_PUBLISHER (self));
#line 652 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_if_fail (PUBLISHING_REST_SUPPORT_IS_TRANSACTION (txn));
#line 654 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_debug ("RajcePublishing.vala:654: EVENT: on_close_album_complete");
#line 655 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_signal_parse_name ("completed", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp0_, NULL, FALSE);
#line 655 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_signal_handlers_disconnect_matched (txn, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp0_, 0, NULL, (GCallback) _publishing_rajce_rajce_publisher_on_close_album_complete_publishing_rest_support_transaction_completed, self);
#line 656 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_signal_parse_name ("network-error", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp1_, NULL, FALSE);
#line 656 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_signal_handlers_disconnect_matched (txn, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _publishing_rajce_rajce_publisher_on_close_album_error_publishing_rest_support_transaction_network_error, self);
#line 657 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp2_ = publishing_rest_support_transaction_get_response (txn);
#line 657 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp3_ = _tmp2_;
#line 657 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_debug ("RajcePublishing.vala:657: RajcePlugin: close album: %s", _tmp3_);
#line 657 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_free0 (_tmp3_);
#line 5402 "RajcePublishing.c"
	{
		PublishingRESTSupportXmlDocument* doc = NULL;
		gchar* _tmp4_;
		gchar* _tmp5_;
		PublishingRESTSupportXmlDocument* _tmp6_;
		PublishingRESTSupportXmlDocument* _tmp7_;
		xmlNode* response = NULL;
		PublishingRESTSupportXmlDocument* _tmp8_;
		xmlNode* _tmp9_;
		xmlNode* _tmp10_ = NULL;
		PublishingRESTSupportXmlDocument* _tmp11_;
		xmlNode* _tmp12_;
		xmlNode* _tmp13_;
		gchar* sessionToken = NULL;
		gchar* _tmp14_;
		PublishingRajceSession* _tmp15_;
		const gchar* _tmp16_;
		PublishingRajceSession* _tmp17_;
#line 660 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp4_ = publishing_rest_support_transaction_get_response (txn);
#line 660 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp5_ = _tmp4_;
#line 660 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp6_ = publishing_rest_support_xml_document_parse_string (_tmp5_, _publishing_rajce_transaction_validate_xml_publishing_rest_support_xml_document_check_for_error_response, NULL, &_inner_error_);
#line 660 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp7_ = _tmp6_;
#line 660 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_g_free0 (_tmp5_);
#line 660 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		doc = _tmp7_;
#line 660 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 660 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 5437 "RajcePublishing.c"
				goto __catch27_spit_publishing_publishing_error;
			}
#line 660 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 660 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			g_clear_error (&_inner_error_);
#line 660 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			return;
#line 5446 "RajcePublishing.c"
		}
#line 661 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp8_ = doc;
#line 661 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp9_ = publishing_rest_support_xml_document_get_root_node (_tmp8_);
#line 661 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		response = _tmp9_;
#line 662 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp11_ = doc;
#line 662 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp12_ = response;
#line 662 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp13_ = publishing_rest_support_xml_document_get_named_child (_tmp11_, _tmp12_, "sessionToken", &_inner_error_);
#line 662 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp10_ = _tmp13_;
#line 662 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 662 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			_publishing_rest_support_xml_document_unref0 (doc);
#line 662 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 5468 "RajcePublishing.c"
				goto __catch27_spit_publishing_publishing_error;
			}
#line 662 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			_publishing_rest_support_xml_document_unref0 (doc);
#line 662 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 662 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			g_clear_error (&_inner_error_);
#line 662 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			return;
#line 5479 "RajcePublishing.c"
		}
#line 662 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp14_ = (gchar*) xmlNodeGetContent (_tmp10_);
#line 662 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		sessionToken = _tmp14_;
#line 663 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp15_ = self->priv->session;
#line 663 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp16_ = sessionToken;
#line 663 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		publishing_rajce_session_set_usertoken (_tmp15_, _tmp16_);
#line 664 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp17_ = self->priv->session;
#line 664 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		publishing_rajce_session_set_albumtoken (_tmp17_, NULL);
#line 658 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_g_free0 (sessionToken);
#line 658 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_publishing_rest_support_xml_document_unref0 (doc);
#line 5499 "RajcePublishing.c"
	}
	goto __finally27;
	__catch27_spit_publishing_publishing_error:
	{
		GError* err = NULL;
		GError* _tmp18_;
#line 658 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		err = _inner_error_;
#line 658 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_inner_error_ = NULL;
#line 668 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		g_debug ("RajcePublishing.vala:668: ERROR: on_close_album_complete");
#line 669 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp18_ = err;
#line 669 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		publishing_rajce_rajce_publisher_do_show_error (self, _tmp18_);
#line 670 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_g_error_free0 (err);
#line 670 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		return;
#line 5520 "RajcePublishing.c"
	}
	__finally27:
#line 658 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 658 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 658 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		g_clear_error (&_inner_error_);
#line 658 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		return;
#line 5531 "RajcePublishing.c"
	}
#line 672 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rajce_rajce_publisher_do_show_success_pane (self);
#line 5535 "RajcePublishing.c"
}


/**
     * Event triggered when the close album transaction fails due to a network error.
     */
static void
publishing_rajce_rajce_publisher_on_close_album_error (PublishingRajceRajcePublisher* self,
                                                       PublishingRESTSupportTransaction* bad_txn,
                                                       GError* err)
{
	guint _tmp0_;
	guint _tmp1_;
#line 678 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_if_fail (PUBLISHING_RAJCE_IS_RAJCE_PUBLISHER (self));
#line 678 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_if_fail (PUBLISHING_REST_SUPPORT_IS_TRANSACTION (bad_txn));
#line 680 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_debug ("RajcePublishing.vala:680: EVENT: on_close_album_error");
#line 681 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_signal_parse_name ("completed", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp0_, NULL, FALSE);
#line 681 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_signal_handlers_disconnect_matched (bad_txn, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp0_, 0, NULL, (GCallback) _publishing_rajce_rajce_publisher_on_close_album_complete_publishing_rest_support_transaction_completed, self);
#line 682 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_signal_parse_name ("network-error", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp1_, NULL, FALSE);
#line 682 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_signal_handlers_disconnect_matched (bad_txn, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _publishing_rajce_rajce_publisher_on_close_album_error_publishing_rest_support_transaction_network_error, self);
#line 685 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rajce_rajce_publisher_do_show_success_pane (self);
#line 5565 "RajcePublishing.c"
}


/**
     * Action to display the success pane in the publishing dialog.
     */
static void
publishing_rajce_rajce_publisher_do_show_success_pane (PublishingRajceRajcePublisher* self)
{
	gboolean _tmp0_ = FALSE;
	SpitPublishingPluginHost* _tmp9_;
	SpitPublishingPluginHost* _tmp10_;
	GError * _inner_error_ = NULL;
#line 692 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_if_fail (PUBLISHING_RAJCE_IS_RAJCE_PUBLISHER (self));
#line 694 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_debug ("RajcePublishing.vala:694: ACTION: installing success pane");
#line 695 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	if (publishing_rajce_rajce_publisher_get_show_album (self)) {
#line 5585 "RajcePublishing.c"
		PublishingRajceSession* _tmp1_;
		gchar* _tmp2_;
		gchar* _tmp3_;
#line 695 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp1_ = self->priv->session;
#line 695 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp2_ = publishing_rajce_session_get_albumticket (_tmp1_);
#line 695 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp3_ = _tmp2_;
#line 695 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp0_ = _tmp3_ != NULL;
#line 695 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_g_free0 (_tmp3_);
#line 5599 "RajcePublishing.c"
	} else {
#line 695 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp0_ = FALSE;
#line 5603 "RajcePublishing.c"
	}
#line 695 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	if (_tmp0_) {
#line 5607 "RajcePublishing.c"
		{
			PublishingRajceSession* _tmp4_;
			gchar* _tmp5_;
			gchar* _tmp6_;
			gchar* _tmp7_;
			gchar* _tmp8_;
#line 699 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			_tmp4_ = self->priv->session;
#line 699 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			_tmp5_ = publishing_rajce_session_get_albumticket (_tmp4_);
#line 699 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			_tmp6_ = _tmp5_;
#line 699 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			_tmp7_ = g_strconcat ("xdg-open ", _tmp6_, NULL);
#line 699 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			_tmp8_ = _tmp7_;
#line 699 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			g_spawn_command_line_async (_tmp8_, &_inner_error_);
#line 699 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			_g_free0 (_tmp8_);
#line 699 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			_g_free0 (_tmp6_);
#line 699 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 699 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
				if (_inner_error_->domain == G_SPAWN_ERROR) {
#line 5634 "RajcePublishing.c"
					goto __catch28_g_spawn_error;
				}
#line 699 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
				g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 699 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
				g_clear_error (&_inner_error_);
#line 699 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
				return;
#line 5643 "RajcePublishing.c"
			}
		}
		goto __finally28;
		__catch28_g_spawn_error:
		{
			GError* e = NULL;
#line 697 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			e = _inner_error_;
#line 697 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			_inner_error_ = NULL;
#line 697 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			_g_error_free0 (e);
#line 5656 "RajcePublishing.c"
		}
		__finally28:
#line 697 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 697 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 697 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			g_clear_error (&_inner_error_);
#line 697 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			return;
#line 5667 "RajcePublishing.c"
		}
	}
#line 705 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp9_ = self->priv->host;
#line 705 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	spit_publishing_plugin_host_set_service_locked (_tmp9_, FALSE);
#line 706 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp10_ = self->priv->host;
#line 706 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	spit_publishing_plugin_host_install_success_pane (_tmp10_);
#line 5678 "RajcePublishing.c"
}


/**
     * Helper event to handle network errors.
     */
static void
publishing_rajce_rajce_publisher_on_network_error (PublishingRajceRajcePublisher* self,
                                                   PublishingRESTSupportTransaction* bad_txn,
                                                   GError* err)
{
#line 712 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_if_fail (PUBLISHING_RAJCE_IS_RAJCE_PUBLISHER (self));
#line 712 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_if_fail (PUBLISHING_REST_SUPPORT_IS_TRANSACTION (bad_txn));
#line 714 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_debug ("RajcePublishing.vala:714: EVENT: on_network_error");
#line 715 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rajce_rajce_publisher_do_show_error (self, err);
#line 5698 "RajcePublishing.c"
}


/**
     * Action to display an error to the user.
     */
static void
publishing_rajce_rajce_publisher_do_show_error (PublishingRajceRajcePublisher* self,
                                                GError* e)
{
	gchar* error_type = NULL;
	gchar* _tmp0_;
	const gchar* _tmp7_;
	const gchar* _tmp8_;
	gchar* _tmp9_;
	gchar* _tmp10_;
#line 721 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_if_fail (PUBLISHING_RAJCE_IS_RAJCE_PUBLISHER (self));
#line 723 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_debug ("RajcePublishing.vala:723: ACTION: do_show_error");
#line 724 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp0_ = g_strdup ("UNKNOWN");
#line 724 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	error_type = _tmp0_;
#line 725 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	if (g_error_matches (e, SPIT_PUBLISHING_PUBLISHING_ERROR, SPIT_PUBLISHING_PUBLISHING_ERROR_NO_ANSWER)) {
#line 727 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		publishing_rajce_rajce_publisher_do_show_authentication_pane (self, PUBLISHING_RAJCE_AUTHENTICATION_PANE_MODE_FAILED_RETRY_USER);
#line 728 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_g_free0 (error_type);
#line 728 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		return;
#line 5731 "RajcePublishing.c"
	} else {
#line 729 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		if (g_error_matches (e, SPIT_PUBLISHING_PUBLISHING_ERROR, SPIT_PUBLISHING_PUBLISHING_ERROR_COMMUNICATION_FAILED)) {
#line 5735 "RajcePublishing.c"
			gchar* _tmp1_;
#line 730 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			_tmp1_ = g_strdup ("COMMUNICATION_FAILED");
#line 730 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			_g_free0 (error_type);
#line 730 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			error_type = _tmp1_;
#line 5743 "RajcePublishing.c"
		} else {
#line 731 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			if (g_error_matches (e, SPIT_PUBLISHING_PUBLISHING_ERROR, SPIT_PUBLISHING_PUBLISHING_ERROR_PROTOCOL_ERROR)) {
#line 5747 "RajcePublishing.c"
				gchar* _tmp2_;
#line 732 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
				_tmp2_ = g_strdup ("PROTOCOL_ERROR");
#line 732 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
				_g_free0 (error_type);
#line 732 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
				error_type = _tmp2_;
#line 5755 "RajcePublishing.c"
			} else {
#line 733 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
				if (g_error_matches (e, SPIT_PUBLISHING_PUBLISHING_ERROR, SPIT_PUBLISHING_PUBLISHING_ERROR_SERVICE_ERROR)) {
#line 5759 "RajcePublishing.c"
					gchar* _tmp3_;
#line 734 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
					_tmp3_ = g_strdup ("SERVICE_ERROR");
#line 734 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
					_g_free0 (error_type);
#line 734 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
					error_type = _tmp3_;
#line 5767 "RajcePublishing.c"
				} else {
#line 735 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
					if (g_error_matches (e, SPIT_PUBLISHING_PUBLISHING_ERROR, SPIT_PUBLISHING_PUBLISHING_ERROR_MALFORMED_RESPONSE)) {
#line 5771 "RajcePublishing.c"
						gchar* _tmp4_;
#line 736 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						_tmp4_ = g_strdup ("MALFORMED_RESPONSE");
#line 736 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						_g_free0 (error_type);
#line 736 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						error_type = _tmp4_;
#line 5779 "RajcePublishing.c"
					} else {
#line 737 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
						if (g_error_matches (e, SPIT_PUBLISHING_PUBLISHING_ERROR, SPIT_PUBLISHING_PUBLISHING_ERROR_LOCAL_FILE_ERROR)) {
#line 5783 "RajcePublishing.c"
							gchar* _tmp5_;
#line 738 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
							_tmp5_ = g_strdup ("LOCAL_FILE_ERROR");
#line 738 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
							_g_free0 (error_type);
#line 738 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
							error_type = _tmp5_;
#line 5791 "RajcePublishing.c"
						} else {
#line 739 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
							if (g_error_matches (e, SPIT_PUBLISHING_PUBLISHING_ERROR, SPIT_PUBLISHING_PUBLISHING_ERROR_EXPIRED_SESSION)) {
#line 5795 "RajcePublishing.c"
								gchar* _tmp6_;
#line 740 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
								_tmp6_ = g_strdup ("EXPIRED_SESSION");
#line 740 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
								_g_free0 (error_type);
#line 740 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
								error_type = _tmp6_;
#line 5803 "RajcePublishing.c"
							}
						}
					}
				}
			}
		}
	}
#line 743 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp7_ = error_type;
#line 743 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp8_ = e->message;
#line 743 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp9_ = g_strdup_printf ("Unhandled error: type=%s; message='%s'", _tmp7_, _tmp8_);
#line 743 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp10_ = _tmp9_;
#line 743 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_debug ("RajcePublishing.vala:743: %s", _tmp10_);
#line 743 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_free0 (_tmp10_);
#line 744 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rajce_rajce_publisher_do_show_error_message (self, _ ("An error message occurred when publishing to Rajce. Please try again."));
#line 721 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_free0 (error_type);
#line 5827 "RajcePublishing.c"
}


/**
     * Action to display an error message to the user.
     */
static void
publishing_rajce_rajce_publisher_do_show_error_message (PublishingRajceRajcePublisher* self,
                                                        const gchar* message)
{
	SpitPublishingPluginHost* _tmp0_;
#line 750 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_if_fail (PUBLISHING_RAJCE_IS_RAJCE_PUBLISHER (self));
#line 750 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_if_fail (message != NULL);
#line 752 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_debug ("RajcePublishing.vala:752: ACTION: do_show_error_message");
#line 753 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp0_ = self->priv->host;
#line 753 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	spit_publishing_plugin_host_install_static_message_pane (_tmp0_, message, SPIT_PUBLISHING_PLUGIN_HOST_BUTTON_MODE_CLOSE);
#line 5849 "RajcePublishing.c"
}


static void
publishing_rajce_rajce_publisher_class_init (PublishingRajceRajcePublisherClass * klass)
{
#line 66 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rajce_rajce_publisher_parent_class = g_type_class_peek_parent (klass);
#line 66 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_type_class_add_private (klass, sizeof (PublishingRajceRajcePublisherPrivate));
#line 66 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	G_OBJECT_CLASS (klass)->finalize = publishing_rajce_rajce_publisher_finalize;
#line 5862 "RajcePublishing.c"
}


static void
publishing_rajce_rajce_publisher_spit_publishing_publisher_interface_init (SpitPublishingPublisherIface * iface)
{
#line 66 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rajce_rajce_publisher_spit_publishing_publisher_parent_iface = g_type_interface_peek_parent (iface);
#line 66 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	iface->get_service = (SpitPublishingService* (*) (SpitPublishingPublisher *)) publishing_rajce_rajce_publisher_real_get_service;
#line 66 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	iface->is_running = (gboolean (*) (SpitPublishingPublisher *)) publishing_rajce_rajce_publisher_real_is_running;
#line 66 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	iface->start = (void (*) (SpitPublishingPublisher *)) publishing_rajce_rajce_publisher_real_start;
#line 66 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	iface->stop = (void (*) (SpitPublishingPublisher *)) publishing_rajce_rajce_publisher_real_stop;
#line 5879 "RajcePublishing.c"
}


static void
publishing_rajce_rajce_publisher_instance_init (PublishingRajceRajcePublisher * self)
{
#line 66 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self->priv = PUBLISHING_RAJCE_RAJCE_PUBLISHER_GET_PRIVATE (self);
#line 68 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self->priv->host = NULL;
#line 69 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self->priv->progress_reporter = NULL;
#line 69 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self->priv->progress_reporter_target = self;
#line 69 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self->priv->progress_reporter_target_destroy_notify = NULL;
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self->priv->service = NULL;
#line 71 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self->priv->running = FALSE;
#line 80 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self->priv->albums = NULL;
#line 80 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self->priv->albums_length1 = 0;
#line 80 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self->priv->_albums_size_ = self->priv->albums_length1;
#line 81 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self->priv->parameters = NULL;
#line 82 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self->priv->media_type = SPIT_PUBLISHING_PUBLISHER_MEDIA_TYPE_NONE;
#line 5910 "RajcePublishing.c"
}


static void
publishing_rajce_rajce_publisher_finalize (GObject * obj)
{
	PublishingRajceRajcePublisher * self;
#line 66 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_RAJCE_TYPE_RAJCE_PUBLISHER, PublishingRajceRajcePublisher);
#line 68 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_object_unref0 (self->priv->host);
#line 69 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	(self->priv->progress_reporter_target_destroy_notify == NULL) ? NULL : (self->priv->progress_reporter_target_destroy_notify (self->priv->progress_reporter_target), NULL);
#line 69 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self->priv->progress_reporter = NULL;
#line 69 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self->priv->progress_reporter_target = NULL;
#line 69 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self->priv->progress_reporter_target_destroy_notify = NULL;
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_object_unref0 (self->priv->service);
#line 72 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_publishing_rest_support_session_unref0 (self->priv->session);
#line 80 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self->priv->albums = (_vala_array_free (self->priv->albums, self->priv->albums_length1, (GDestroyNotify) publishing_rajce_album_unref), NULL);
#line 81 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_publishing_rajce_publishing_parameters_unref0 (self->priv->parameters);
#line 66 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	G_OBJECT_CLASS (publishing_rajce_rajce_publisher_parent_class)->finalize (obj);
#line 5940 "RajcePublishing.c"
}


GType
publishing_rajce_rajce_publisher_get_type (void)
{
	static volatile gsize publishing_rajce_rajce_publisher_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_rajce_rajce_publisher_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingRajceRajcePublisherClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_rajce_rajce_publisher_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingRajceRajcePublisher), 0, (GInstanceInitFunc) publishing_rajce_rajce_publisher_instance_init, NULL };
		static const GInterfaceInfo spit_publishing_publisher_info = { (GInterfaceInitFunc) publishing_rajce_rajce_publisher_spit_publishing_publisher_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType publishing_rajce_rajce_publisher_type_id;
		publishing_rajce_rajce_publisher_type_id = g_type_register_static (G_TYPE_OBJECT, "PublishingRajceRajcePublisher", &g_define_type_info, 0);
		g_type_add_interface_static (publishing_rajce_rajce_publisher_type_id, SPIT_PUBLISHING_TYPE_PUBLISHER, &spit_publishing_publisher_info);
		g_once_init_leave (&publishing_rajce_rajce_publisher_type_id__volatile, publishing_rajce_rajce_publisher_type_id);
	}
	return publishing_rajce_rajce_publisher_type_id__volatile;
}


PublishingRajceAlbum*
publishing_rajce_album_construct (GType object_type,
                                  gint id,
                                  const gchar* albumName,
                                  const gchar* url,
                                  const gchar* thumbUrl,
                                  const gchar* createDate,
                                  const gchar* updateDate,
                                  gboolean hidden,
                                  gboolean secure,
                                  gint photoCount)
{
	PublishingRajceAlbum* self = NULL;
	gchar* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	gchar* _tmp4_;
#line 771 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_val_if_fail (albumName != NULL, NULL);
#line 771 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_val_if_fail (url != NULL, NULL);
#line 771 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_val_if_fail (thumbUrl != NULL, NULL);
#line 771 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_val_if_fail (createDate != NULL, NULL);
#line 771 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_val_if_fail (updateDate != NULL, NULL);
#line 771 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self = (PublishingRajceAlbum*) g_type_create_instance (object_type);
#line 773 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self->id = id;
#line 774 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp0_ = g_strdup (albumName);
#line 774 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_free0 (self->albumName);
#line 774 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self->albumName = _tmp0_;
#line 775 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp1_ = g_strdup (url);
#line 775 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_free0 (self->url);
#line 775 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self->url = _tmp1_;
#line 776 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp2_ = g_strdup (thumbUrl);
#line 776 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_free0 (self->thumbUrl);
#line 776 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self->thumbUrl = _tmp2_;
#line 777 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp3_ = g_strdup (createDate);
#line 777 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_free0 (self->createDate);
#line 777 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self->createDate = _tmp3_;
#line 778 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp4_ = g_strdup (updateDate);
#line 778 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_free0 (self->updateDate);
#line 778 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self->updateDate = _tmp4_;
#line 779 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self->hidden = hidden;
#line 780 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self->secure = secure;
#line 781 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self->photoCount = photoCount;
#line 771 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	return self;
#line 6030 "RajcePublishing.c"
}


PublishingRajceAlbum*
publishing_rajce_album_new (gint id,
                            const gchar* albumName,
                            const gchar* url,
                            const gchar* thumbUrl,
                            const gchar* createDate,
                            const gchar* updateDate,
                            gboolean hidden,
                            gboolean secure,
                            gint photoCount)
{
#line 771 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	return publishing_rajce_album_construct (PUBLISHING_RAJCE_TYPE_ALBUM, id, albumName, url, thumbUrl, createDate, updateDate, hidden, secure, photoCount);
#line 6047 "RajcePublishing.c"
}


gint
publishing_rajce_album_compare_albums (PublishingRajceAlbum* a,
                                       PublishingRajceAlbum* b)
{
	gint result = 0;
	gboolean _tmp0_ = FALSE;
	const gchar* _tmp3_;
	const gchar* _tmp4_;
#line 783 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_val_if_fail ((a == NULL) || PUBLISHING_RAJCE_IS_ALBUM (a), 0);
#line 783 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_val_if_fail ((b == NULL) || PUBLISHING_RAJCE_IS_ALBUM (b), 0);
#line 785 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	if (a == NULL) {
#line 785 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp0_ = b == NULL;
#line 6067 "RajcePublishing.c"
	} else {
#line 785 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp0_ = FALSE;
#line 6071 "RajcePublishing.c"
	}
#line 785 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	if (_tmp0_) {
#line 787 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		result = 0;
#line 787 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		return result;
#line 6079 "RajcePublishing.c"
	} else {
		gboolean _tmp1_ = FALSE;
#line 789 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		if (a == NULL) {
#line 789 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			_tmp1_ = b != NULL;
#line 6086 "RajcePublishing.c"
		} else {
#line 789 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			_tmp1_ = FALSE;
#line 6090 "RajcePublishing.c"
		}
#line 789 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		if (_tmp1_) {
#line 791 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			result = 1;
#line 791 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			return result;
#line 6098 "RajcePublishing.c"
		} else {
			gboolean _tmp2_ = FALSE;
#line 793 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			if (a != NULL) {
#line 793 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
				_tmp2_ = b == NULL;
#line 6105 "RajcePublishing.c"
			} else {
#line 793 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
				_tmp2_ = FALSE;
#line 6109 "RajcePublishing.c"
			}
#line 793 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			if (_tmp2_) {
#line 795 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
				result = -1;
#line 795 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
				return result;
#line 6117 "RajcePublishing.c"
			}
		}
	}
#line 797 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp3_ = b->updateDate;
#line 797 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp4_ = a->updateDate;
#line 797 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	result = g_ascii_strcasecmp (_tmp3_, _tmp4_);
#line 797 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	return result;
#line 6129 "RajcePublishing.c"
}


static void
publishing_rajce_value_album_init (GValue* value)
{
#line 759 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	value->data[0].v_pointer = NULL;
#line 6138 "RajcePublishing.c"
}


static void
publishing_rajce_value_album_free_value (GValue* value)
{
#line 759 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	if (value->data[0].v_pointer) {
#line 759 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		publishing_rajce_album_unref (value->data[0].v_pointer);
#line 6149 "RajcePublishing.c"
	}
}


static void
publishing_rajce_value_album_copy_value (const GValue* src_value,
                                         GValue* dest_value)
{
#line 759 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	if (src_value->data[0].v_pointer) {
#line 759 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		dest_value->data[0].v_pointer = publishing_rajce_album_ref (src_value->data[0].v_pointer);
#line 6162 "RajcePublishing.c"
	} else {
#line 759 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		dest_value->data[0].v_pointer = NULL;
#line 6166 "RajcePublishing.c"
	}
}


static gpointer
publishing_rajce_value_album_peek_pointer (const GValue* value)
{
#line 759 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	return value->data[0].v_pointer;
#line 6176 "RajcePublishing.c"
}


static gchar*
publishing_rajce_value_album_collect_value (GValue* value,
                                            guint n_collect_values,
                                            GTypeCValue* collect_values,
                                            guint collect_flags)
{
#line 759 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	if (collect_values[0].v_pointer) {
#line 6188 "RajcePublishing.c"
		PublishingRajceAlbum * object;
		object = collect_values[0].v_pointer;
#line 759 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		if (object->parent_instance.g_class == NULL) {
#line 759 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 6195 "RajcePublishing.c"
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
#line 759 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 6199 "RajcePublishing.c"
		}
#line 759 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		value->data[0].v_pointer = publishing_rajce_album_ref (object);
#line 6203 "RajcePublishing.c"
	} else {
#line 759 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		value->data[0].v_pointer = NULL;
#line 6207 "RajcePublishing.c"
	}
#line 759 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	return NULL;
#line 6211 "RajcePublishing.c"
}


static gchar*
publishing_rajce_value_album_lcopy_value (const GValue* value,
                                          guint n_collect_values,
                                          GTypeCValue* collect_values,
                                          guint collect_flags)
{
	PublishingRajceAlbum ** object_p;
	object_p = collect_values[0].v_pointer;
#line 759 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	if (!object_p) {
#line 759 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
#line 6227 "RajcePublishing.c"
	}
#line 759 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	if (!value->data[0].v_pointer) {
#line 759 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		*object_p = NULL;
#line 6233 "RajcePublishing.c"
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
#line 759 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		*object_p = value->data[0].v_pointer;
#line 6237 "RajcePublishing.c"
	} else {
#line 759 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		*object_p = publishing_rajce_album_ref (value->data[0].v_pointer);
#line 6241 "RajcePublishing.c"
	}
#line 759 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	return NULL;
#line 6245 "RajcePublishing.c"
}


GParamSpec*
publishing_rajce_param_spec_album (const gchar* name,
                                   const gchar* nick,
                                   const gchar* blurb,
                                   GType object_type,
                                   GParamFlags flags)
{
	PublishingRajceParamSpecAlbum* spec;
#line 759 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_val_if_fail (g_type_is_a (object_type, PUBLISHING_RAJCE_TYPE_ALBUM), NULL);
#line 759 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
#line 759 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	G_PARAM_SPEC (spec)->value_type = object_type;
#line 759 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	return G_PARAM_SPEC (spec);
#line 6265 "RajcePublishing.c"
}


gpointer
publishing_rajce_value_get_album (const GValue* value)
{
#line 759 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_RAJCE_TYPE_ALBUM), NULL);
#line 759 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	return value->data[0].v_pointer;
#line 6276 "RajcePublishing.c"
}


void
publishing_rajce_value_set_album (GValue* value,
                                  gpointer v_object)
{
	PublishingRajceAlbum * old;
#line 759 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_RAJCE_TYPE_ALBUM));
#line 759 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	old = value->data[0].v_pointer;
#line 759 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	if (v_object) {
#line 759 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, PUBLISHING_RAJCE_TYPE_ALBUM));
#line 759 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 759 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		value->data[0].v_pointer = v_object;
#line 759 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		publishing_rajce_album_ref (value->data[0].v_pointer);
#line 6299 "RajcePublishing.c"
	} else {
#line 759 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		value->data[0].v_pointer = NULL;
#line 6303 "RajcePublishing.c"
	}
#line 759 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	if (old) {
#line 759 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		publishing_rajce_album_unref (old);
#line 6309 "RajcePublishing.c"
	}
}


void
publishing_rajce_value_take_album (GValue* value,
                                   gpointer v_object)
{
	PublishingRajceAlbum * old;
#line 759 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_RAJCE_TYPE_ALBUM));
#line 759 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	old = value->data[0].v_pointer;
#line 759 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	if (v_object) {
#line 759 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, PUBLISHING_RAJCE_TYPE_ALBUM));
#line 759 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 759 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		value->data[0].v_pointer = v_object;
#line 6331 "RajcePublishing.c"
	} else {
#line 759 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		value->data[0].v_pointer = NULL;
#line 6335 "RajcePublishing.c"
	}
#line 759 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	if (old) {
#line 759 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		publishing_rajce_album_unref (old);
#line 6341 "RajcePublishing.c"
	}
}


static void
publishing_rajce_album_class_init (PublishingRajceAlbumClass * klass)
{
#line 759 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rajce_album_parent_class = g_type_class_peek_parent (klass);
#line 759 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	((PublishingRajceAlbumClass *) klass)->finalize = publishing_rajce_album_finalize;
#line 6353 "RajcePublishing.c"
}


static void
publishing_rajce_album_instance_init (PublishingRajceAlbum * self)
{
#line 759 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self->ref_count = 1;
#line 6362 "RajcePublishing.c"
}


static void
publishing_rajce_album_finalize (PublishingRajceAlbum * obj)
{
	PublishingRajceAlbum * self;
#line 759 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_RAJCE_TYPE_ALBUM, PublishingRajceAlbum);
#line 759 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_signal_handlers_destroy (self);
#line 762 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_free0 (self->albumName);
#line 763 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_free0 (self->url);
#line 764 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_free0 (self->thumbUrl);
#line 765 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_free0 (self->createDate);
#line 766 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_free0 (self->updateDate);
#line 6384 "RajcePublishing.c"
}


GType
publishing_rajce_album_get_type (void)
{
	static volatile gsize publishing_rajce_album_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_rajce_album_type_id__volatile)) {
		static const GTypeValueTable g_define_type_value_table = { publishing_rajce_value_album_init, publishing_rajce_value_album_free_value, publishing_rajce_value_album_copy_value, publishing_rajce_value_album_peek_pointer, "p", publishing_rajce_value_album_collect_value, "p", publishing_rajce_value_album_lcopy_value };
		static const GTypeInfo g_define_type_info = { sizeof (PublishingRajceAlbumClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_rajce_album_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingRajceAlbum), 0, (GInstanceInitFunc) publishing_rajce_album_instance_init, &g_define_type_value_table };
		static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
		GType publishing_rajce_album_type_id;
		publishing_rajce_album_type_id = g_type_register_fundamental (g_type_fundamental_next (), "PublishingRajceAlbum", &g_define_type_info, &g_define_type_fundamental_info, 0);
		g_once_init_leave (&publishing_rajce_album_type_id__volatile, publishing_rajce_album_type_id);
	}
	return publishing_rajce_album_type_id__volatile;
}


gpointer
publishing_rajce_album_ref (gpointer instance)
{
	PublishingRajceAlbum * self;
	self = instance;
#line 759 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_atomic_int_inc (&self->ref_count);
#line 759 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	return instance;
#line 6413 "RajcePublishing.c"
}


void
publishing_rajce_album_unref (gpointer instance)
{
	PublishingRajceAlbum * self;
	self = instance;
#line 759 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
#line 759 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		PUBLISHING_RAJCE_ALBUM_GET_CLASS (self)->finalize (self);
#line 759 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		g_type_free_instance ((GTypeInstance *) self);
#line 6428 "RajcePublishing.c"
	}
}


PublishingRajceUploader*
publishing_rajce_uploader_construct (GType object_type,
                                     PublishingRajceSession* session,
                                     const gchar* url,
                                     SpitPublishingPublishable** publishables,
                                     int publishables_length1,
                                     PublishingRajcePublishingParameters* parameters)
{
	PublishingRajceUploader* self = NULL;
	PublishingRajcePublishingParameters* _tmp0_;
	gchar* _tmp1_;
#line 807 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_val_if_fail (PUBLISHING_RAJCE_IS_SESSION (session), NULL);
#line 807 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_val_if_fail (url != NULL, NULL);
#line 807 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_val_if_fail (PUBLISHING_RAJCE_IS_PUBLISHING_PARAMETERS (parameters), NULL);
#line 809 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self = (PublishingRajceUploader*) publishing_rest_support_batch_uploader_construct (object_type, G_TYPE_CHECK_INSTANCE_CAST (session, PUBLISHING_REST_SUPPORT_TYPE_SESSION, PublishingRESTSupportSession), publishables, publishables_length1);
#line 810 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp0_ = _publishing_rajce_publishing_parameters_ref0 (parameters);
#line 810 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_publishing_rajce_publishing_parameters_unref0 (self->priv->parameters);
#line 810 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self->priv->parameters = _tmp0_;
#line 811 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp1_ = g_strdup (url);
#line 811 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_free0 (self->priv->url);
#line 811 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self->priv->url = _tmp1_;
#line 807 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	return self;
#line 6466 "RajcePublishing.c"
}


PublishingRajceUploader*
publishing_rajce_uploader_new (PublishingRajceSession* session,
                               const gchar* url,
                               SpitPublishingPublishable** publishables,
                               int publishables_length1,
                               PublishingRajcePublishingParameters* parameters)
{
#line 807 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	return publishing_rajce_uploader_construct (PUBLISHING_RAJCE_TYPE_UPLOADER, session, url, publishables, publishables_length1, parameters);
#line 6479 "RajcePublishing.c"
}


static PublishingRESTSupportTransaction*
publishing_rajce_uploader_real_create_transaction (PublishingRESTSupportBatchUploader* base,
                                                   SpitPublishingPublishable* publishable)
{
	PublishingRajceUploader * self;
	PublishingRESTSupportTransaction* result = NULL;
	PublishingRESTSupportSession* _tmp0_;
	PublishingRajceSession* _tmp1_;
	const gchar* _tmp2_;
	PublishingRajcePublishingParameters* _tmp3_;
	PublishingRajceAddPhotoTransaction* _tmp4_;
	PublishingRESTSupportTransaction* _tmp5_;
#line 814 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_RAJCE_TYPE_UPLOADER, PublishingRajceUploader);
#line 814 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_val_if_fail (SPIT_PUBLISHING_IS_PUBLISHABLE (publishable), NULL);
#line 816 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp0_ = publishing_rest_support_batch_uploader_get_session (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_BATCH_UPLOADER, PublishingRESTSupportBatchUploader));
#line 816 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp1_ = G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, PUBLISHING_RAJCE_TYPE_SESSION, PublishingRajceSession);
#line 816 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp2_ = self->priv->url;
#line 816 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp3_ = self->priv->parameters;
#line 816 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp4_ = publishing_rajce_add_photo_transaction_new (_tmp1_, _tmp2_, _tmp3_, publishable);
#line 816 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp5_ = G_TYPE_CHECK_INSTANCE_CAST (_tmp4_, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction);
#line 816 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_publishing_rest_support_session_unref0 (_tmp1_);
#line 816 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	result = _tmp5_;
#line 816 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	return result;
#line 6517 "RajcePublishing.c"
}


static void
publishing_rajce_uploader_class_init (PublishingRajceUploaderClass * klass)
{
#line 802 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rajce_uploader_parent_class = g_type_class_peek_parent (klass);
#line 802 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	((PublishingRESTSupportBatchUploaderClass *) klass)->finalize = publishing_rajce_uploader_finalize;
#line 802 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_type_class_add_private (klass, sizeof (PublishingRajceUploaderPrivate));
#line 802 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	((PublishingRESTSupportBatchUploaderClass *) klass)->create_transaction = (PublishingRESTSupportTransaction* (*) (PublishingRESTSupportBatchUploader *, SpitPublishingPublishable*)) publishing_rajce_uploader_real_create_transaction;
#line 6532 "RajcePublishing.c"
}


static void
publishing_rajce_uploader_instance_init (PublishingRajceUploader * self)
{
#line 802 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self->priv = PUBLISHING_RAJCE_UPLOADER_GET_PRIVATE (self);
#line 6541 "RajcePublishing.c"
}


static void
publishing_rajce_uploader_finalize (PublishingRESTSupportBatchUploader * obj)
{
	PublishingRajceUploader * self;
#line 802 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_RAJCE_TYPE_UPLOADER, PublishingRajceUploader);
#line 804 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_publishing_rajce_publishing_parameters_unref0 (self->priv->parameters);
#line 805 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_free0 (self->priv->url);
#line 802 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	PUBLISHING_REST_SUPPORT_BATCH_UPLOADER_CLASS (publishing_rajce_uploader_parent_class)->finalize (obj);
#line 6557 "RajcePublishing.c"
}


GType
publishing_rajce_uploader_get_type (void)
{
	static volatile gsize publishing_rajce_uploader_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_rajce_uploader_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingRajceUploaderClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_rajce_uploader_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingRajceUploader), 0, (GInstanceInitFunc) publishing_rajce_uploader_instance_init, NULL };
		GType publishing_rajce_uploader_type_id;
		publishing_rajce_uploader_type_id = g_type_register_static (PUBLISHING_REST_SUPPORT_TYPE_BATCH_UPLOADER, "PublishingRajceUploader", &g_define_type_info, 0);
		g_once_init_leave (&publishing_rajce_uploader_type_id__volatile, publishing_rajce_uploader_type_id);
	}
	return publishing_rajce_uploader_type_id__volatile;
}


GType
publishing_rajce_authentication_pane_mode_get_type (void)
{
	static volatile gsize publishing_rajce_authentication_pane_mode_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_rajce_authentication_pane_mode_type_id__volatile)) {
		static const GEnumValue values[] = {{PUBLISHING_RAJCE_AUTHENTICATION_PANE_MODE_INTRO, "PUBLISHING_RAJCE_AUTHENTICATION_PANE_MODE_INTRO", "intro"}, {PUBLISHING_RAJCE_AUTHENTICATION_PANE_MODE_FAILED_RETRY_USER, "PUBLISHING_RAJCE_AUTHENTICATION_PANE_MODE_FAILED_RETRY_USER", "failed-retry-user"}, {0, NULL, NULL}};
		GType publishing_rajce_authentication_pane_mode_type_id;
		publishing_rajce_authentication_pane_mode_type_id = g_enum_register_static ("PublishingRajceAuthenticationPaneMode", values);
		g_once_init_leave (&publishing_rajce_authentication_pane_mode_type_id__volatile, publishing_rajce_authentication_pane_mode_type_id);
	}
	return publishing_rajce_authentication_pane_mode_type_id__volatile;
}


static void
_publishing_rajce_authentication_pane_on_user_changed_gtk_editable_changed (GtkEditable* _sender,
                                                                            gpointer self)
{
#line 897 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rajce_authentication_pane_on_user_changed ((PublishingRajceAuthenticationPane*) self);
#line 6595 "RajcePublishing.c"
}


static void
_publishing_rajce_authentication_pane_on_password_changed_gtk_editable_changed (GtkEditable* _sender,
                                                                                gpointer self)
{
#line 898 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rajce_authentication_pane_on_password_changed ((PublishingRajceAuthenticationPane*) self);
#line 6605 "RajcePublishing.c"
}


static void
_publishing_rajce_authentication_pane_on_login_button_clicked_gtk_button_clicked (GtkButton* _sender,
                                                                                  gpointer self)
{
#line 899 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rajce_authentication_pane_on_login_button_clicked ((PublishingRajceAuthenticationPane*) self);
#line 6615 "RajcePublishing.c"
}


PublishingRajceAuthenticationPane*
publishing_rajce_authentication_pane_construct (GType object_type,
                                                PublishingRajceRajcePublisher* publisher,
                                                PublishingRajceAuthenticationPaneMode mode)
{
	PublishingRajceAuthenticationPane * self = NULL;
	GtkBox* _tmp0_;
	GError * _inner_error_ = NULL;
#line 846 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_val_if_fail (PUBLISHING_RAJCE_IS_RAJCE_PUBLISHER (publisher), NULL);
#line 846 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self = (PublishingRajceAuthenticationPane*) g_object_new (object_type, NULL);
#line 848 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp0_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
#line 848 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_object_ref_sink (_tmp0_);
#line 848 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_object_unref0 (self->priv->pane_widget);
#line 848 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self->priv->pane_widget = _tmp0_;
#line 6639 "RajcePublishing.c"
	{
		GtkBuilder* _tmp1_;
		GtkBuilder* _tmp2_;
		GtkBuilder* _tmp3_;
		GtkBox* content = NULL;
		GtkBuilder* _tmp4_;
		GObject* _tmp5_;
		GtkBox* _tmp6_;
		GtkLabel* message_label = NULL;
		GtkBuilder* _tmp7_;
		GObject* _tmp8_;
		GtkLabel* _tmp9_;
		GtkBuilder* _tmp16_;
		GObject* _tmp17_;
		GtkEntry* _tmp18_;
		gchar* persistent_username = NULL;
		gchar* _tmp19_;
		const gchar* _tmp20_;
		GtkBuilder* _tmp23_;
		GObject* _tmp24_;
		GtkEntry* _tmp25_;
		gchar* persistent_token = NULL;
		gchar* _tmp26_;
		const gchar* _tmp27_;
		GtkBuilder* _tmp30_;
		GObject* _tmp31_;
		GtkCheckButton* _tmp32_;
		GtkCheckButton* _tmp33_;
		GtkBuilder* _tmp34_;
		GObject* _tmp35_;
		GtkButton* _tmp36_;
		GtkLabel* label2 = NULL;
		GtkBuilder* _tmp37_;
		GObject* _tmp38_;
		GtkLabel* _tmp39_;
		GtkLabel* label3 = NULL;
		GtkBuilder* _tmp40_;
		GObject* _tmp41_;
		GtkLabel* _tmp42_;
		GtkLabel* _tmp43_;
		GtkLabel* _tmp44_;
		GtkCheckButton* _tmp45_;
		GtkButton* _tmp46_;
		GtkEntry* _tmp47_;
		GtkEntry* _tmp48_;
		GtkButton* _tmp49_;
		GtkBox* _tmp50_;
		GtkContainer* _tmp51_;
		GtkContainer* _tmp52_;
		GtkBox* _tmp53_;
		GtkBox* _tmp54_;
		GtkBox* _tmp55_;
		SpitPublishingPluginHost* _tmp56_;
		SpitPublishingPluginHost* _tmp57_;
		GtkButton* _tmp58_;
#line 851 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp1_ = gtk_builder_new ();
#line 851 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_g_object_unref0 (self->priv->builder);
#line 851 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		self->priv->builder = _tmp1_;
#line 852 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp2_ = self->priv->builder;
#line 852 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		gtk_builder_add_from_resource (_tmp2_, PLUGIN_RESOURCE_PATH "/rajce_authentication_pane.ui", &_inner_error_);
#line 852 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 6707 "RajcePublishing.c"
			goto __catch29_g_error;
		}
#line 854 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp3_ = self->priv->builder;
#line 854 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		gtk_builder_connect_signals (_tmp3_, NULL);
#line 855 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp4_ = self->priv->builder;
#line 855 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp5_ = gtk_builder_get_object (_tmp4_, "content");
#line 855 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp6_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp5_, gtk_box_get_type ()) ? ((GtkBox*) _tmp5_) : NULL);
#line 855 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		content = _tmp6_;
#line 856 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp7_ = self->priv->builder;
#line 856 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp8_ = gtk_builder_get_object (_tmp7_, "message_label");
#line 856 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp9_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp8_, gtk_label_get_type ()) ? ((GtkLabel*) _tmp8_) : NULL);
#line 856 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		message_label = _tmp9_;
#line 857 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		switch (mode) {
#line 857 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			case PUBLISHING_RAJCE_AUTHENTICATION_PANE_MODE_INTRO:
#line 6734 "RajcePublishing.c"
			{
				GtkLabel* _tmp10_;
				const gchar* _tmp11_;
#line 860 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
				_tmp10_ = message_label;
#line 860 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
				_tmp11_ = publishing_rajce_authentication_pane_INTRO_MESSAGE;
#line 860 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
				gtk_label_set_text (_tmp10_, _tmp11_);
#line 861 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
				break;
#line 6746 "RajcePublishing.c"
			}
#line 857 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			case PUBLISHING_RAJCE_AUTHENTICATION_PANE_MODE_FAILED_RETRY_USER:
#line 6750 "RajcePublishing.c"
			{
				GtkLabel* _tmp12_;
				const gchar* _tmp13_;
				gchar* _tmp14_;
				gchar* _tmp15_;
#line 864 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
				_tmp12_ = message_label;
#line 864 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
				_tmp13_ = publishing_rajce_authentication_pane_FAILED_RETRY_USER_MESSAGE;
#line 864 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
				_tmp14_ = g_strdup_printf ("<b>%s</b>\n\n%s", _ ("Invalid User Email or Password"), _tmp13_);
#line 864 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
				_tmp15_ = _tmp14_;
#line 864 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
				gtk_label_set_markup (_tmp12_, _tmp15_);
#line 864 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
				_g_free0 (_tmp15_);
#line 866 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
				break;
#line 6770 "RajcePublishing.c"
			}
			default:
#line 857 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			break;
#line 6775 "RajcePublishing.c"
		}
#line 868 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp16_ = self->priv->builder;
#line 868 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp17_ = gtk_builder_get_object (_tmp16_, "username_entry");
#line 868 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp18_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp17_, gtk_entry_get_type ()) ? ((GtkEntry*) _tmp17_) : NULL);
#line 868 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_g_object_unref0 (self->priv->username_entry);
#line 868 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		self->priv->username_entry = _tmp18_;
#line 869 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp19_ = publishing_rajce_rajce_publisher_get_username (publisher);
#line 869 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		persistent_username = _tmp19_;
#line 870 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp20_ = persistent_username;
#line 870 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		if (_tmp20_ != NULL) {
#line 6795 "RajcePublishing.c"
			GtkEntry* _tmp21_;
			const gchar* _tmp22_;
#line 872 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			_tmp21_ = self->priv->username_entry;
#line 872 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			_tmp22_ = persistent_username;
#line 872 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			gtk_entry_set_text (_tmp21_, _tmp22_);
#line 6804 "RajcePublishing.c"
		}
#line 874 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp23_ = self->priv->builder;
#line 874 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp24_ = gtk_builder_get_object (_tmp23_, "password_entry");
#line 874 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp25_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp24_, gtk_entry_get_type ()) ? ((GtkEntry*) _tmp24_) : NULL);
#line 874 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_g_object_unref0 (self->priv->password_entry);
#line 874 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		self->priv->password_entry = _tmp25_;
#line 875 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp26_ = publishing_rajce_rajce_publisher_get_token (publisher);
#line 875 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		persistent_token = _tmp26_;
#line 876 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp27_ = persistent_token;
#line 876 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		if (_tmp27_ != NULL) {
#line 6824 "RajcePublishing.c"
			GtkEntry* _tmp28_;
			const gchar* _tmp29_;
#line 878 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			_tmp28_ = self->priv->password_entry;
#line 878 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			_tmp29_ = persistent_token;
#line 878 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			gtk_entry_set_text (_tmp28_, _tmp29_);
#line 879 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			self->priv->crypt = FALSE;
#line 6835 "RajcePublishing.c"
		} else {
#line 883 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			self->priv->crypt = TRUE;
#line 6839 "RajcePublishing.c"
		}
#line 885 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp30_ = self->priv->builder;
#line 885 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp31_ = gtk_builder_get_object (_tmp30_, "remember_checkbutton");
#line 885 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp32_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp31_, gtk_check_button_get_type ()) ? ((GtkCheckButton*) _tmp31_) : NULL);
#line 885 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_g_object_unref0 (self->priv->remember_checkbutton);
#line 885 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		self->priv->remember_checkbutton = _tmp32_;
#line 886 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp33_ = self->priv->remember_checkbutton;
#line 886 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		gtk_toggle_button_set_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp33_, gtk_toggle_button_get_type (), GtkToggleButton), publishing_rajce_rajce_publisher_get_remember (publisher));
#line 887 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp34_ = self->priv->builder;
#line 887 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp35_ = gtk_builder_get_object (_tmp34_, "login_button");
#line 887 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp36_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp35_, gtk_button_get_type ()) ? ((GtkButton*) _tmp35_) : NULL);
#line 887 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_g_object_unref0 (self->priv->login_button);
#line 887 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		self->priv->login_button = _tmp36_;
#line 889 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp37_ = self->priv->builder;
#line 889 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp38_ = gtk_builder_get_object (_tmp37_, "label2");
#line 889 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp39_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp38_, gtk_label_get_type ()) ? ((GtkLabel*) _tmp38_) : NULL);
#line 889 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		label2 = _tmp39_;
#line 890 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp40_ = self->priv->builder;
#line 890 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp41_ = gtk_builder_get_object (_tmp40_, "label3");
#line 890 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp42_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp41_, gtk_label_get_type ()) ? ((GtkLabel*) _tmp41_) : NULL);
#line 890 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		label3 = _tmp42_;
#line 892 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp43_ = label2;
#line 892 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		gtk_label_set_label (_tmp43_, _ ("_Email address"));
#line 893 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp44_ = label3;
#line 893 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		gtk_label_set_label (_tmp44_, _ ("_Password"));
#line 894 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp45_ = self->priv->remember_checkbutton;
#line 894 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		gtk_button_set_label (G_TYPE_CHECK_INSTANCE_CAST (_tmp45_, gtk_button_get_type (), GtkButton), _ ("_Remember"));
#line 895 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp46_ = self->priv->login_button;
#line 895 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		gtk_button_set_label (_tmp46_, _ ("Log in"));
#line 897 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp47_ = self->priv->username_entry;
#line 897 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp47_, gtk_editable_get_type (), GtkEditable), "changed", (GCallback) _publishing_rajce_authentication_pane_on_user_changed_gtk_editable_changed, self, 0);
#line 898 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp48_ = self->priv->password_entry;
#line 898 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp48_, gtk_editable_get_type (), GtkEditable), "changed", (GCallback) _publishing_rajce_authentication_pane_on_password_changed_gtk_editable_changed, self, 0);
#line 899 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp49_ = self->priv->login_button;
#line 899 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		g_signal_connect_object (_tmp49_, "clicked", (GCallback) _publishing_rajce_authentication_pane_on_login_button_clicked_gtk_button_clicked, self, 0);
#line 900 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp50_ = content;
#line 900 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp51_ = gtk_widget_get_parent (G_TYPE_CHECK_INSTANCE_CAST (_tmp50_, gtk_widget_get_type (), GtkWidget));
#line 900 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp52_ = _tmp51_;
#line 900 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp53_ = content;
#line 900 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		gtk_container_remove (_tmp52_, G_TYPE_CHECK_INSTANCE_CAST (_tmp53_, gtk_widget_get_type (), GtkWidget));
#line 901 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp54_ = self->priv->pane_widget;
#line 901 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp55_ = content;
#line 901 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		gtk_container_add (G_TYPE_CHECK_INSTANCE_CAST (_tmp54_, gtk_container_get_type (), GtkContainer), G_TYPE_CHECK_INSTANCE_CAST (_tmp55_, gtk_widget_get_type (), GtkWidget));
#line 902 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp56_ = publishing_rajce_rajce_publisher_get_host (publisher);
#line 902 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp57_ = _tmp56_;
#line 902 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp58_ = self->priv->login_button;
#line 902 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		spit_publishing_plugin_host_set_dialog_default_widget (_tmp57_, G_TYPE_CHECK_INSTANCE_CAST (_tmp58_, gtk_widget_get_type (), GtkWidget));
#line 902 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_g_object_unref0 (_tmp57_);
#line 849 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_g_object_unref0 (label3);
#line 849 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_g_object_unref0 (label2);
#line 849 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_g_free0 (persistent_token);
#line 849 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_g_free0 (persistent_username);
#line 849 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_g_object_unref0 (message_label);
#line 849 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_g_object_unref0 (content);
#line 6947 "RajcePublishing.c"
	}
	goto __finally29;
	__catch29_g_error:
	{
		GError* e = NULL;
		GError* _tmp59_;
		const gchar* _tmp60_;
#line 849 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		e = _inner_error_;
#line 849 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_inner_error_ = NULL;
#line 906 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp59_ = e;
#line 906 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp60_ = _tmp59_->message;
#line 906 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		g_warning ("RajcePublishing.vala:906: Could not load UI: %s", _tmp60_);
#line 849 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_g_error_free0 (e);
#line 6967 "RajcePublishing.c"
	}
	__finally29:
#line 849 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 849 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 849 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		g_clear_error (&_inner_error_);
#line 849 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		return NULL;
#line 6978 "RajcePublishing.c"
	}
#line 846 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	return self;
#line 6982 "RajcePublishing.c"
}


PublishingRajceAuthenticationPane*
publishing_rajce_authentication_pane_new (PublishingRajceRajcePublisher* publisher,
                                          PublishingRajceAuthenticationPaneMode mode)
{
#line 846 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	return publishing_rajce_authentication_pane_construct (PUBLISHING_RAJCE_TYPE_AUTHENTICATION_PANE, publisher, mode);
#line 6992 "RajcePublishing.c"
}


GtkWidget*
publishing_rajce_authentication_pane_get_default_widget (PublishingRajceAuthenticationPane* self)
{
	GtkWidget* result = NULL;
	GtkButton* _tmp0_;
	GtkWidget* _tmp1_;
#line 910 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_val_if_fail (PUBLISHING_RAJCE_IS_AUTHENTICATION_PANE (self), NULL);
#line 912 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp0_ = self->priv->login_button;
#line 912 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp1_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, gtk_widget_get_type (), GtkWidget));
#line 912 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	result = _tmp1_;
#line 912 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	return result;
#line 7012 "RajcePublishing.c"
}


static void
publishing_rajce_authentication_pane_on_login_button_clicked (PublishingRajceAuthenticationPane* self)
{
	gchar* token = NULL;
	GtkEntry* _tmp0_;
	const gchar* _tmp1_;
	gchar* _tmp2_;
	gboolean _tmp3_;
	GtkEntry* _tmp6_;
	const gchar* _tmp7_;
	const gchar* _tmp8_;
	GtkCheckButton* _tmp9_;
#line 915 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_if_fail (PUBLISHING_RAJCE_IS_AUTHENTICATION_PANE (self));
#line 917 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp0_ = self->priv->password_entry;
#line 917 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp1_ = gtk_entry_get_text (_tmp0_);
#line 917 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp2_ = g_strdup (_tmp1_);
#line 917 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	token = _tmp2_;
#line 918 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp3_ = self->priv->crypt;
#line 918 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	if (_tmp3_) {
#line 7042 "RajcePublishing.c"
		const gchar* _tmp4_;
		gchar* _tmp5_;
#line 920 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp4_ = token;
#line 920 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp5_ = g_compute_checksum_for_string (G_CHECKSUM_MD5, _tmp4_, (gsize) -1);
#line 920 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_g_free0 (token);
#line 920 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		token = _tmp5_;
#line 7053 "RajcePublishing.c"
	}
#line 922 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp6_ = self->priv->username_entry;
#line 922 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp7_ = gtk_entry_get_text (_tmp6_);
#line 922 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp8_ = token;
#line 922 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp9_ = self->priv->remember_checkbutton;
#line 922 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_signal_emit (self, publishing_rajce_authentication_pane_signals[PUBLISHING_RAJCE_AUTHENTICATION_PANE_LOGIN_SIGNAL], 0, _tmp7_, _tmp8_, gtk_toggle_button_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, gtk_toggle_button_get_type (), GtkToggleButton)));
#line 915 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_free0 (token);
#line 7067 "RajcePublishing.c"
}


static void
publishing_rajce_authentication_pane_on_user_changed (PublishingRajceAuthenticationPane* self)
{
#line 925 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_if_fail (PUBLISHING_RAJCE_IS_AUTHENTICATION_PANE (self));
#line 927 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rajce_authentication_pane_update_login_button_sensitivity (self);
#line 7078 "RajcePublishing.c"
}


static void
publishing_rajce_authentication_pane_on_password_changed (PublishingRajceAuthenticationPane* self)
{
#line 930 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_if_fail (PUBLISHING_RAJCE_IS_AUTHENTICATION_PANE (self));
#line 932 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self->priv->crypt = TRUE;
#line 933 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rajce_authentication_pane_update_login_button_sensitivity (self);
#line 7091 "RajcePublishing.c"
}


static void
publishing_rajce_authentication_pane_update_login_button_sensitivity (PublishingRajceAuthenticationPane* self)
{
	gboolean _tmp0_ = FALSE;
	GtkEntry* _tmp1_;
	guint _tmp2_;
	guint _tmp3_;
	GtkButton* _tmp7_;
#line 936 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_if_fail (PUBLISHING_RAJCE_IS_AUTHENTICATION_PANE (self));
#line 938 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp1_ = self->priv->username_entry;
#line 938 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp2_ = gtk_entry_get_text_length (_tmp1_);
#line 938 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp3_ = _tmp2_;
#line 938 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	if (_tmp3_ > ((guint) 0)) {
#line 7113 "RajcePublishing.c"
		GtkEntry* _tmp4_;
		guint _tmp5_;
		guint _tmp6_;
#line 939 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp4_ = self->priv->password_entry;
#line 939 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp5_ = gtk_entry_get_text_length (_tmp4_);
#line 939 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp6_ = _tmp5_;
#line 939 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp0_ = _tmp6_ > ((guint) 0);
#line 7125 "RajcePublishing.c"
	} else {
#line 938 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp0_ = FALSE;
#line 7129 "RajcePublishing.c"
	}
#line 938 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp7_ = self->priv->login_button;
#line 938 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp7_, gtk_widget_get_type (), GtkWidget), _tmp0_);
#line 7135 "RajcePublishing.c"
}


static GtkWidget*
publishing_rajce_authentication_pane_real_get_widget (SpitPublishingDialogPane* base)
{
	PublishingRajceAuthenticationPane * self;
	GtkWidget* result = NULL;
	GtkBox* _tmp0_;
	GtkWidget* _tmp1_;
#line 942 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_RAJCE_TYPE_AUTHENTICATION_PANE, PublishingRajceAuthenticationPane);
#line 944 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp0_ = self->priv->pane_widget;
#line 944 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp1_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, gtk_widget_get_type (), GtkWidget));
#line 944 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	result = _tmp1_;
#line 944 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	return result;
#line 7156 "RajcePublishing.c"
}


static SpitPublishingDialogPaneGeometryOptions
publishing_rajce_authentication_pane_real_get_preferred_geometry (SpitPublishingDialogPane* base)
{
	PublishingRajceAuthenticationPane * self;
	SpitPublishingDialogPaneGeometryOptions result = 0;
#line 947 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_RAJCE_TYPE_AUTHENTICATION_PANE, PublishingRajceAuthenticationPane);
#line 949 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	result = SPIT_PUBLISHING_DIALOG_PANE_GEOMETRY_OPTIONS_NONE;
#line 949 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	return result;
#line 7171 "RajcePublishing.c"
}


static void
publishing_rajce_authentication_pane_real_on_pane_installed (SpitPublishingDialogPane* base)
{
	PublishingRajceAuthenticationPane * self;
	GtkEntry* _tmp0_;
	GtkEntry* _tmp1_;
	GtkButton* _tmp2_;
#line 952 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_RAJCE_TYPE_AUTHENTICATION_PANE, PublishingRajceAuthenticationPane);
#line 954 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp0_ = self->priv->username_entry;
#line 954 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	gtk_widget_grab_focus (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, gtk_widget_get_type (), GtkWidget));
#line 955 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp1_ = self->priv->password_entry;
#line 955 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	gtk_entry_set_activates_default (_tmp1_, TRUE);
#line 956 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp2_ = self->priv->login_button;
#line 956 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	gtk_widget_set_can_default (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, gtk_widget_get_type (), GtkWidget), TRUE);
#line 957 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rajce_authentication_pane_update_login_button_sensitivity (self);
#line 7198 "RajcePublishing.c"
}


static void
publishing_rajce_authentication_pane_real_on_pane_uninstalled (SpitPublishingDialogPane* base)
{
	PublishingRajceAuthenticationPane * self;
#line 959 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_RAJCE_TYPE_AUTHENTICATION_PANE, PublishingRajceAuthenticationPane);
#line 7208 "RajcePublishing.c"
}


static void
g_cclosure_user_marshal_VOID__STRING_STRING_BOOLEAN (GClosure * closure,
                                                     GValue * return_value,
                                                     guint n_param_values,
                                                     const GValue * param_values,
                                                     gpointer invocation_hint,
                                                     gpointer marshal_data)
{
	typedef void (*GMarshalFunc_VOID__STRING_STRING_BOOLEAN) (gpointer data1, const char* arg_1, const char* arg_2, gboolean arg_3, gpointer data2);
	register GMarshalFunc_VOID__STRING_STRING_BOOLEAN callback;
	register GCClosure * cc;
	register gpointer data1;
	register gpointer data2;
	cc = (GCClosure *) closure;
#line 826 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_if_fail (n_param_values == 4);
#line 826 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	if (G_CCLOSURE_SWAP_DATA (closure)) {
#line 826 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		data1 = closure->data;
#line 826 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		data2 = param_values->data[0].v_pointer;
#line 7234 "RajcePublishing.c"
	} else {
#line 826 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		data1 = param_values->data[0].v_pointer;
#line 826 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		data2 = closure->data;
#line 7240 "RajcePublishing.c"
	}
#line 826 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	callback = (GMarshalFunc_VOID__STRING_STRING_BOOLEAN) (marshal_data ? marshal_data : cc->callback);
#line 826 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	callback (data1, g_value_get_string (param_values + 1), g_value_get_string (param_values + 2), g_value_get_boolean (param_values + 3), data2);
#line 7246 "RajcePublishing.c"
}


static void
publishing_rajce_authentication_pane_class_init (PublishingRajceAuthenticationPaneClass * klass)
{
	gchar* _tmp0_;
	gchar* _tmp1_;
#line 826 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rajce_authentication_pane_parent_class = g_type_class_peek_parent (klass);
#line 826 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_type_class_add_private (klass, sizeof (PublishingRajceAuthenticationPanePrivate));
#line 826 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	G_OBJECT_CLASS (klass)->finalize = publishing_rajce_authentication_pane_finalize;
#line 826 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rajce_authentication_pane_signals[PUBLISHING_RAJCE_AUTHENTICATION_PANE_LOGIN_SIGNAL] = g_signal_new ("login", PUBLISHING_RAJCE_TYPE_AUTHENTICATION_PANE, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_user_marshal_VOID__STRING_STRING_BOOLEAN, G_TYPE_NONE, 3, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_BOOLEAN);
#line 833 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp0_ = g_strdup (_ ("Enter email and password associated with your Rajce account."));
#line 833 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rajce_authentication_pane_INTRO_MESSAGE = _tmp0_;
#line 834 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp1_ = g_strdup (_ ("Invalid email and/or password. Please try again"));
#line 834 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rajce_authentication_pane_FAILED_RETRY_USER_MESSAGE = _tmp1_;
#line 7271 "RajcePublishing.c"
}


static void
publishing_rajce_authentication_pane_spit_publishing_dialog_pane_interface_init (SpitPublishingDialogPaneIface * iface)
{
#line 826 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rajce_authentication_pane_spit_publishing_dialog_pane_parent_iface = g_type_interface_peek_parent (iface);
#line 826 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	iface->get_widget = (GtkWidget* (*) (SpitPublishingDialogPane *)) publishing_rajce_authentication_pane_real_get_widget;
#line 826 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	iface->get_preferred_geometry = (SpitPublishingDialogPaneGeometryOptions (*) (SpitPublishingDialogPane *)) publishing_rajce_authentication_pane_real_get_preferred_geometry;
#line 826 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	iface->on_pane_installed = (void (*) (SpitPublishingDialogPane *)) publishing_rajce_authentication_pane_real_on_pane_installed;
#line 826 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	iface->on_pane_uninstalled = (void (*) (SpitPublishingDialogPane *)) publishing_rajce_authentication_pane_real_on_pane_uninstalled;
#line 7288 "RajcePublishing.c"
}


static void
publishing_rajce_authentication_pane_instance_init (PublishingRajceAuthenticationPane * self)
{
#line 826 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self->priv = PUBLISHING_RAJCE_AUTHENTICATION_PANE_GET_PRIVATE (self);
#line 836 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self->priv->pane_widget = NULL;
#line 842 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self->priv->crypt = TRUE;
#line 7301 "RajcePublishing.c"
}


static void
publishing_rajce_authentication_pane_finalize (GObject * obj)
{
	PublishingRajceAuthenticationPane * self;
#line 826 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_RAJCE_TYPE_AUTHENTICATION_PANE, PublishingRajceAuthenticationPane);
#line 836 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_object_unref0 (self->priv->pane_widget);
#line 837 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_object_unref0 (self->priv->builder);
#line 838 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_object_unref0 (self->priv->username_entry);
#line 839 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_object_unref0 (self->priv->password_entry);
#line 840 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_object_unref0 (self->priv->remember_checkbutton);
#line 841 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_object_unref0 (self->priv->login_button);
#line 826 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	G_OBJECT_CLASS (publishing_rajce_authentication_pane_parent_class)->finalize (obj);
#line 7325 "RajcePublishing.c"
}


/**
 * The authentication pane used when asking service URL, user name and password
 * from the user.
 */
GType
publishing_rajce_authentication_pane_get_type (void)
{
	static volatile gsize publishing_rajce_authentication_pane_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_rajce_authentication_pane_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingRajceAuthenticationPaneClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_rajce_authentication_pane_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingRajceAuthenticationPane), 0, (GInstanceInitFunc) publishing_rajce_authentication_pane_instance_init, NULL };
		static const GInterfaceInfo spit_publishing_dialog_pane_info = { (GInterfaceInitFunc) publishing_rajce_authentication_pane_spit_publishing_dialog_pane_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType publishing_rajce_authentication_pane_type_id;
		publishing_rajce_authentication_pane_type_id = g_type_register_static (G_TYPE_OBJECT, "PublishingRajceAuthenticationPane", &g_define_type_info, 0);
		g_type_add_interface_static (publishing_rajce_authentication_pane_type_id, SPIT_PUBLISHING_TYPE_DIALOG_PANE, &spit_publishing_dialog_pane_info);
		g_once_init_leave (&publishing_rajce_authentication_pane_type_id__volatile, publishing_rajce_authentication_pane_type_id);
	}
	return publishing_rajce_authentication_pane_type_id__volatile;
}


static gpointer
_publishing_rajce_album_ref0 (gpointer self)
{
#line 988 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	return self ? publishing_rajce_album_ref (self) : NULL;
#line 7354 "RajcePublishing.c"
}


static PublishingRajceAlbum**
_vala_array_dup5 (PublishingRajceAlbum** self,
                  int length)
{
	PublishingRajceAlbum** result;
	int i;
#line 988 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	result = g_new0 (PublishingRajceAlbum*, length + 1);
#line 988 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	for (i = 0; i < length; i++) {
#line 7368 "RajcePublishing.c"
		PublishingRajceAlbum* _tmp0_;
#line 988 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp0_ = _publishing_rajce_album_ref0 (self[i]);
#line 988 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		result[i] = _tmp0_;
#line 7374 "RajcePublishing.c"
	}
#line 988 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	return result;
#line 7378 "RajcePublishing.c"
}


static void
_publishing_rajce_publishing_options_pane_on_use_existing_radio_clicked_gtk_button_clicked (GtkButton* _sender,
                                                                                            gpointer self)
{
#line 1021 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rajce_publishing_options_pane_on_use_existing_radio_clicked ((PublishingRajcePublishingOptionsPane*) self);
#line 7388 "RajcePublishing.c"
}


static void
_publishing_rajce_publishing_options_pane_on_create_new_radio_clicked_gtk_button_clicked (GtkButton* _sender,
                                                                                          gpointer self)
{
#line 1022 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rajce_publishing_options_pane_on_create_new_radio_clicked ((PublishingRajcePublishingOptionsPane*) self);
#line 7398 "RajcePublishing.c"
}


static void
_publishing_rajce_publishing_options_pane_on_new_album_entry_changed_gtk_editable_changed (GtkEditable* _sender,
                                                                                           gpointer self)
{
#line 1023 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rajce_publishing_options_pane_on_new_album_entry_changed ((PublishingRajcePublishingOptionsPane*) self);
#line 7408 "RajcePublishing.c"
}


static void
_publishing_rajce_publishing_options_pane_on_logout_clicked_gtk_button_clicked (GtkButton* _sender,
                                                                                gpointer self)
{
#line 1024 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rajce_publishing_options_pane_on_logout_clicked ((PublishingRajcePublishingOptionsPane*) self);
#line 7418 "RajcePublishing.c"
}


static void
_publishing_rajce_publishing_options_pane_on_publish_clicked_gtk_button_clicked (GtkButton* _sender,
                                                                                 gpointer self)
{
#line 1025 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rajce_publishing_options_pane_on_publish_clicked ((PublishingRajcePublishingOptionsPane*) self);
#line 7428 "RajcePublishing.c"
}


PublishingRajcePublishingOptionsPane*
publishing_rajce_publishing_options_pane_construct (GType object_type,
                                                    PublishingRajceRajcePublisher* publisher,
                                                    const gchar* username,
                                                    PublishingRajceAlbum** albums,
                                                    int albums_length1)
{
	PublishingRajcePublishingOptionsPane * self = NULL;
	gchar* _tmp0_;
	PublishingRajceAlbum** _tmp1_;
	gint _tmp1__length1;
	PublishingRajceRajcePublisher* _tmp2_;
	GtkBox* _tmp3_;
	GError * _inner_error_ = NULL;
#line 985 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_val_if_fail (PUBLISHING_RAJCE_IS_RAJCE_PUBLISHER (publisher), NULL);
#line 985 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_val_if_fail (username != NULL, NULL);
#line 985 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self = (PublishingRajcePublishingOptionsPane*) g_object_new (object_type, NULL);
#line 987 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp0_ = g_strdup (username);
#line 987 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_free0 (self->priv->username);
#line 987 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self->priv->username = _tmp0_;
#line 988 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp1_ = (albums != NULL) ? _vala_array_dup5 (albums, albums_length1) : ((gpointer) albums);
#line 988 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp1__length1 = albums_length1;
#line 988 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self->priv->albums = (_vala_array_free (self->priv->albums, self->priv->albums_length1, (GDestroyNotify) publishing_rajce_album_unref), NULL);
#line 988 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self->priv->albums = _tmp1_;
#line 988 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self->priv->albums_length1 = _tmp1__length1;
#line 988 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self->priv->_albums_size_ = self->priv->albums_length1;
#line 989 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp2_ = _g_object_ref0 (publisher);
#line 989 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_object_unref0 (self->priv->publisher);
#line 989 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self->priv->publisher = _tmp2_;
#line 990 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp3_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
#line 990 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_object_ref_sink (_tmp3_);
#line 990 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_object_unref0 (self->priv->pane_widget);
#line 990 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self->priv->pane_widget = _tmp3_;
#line 7484 "RajcePublishing.c"
	{
		GtkBuilder* _tmp4_;
		GtkBuilder* _tmp5_;
		GtkBuilder* _tmp6_;
		GtkBuilder* _tmp7_;
		GObject* _tmp8_;
		GtkBox* _tmp9_;
		GtkBuilder* _tmp10_;
		GObject* _tmp11_;
		GtkLabel* _tmp12_;
		GtkBuilder* _tmp13_;
		GObject* _tmp14_;
		GtkLabel* _tmp15_;
		GtkBuilder* _tmp16_;
		GObject* _tmp17_;
		GtkRadioButton* _tmp18_;
		GtkBuilder* _tmp19_;
		GObject* _tmp20_;
		GtkComboBoxText* _tmp21_;
		GtkBuilder* _tmp22_;
		GObject* _tmp23_;
		GtkRadioButton* _tmp24_;
		GtkBuilder* _tmp25_;
		GObject* _tmp26_;
		GtkEntry* _tmp27_;
		GtkBuilder* _tmp28_;
		GObject* _tmp29_;
		GtkCheckButton* _tmp30_;
		GtkCheckButton* _tmp31_;
		GtkBuilder* _tmp32_;
		GObject* _tmp33_;
		GtkCheckButton* _tmp34_;
		GtkBuilder* _tmp35_;
		GObject* _tmp36_;
		GtkButton* _tmp37_;
		GtkBuilder* _tmp38_;
		GObject* _tmp39_;
		GtkButton* _tmp40_;
		GtkCheckButton* _tmp41_;
		GtkCheckButton* _tmp42_;
		GtkLabel* _tmp43_;
		gchar* _tmp44_;
		gchar* _tmp45_;
		GtkLabel* _tmp46_;
		GtkRadioButton* _tmp47_;
		GtkRadioButton* _tmp48_;
		GtkCheckButton* _tmp49_;
		GtkButton* _tmp50_;
		GtkButton* _tmp51_;
		GtkRadioButton* _tmp52_;
		GtkRadioButton* _tmp53_;
		GtkEntry* _tmp54_;
		GtkButton* _tmp55_;
		GtkButton* _tmp56_;
#line 994 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp4_ = gtk_builder_new ();
#line 994 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_g_object_unref0 (self->priv->builder);
#line 994 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		self->priv->builder = _tmp4_;
#line 995 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp5_ = self->priv->builder;
#line 995 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		gtk_builder_add_from_resource (_tmp5_, PLUGIN_RESOURCE_PATH "/rajce_publishing_options_pane.ui", &_inner_error_);
#line 995 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 7551 "RajcePublishing.c"
			goto __catch30_g_error;
		}
#line 996 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp6_ = self->priv->builder;
#line 996 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		gtk_builder_connect_signals (_tmp6_, NULL);
#line 998 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp7_ = self->priv->builder;
#line 998 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp8_ = gtk_builder_get_object (_tmp7_, "rajce_pane_widget");
#line 998 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp9_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp8_, gtk_box_get_type (), GtkBox));
#line 998 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_g_object_unref0 (self->priv->pane_widget);
#line 998 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		self->priv->pane_widget = _tmp9_;
#line 999 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp10_ = self->priv->builder;
#line 999 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp11_ = gtk_builder_get_object (_tmp10_, "login_identity_label");
#line 999 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp12_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp11_, gtk_label_get_type (), GtkLabel));
#line 999 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_g_object_unref0 (self->priv->login_identity_label);
#line 999 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		self->priv->login_identity_label = _tmp12_;
#line 1000 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp13_ = self->priv->builder;
#line 1000 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp14_ = gtk_builder_get_object (_tmp13_, "publish_to_label");
#line 1000 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp15_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp14_, gtk_label_get_type (), GtkLabel));
#line 1000 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_g_object_unref0 (self->priv->publish_to_label);
#line 1000 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		self->priv->publish_to_label = _tmp15_;
#line 1001 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp16_ = self->priv->builder;
#line 1001 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp17_ = gtk_builder_get_object (_tmp16_, "use_existing_radio");
#line 1001 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp18_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp17_, gtk_radio_button_get_type (), GtkRadioButton));
#line 1001 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_g_object_unref0 (self->priv->use_existing_radio);
#line 1001 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		self->priv->use_existing_radio = _tmp18_;
#line 1002 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp19_ = self->priv->builder;
#line 1002 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp20_ = gtk_builder_get_object (_tmp19_, "existing_albums_combo");
#line 1002 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp21_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp20_, gtk_combo_box_text_get_type (), GtkComboBoxText));
#line 1002 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_g_object_unref0 (self->priv->existing_albums_combo);
#line 1002 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		self->priv->existing_albums_combo = _tmp21_;
#line 1003 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp22_ = self->priv->builder;
#line 1003 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp23_ = gtk_builder_get_object (_tmp22_, "create_new_radio");
#line 1003 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp24_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp23_, gtk_radio_button_get_type (), GtkRadioButton));
#line 1003 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_g_object_unref0 (self->priv->create_new_radio);
#line 1003 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		self->priv->create_new_radio = _tmp24_;
#line 1004 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp25_ = self->priv->builder;
#line 1004 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp26_ = gtk_builder_get_object (_tmp25_, "new_album_entry");
#line 1004 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp27_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp26_, gtk_entry_get_type (), GtkEntry));
#line 1004 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_g_object_unref0 (self->priv->new_album_entry);
#line 1004 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		self->priv->new_album_entry = _tmp27_;
#line 1005 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp28_ = self->priv->builder;
#line 1005 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp29_ = gtk_builder_get_object (_tmp28_, "hide_check");
#line 1005 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp30_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp29_, gtk_check_button_get_type (), GtkCheckButton));
#line 1005 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_g_object_unref0 (self->priv->hide_check);
#line 1005 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		self->priv->hide_check = _tmp30_;
#line 1006 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp31_ = self->priv->hide_check;
#line 1006 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		gtk_button_set_label (G_TYPE_CHECK_INSTANCE_CAST (_tmp31_, gtk_button_get_type (), GtkButton), _ ("_Hide album"));
#line 1007 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp32_ = self->priv->builder;
#line 1007 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp33_ = gtk_builder_get_object (_tmp32_, "show_check");
#line 1007 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp34_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp33_, gtk_check_button_get_type (), GtkCheckButton));
#line 1007 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_g_object_unref0 (self->priv->show_check);
#line 1007 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		self->priv->show_check = _tmp34_;
#line 1008 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp35_ = self->priv->builder;
#line 1008 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp36_ = gtk_builder_get_object (_tmp35_, "publish_button");
#line 1008 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp37_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp36_, gtk_button_get_type (), GtkButton));
#line 1008 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_g_object_unref0 (self->priv->publish_button);
#line 1008 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		self->priv->publish_button = _tmp37_;
#line 1009 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp38_ = self->priv->builder;
#line 1009 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp39_ = gtk_builder_get_object (_tmp38_, "logout_button");
#line 1009 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp40_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp39_, gtk_button_get_type (), GtkButton));
#line 1009 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_g_object_unref0 (self->priv->logout_button);
#line 1009 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		self->priv->logout_button = _tmp40_;
#line 1011 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp41_ = self->priv->hide_check;
#line 1011 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		gtk_toggle_button_set_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp41_, gtk_toggle_button_get_type (), GtkToggleButton), publishing_rajce_rajce_publisher_get_hide_album (publisher));
#line 1012 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp42_ = self->priv->show_check;
#line 1012 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		gtk_toggle_button_set_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp42_, gtk_toggle_button_get_type (), GtkToggleButton), publishing_rajce_rajce_publisher_get_show_album (publisher));
#line 1013 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp43_ = self->priv->login_identity_label;
#line 1013 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp44_ = g_strdup_printf (_ ("You are logged into Rajce as %s."), username);
#line 1013 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp45_ = _tmp44_;
#line 1013 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		gtk_label_set_label (_tmp43_, _tmp45_);
#line 1013 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_g_free0 (_tmp45_);
#line 1014 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp46_ = self->priv->publish_to_label;
#line 1014 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		gtk_label_set_label (_tmp46_, _ ("Photos will appear in:"));
#line 1015 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp47_ = self->priv->use_existing_radio;
#line 1015 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		gtk_button_set_label (G_TYPE_CHECK_INSTANCE_CAST (_tmp47_, gtk_button_get_type (), GtkButton), _ ("An _existing album:"));
#line 1016 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp48_ = self->priv->create_new_radio;
#line 1016 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		gtk_button_set_label (G_TYPE_CHECK_INSTANCE_CAST (_tmp48_, gtk_button_get_type (), GtkButton), _ ("A _new album named:"));
#line 1017 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp49_ = self->priv->show_check;
#line 1017 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		gtk_button_set_label (G_TYPE_CHECK_INSTANCE_CAST (_tmp49_, gtk_button_get_type (), GtkButton), _ ("Open target _album in browser"));
#line 1018 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp50_ = self->priv->publish_button;
#line 1018 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		gtk_button_set_label (_tmp50_, _ ("_Publish"));
#line 1019 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp51_ = self->priv->logout_button;
#line 1019 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		gtk_button_set_label (_tmp51_, _ ("_Logout"));
#line 1021 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp52_ = self->priv->use_existing_radio;
#line 1021 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp52_, gtk_button_get_type (), GtkButton), "clicked", (GCallback) _publishing_rajce_publishing_options_pane_on_use_existing_radio_clicked_gtk_button_clicked, self, 0);
#line 1022 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp53_ = self->priv->create_new_radio;
#line 1022 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp53_, gtk_button_get_type (), GtkButton), "clicked", (GCallback) _publishing_rajce_publishing_options_pane_on_create_new_radio_clicked_gtk_button_clicked, self, 0);
#line 1023 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp54_ = self->priv->new_album_entry;
#line 1023 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp54_, gtk_editable_get_type (), GtkEditable), "changed", (GCallback) _publishing_rajce_publishing_options_pane_on_new_album_entry_changed_gtk_editable_changed, self, 0);
#line 1024 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp55_ = self->priv->logout_button;
#line 1024 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		g_signal_connect_object (_tmp55_, "clicked", (GCallback) _publishing_rajce_publishing_options_pane_on_logout_clicked_gtk_button_clicked, self, 0);
#line 1025 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp56_ = self->priv->publish_button;
#line 1025 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		g_signal_connect_object (_tmp56_, "clicked", (GCallback) _publishing_rajce_publishing_options_pane_on_publish_clicked_gtk_button_clicked, self, 0);
#line 7734 "RajcePublishing.c"
	}
	goto __finally30;
	__catch30_g_error:
	{
		GError* e = NULL;
		GError* _tmp57_;
		const gchar* _tmp58_;
#line 992 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		e = _inner_error_;
#line 992 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_inner_error_ = NULL;
#line 1029 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp57_ = e;
#line 1029 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp58_ = _tmp57_->message;
#line 1029 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		g_warning ("RajcePublishing.vala:1029: Could not load UI: %s", _tmp58_);
#line 992 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_g_error_free0 (e);
#line 7754 "RajcePublishing.c"
	}
	__finally30:
#line 992 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 992 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 992 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		g_clear_error (&_inner_error_);
#line 992 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		return NULL;
#line 7765 "RajcePublishing.c"
	}
#line 985 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	return self;
#line 7769 "RajcePublishing.c"
}


PublishingRajcePublishingOptionsPane*
publishing_rajce_publishing_options_pane_new (PublishingRajceRajcePublisher* publisher,
                                              const gchar* username,
                                              PublishingRajceAlbum** albums,
                                              int albums_length1)
{
#line 985 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	return publishing_rajce_publishing_options_pane_construct (PUBLISHING_RAJCE_TYPE_PUBLISHING_OPTIONS_PANE, publisher, username, albums, albums_length1);
#line 7781 "RajcePublishing.c"
}


static void
publishing_rajce_publishing_options_pane_on_publish_clicked (PublishingRajcePublishingOptionsPane* self)
{
	gboolean show_album = FALSE;
	GtkCheckButton* _tmp0_;
	PublishingRajceRajcePublisher* _tmp1_;
	gboolean _tmp2_;
	GtkRadioButton* _tmp3_;
#line 1034 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_if_fail (PUBLISHING_RAJCE_IS_PUBLISHING_OPTIONS_PANE (self));
#line 1036 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp0_ = self->priv->show_check;
#line 1036 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	show_album = gtk_toggle_button_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, gtk_toggle_button_get_type (), GtkToggleButton));
#line 1037 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp1_ = self->priv->publisher;
#line 1037 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp2_ = show_album;
#line 1037 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rajce_rajce_publisher_set_show_album (_tmp1_, _tmp2_);
#line 1038 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp3_ = self->priv->create_new_radio;
#line 1038 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	if (gtk_toggle_button_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, gtk_toggle_button_get_type (), GtkToggleButton))) {
#line 7809 "RajcePublishing.c"
		gchar* album_name = NULL;
		GtkEntry* _tmp4_;
		const gchar* _tmp5_;
		gchar* _tmp6_;
		gboolean hide_album = FALSE;
		GtkCheckButton* _tmp7_;
		PublishingRajceRajcePublisher* _tmp8_;
		gboolean _tmp9_;
		const gchar* _tmp10_;
		gboolean _tmp11_;
		PublishingRajcePublishingParameters* _tmp12_;
		PublishingRajcePublishingParameters* _tmp13_;
#line 1040 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp4_ = self->priv->new_album_entry;
#line 1040 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp5_ = gtk_entry_get_text (_tmp4_);
#line 1040 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp6_ = g_strdup (_tmp5_);
#line 1040 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		album_name = _tmp6_;
#line 1041 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp7_ = self->priv->hide_check;
#line 1041 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		hide_album = gtk_toggle_button_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp7_, gtk_toggle_button_get_type (), GtkToggleButton));
#line 1042 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp8_ = self->priv->publisher;
#line 1042 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp9_ = hide_album;
#line 1042 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		publishing_rajce_rajce_publisher_set_hide_album (_tmp8_, _tmp9_);
#line 1043 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp10_ = album_name;
#line 1043 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp11_ = hide_album;
#line 1043 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp12_ = publishing_rajce_publishing_parameters_new_to_new_album (_tmp10_, _tmp11_);
#line 1043 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp13_ = _tmp12_;
#line 1043 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		g_signal_emit (self, publishing_rajce_publishing_options_pane_signals[PUBLISHING_RAJCE_PUBLISHING_OPTIONS_PANE_PUBLISH_SIGNAL], 0, _tmp13_);
#line 1043 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_publishing_rajce_publishing_parameters_unref0 (_tmp13_);
#line 1038 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_g_free0 (album_name);
#line 7854 "RajcePublishing.c"
	} else {
		gint id = 0;
		PublishingRajceAlbum** _tmp14_;
		gint _tmp14__length1;
		GtkComboBoxText* _tmp15_;
		PublishingRajceAlbum* _tmp16_;
		gint _tmp17_;
		gchar* album_name = NULL;
		PublishingRajceAlbum** _tmp18_;
		gint _tmp18__length1;
		GtkComboBoxText* _tmp19_;
		PublishingRajceAlbum* _tmp20_;
		const gchar* _tmp21_;
		gchar* _tmp22_;
		const gchar* _tmp23_;
		gint _tmp24_;
		PublishingRajcePublishingParameters* _tmp25_;
		PublishingRajcePublishingParameters* _tmp26_;
#line 1047 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp14_ = self->priv->albums;
#line 1047 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp14__length1 = self->priv->albums_length1;
#line 1047 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp15_ = self->priv->existing_albums_combo;
#line 1047 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp16_ = _tmp14_[gtk_combo_box_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp15_, gtk_combo_box_get_type (), GtkComboBox))];
#line 1047 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp17_ = _tmp16_->id;
#line 1047 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		id = _tmp17_;
#line 1048 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp18_ = self->priv->albums;
#line 1048 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp18__length1 = self->priv->albums_length1;
#line 1048 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp19_ = self->priv->existing_albums_combo;
#line 1048 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp20_ = _tmp18_[gtk_combo_box_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp19_, gtk_combo_box_get_type (), GtkComboBox))];
#line 1048 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp21_ = _tmp20_->albumName;
#line 1048 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp22_ = g_strdup (_tmp21_);
#line 1048 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		album_name = _tmp22_;
#line 1049 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp23_ = album_name;
#line 1049 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp24_ = id;
#line 1049 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp25_ = publishing_rajce_publishing_parameters_new_to_existing_album (_tmp23_, _tmp24_);
#line 1049 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp26_ = _tmp25_;
#line 1049 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		g_signal_emit (self, publishing_rajce_publishing_options_pane_signals[PUBLISHING_RAJCE_PUBLISHING_OPTIONS_PANE_PUBLISH_SIGNAL], 0, _tmp26_);
#line 1049 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_publishing_rajce_publishing_parameters_unref0 (_tmp26_);
#line 1038 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_g_free0 (album_name);
#line 7913 "RajcePublishing.c"
	}
}


static void
publishing_rajce_publishing_options_pane_on_use_existing_radio_clicked (PublishingRajcePublishingOptionsPane* self)
{
	GtkComboBoxText* _tmp0_;
	GtkEntry* _tmp1_;
	GtkComboBoxText* _tmp2_;
	GtkCheckButton* _tmp3_;
#line 1053 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_if_fail (PUBLISHING_RAJCE_IS_PUBLISHING_OPTIONS_PANE (self));
#line 1055 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp0_ = self->priv->existing_albums_combo;
#line 1055 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, gtk_widget_get_type (), GtkWidget), TRUE);
#line 1056 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp1_ = self->priv->new_album_entry;
#line 1056 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, gtk_widget_get_type (), GtkWidget), FALSE);
#line 1057 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp2_ = self->priv->existing_albums_combo;
#line 1057 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	gtk_widget_grab_focus (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, gtk_widget_get_type (), GtkWidget));
#line 1058 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rajce_publishing_options_pane_update_publish_button_sensitivity (self);
#line 1059 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp3_ = self->priv->hide_check;
#line 1059 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, gtk_widget_get_type (), GtkWidget), FALSE);
#line 7945 "RajcePublishing.c"
}


static void
publishing_rajce_publishing_options_pane_on_create_new_radio_clicked (PublishingRajcePublishingOptionsPane* self)
{
	GtkEntry* _tmp0_;
	GtkComboBoxText* _tmp1_;
	GtkEntry* _tmp2_;
	GtkCheckButton* _tmp3_;
#line 1062 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_if_fail (PUBLISHING_RAJCE_IS_PUBLISHING_OPTIONS_PANE (self));
#line 1064 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp0_ = self->priv->new_album_entry;
#line 1064 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, gtk_widget_get_type (), GtkWidget), TRUE);
#line 1065 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp1_ = self->priv->existing_albums_combo;
#line 1065 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, gtk_widget_get_type (), GtkWidget), FALSE);
#line 1066 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp2_ = self->priv->new_album_entry;
#line 1066 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	gtk_widget_grab_focus (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, gtk_widget_get_type (), GtkWidget));
#line 1067 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rajce_publishing_options_pane_update_publish_button_sensitivity (self);
#line 1068 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp3_ = self->priv->hide_check;
#line 1068 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, gtk_widget_get_type (), GtkWidget), TRUE);
#line 7976 "RajcePublishing.c"
}


static void
publishing_rajce_publishing_options_pane_on_logout_clicked (PublishingRajcePublishingOptionsPane* self)
{
#line 1071 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_if_fail (PUBLISHING_RAJCE_IS_PUBLISHING_OPTIONS_PANE (self));
#line 1073 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_signal_emit (self, publishing_rajce_publishing_options_pane_signals[PUBLISHING_RAJCE_PUBLISHING_OPTIONS_PANE_LOGOUT_SIGNAL], 0);
#line 7987 "RajcePublishing.c"
}


static gchar*
string_strip (const gchar* self)
{
	gchar* result = NULL;
	gchar* _result_ = NULL;
	gchar* _tmp0_;
	const gchar* _tmp1_;
#line 1248 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, NULL);
#line 1249 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	_tmp0_ = g_strdup (self);
#line 1249 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	_result_ = _tmp0_;
#line 1250 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	_tmp1_ = _result_;
#line 1250 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	g_strstrip (_tmp1_);
#line 1251 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	result = _result_;
#line 1251 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	return result;
#line 8012 "RajcePublishing.c"
}


static void
publishing_rajce_publishing_options_pane_update_publish_button_sensitivity (PublishingRajcePublishingOptionsPane* self)
{
	gchar* album_name = NULL;
	GtkEntry* _tmp0_;
	const gchar* _tmp1_;
	gchar* _tmp2_;
	gboolean _tmp3_ = FALSE;
	const gchar* _tmp4_;
	gchar* _tmp5_;
	gchar* _tmp6_;
	gboolean _tmp7_;
	GtkButton* _tmp9_;
#line 1075 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_if_fail (PUBLISHING_RAJCE_IS_PUBLISHING_OPTIONS_PANE (self));
#line 1077 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp0_ = self->priv->new_album_entry;
#line 1077 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp1_ = gtk_entry_get_text (_tmp0_);
#line 1077 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp2_ = g_strdup (_tmp1_);
#line 1077 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	album_name = _tmp2_;
#line 1078 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp4_ = album_name;
#line 1078 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp5_ = string_strip (_tmp4_);
#line 1078 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp6_ = _tmp5_;
#line 1078 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp7_ = g_strcmp0 (_tmp6_, "") != 0;
#line 1078 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_free0 (_tmp6_);
#line 1078 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	if (_tmp7_) {
#line 1078 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp3_ = TRUE;
#line 8053 "RajcePublishing.c"
	} else {
		GtkRadioButton* _tmp8_;
#line 1078 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp8_ = self->priv->create_new_radio;
#line 1078 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp3_ = !gtk_toggle_button_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp8_, gtk_toggle_button_get_type (), GtkToggleButton));
#line 8060 "RajcePublishing.c"
	}
#line 1078 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp9_ = self->priv->publish_button;
#line 1078 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, gtk_widget_get_type (), GtkWidget), _tmp3_);
#line 1075 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_free0 (album_name);
#line 8068 "RajcePublishing.c"
}


static void
publishing_rajce_publishing_options_pane_on_new_album_entry_changed (PublishingRajcePublishingOptionsPane* self)
{
#line 1080 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_if_fail (PUBLISHING_RAJCE_IS_PUBLISHING_OPTIONS_PANE (self));
#line 1082 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rajce_publishing_options_pane_update_publish_button_sensitivity (self);
#line 8079 "RajcePublishing.c"
}


void
publishing_rajce_publishing_options_pane_installed (PublishingRajcePublishingOptionsPane* self)
{
	PublishingRajceAlbum** _tmp9_;
	gint _tmp9__length1;
	GtkRadioButton* _tmp15_;
#line 1084 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_if_fail (PUBLISHING_RAJCE_IS_PUBLISHING_OPTIONS_PANE (self));
#line 8091 "RajcePublishing.c"
	{
		gint i = 0;
#line 1086 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		i = 0;
#line 8096 "RajcePublishing.c"
		{
			gboolean _tmp0_ = FALSE;
#line 1086 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			_tmp0_ = TRUE;
#line 1086 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			while (TRUE) {
#line 8103 "RajcePublishing.c"
				gint _tmp2_;
				PublishingRajceAlbum** _tmp3_;
				gint _tmp3__length1;
				GtkComboBoxText* _tmp4_;
				PublishingRajceAlbum** _tmp5_;
				gint _tmp5__length1;
				gint _tmp6_;
				PublishingRajceAlbum* _tmp7_;
				const gchar* _tmp8_;
#line 1086 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
				if (!_tmp0_) {
#line 8115 "RajcePublishing.c"
					gint _tmp1_;
#line 1086 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
					_tmp1_ = i;
#line 1086 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
					i = _tmp1_ + 1;
#line 8121 "RajcePublishing.c"
				}
#line 1086 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
				_tmp0_ = FALSE;
#line 1086 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
				_tmp2_ = i;
#line 1086 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
				_tmp3_ = self->priv->albums;
#line 1086 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
				_tmp3__length1 = self->priv->albums_length1;
#line 1086 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
				if (!(_tmp2_ < _tmp3__length1)) {
#line 1086 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
					break;
#line 8135 "RajcePublishing.c"
				}
#line 1089 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
				_tmp4_ = self->priv->existing_albums_combo;
#line 1089 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
				_tmp5_ = self->priv->albums;
#line 1089 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
				_tmp5__length1 = self->priv->albums_length1;
#line 1089 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
				_tmp6_ = i;
#line 1089 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
				_tmp7_ = _tmp5_[_tmp6_];
#line 1089 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
				_tmp8_ = _tmp7_->albumName;
#line 1089 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
				gtk_combo_box_text_append_text (_tmp4_, _tmp8_);
#line 8151 "RajcePublishing.c"
			}
		}
	}
#line 1091 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp9_ = self->priv->albums;
#line 1091 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp9__length1 = self->priv->albums_length1;
#line 1091 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	if (_tmp9__length1 == 0) {
#line 8161 "RajcePublishing.c"
		GtkComboBoxText* _tmp10_;
		GtkRadioButton* _tmp11_;
#line 1093 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp10_ = self->priv->existing_albums_combo;
#line 1093 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp10_, gtk_widget_get_type (), GtkWidget), FALSE);
#line 1094 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp11_ = self->priv->use_existing_radio;
#line 1094 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp11_, gtk_widget_get_type (), GtkWidget), FALSE);
#line 8172 "RajcePublishing.c"
	} else {
		GtkComboBoxText* _tmp12_;
		GtkComboBoxText* _tmp13_;
		GtkRadioButton* _tmp14_;
#line 1098 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp12_ = self->priv->existing_albums_combo;
#line 1098 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		gtk_combo_box_set_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp12_, gtk_combo_box_get_type (), GtkComboBox), 0);
#line 1099 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp13_ = self->priv->existing_albums_combo;
#line 1099 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp13_, gtk_widget_get_type (), GtkWidget), TRUE);
#line 1100 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp14_ = self->priv->use_existing_radio;
#line 1100 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp14_, gtk_widget_get_type (), GtkWidget), TRUE);
#line 8189 "RajcePublishing.c"
	}
#line 1102 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp15_ = self->priv->create_new_radio;
#line 1102 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	gtk_toggle_button_set_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp15_, gtk_toggle_button_get_type (), GtkToggleButton), TRUE);
#line 1103 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rajce_publishing_options_pane_on_create_new_radio_clicked (self);
#line 8197 "RajcePublishing.c"
}


void
publishing_rajce_publishing_options_pane_notify_publish (PublishingRajcePublishingOptionsPane* self,
                                                         PublishingRajcePublishingParameters* parameters)
{
#line 1106 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_if_fail (PUBLISHING_RAJCE_IS_PUBLISHING_OPTIONS_PANE (self));
#line 1106 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_if_fail (PUBLISHING_RAJCE_IS_PUBLISHING_PARAMETERS (parameters));
#line 1108 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_signal_emit (self, publishing_rajce_publishing_options_pane_signals[PUBLISHING_RAJCE_PUBLISHING_OPTIONS_PANE_PUBLISH_SIGNAL], 0, parameters);
#line 8211 "RajcePublishing.c"
}


void
publishing_rajce_publishing_options_pane_notify_logout (PublishingRajcePublishingOptionsPane* self)
{
#line 1111 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_if_fail (PUBLISHING_RAJCE_IS_PUBLISHING_OPTIONS_PANE (self));
#line 1113 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_signal_emit (self, publishing_rajce_publishing_options_pane_signals[PUBLISHING_RAJCE_PUBLISHING_OPTIONS_PANE_LOGOUT_SIGNAL], 0);
#line 8222 "RajcePublishing.c"
}


GtkWidget*
publishing_rajce_publishing_options_pane_get_default_widget (PublishingRajcePublishingOptionsPane* self)
{
	GtkWidget* result = NULL;
	GtkButton* _tmp0_;
	GtkWidget* _tmp1_;
#line 1116 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_val_if_fail (PUBLISHING_RAJCE_IS_PUBLISHING_OPTIONS_PANE (self), NULL);
#line 1118 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp0_ = self->priv->logout_button;
#line 1118 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp1_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, gtk_widget_get_type (), GtkWidget));
#line 1118 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	result = _tmp1_;
#line 1118 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	return result;
#line 8242 "RajcePublishing.c"
}


static GtkWidget*
publishing_rajce_publishing_options_pane_real_get_widget (SpitPublishingDialogPane* base)
{
	PublishingRajcePublishingOptionsPane * self;
	GtkWidget* result = NULL;
	GtkBox* _tmp0_;
	GtkWidget* _tmp1_;
#line 1120 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_RAJCE_TYPE_PUBLISHING_OPTIONS_PANE, PublishingRajcePublishingOptionsPane);
#line 1122 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp0_ = self->priv->pane_widget;
#line 1122 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp1_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, gtk_widget_get_type (), GtkWidget));
#line 1122 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	result = _tmp1_;
#line 1122 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	return result;
#line 8263 "RajcePublishing.c"
}


static SpitPublishingDialogPaneGeometryOptions
publishing_rajce_publishing_options_pane_real_get_preferred_geometry (SpitPublishingDialogPane* base)
{
	PublishingRajcePublishingOptionsPane * self;
	SpitPublishingDialogPaneGeometryOptions result = 0;
#line 1125 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_RAJCE_TYPE_PUBLISHING_OPTIONS_PANE, PublishingRajcePublishingOptionsPane);
#line 1127 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	result = SPIT_PUBLISHING_DIALOG_PANE_GEOMETRY_OPTIONS_NONE;
#line 1127 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	return result;
#line 8278 "RajcePublishing.c"
}


static void
_publishing_rajce_publishing_options_pane_notify_publish_publishing_rajce_publishing_options_pane_publish (PublishingRajcePublishingOptionsPane* _sender,
                                                                                                           PublishingRajcePublishingParameters* parameters,
                                                                                                           gpointer self)
{
#line 1133 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rajce_publishing_options_pane_notify_publish ((PublishingRajcePublishingOptionsPane*) self, parameters);
#line 8289 "RajcePublishing.c"
}


static void
_publishing_rajce_publishing_options_pane_notify_logout_publishing_rajce_publishing_options_pane_logout (PublishingRajcePublishingOptionsPane* _sender,
                                                                                                         gpointer self)
{
#line 1134 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rajce_publishing_options_pane_notify_logout ((PublishingRajcePublishingOptionsPane*) self);
#line 8299 "RajcePublishing.c"
}


static void
publishing_rajce_publishing_options_pane_real_on_pane_installed (SpitPublishingDialogPane* base)
{
	PublishingRajcePublishingOptionsPane * self;
#line 1130 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_RAJCE_TYPE_PUBLISHING_OPTIONS_PANE, PublishingRajcePublishingOptionsPane);
#line 1132 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rajce_publishing_options_pane_installed (self);
#line 1133 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_signal_connect_object (self, "publish", (GCallback) _publishing_rajce_publishing_options_pane_notify_publish_publishing_rajce_publishing_options_pane_publish, self, 0);
#line 1134 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_signal_connect_object (self, "logout", (GCallback) _publishing_rajce_publishing_options_pane_notify_logout_publishing_rajce_publishing_options_pane_logout, self, 0);
#line 8315 "RajcePublishing.c"
}


static void
publishing_rajce_publishing_options_pane_real_on_pane_uninstalled (SpitPublishingDialogPane* base)
{
	PublishingRajcePublishingOptionsPane * self;
	guint _tmp0_;
	guint _tmp1_;
#line 1137 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_RAJCE_TYPE_PUBLISHING_OPTIONS_PANE, PublishingRajcePublishingOptionsPane);
#line 1139 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_signal_parse_name ("publish", PUBLISHING_RAJCE_TYPE_PUBLISHING_OPTIONS_PANE, &_tmp0_, NULL, FALSE);
#line 1139 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_signal_handlers_disconnect_matched (self, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp0_, 0, NULL, (GCallback) _publishing_rajce_publishing_options_pane_notify_publish_publishing_rajce_publishing_options_pane_publish, self);
#line 1140 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_signal_parse_name ("logout", PUBLISHING_RAJCE_TYPE_PUBLISHING_OPTIONS_PANE, &_tmp1_, NULL, FALSE);
#line 1140 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_signal_handlers_disconnect_matched (self, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _publishing_rajce_publishing_options_pane_notify_logout_publishing_rajce_publishing_options_pane_logout, self);
#line 8335 "RajcePublishing.c"
}


static void
g_cclosure_user_marshal_VOID__PUBLISHING_RAJCE_PUBLISHING_PARAMETERS (GClosure * closure,
                                                                      GValue * return_value,
                                                                      guint n_param_values,
                                                                      const GValue * param_values,
                                                                      gpointer invocation_hint,
                                                                      gpointer marshal_data)
{
	typedef void (*GMarshalFunc_VOID__PUBLISHING_RAJCE_PUBLISHING_PARAMETERS) (gpointer data1, gpointer arg_1, gpointer data2);
	register GMarshalFunc_VOID__PUBLISHING_RAJCE_PUBLISHING_PARAMETERS callback;
	register GCClosure * cc;
	register gpointer data1;
	register gpointer data2;
	cc = (GCClosure *) closure;
#line 963 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_if_fail (n_param_values == 2);
#line 963 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	if (G_CCLOSURE_SWAP_DATA (closure)) {
#line 963 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		data1 = closure->data;
#line 963 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		data2 = param_values->data[0].v_pointer;
#line 8361 "RajcePublishing.c"
	} else {
#line 963 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		data1 = param_values->data[0].v_pointer;
#line 963 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		data2 = closure->data;
#line 8367 "RajcePublishing.c"
	}
#line 963 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	callback = (GMarshalFunc_VOID__PUBLISHING_RAJCE_PUBLISHING_PARAMETERS) (marshal_data ? marshal_data : cc->callback);
#line 963 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	callback (data1, publishing_rajce_value_get_publishing_parameters (param_values + 1), data2);
#line 8373 "RajcePublishing.c"
}


static void
publishing_rajce_publishing_options_pane_class_init (PublishingRajcePublishingOptionsPaneClass * klass)
{
#line 963 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rajce_publishing_options_pane_parent_class = g_type_class_peek_parent (klass);
#line 963 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_type_class_add_private (klass, sizeof (PublishingRajcePublishingOptionsPanePrivate));
#line 963 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	G_OBJECT_CLASS (klass)->finalize = publishing_rajce_publishing_options_pane_finalize;
#line 963 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rajce_publishing_options_pane_signals[PUBLISHING_RAJCE_PUBLISHING_OPTIONS_PANE_PUBLISH_SIGNAL] = g_signal_new ("publish", PUBLISHING_RAJCE_TYPE_PUBLISHING_OPTIONS_PANE, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_user_marshal_VOID__PUBLISHING_RAJCE_PUBLISHING_PARAMETERS, G_TYPE_NONE, 1, PUBLISHING_RAJCE_TYPE_PUBLISHING_PARAMETERS);
#line 963 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rajce_publishing_options_pane_signals[PUBLISHING_RAJCE_PUBLISHING_OPTIONS_PANE_LOGOUT_SIGNAL] = g_signal_new ("logout", PUBLISHING_RAJCE_TYPE_PUBLISHING_OPTIONS_PANE, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
#line 8390 "RajcePublishing.c"
}


static void
publishing_rajce_publishing_options_pane_spit_publishing_dialog_pane_interface_init (SpitPublishingDialogPaneIface * iface)
{
#line 963 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rajce_publishing_options_pane_spit_publishing_dialog_pane_parent_iface = g_type_interface_peek_parent (iface);
#line 963 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	iface->get_widget = (GtkWidget* (*) (SpitPublishingDialogPane *)) publishing_rajce_publishing_options_pane_real_get_widget;
#line 963 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	iface->get_preferred_geometry = (SpitPublishingDialogPaneGeometryOptions (*) (SpitPublishingDialogPane *)) publishing_rajce_publishing_options_pane_real_get_preferred_geometry;
#line 963 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	iface->on_pane_installed = (void (*) (SpitPublishingDialogPane *)) publishing_rajce_publishing_options_pane_real_on_pane_installed;
#line 963 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	iface->on_pane_uninstalled = (void (*) (SpitPublishingDialogPane *)) publishing_rajce_publishing_options_pane_real_on_pane_uninstalled;
#line 8407 "RajcePublishing.c"
}


static void
publishing_rajce_publishing_options_pane_instance_init (PublishingRajcePublishingOptionsPane * self)
{
#line 963 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self->priv = PUBLISHING_RAJCE_PUBLISHING_OPTIONS_PANE_GET_PRIVATE (self);
#line 969 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self->priv->builder = NULL;
#line 970 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self->priv->pane_widget = NULL;
#line 971 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self->priv->login_identity_label = NULL;
#line 972 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self->priv->publish_to_label = NULL;
#line 973 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self->priv->use_existing_radio = NULL;
#line 974 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self->priv->existing_albums_combo = NULL;
#line 975 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self->priv->create_new_radio = NULL;
#line 976 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self->priv->new_album_entry = NULL;
#line 977 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self->priv->hide_check = NULL;
#line 978 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self->priv->show_check = NULL;
#line 979 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self->priv->publish_button = NULL;
#line 980 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self->priv->logout_button = NULL;
#line 8440 "RajcePublishing.c"
}


static void
publishing_rajce_publishing_options_pane_finalize (GObject * obj)
{
	PublishingRajcePublishingOptionsPane * self;
#line 963 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_RAJCE_TYPE_PUBLISHING_OPTIONS_PANE, PublishingRajcePublishingOptionsPane);
#line 965 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_object_unref0 (self->priv->publisher);
#line 966 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self->priv->albums = (_vala_array_free (self->priv->albums, self->priv->albums_length1, (GDestroyNotify) publishing_rajce_album_unref), NULL);
#line 967 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_free0 (self->priv->username);
#line 969 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_object_unref0 (self->priv->builder);
#line 970 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_object_unref0 (self->priv->pane_widget);
#line 971 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_object_unref0 (self->priv->login_identity_label);
#line 972 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_object_unref0 (self->priv->publish_to_label);
#line 973 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_object_unref0 (self->priv->use_existing_radio);
#line 974 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_object_unref0 (self->priv->existing_albums_combo);
#line 975 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_object_unref0 (self->priv->create_new_radio);
#line 976 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_object_unref0 (self->priv->new_album_entry);
#line 977 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_object_unref0 (self->priv->hide_check);
#line 978 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_object_unref0 (self->priv->show_check);
#line 979 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_object_unref0 (self->priv->publish_button);
#line 980 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_object_unref0 (self->priv->logout_button);
#line 963 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	G_OBJECT_CLASS (publishing_rajce_publishing_options_pane_parent_class)->finalize (obj);
#line 8482 "RajcePublishing.c"
}


GType
publishing_rajce_publishing_options_pane_get_type (void)
{
	static volatile gsize publishing_rajce_publishing_options_pane_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_rajce_publishing_options_pane_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingRajcePublishingOptionsPaneClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_rajce_publishing_options_pane_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingRajcePublishingOptionsPane), 0, (GInstanceInitFunc) publishing_rajce_publishing_options_pane_instance_init, NULL };
		static const GInterfaceInfo spit_publishing_dialog_pane_info = { (GInterfaceInitFunc) publishing_rajce_publishing_options_pane_spit_publishing_dialog_pane_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType publishing_rajce_publishing_options_pane_type_id;
		publishing_rajce_publishing_options_pane_type_id = g_type_register_static (G_TYPE_OBJECT, "PublishingRajcePublishingOptionsPane", &g_define_type_info, 0);
		g_type_add_interface_static (publishing_rajce_publishing_options_pane_type_id, SPIT_PUBLISHING_TYPE_DIALOG_PANE, &spit_publishing_dialog_pane_info);
		g_once_init_leave (&publishing_rajce_publishing_options_pane_type_id__volatile, publishing_rajce_publishing_options_pane_type_id);
	}
	return publishing_rajce_publishing_options_pane_type_id__volatile;
}


static PublishingRajcePublishingParameters*
publishing_rajce_publishing_parameters_construct (GType object_type)
{
	PublishingRajcePublishingParameters* self = NULL;
#line 1150 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self = (PublishingRajcePublishingParameters*) g_type_create_instance (object_type);
#line 1150 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	return self;
#line 8510 "RajcePublishing.c"
}


static PublishingRajcePublishingParameters*
publishing_rajce_publishing_parameters_new (void)
{
#line 1150 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	return publishing_rajce_publishing_parameters_construct (PUBLISHING_RAJCE_TYPE_PUBLISHING_PARAMETERS);
#line 8519 "RajcePublishing.c"
}


PublishingRajcePublishingParameters*
publishing_rajce_publishing_parameters_construct_to_new_album (GType object_type,
                                                               const gchar* album_name,
                                                               gboolean album_hidden)
{
	PublishingRajcePublishingParameters* self = NULL;
	gchar* _tmp0_;
	gboolean* _tmp1_;
	gint _tmp2_;
	gint* _tmp3_;
#line 1153 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_val_if_fail (album_name != NULL, NULL);
#line 1153 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self = (PublishingRajcePublishingParameters*) g_type_create_instance (object_type);
#line 1155 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp0_ = g_strdup (album_name);
#line 1155 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_free0 (self->album_name);
#line 1155 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self->album_name = _tmp0_;
#line 1156 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp1_ = __bool_dup0 (&album_hidden);
#line 1156 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_free0 (self->album_hidden);
#line 1156 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self->album_hidden = _tmp1_;
#line 1157 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp2_ = 0;
#line 1157 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp3_ = __int_dup0 (&_tmp2_);
#line 1157 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_free0 (self->album_id);
#line 1157 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self->album_id = _tmp3_;
#line 1153 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	return self;
#line 8559 "RajcePublishing.c"
}


PublishingRajcePublishingParameters*
publishing_rajce_publishing_parameters_new_to_new_album (const gchar* album_name,
                                                         gboolean album_hidden)
{
#line 1153 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	return publishing_rajce_publishing_parameters_construct_to_new_album (PUBLISHING_RAJCE_TYPE_PUBLISHING_PARAMETERS, album_name, album_hidden);
#line 8569 "RajcePublishing.c"
}


PublishingRajcePublishingParameters*
publishing_rajce_publishing_parameters_construct_to_existing_album (GType object_type,
                                                                    const gchar* album_name,
                                                                    gint album_id)
{
	PublishingRajcePublishingParameters* self = NULL;
	gchar* _tmp0_;
	gint* _tmp1_;
#line 1159 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_val_if_fail (album_name != NULL, NULL);
#line 1159 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self = (PublishingRajcePublishingParameters*) g_type_create_instance (object_type);
#line 1161 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp0_ = g_strdup (album_name);
#line 1161 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_free0 (self->album_name);
#line 1161 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self->album_name = _tmp0_;
#line 1162 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_free0 (self->album_hidden);
#line 1162 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self->album_hidden = NULL;
#line 1163 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp1_ = __int_dup0 (&album_id);
#line 1163 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_free0 (self->album_id);
#line 1163 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self->album_id = _tmp1_;
#line 1159 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	return self;
#line 8603 "RajcePublishing.c"
}


PublishingRajcePublishingParameters*
publishing_rajce_publishing_parameters_new_to_existing_album (const gchar* album_name,
                                                              gint album_id)
{
#line 1159 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	return publishing_rajce_publishing_parameters_construct_to_existing_album (PUBLISHING_RAJCE_TYPE_PUBLISHING_PARAMETERS, album_name, album_id);
#line 8613 "RajcePublishing.c"
}


static void
publishing_rajce_value_publishing_parameters_init (GValue* value)
{
#line 1144 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	value->data[0].v_pointer = NULL;
#line 8622 "RajcePublishing.c"
}


static void
publishing_rajce_value_publishing_parameters_free_value (GValue* value)
{
#line 1144 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	if (value->data[0].v_pointer) {
#line 1144 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		publishing_rajce_publishing_parameters_unref (value->data[0].v_pointer);
#line 8633 "RajcePublishing.c"
	}
}


static void
publishing_rajce_value_publishing_parameters_copy_value (const GValue* src_value,
                                                         GValue* dest_value)
{
#line 1144 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	if (src_value->data[0].v_pointer) {
#line 1144 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		dest_value->data[0].v_pointer = publishing_rajce_publishing_parameters_ref (src_value->data[0].v_pointer);
#line 8646 "RajcePublishing.c"
	} else {
#line 1144 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		dest_value->data[0].v_pointer = NULL;
#line 8650 "RajcePublishing.c"
	}
}


static gpointer
publishing_rajce_value_publishing_parameters_peek_pointer (const GValue* value)
{
#line 1144 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	return value->data[0].v_pointer;
#line 8660 "RajcePublishing.c"
}


static gchar*
publishing_rajce_value_publishing_parameters_collect_value (GValue* value,
                                                            guint n_collect_values,
                                                            GTypeCValue* collect_values,
                                                            guint collect_flags)
{
#line 1144 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	if (collect_values[0].v_pointer) {
#line 8672 "RajcePublishing.c"
		PublishingRajcePublishingParameters * object;
		object = collect_values[0].v_pointer;
#line 1144 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		if (object->parent_instance.g_class == NULL) {
#line 1144 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 8679 "RajcePublishing.c"
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
#line 1144 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 8683 "RajcePublishing.c"
		}
#line 1144 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		value->data[0].v_pointer = publishing_rajce_publishing_parameters_ref (object);
#line 8687 "RajcePublishing.c"
	} else {
#line 1144 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		value->data[0].v_pointer = NULL;
#line 8691 "RajcePublishing.c"
	}
#line 1144 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	return NULL;
#line 8695 "RajcePublishing.c"
}


static gchar*
publishing_rajce_value_publishing_parameters_lcopy_value (const GValue* value,
                                                          guint n_collect_values,
                                                          GTypeCValue* collect_values,
                                                          guint collect_flags)
{
	PublishingRajcePublishingParameters ** object_p;
	object_p = collect_values[0].v_pointer;
#line 1144 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	if (!object_p) {
#line 1144 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
#line 8711 "RajcePublishing.c"
	}
#line 1144 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	if (!value->data[0].v_pointer) {
#line 1144 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		*object_p = NULL;
#line 8717 "RajcePublishing.c"
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
#line 1144 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		*object_p = value->data[0].v_pointer;
#line 8721 "RajcePublishing.c"
	} else {
#line 1144 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		*object_p = publishing_rajce_publishing_parameters_ref (value->data[0].v_pointer);
#line 8725 "RajcePublishing.c"
	}
#line 1144 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	return NULL;
#line 8729 "RajcePublishing.c"
}


GParamSpec*
publishing_rajce_param_spec_publishing_parameters (const gchar* name,
                                                   const gchar* nick,
                                                   const gchar* blurb,
                                                   GType object_type,
                                                   GParamFlags flags)
{
	PublishingRajceParamSpecPublishingParameters* spec;
#line 1144 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_val_if_fail (g_type_is_a (object_type, PUBLISHING_RAJCE_TYPE_PUBLISHING_PARAMETERS), NULL);
#line 1144 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
#line 1144 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	G_PARAM_SPEC (spec)->value_type = object_type;
#line 1144 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	return G_PARAM_SPEC (spec);
#line 8749 "RajcePublishing.c"
}


gpointer
publishing_rajce_value_get_publishing_parameters (const GValue* value)
{
#line 1144 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_RAJCE_TYPE_PUBLISHING_PARAMETERS), NULL);
#line 1144 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	return value->data[0].v_pointer;
#line 8760 "RajcePublishing.c"
}


void
publishing_rajce_value_set_publishing_parameters (GValue* value,
                                                  gpointer v_object)
{
	PublishingRajcePublishingParameters * old;
#line 1144 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_RAJCE_TYPE_PUBLISHING_PARAMETERS));
#line 1144 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	old = value->data[0].v_pointer;
#line 1144 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	if (v_object) {
#line 1144 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, PUBLISHING_RAJCE_TYPE_PUBLISHING_PARAMETERS));
#line 1144 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 1144 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		value->data[0].v_pointer = v_object;
#line 1144 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		publishing_rajce_publishing_parameters_ref (value->data[0].v_pointer);
#line 8783 "RajcePublishing.c"
	} else {
#line 1144 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		value->data[0].v_pointer = NULL;
#line 8787 "RajcePublishing.c"
	}
#line 1144 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	if (old) {
#line 1144 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		publishing_rajce_publishing_parameters_unref (old);
#line 8793 "RajcePublishing.c"
	}
}


void
publishing_rajce_value_take_publishing_parameters (GValue* value,
                                                   gpointer v_object)
{
	PublishingRajcePublishingParameters * old;
#line 1144 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_RAJCE_TYPE_PUBLISHING_PARAMETERS));
#line 1144 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	old = value->data[0].v_pointer;
#line 1144 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	if (v_object) {
#line 1144 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, PUBLISHING_RAJCE_TYPE_PUBLISHING_PARAMETERS));
#line 1144 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 1144 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		value->data[0].v_pointer = v_object;
#line 8815 "RajcePublishing.c"
	} else {
#line 1144 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		value->data[0].v_pointer = NULL;
#line 8819 "RajcePublishing.c"
	}
#line 1144 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	if (old) {
#line 1144 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		publishing_rajce_publishing_parameters_unref (old);
#line 8825 "RajcePublishing.c"
	}
}


static void
publishing_rajce_publishing_parameters_class_init (PublishingRajcePublishingParametersClass * klass)
{
#line 1144 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rajce_publishing_parameters_parent_class = g_type_class_peek_parent (klass);
#line 1144 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	((PublishingRajcePublishingParametersClass *) klass)->finalize = publishing_rajce_publishing_parameters_finalize;
#line 8837 "RajcePublishing.c"
}


static void
publishing_rajce_publishing_parameters_instance_init (PublishingRajcePublishingParameters * self)
{
#line 1144 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self->ref_count = 1;
#line 8846 "RajcePublishing.c"
}


static void
publishing_rajce_publishing_parameters_finalize (PublishingRajcePublishingParameters * obj)
{
	PublishingRajcePublishingParameters * self;
#line 1144 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_RAJCE_TYPE_PUBLISHING_PARAMETERS, PublishingRajcePublishingParameters);
#line 1144 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_signal_handlers_destroy (self);
#line 1146 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_free0 (self->album_name);
#line 1147 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_free0 (self->album_hidden);
#line 1148 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_free0 (self->album_id);
#line 8864 "RajcePublishing.c"
}


GType
publishing_rajce_publishing_parameters_get_type (void)
{
	static volatile gsize publishing_rajce_publishing_parameters_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_rajce_publishing_parameters_type_id__volatile)) {
		static const GTypeValueTable g_define_type_value_table = { publishing_rajce_value_publishing_parameters_init, publishing_rajce_value_publishing_parameters_free_value, publishing_rajce_value_publishing_parameters_copy_value, publishing_rajce_value_publishing_parameters_peek_pointer, "p", publishing_rajce_value_publishing_parameters_collect_value, "p", publishing_rajce_value_publishing_parameters_lcopy_value };
		static const GTypeInfo g_define_type_info = { sizeof (PublishingRajcePublishingParametersClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_rajce_publishing_parameters_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingRajcePublishingParameters), 0, (GInstanceInitFunc) publishing_rajce_publishing_parameters_instance_init, &g_define_type_value_table };
		static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
		GType publishing_rajce_publishing_parameters_type_id;
		publishing_rajce_publishing_parameters_type_id = g_type_register_fundamental (g_type_fundamental_next (), "PublishingRajcePublishingParameters", &g_define_type_info, &g_define_type_fundamental_info, 0);
		g_once_init_leave (&publishing_rajce_publishing_parameters_type_id__volatile, publishing_rajce_publishing_parameters_type_id);
	}
	return publishing_rajce_publishing_parameters_type_id__volatile;
}


gpointer
publishing_rajce_publishing_parameters_ref (gpointer instance)
{
	PublishingRajcePublishingParameters * self;
	self = instance;
#line 1144 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_atomic_int_inc (&self->ref_count);
#line 1144 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	return instance;
#line 8893 "RajcePublishing.c"
}


void
publishing_rajce_publishing_parameters_unref (gpointer instance)
{
	PublishingRajcePublishingParameters * self;
	self = instance;
#line 1144 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
#line 1144 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		PUBLISHING_RAJCE_PUBLISHING_PARAMETERS_GET_CLASS (self)->finalize (self);
#line 1144 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		g_type_free_instance ((GTypeInstance *) self);
#line 8908 "RajcePublishing.c"
	}
}


PublishingRajceSession*
publishing_rajce_session_construct (GType object_type)
{
	PublishingRajceSession* self = NULL;
#line 1182 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self = (PublishingRajceSession*) publishing_rest_support_session_construct (object_type, "");
#line 1180 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	return self;
#line 8921 "RajcePublishing.c"
}


PublishingRajceSession*
publishing_rajce_session_new (void)
{
#line 1180 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	return publishing_rajce_session_construct (PUBLISHING_RAJCE_TYPE_SESSION);
#line 8930 "RajcePublishing.c"
}


static gboolean
publishing_rajce_session_real_is_authenticated (PublishingRESTSupportSession* base)
{
	PublishingRajceSession * self;
	gboolean result = FALSE;
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_ = FALSE;
	gint* _tmp2_;
#line 1185 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_RAJCE_TYPE_SESSION, PublishingRajceSession);
#line 1187 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp2_ = self->priv->userid;
#line 1187 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	if (_tmp2_ != NULL) {
#line 8948 "RajcePublishing.c"
		const gchar* _tmp3_;
#line 1187 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp3_ = self->priv->usertoken;
#line 1187 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp1_ = _tmp3_ != NULL;
#line 8954 "RajcePublishing.c"
	} else {
#line 1187 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp1_ = FALSE;
#line 8958 "RajcePublishing.c"
	}
#line 1187 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	if (_tmp1_) {
#line 8962 "RajcePublishing.c"
		const gchar* _tmp4_;
#line 1187 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp4_ = self->priv->username;
#line 1187 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp0_ = _tmp4_ != NULL;
#line 8968 "RajcePublishing.c"
	} else {
#line 1187 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp0_ = FALSE;
#line 8972 "RajcePublishing.c"
	}
#line 1187 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	result = _tmp0_;
#line 1187 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	return result;
#line 8978 "RajcePublishing.c"
}


void
publishing_rajce_session_authenticate (PublishingRajceSession* self,
                                       const gchar* token,
                                       const gchar* name,
                                       gint id,
                                       gint maxsize,
                                       gint quality)
{
	gchar* _tmp0_;
	gchar* _tmp1_;
	gint* _tmp2_;
	gint* _tmp3_;
	gint* _tmp4_;
#line 1190 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_if_fail (PUBLISHING_RAJCE_IS_SESSION (self));
#line 1190 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_if_fail (token != NULL);
#line 1190 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_if_fail (name != NULL);
#line 1192 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp0_ = g_strdup (token);
#line 1192 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_free0 (self->priv->usertoken);
#line 1192 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self->priv->usertoken = _tmp0_;
#line 1193 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp1_ = g_strdup (name);
#line 1193 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_free0 (self->priv->username);
#line 1193 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self->priv->username = _tmp1_;
#line 1194 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp2_ = __int_dup0 (&id);
#line 1194 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_free0 (self->priv->userid);
#line 1194 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self->priv->userid = _tmp2_;
#line 1195 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp3_ = __int_dup0 (&maxsize);
#line 1195 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_free0 (self->priv->maxsize);
#line 1195 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self->priv->maxsize = _tmp3_;
#line 1196 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp4_ = __int_dup0 (&quality);
#line 1196 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_free0 (self->priv->quality);
#line 1196 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self->priv->quality = _tmp4_;
#line 9031 "RajcePublishing.c"
}


void
publishing_rajce_session_deauthenticate (PublishingRajceSession* self)
{
#line 1199 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_if_fail (PUBLISHING_RAJCE_IS_SESSION (self));
#line 1201 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_free0 (self->priv->usertoken);
#line 1201 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self->priv->usertoken = NULL;
#line 1202 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_free0 (self->priv->albumtoken);
#line 1202 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self->priv->albumtoken = NULL;
#line 1203 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_free0 (self->priv->albumticket);
#line 1203 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self->priv->albumticket = NULL;
#line 1204 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_free0 (self->priv->username);
#line 1204 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self->priv->username = NULL;
#line 1205 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_free0 (self->priv->userid);
#line 1205 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self->priv->userid = NULL;
#line 1206 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_free0 (self->priv->maxsize);
#line 1206 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self->priv->maxsize = NULL;
#line 1207 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_free0 (self->priv->quality);
#line 1207 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self->priv->quality = NULL;
#line 9068 "RajcePublishing.c"
}


void
publishing_rajce_session_set_usertoken (PublishingRajceSession* self,
                                        const gchar* usertoken)
{
	gchar* _tmp0_;
#line 1210 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_if_fail (PUBLISHING_RAJCE_IS_SESSION (self));
#line 1210 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp0_ = g_strdup (usertoken);
#line 1210 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_free0 (self->priv->usertoken);
#line 1210 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self->priv->usertoken = _tmp0_;
#line 9085 "RajcePublishing.c"
}


void
publishing_rajce_session_set_albumtoken (PublishingRajceSession* self,
                                         const gchar* albumtoken)
{
	gchar* _tmp0_;
#line 1211 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_if_fail (PUBLISHING_RAJCE_IS_SESSION (self));
#line 1211 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp0_ = g_strdup (albumtoken);
#line 1211 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_free0 (self->priv->albumtoken);
#line 1211 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self->priv->albumtoken = _tmp0_;
#line 9102 "RajcePublishing.c"
}


void
publishing_rajce_session_set_albumticket (PublishingRajceSession* self,
                                          const gchar* albumticket)
{
	gchar* _tmp0_;
#line 1212 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_if_fail (PUBLISHING_RAJCE_IS_SESSION (self));
#line 1212 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp0_ = g_strdup (albumticket);
#line 1212 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_free0 (self->priv->albumticket);
#line 1212 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self->priv->albumticket = _tmp0_;
#line 9119 "RajcePublishing.c"
}


gchar*
publishing_rajce_session_get_usertoken (PublishingRajceSession* self)
{
	gchar* result = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 1214 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_val_if_fail (PUBLISHING_RAJCE_IS_SESSION (self), NULL);
#line 1214 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp0_ = self->priv->usertoken;
#line 1214 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 1214 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	result = _tmp1_;
#line 1214 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	return result;
#line 9139 "RajcePublishing.c"
}


gchar*
publishing_rajce_session_get_albumtoken (PublishingRajceSession* self)
{
	gchar* result = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 1215 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_val_if_fail (PUBLISHING_RAJCE_IS_SESSION (self), NULL);
#line 1215 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp0_ = self->priv->albumtoken;
#line 1215 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 1215 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	result = _tmp1_;
#line 1215 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	return result;
#line 9159 "RajcePublishing.c"
}


gchar*
publishing_rajce_session_get_albumticket (PublishingRajceSession* self)
{
	gchar* result = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 1216 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_val_if_fail (PUBLISHING_RAJCE_IS_SESSION (self), NULL);
#line 1216 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp0_ = self->priv->albumticket;
#line 1216 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 1216 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	result = _tmp1_;
#line 1216 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	return result;
#line 9179 "RajcePublishing.c"
}


gchar*
publishing_rajce_session_get_username (PublishingRajceSession* self)
{
	gchar* result = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 1217 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_val_if_fail (PUBLISHING_RAJCE_IS_SESSION (self), NULL);
#line 1217 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp0_ = self->priv->username;
#line 1217 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 1217 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	result = _tmp1_;
#line 1217 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	return result;
#line 9199 "RajcePublishing.c"
}


gint
publishing_rajce_session_get_maxsize (PublishingRajceSession* self)
{
	gint result = 0;
	gint* _tmp0_;
#line 1219 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_val_if_fail (PUBLISHING_RAJCE_IS_SESSION (self), 0);
#line 1219 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp0_ = self->priv->maxsize;
#line 1219 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	result = *_tmp0_;
#line 1219 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	return result;
#line 9216 "RajcePublishing.c"
}


static void
publishing_rajce_session_class_init (PublishingRajceSessionClass * klass)
{
#line 1171 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rajce_session_parent_class = g_type_class_peek_parent (klass);
#line 1171 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	((PublishingRESTSupportSessionClass *) klass)->finalize = publishing_rajce_session_finalize;
#line 1171 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_type_class_add_private (klass, sizeof (PublishingRajceSessionPrivate));
#line 1171 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	((PublishingRESTSupportSessionClass *) klass)->is_authenticated = (gboolean (*) (PublishingRESTSupportSession *)) publishing_rajce_session_real_is_authenticated;
#line 9231 "RajcePublishing.c"
}


static void
publishing_rajce_session_instance_init (PublishingRajceSession * self)
{
#line 1171 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self->priv = PUBLISHING_RAJCE_SESSION_GET_PRIVATE (self);
#line 1172 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self->priv->usertoken = NULL;
#line 1173 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self->priv->albumtoken = NULL;
#line 1174 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self->priv->albumticket = NULL;
#line 1175 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self->priv->username = NULL;
#line 1176 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self->priv->userid = NULL;
#line 1177 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self->priv->maxsize = NULL;
#line 1178 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self->priv->quality = NULL;
#line 9254 "RajcePublishing.c"
}


static void
publishing_rajce_session_finalize (PublishingRESTSupportSession * obj)
{
	PublishingRajceSession * self;
#line 1171 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_RAJCE_TYPE_SESSION, PublishingRajceSession);
#line 1172 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_free0 (self->priv->usertoken);
#line 1173 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_free0 (self->priv->albumtoken);
#line 1174 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_free0 (self->priv->albumticket);
#line 1175 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_free0 (self->priv->username);
#line 1176 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_free0 (self->priv->userid);
#line 1177 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_free0 (self->priv->maxsize);
#line 1178 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_free0 (self->priv->quality);
#line 1171 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	PUBLISHING_REST_SUPPORT_SESSION_CLASS (publishing_rajce_session_parent_class)->finalize (obj);
#line 9280 "RajcePublishing.c"
}


/**
 * Session class that keeps track of the credentials
 */
GType
publishing_rajce_session_get_type (void)
{
	static volatile gsize publishing_rajce_session_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_rajce_session_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingRajceSessionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_rajce_session_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingRajceSession), 0, (GInstanceInitFunc) publishing_rajce_session_instance_init, NULL };
		GType publishing_rajce_session_type_id;
		publishing_rajce_session_type_id = g_type_register_static (PUBLISHING_REST_SUPPORT_TYPE_SESSION, "PublishingRajceSession", &g_define_type_info, 0);
		g_once_init_leave (&publishing_rajce_session_type_id__volatile, publishing_rajce_session_type_id);
	}
	return publishing_rajce_session_type_id__volatile;
}


static gpointer
_publishing_rajce_arg_item_ref0 (gpointer self)
{
#line 1248 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	return self ? publishing_rajce_arg_item_ref (self) : NULL;
#line 9306 "RajcePublishing.c"
}


PublishingRajceArgItem*
publishing_rajce_arg_item_construct (GType object_type,
                                     const gchar* k,
                                     const gchar* v)
{
	PublishingRajceArgItem* self = NULL;
	gchar* _tmp0_;
	gchar* _tmp1_;
	PublishingRajceArgItem** _tmp2_;
#line 1229 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self = (PublishingRajceArgItem*) g_type_create_instance (object_type);
#line 1231 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp0_ = g_strdup (k);
#line 1231 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_free0 (self->key);
#line 1231 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self->key = _tmp0_;
#line 1232 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp1_ = g_strdup (v);
#line 1232 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_free0 (self->val);
#line 1232 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self->val = _tmp1_;
#line 1233 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp2_ = g_new0 (PublishingRajceArgItem*, 0 + 1);
#line 1233 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self->children = (_vala_array_free (self->children, self->children_length1, (GDestroyNotify) publishing_rajce_arg_item_unref), NULL);
#line 1233 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self->children = _tmp2_;
#line 1233 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self->children_length1 = 0;
#line 1233 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self->_children_size_ = self->children_length1;
#line 1229 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	return self;
#line 9345 "RajcePublishing.c"
}


PublishingRajceArgItem*
publishing_rajce_arg_item_new (const gchar* k,
                               const gchar* v)
{
#line 1229 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	return publishing_rajce_arg_item_construct (PUBLISHING_RAJCE_TYPE_ARG_ITEM, k, v);
#line 9355 "RajcePublishing.c"
}


static void
_vala_array_add6 (PublishingRajceArgItem** * array,
                  int* length,
                  int* size,
                  PublishingRajceArgItem* value)
{
#line 1237 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	if ((*length) == (*size)) {
#line 1237 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 1237 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		*array = g_renew (PublishingRajceArgItem*, *array, (*size) + 1);
#line 9371 "RajcePublishing.c"
	}
#line 1237 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	(*array)[(*length)++] = value;
#line 1237 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	(*array)[*length] = NULL;
#line 9377 "RajcePublishing.c"
}


void
publishing_rajce_arg_item_AddChild (PublishingRajceArgItem* self,
                                    PublishingRajceArgItem* child)
{
	PublishingRajceArgItem** _tmp0_;
	gint _tmp0__length1;
	PublishingRajceArgItem* _tmp1_;
#line 1235 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_if_fail (PUBLISHING_RAJCE_IS_ARG_ITEM (self));
#line 1235 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_if_fail (PUBLISHING_RAJCE_IS_ARG_ITEM (child));
#line 1237 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp0_ = self->children;
#line 1237 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp0__length1 = self->children_length1;
#line 1237 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp1_ = _publishing_rajce_arg_item_ref0 (child);
#line 1237 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_vala_array_add6 (&self->children, &self->children_length1, &self->_children_size_, _tmp1_);
#line 9400 "RajcePublishing.c"
}


void
publishing_rajce_arg_item_AddChildren (PublishingRajceArgItem* self,
                                       PublishingRajceArgItem** newchildren,
                                       int newchildren_length1)
{
#line 1239 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_if_fail (PUBLISHING_RAJCE_IS_ARG_ITEM (self));
#line 9411 "RajcePublishing.c"
	{
		PublishingRajceArgItem** child_collection = NULL;
		gint child_collection_length1 = 0;
		gint _child_collection_size_ = 0;
		gint child_it = 0;
#line 1241 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		child_collection = newchildren;
#line 1241 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		child_collection_length1 = newchildren_length1;
#line 1241 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		for (child_it = 0; child_it < newchildren_length1; child_it = child_it + 1) {
#line 9423 "RajcePublishing.c"
			PublishingRajceArgItem* _tmp0_;
			PublishingRajceArgItem* child = NULL;
#line 1241 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			_tmp0_ = _publishing_rajce_arg_item_ref0 (child_collection[child_it]);
#line 1241 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			child = _tmp0_;
#line 9430 "RajcePublishing.c"
			{
				PublishingRajceArgItem* _tmp1_;
#line 1243 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
				_tmp1_ = child;
#line 1243 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
				publishing_rajce_arg_item_AddChild (self, _tmp1_);
#line 1241 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
				_publishing_rajce_arg_item_unref0 (child);
#line 9439 "RajcePublishing.c"
			}
		}
	}
}


static void
publishing_rajce_value_arg_item_init (GValue* value)
{
#line 1223 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	value->data[0].v_pointer = NULL;
#line 9451 "RajcePublishing.c"
}


static void
publishing_rajce_value_arg_item_free_value (GValue* value)
{
#line 1223 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	if (value->data[0].v_pointer) {
#line 1223 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		publishing_rajce_arg_item_unref (value->data[0].v_pointer);
#line 9462 "RajcePublishing.c"
	}
}


static void
publishing_rajce_value_arg_item_copy_value (const GValue* src_value,
                                            GValue* dest_value)
{
#line 1223 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	if (src_value->data[0].v_pointer) {
#line 1223 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		dest_value->data[0].v_pointer = publishing_rajce_arg_item_ref (src_value->data[0].v_pointer);
#line 9475 "RajcePublishing.c"
	} else {
#line 1223 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		dest_value->data[0].v_pointer = NULL;
#line 9479 "RajcePublishing.c"
	}
}


static gpointer
publishing_rajce_value_arg_item_peek_pointer (const GValue* value)
{
#line 1223 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	return value->data[0].v_pointer;
#line 9489 "RajcePublishing.c"
}


static gchar*
publishing_rajce_value_arg_item_collect_value (GValue* value,
                                               guint n_collect_values,
                                               GTypeCValue* collect_values,
                                               guint collect_flags)
{
#line 1223 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	if (collect_values[0].v_pointer) {
#line 9501 "RajcePublishing.c"
		PublishingRajceArgItem * object;
		object = collect_values[0].v_pointer;
#line 1223 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		if (object->parent_instance.g_class == NULL) {
#line 1223 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 9508 "RajcePublishing.c"
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
#line 1223 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 9512 "RajcePublishing.c"
		}
#line 1223 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		value->data[0].v_pointer = publishing_rajce_arg_item_ref (object);
#line 9516 "RajcePublishing.c"
	} else {
#line 1223 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		value->data[0].v_pointer = NULL;
#line 9520 "RajcePublishing.c"
	}
#line 1223 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	return NULL;
#line 9524 "RajcePublishing.c"
}


static gchar*
publishing_rajce_value_arg_item_lcopy_value (const GValue* value,
                                             guint n_collect_values,
                                             GTypeCValue* collect_values,
                                             guint collect_flags)
{
	PublishingRajceArgItem ** object_p;
	object_p = collect_values[0].v_pointer;
#line 1223 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	if (!object_p) {
#line 1223 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
#line 9540 "RajcePublishing.c"
	}
#line 1223 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	if (!value->data[0].v_pointer) {
#line 1223 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		*object_p = NULL;
#line 9546 "RajcePublishing.c"
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
#line 1223 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		*object_p = value->data[0].v_pointer;
#line 9550 "RajcePublishing.c"
	} else {
#line 1223 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		*object_p = publishing_rajce_arg_item_ref (value->data[0].v_pointer);
#line 9554 "RajcePublishing.c"
	}
#line 1223 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	return NULL;
#line 9558 "RajcePublishing.c"
}


GParamSpec*
publishing_rajce_param_spec_arg_item (const gchar* name,
                                      const gchar* nick,
                                      const gchar* blurb,
                                      GType object_type,
                                      GParamFlags flags)
{
	PublishingRajceParamSpecArgItem* spec;
#line 1223 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_val_if_fail (g_type_is_a (object_type, PUBLISHING_RAJCE_TYPE_ARG_ITEM), NULL);
#line 1223 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
#line 1223 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	G_PARAM_SPEC (spec)->value_type = object_type;
#line 1223 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	return G_PARAM_SPEC (spec);
#line 9578 "RajcePublishing.c"
}


gpointer
publishing_rajce_value_get_arg_item (const GValue* value)
{
#line 1223 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_RAJCE_TYPE_ARG_ITEM), NULL);
#line 1223 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	return value->data[0].v_pointer;
#line 9589 "RajcePublishing.c"
}


void
publishing_rajce_value_set_arg_item (GValue* value,
                                     gpointer v_object)
{
	PublishingRajceArgItem * old;
#line 1223 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_RAJCE_TYPE_ARG_ITEM));
#line 1223 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	old = value->data[0].v_pointer;
#line 1223 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	if (v_object) {
#line 1223 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, PUBLISHING_RAJCE_TYPE_ARG_ITEM));
#line 1223 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 1223 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		value->data[0].v_pointer = v_object;
#line 1223 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		publishing_rajce_arg_item_ref (value->data[0].v_pointer);
#line 9612 "RajcePublishing.c"
	} else {
#line 1223 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		value->data[0].v_pointer = NULL;
#line 9616 "RajcePublishing.c"
	}
#line 1223 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	if (old) {
#line 1223 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		publishing_rajce_arg_item_unref (old);
#line 9622 "RajcePublishing.c"
	}
}


void
publishing_rajce_value_take_arg_item (GValue* value,
                                      gpointer v_object)
{
	PublishingRajceArgItem * old;
#line 1223 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_RAJCE_TYPE_ARG_ITEM));
#line 1223 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	old = value->data[0].v_pointer;
#line 1223 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	if (v_object) {
#line 1223 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, PUBLISHING_RAJCE_TYPE_ARG_ITEM));
#line 1223 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 1223 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		value->data[0].v_pointer = v_object;
#line 9644 "RajcePublishing.c"
	} else {
#line 1223 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		value->data[0].v_pointer = NULL;
#line 9648 "RajcePublishing.c"
	}
#line 1223 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	if (old) {
#line 1223 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		publishing_rajce_arg_item_unref (old);
#line 9654 "RajcePublishing.c"
	}
}


static void
publishing_rajce_arg_item_class_init (PublishingRajceArgItemClass * klass)
{
#line 1223 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rajce_arg_item_parent_class = g_type_class_peek_parent (klass);
#line 1223 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	((PublishingRajceArgItemClass *) klass)->finalize = publishing_rajce_arg_item_finalize;
#line 9666 "RajcePublishing.c"
}


static void
publishing_rajce_arg_item_instance_init (PublishingRajceArgItem * self)
{
#line 1223 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self->ref_count = 1;
#line 9675 "RajcePublishing.c"
}


static void
publishing_rajce_arg_item_finalize (PublishingRajceArgItem * obj)
{
	PublishingRajceArgItem * self;
	PublishingRajceArgItem** _tmp0_;
	gint _tmp0__length1;
#line 1223 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_RAJCE_TYPE_ARG_ITEM, PublishingRajceArgItem);
#line 1223 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_signal_handlers_destroy (self);
#line 1248 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp0_ = self->children;
#line 1248 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp0__length1 = self->children_length1;
#line 9693 "RajcePublishing.c"
	{
		PublishingRajceArgItem** child_collection = NULL;
		gint child_collection_length1 = 0;
		gint _child_collection_size_ = 0;
		gint child_it = 0;
#line 1248 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		child_collection = _tmp0_;
#line 1248 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		child_collection_length1 = _tmp0__length1;
#line 1248 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		for (child_it = 0; child_it < _tmp0__length1; child_it = child_it + 1) {
#line 9705 "RajcePublishing.c"
			PublishingRajceArgItem* _tmp1_;
			PublishingRajceArgItem* child = NULL;
#line 1248 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			_tmp1_ = _publishing_rajce_arg_item_ref0 (child_collection[child_it]);
#line 1248 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			child = _tmp1_;
#line 9712 "RajcePublishing.c"
			{
#line 1250 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
				_publishing_rajce_arg_item_unref0 (child);
#line 1250 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
				child = NULL;
#line 1248 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
				_publishing_rajce_arg_item_unref0 (child);
#line 9720 "RajcePublishing.c"
			}
		}
	}
#line 1225 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_free0 (self->key);
#line 1226 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_free0 (self->val);
#line 1227 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self->children = (_vala_array_free (self->children, self->children_length1, (GDestroyNotify) publishing_rajce_arg_item_unref), NULL);
#line 9730 "RajcePublishing.c"
}


GType
publishing_rajce_arg_item_get_type (void)
{
	static volatile gsize publishing_rajce_arg_item_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_rajce_arg_item_type_id__volatile)) {
		static const GTypeValueTable g_define_type_value_table = { publishing_rajce_value_arg_item_init, publishing_rajce_value_arg_item_free_value, publishing_rajce_value_arg_item_copy_value, publishing_rajce_value_arg_item_peek_pointer, "p", publishing_rajce_value_arg_item_collect_value, "p", publishing_rajce_value_arg_item_lcopy_value };
		static const GTypeInfo g_define_type_info = { sizeof (PublishingRajceArgItemClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_rajce_arg_item_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingRajceArgItem), 0, (GInstanceInitFunc) publishing_rajce_arg_item_instance_init, &g_define_type_value_table };
		static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
		GType publishing_rajce_arg_item_type_id;
		publishing_rajce_arg_item_type_id = g_type_register_fundamental (g_type_fundamental_next (), "PublishingRajceArgItem", &g_define_type_info, &g_define_type_fundamental_info, 0);
		g_once_init_leave (&publishing_rajce_arg_item_type_id__volatile, publishing_rajce_arg_item_type_id);
	}
	return publishing_rajce_arg_item_type_id__volatile;
}


gpointer
publishing_rajce_arg_item_ref (gpointer instance)
{
	PublishingRajceArgItem * self;
	self = instance;
#line 1223 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_atomic_int_inc (&self->ref_count);
#line 1223 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	return instance;
#line 9759 "RajcePublishing.c"
}


void
publishing_rajce_arg_item_unref (gpointer instance)
{
	PublishingRajceArgItem * self;
	self = instance;
#line 1223 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
#line 1223 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		PUBLISHING_RAJCE_ARG_ITEM_GET_CLASS (self)->finalize (self);
#line 1223 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		g_type_free_instance ((GTypeInstance *) self);
#line 9774 "RajcePublishing.c"
	}
}


PublishingRajceLiveApiRequest*
publishing_rajce_live_api_request_construct (GType object_type,
                                             const gchar* cmd)
{
	PublishingRajceLiveApiRequest* self = NULL;
	PublishingRajceArgItem** _tmp0_;
	gchar* _tmp1_;
#line 1262 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_val_if_fail (cmd != NULL, NULL);
#line 1262 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self = (PublishingRajceLiveApiRequest*) g_type_create_instance (object_type);
#line 1264 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp0_ = g_new0 (PublishingRajceArgItem*, 0 + 1);
#line 1264 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self->priv->_params = (_vala_array_free (self->priv->_params, self->priv->_params_length1, (GDestroyNotify) publishing_rajce_arg_item_unref), NULL);
#line 1264 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self->priv->_params = _tmp0_;
#line 1264 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self->priv->_params_length1 = 0;
#line 1264 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self->priv->__params_size_ = self->priv->_params_length1;
#line 1265 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp1_ = g_strdup (cmd);
#line 1265 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_free0 (self->priv->_cmd);
#line 1265 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self->priv->_cmd = _tmp1_;
#line 1262 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	return self;
#line 9808 "RajcePublishing.c"
}


PublishingRajceLiveApiRequest*
publishing_rajce_live_api_request_new (const gchar* cmd)
{
#line 1262 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	return publishing_rajce_live_api_request_construct (PUBLISHING_RAJCE_TYPE_LIVE_API_REQUEST, cmd);
#line 9817 "RajcePublishing.c"
}


static void
_vala_array_add7 (PublishingRajceArgItem** * array,
                  int* length,
                  int* size,
                  PublishingRajceArgItem* value)
{
#line 1272 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	if ((*length) == (*size)) {
#line 1272 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 1272 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		*array = g_renew (PublishingRajceArgItem*, *array, (*size) + 1);
#line 9833 "RajcePublishing.c"
	}
#line 1272 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	(*array)[(*length)++] = value;
#line 1272 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	(*array)[*length] = NULL;
#line 9839 "RajcePublishing.c"
}


void
publishing_rajce_live_api_request_AddParam (PublishingRajceLiveApiRequest* self,
                                            const gchar* name,
                                            const gchar* val)
{
	PublishingRajceArgItem** _tmp0_;
	gint _tmp0__length1;
	PublishingRajceArgItem* _tmp1_;
#line 1270 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_if_fail (PUBLISHING_RAJCE_IS_LIVE_API_REQUEST (self));
#line 1270 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_if_fail (name != NULL);
#line 1270 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_if_fail (val != NULL);
#line 1272 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp0_ = self->priv->_params;
#line 1272 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp0__length1 = self->priv->_params_length1;
#line 1272 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp1_ = publishing_rajce_arg_item_new (name, val);
#line 1272 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_vala_array_add7 (&self->priv->_params, &self->priv->_params_length1, &self->priv->__params_size_, _tmp1_);
#line 9865 "RajcePublishing.c"
}


void
publishing_rajce_live_api_request_AddParamBool (PublishingRajceLiveApiRequest* self,
                                                const gchar* name,
                                                gboolean val)
{
	const gchar* _tmp0_ = NULL;
#line 1277 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_if_fail (PUBLISHING_RAJCE_IS_LIVE_API_REQUEST (self));
#line 1277 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_if_fail (name != NULL);
#line 1279 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	if (val) {
#line 1279 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp0_ = "1";
#line 9883 "RajcePublishing.c"
	} else {
#line 1279 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp0_ = "0";
#line 9887 "RajcePublishing.c"
	}
#line 1279 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rajce_live_api_request_AddParam (self, name, _tmp0_);
#line 9891 "RajcePublishing.c"
}


void
publishing_rajce_live_api_request_AddParamInt (PublishingRajceLiveApiRequest* self,
                                               const gchar* name,
                                               gint val)
{
	gchar* _tmp0_;
	gchar* _tmp1_;
#line 1284 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_if_fail (PUBLISHING_RAJCE_IS_LIVE_API_REQUEST (self));
#line 1284 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_if_fail (name != NULL);
#line 1286 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp0_ = g_strdup_printf ("%i", val);
#line 1286 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp1_ = _tmp0_;
#line 1286 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rajce_live_api_request_AddParam (self, name, _tmp1_);
#line 1286 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_free0 (_tmp1_);
#line 9914 "RajcePublishing.c"
}


static void
_vala_array_add8 (PublishingRajceArgItem** * array,
                  int* length,
                  int* size,
                  PublishingRajceArgItem* value)
{
#line 1302 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	if ((*length) == (*size)) {
#line 1302 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 1302 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		*array = g_renew (PublishingRajceArgItem*, *array, (*size) + 1);
#line 9930 "RajcePublishing.c"
	}
#line 1302 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	(*array)[(*length)++] = value;
#line 1302 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	(*array)[*length] = NULL;
#line 9936 "RajcePublishing.c"
}


void
publishing_rajce_live_api_request_AddParamNode (PublishingRajceLiveApiRequest* self,
                                                const gchar* name,
                                                PublishingRajceArgItem** val,
                                                int val_length1)
{
	PublishingRajceArgItem* newItem = NULL;
	PublishingRajceArgItem* _tmp0_;
	PublishingRajceArgItem** _tmp1_;
	gint _tmp1__length1;
	PublishingRajceArgItem* _tmp2_;
#line 1298 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_if_fail (PUBLISHING_RAJCE_IS_LIVE_API_REQUEST (self));
#line 1298 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_if_fail (name != NULL);
#line 1300 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp0_ = publishing_rajce_arg_item_new (name, NULL);
#line 1300 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	newItem = _tmp0_;
#line 1301 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rajce_arg_item_AddChildren (newItem, val, val_length1);
#line 1302 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp1_ = self->priv->_params;
#line 1302 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp1__length1 = self->priv->_params_length1;
#line 1302 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp2_ = _publishing_rajce_arg_item_ref0 (newItem);
#line 1302 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_vala_array_add8 (&self->priv->_params, &self->priv->_params_length1, &self->priv->__params_size_, _tmp2_);
#line 1298 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_publishing_rajce_arg_item_unref0 (newItem);
#line 9971 "RajcePublishing.c"
}


gchar*
publishing_rajce_live_api_request_Params2XmlString (PublishingRajceLiveApiRequest* self,
                                                    gboolean urlencode)
{
	gchar* result = NULL;
	xmlDoc* doc = NULL;
	xmlDoc* _tmp0_;
	xmlNode* root = NULL;
	xmlNode* _tmp1_;
	xmlDoc* _tmp2_;
	xmlNode* _tmp3_;
	xmlNode* _tmp4_;
	const gchar* _tmp5_;
	xmlNode* par = NULL;
	xmlNode* _tmp6_;
	xmlNode* _tmp7_;
	PublishingRajceArgItem** _tmp8_;
	gint _tmp8__length1;
	gchar* xmlstr = NULL;
	xmlDoc* _tmp12_;
	gchar* _tmp13_ = NULL;
	xmlDoc* _tmp14_;
#line 1307 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_val_if_fail (PUBLISHING_RAJCE_IS_LIVE_API_REQUEST (self), NULL);
#line 1309 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp0_ = xmlNewDoc ((xmlChar*) "1.0");
#line 1309 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	doc = _tmp0_;
#line 1310 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp1_ = xmlNewNode (NULL, (xmlChar*) "request");
#line 1310 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	root = _tmp1_;
#line 1311 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp2_ = doc;
#line 1311 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp3_ = root;
#line 1311 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	xmlDocSetRootElement (_tmp2_, _tmp3_);
#line 1312 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp4_ = root;
#line 1312 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp5_ = self->priv->_cmd;
#line 1312 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	xmlNewTextChild (_tmp4_, NULL, (xmlChar*) "command", (xmlChar*) _tmp5_);
#line 1313 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp6_ = root;
#line 1313 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp7_ = xmlNewTextChild (_tmp6_, NULL, (xmlChar*) "parameters", (xmlChar*) "");
#line 1313 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	par = _tmp7_;
#line 1314 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp8_ = self->priv->_params;
#line 1314 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp8__length1 = self->priv->_params_length1;
#line 10029 "RajcePublishing.c"
	{
		PublishingRajceArgItem** arg_collection = NULL;
		gint arg_collection_length1 = 0;
		gint _arg_collection_size_ = 0;
		gint arg_it = 0;
#line 1314 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		arg_collection = _tmp8_;
#line 1314 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		arg_collection_length1 = _tmp8__length1;
#line 1314 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		for (arg_it = 0; arg_it < _tmp8__length1; arg_it = arg_it + 1) {
#line 10041 "RajcePublishing.c"
			PublishingRajceArgItem* _tmp9_;
			PublishingRajceArgItem* arg = NULL;
#line 1314 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			_tmp9_ = _publishing_rajce_arg_item_ref0 (arg_collection[arg_it]);
#line 1314 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			arg = _tmp9_;
#line 10048 "RajcePublishing.c"
			{
				xmlNode* _tmp10_;
				PublishingRajceArgItem* _tmp11_;
#line 1316 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
				_tmp10_ = par;
#line 1316 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
				_tmp11_ = arg;
#line 1316 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
				publishing_rajce_live_api_request_WriteParam (_tmp10_, _tmp11_);
#line 1314 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
				_publishing_rajce_arg_item_unref0 (arg);
#line 10060 "RajcePublishing.c"
			}
		}
	}
#line 1319 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp12_ = doc;
#line 1319 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	xmlDocDumpMemoryEnc (_tmp12_, (xmlChar**) (&_tmp13_), NULL, "UTF-8");
#line 1319 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_free0 (xmlstr);
#line 1319 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	xmlstr = _tmp13_;
#line 1320 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp14_ = doc;
#line 1320 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	xmlFreeDoc (_tmp14_);
#line 1321 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	if (urlencode) {
#line 10078 "RajcePublishing.c"
		const gchar* _tmp15_;
		gchar* _tmp16_;
#line 1323 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp15_ = xmlstr;
#line 1323 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp16_ = soup_uri_encode (_tmp15_, "&;");
#line 1323 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		result = _tmp16_;
#line 1323 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_g_free0 (xmlstr);
#line 1323 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		return result;
#line 10091 "RajcePublishing.c"
	}
#line 1325 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	result = xmlstr;
#line 1325 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	return result;
#line 10097 "RajcePublishing.c"
}


static void
publishing_rajce_live_api_request_WriteParam (xmlNode* node,
                                              PublishingRajceArgItem* arg)
{
	PublishingRajceArgItem** _tmp0_;
	gint _tmp0__length1;
#line 1330 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_if_fail (PUBLISHING_RAJCE_IS_ARG_ITEM (arg));
#line 1332 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp0_ = arg->children;
#line 1332 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp0__length1 = arg->children_length1;
#line 1332 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	if (_tmp0__length1 == 0) {
#line 10115 "RajcePublishing.c"
		const gchar* _tmp1_;
		const gchar* _tmp2_;
#line 1334 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp1_ = arg->key;
#line 1334 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp2_ = arg->val;
#line 1334 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		xmlNewTextChild (node, NULL, (xmlChar*) _tmp1_, (xmlChar*) _tmp2_);
#line 10124 "RajcePublishing.c"
	} else {
		xmlNode* subnode = NULL;
		const gchar* _tmp3_;
		xmlNode* _tmp4_;
		PublishingRajceArgItem** _tmp5_;
		gint _tmp5__length1;
#line 1338 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp3_ = arg->key;
#line 1338 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp4_ = xmlNewTextChild (node, NULL, (xmlChar*) _tmp3_, (xmlChar*) "");
#line 1338 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		subnode = _tmp4_;
#line 1339 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp5_ = arg->children;
#line 1339 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp5__length1 = arg->children_length1;
#line 10141 "RajcePublishing.c"
		{
			PublishingRajceArgItem** child_collection = NULL;
			gint child_collection_length1 = 0;
			gint _child_collection_size_ = 0;
			gint child_it = 0;
#line 1339 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			child_collection = _tmp5_;
#line 1339 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			child_collection_length1 = _tmp5__length1;
#line 1339 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			for (child_it = 0; child_it < _tmp5__length1; child_it = child_it + 1) {
#line 10153 "RajcePublishing.c"
				PublishingRajceArgItem* _tmp6_;
				PublishingRajceArgItem* child = NULL;
#line 1339 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
				_tmp6_ = _publishing_rajce_arg_item_ref0 (child_collection[child_it]);
#line 1339 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
				child = _tmp6_;
#line 10160 "RajcePublishing.c"
				{
					xmlNode* _tmp7_;
					PublishingRajceArgItem* _tmp8_;
#line 1341 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
					_tmp7_ = subnode;
#line 1341 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
					_tmp8_ = child;
#line 1341 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
					publishing_rajce_live_api_request_WriteParam (_tmp7_, _tmp8_);
#line 1339 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
					_publishing_rajce_arg_item_unref0 (child);
#line 10172 "RajcePublishing.c"
				}
			}
		}
	}
}


static void
publishing_rajce_value_live_api_request_init (GValue* value)
{
#line 1258 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	value->data[0].v_pointer = NULL;
#line 10185 "RajcePublishing.c"
}


static void
publishing_rajce_value_live_api_request_free_value (GValue* value)
{
#line 1258 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	if (value->data[0].v_pointer) {
#line 1258 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		publishing_rajce_live_api_request_unref (value->data[0].v_pointer);
#line 10196 "RajcePublishing.c"
	}
}


static void
publishing_rajce_value_live_api_request_copy_value (const GValue* src_value,
                                                    GValue* dest_value)
{
#line 1258 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	if (src_value->data[0].v_pointer) {
#line 1258 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		dest_value->data[0].v_pointer = publishing_rajce_live_api_request_ref (src_value->data[0].v_pointer);
#line 10209 "RajcePublishing.c"
	} else {
#line 1258 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		dest_value->data[0].v_pointer = NULL;
#line 10213 "RajcePublishing.c"
	}
}


static gpointer
publishing_rajce_value_live_api_request_peek_pointer (const GValue* value)
{
#line 1258 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	return value->data[0].v_pointer;
#line 10223 "RajcePublishing.c"
}


static gchar*
publishing_rajce_value_live_api_request_collect_value (GValue* value,
                                                       guint n_collect_values,
                                                       GTypeCValue* collect_values,
                                                       guint collect_flags)
{
#line 1258 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	if (collect_values[0].v_pointer) {
#line 10235 "RajcePublishing.c"
		PublishingRajceLiveApiRequest * object;
		object = collect_values[0].v_pointer;
#line 1258 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		if (object->parent_instance.g_class == NULL) {
#line 1258 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 10242 "RajcePublishing.c"
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
#line 1258 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 10246 "RajcePublishing.c"
		}
#line 1258 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		value->data[0].v_pointer = publishing_rajce_live_api_request_ref (object);
#line 10250 "RajcePublishing.c"
	} else {
#line 1258 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		value->data[0].v_pointer = NULL;
#line 10254 "RajcePublishing.c"
	}
#line 1258 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	return NULL;
#line 10258 "RajcePublishing.c"
}


static gchar*
publishing_rajce_value_live_api_request_lcopy_value (const GValue* value,
                                                     guint n_collect_values,
                                                     GTypeCValue* collect_values,
                                                     guint collect_flags)
{
	PublishingRajceLiveApiRequest ** object_p;
	object_p = collect_values[0].v_pointer;
#line 1258 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	if (!object_p) {
#line 1258 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
#line 10274 "RajcePublishing.c"
	}
#line 1258 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	if (!value->data[0].v_pointer) {
#line 1258 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		*object_p = NULL;
#line 10280 "RajcePublishing.c"
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
#line 1258 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		*object_p = value->data[0].v_pointer;
#line 10284 "RajcePublishing.c"
	} else {
#line 1258 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		*object_p = publishing_rajce_live_api_request_ref (value->data[0].v_pointer);
#line 10288 "RajcePublishing.c"
	}
#line 1258 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	return NULL;
#line 10292 "RajcePublishing.c"
}


GParamSpec*
publishing_rajce_param_spec_live_api_request (const gchar* name,
                                              const gchar* nick,
                                              const gchar* blurb,
                                              GType object_type,
                                              GParamFlags flags)
{
	PublishingRajceParamSpecLiveApiRequest* spec;
#line 1258 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_val_if_fail (g_type_is_a (object_type, PUBLISHING_RAJCE_TYPE_LIVE_API_REQUEST), NULL);
#line 1258 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
#line 1258 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	G_PARAM_SPEC (spec)->value_type = object_type;
#line 1258 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	return G_PARAM_SPEC (spec);
#line 10312 "RajcePublishing.c"
}


gpointer
publishing_rajce_value_get_live_api_request (const GValue* value)
{
#line 1258 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_RAJCE_TYPE_LIVE_API_REQUEST), NULL);
#line 1258 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	return value->data[0].v_pointer;
#line 10323 "RajcePublishing.c"
}


void
publishing_rajce_value_set_live_api_request (GValue* value,
                                             gpointer v_object)
{
	PublishingRajceLiveApiRequest * old;
#line 1258 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_RAJCE_TYPE_LIVE_API_REQUEST));
#line 1258 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	old = value->data[0].v_pointer;
#line 1258 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	if (v_object) {
#line 1258 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, PUBLISHING_RAJCE_TYPE_LIVE_API_REQUEST));
#line 1258 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 1258 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		value->data[0].v_pointer = v_object;
#line 1258 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		publishing_rajce_live_api_request_ref (value->data[0].v_pointer);
#line 10346 "RajcePublishing.c"
	} else {
#line 1258 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		value->data[0].v_pointer = NULL;
#line 10350 "RajcePublishing.c"
	}
#line 1258 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	if (old) {
#line 1258 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		publishing_rajce_live_api_request_unref (old);
#line 10356 "RajcePublishing.c"
	}
}


void
publishing_rajce_value_take_live_api_request (GValue* value,
                                              gpointer v_object)
{
	PublishingRajceLiveApiRequest * old;
#line 1258 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_RAJCE_TYPE_LIVE_API_REQUEST));
#line 1258 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	old = value->data[0].v_pointer;
#line 1258 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	if (v_object) {
#line 1258 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, PUBLISHING_RAJCE_TYPE_LIVE_API_REQUEST));
#line 1258 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 1258 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		value->data[0].v_pointer = v_object;
#line 10378 "RajcePublishing.c"
	} else {
#line 1258 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		value->data[0].v_pointer = NULL;
#line 10382 "RajcePublishing.c"
	}
#line 1258 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	if (old) {
#line 1258 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		publishing_rajce_live_api_request_unref (old);
#line 10388 "RajcePublishing.c"
	}
}


static void
publishing_rajce_live_api_request_class_init (PublishingRajceLiveApiRequestClass * klass)
{
#line 1258 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rajce_live_api_request_parent_class = g_type_class_peek_parent (klass);
#line 1258 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	((PublishingRajceLiveApiRequestClass *) klass)->finalize = publishing_rajce_live_api_request_finalize;
#line 1258 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_type_class_add_private (klass, sizeof (PublishingRajceLiveApiRequestPrivate));
#line 10402 "RajcePublishing.c"
}


static void
publishing_rajce_live_api_request_instance_init (PublishingRajceLiveApiRequest * self)
{
#line 1258 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self->priv = PUBLISHING_RAJCE_LIVE_API_REQUEST_GET_PRIVATE (self);
#line 1258 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self->ref_count = 1;
#line 10413 "RajcePublishing.c"
}


static void
publishing_rajce_live_api_request_finalize (PublishingRajceLiveApiRequest * obj)
{
	PublishingRajceLiveApiRequest * self;
#line 1258 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_RAJCE_TYPE_LIVE_API_REQUEST, PublishingRajceLiveApiRequest);
#line 1258 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_signal_handlers_destroy (self);
#line 1260 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self->priv->_params = (_vala_array_free (self->priv->_params, self->priv->_params_length1, (GDestroyNotify) publishing_rajce_arg_item_unref), NULL);
#line 1261 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_free0 (self->priv->_cmd);
#line 10429 "RajcePublishing.c"
}


GType
publishing_rajce_live_api_request_get_type (void)
{
	static volatile gsize publishing_rajce_live_api_request_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_rajce_live_api_request_type_id__volatile)) {
		static const GTypeValueTable g_define_type_value_table = { publishing_rajce_value_live_api_request_init, publishing_rajce_value_live_api_request_free_value, publishing_rajce_value_live_api_request_copy_value, publishing_rajce_value_live_api_request_peek_pointer, "p", publishing_rajce_value_live_api_request_collect_value, "p", publishing_rajce_value_live_api_request_lcopy_value };
		static const GTypeInfo g_define_type_info = { sizeof (PublishingRajceLiveApiRequestClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_rajce_live_api_request_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingRajceLiveApiRequest), 0, (GInstanceInitFunc) publishing_rajce_live_api_request_instance_init, &g_define_type_value_table };
		static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
		GType publishing_rajce_live_api_request_type_id;
		publishing_rajce_live_api_request_type_id = g_type_register_fundamental (g_type_fundamental_next (), "PublishingRajceLiveApiRequest", &g_define_type_info, &g_define_type_fundamental_info, 0);
		g_once_init_leave (&publishing_rajce_live_api_request_type_id__volatile, publishing_rajce_live_api_request_type_id);
	}
	return publishing_rajce_live_api_request_type_id__volatile;
}


gpointer
publishing_rajce_live_api_request_ref (gpointer instance)
{
	PublishingRajceLiveApiRequest * self;
	self = instance;
#line 1258 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_atomic_int_inc (&self->ref_count);
#line 1258 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	return instance;
#line 10458 "RajcePublishing.c"
}


void
publishing_rajce_live_api_request_unref (gpointer instance)
{
	PublishingRajceLiveApiRequest * self;
	self = instance;
#line 1258 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
#line 1258 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		PUBLISHING_RAJCE_LIVE_API_REQUEST_GET_CLASS (self)->finalize (self);
#line 1258 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		g_type_free_instance ((GTypeInstance *) self);
#line 10473 "RajcePublishing.c"
	}
}


PublishingRajceTransaction*
publishing_rajce_transaction_construct (GType object_type,
                                        PublishingRajceSession* session)
{
	PublishingRajceTransaction* self = NULL;
#line 1356 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_val_if_fail (PUBLISHING_RAJCE_IS_SESSION (session), NULL);
#line 1358 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self = (PublishingRajceTransaction*) publishing_rest_support_transaction_construct (object_type, G_TYPE_CHECK_INSTANCE_CAST (session, PUBLISHING_REST_SUPPORT_TYPE_SESSION, PublishingRESTSupportSession), PUBLISHING_REST_SUPPORT_HTTP_METHOD_POST);
#line 1356 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	return self;
#line 10489 "RajcePublishing.c"
}


PublishingRajceTransaction*
publishing_rajce_transaction_new (PublishingRajceSession* session)
{
#line 1356 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	return publishing_rajce_transaction_construct (PUBLISHING_RAJCE_TYPE_TRANSACTION, session);
#line 10498 "RajcePublishing.c"
}


gchar*
publishing_rajce_transaction_validate_xml (PublishingRESTSupportXmlDocument* doc)
{
	gchar* result = NULL;
	xmlNode* root = NULL;
	xmlNode* _tmp0_;
	xmlNode* _tmp1_;
	gchar* name = NULL;
	xmlNode* _tmp3_;
	const gchar* _tmp4_;
	gchar* _tmp5_;
	gboolean _tmp6_ = FALSE;
	const gchar* _tmp7_;
	xmlNode* errcode = NULL;
	xmlNode* _result_ = NULL;
	xmlNode* _tmp16_;
	gchar* _tmp17_;
	gchar* _tmp18_;
	xmlNode* _tmp19_;
	gchar* _tmp20_;
	gchar* _tmp21_;
	gchar* _tmp22_;
	gchar* _tmp23_;
	GError * _inner_error_ = NULL;
#line 1361 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_val_if_fail (PUBLISHING_REST_SUPPORT_IS_XML_DOCUMENT (doc), NULL);
#line 1363 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp0_ = publishing_rest_support_xml_document_get_root_node (doc);
#line 1363 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	root = _tmp0_;
#line 1364 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp1_ = root;
#line 1364 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	if (_tmp1_ == NULL) {
#line 10536 "RajcePublishing.c"
		gchar* _tmp2_;
#line 1366 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp2_ = g_strdup ("No XML returned from server");
#line 1366 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		result = _tmp2_;
#line 1366 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		return result;
#line 10544 "RajcePublishing.c"
	}
#line 1368 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp3_ = root;
#line 1368 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp4_ = _tmp3_->name;
#line 1368 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp5_ = g_strdup (_tmp4_);
#line 1368 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	name = _tmp5_;
#line 1371 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp7_ = name;
#line 1371 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	if (_tmp7_ == NULL) {
#line 1371 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp6_ = TRUE;
#line 10560 "RajcePublishing.c"
	} else {
		const gchar* _tmp8_;
#line 1371 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp8_ = name;
#line 1371 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp6_ = g_strcmp0 (_tmp8_, "response") != 0;
#line 10567 "RajcePublishing.c"
	}
#line 1371 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	if (_tmp6_) {
#line 10571 "RajcePublishing.c"
		gchar* _tmp9_;
#line 1373 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp9_ = g_strdup ("No response from Rajce in XML");
#line 1373 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		result = _tmp9_;
#line 1373 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_g_free0 (name);
#line 1373 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		return result;
#line 10581 "RajcePublishing.c"
	}
	{
		xmlNode* _tmp10_ = NULL;
		xmlNode* _tmp11_;
		xmlNode* _tmp12_;
		xmlNode* _tmp13_ = NULL;
		xmlNode* _tmp14_;
		xmlNode* _tmp15_;
#line 1379 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp11_ = root;
#line 1379 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp12_ = publishing_rest_support_xml_document_get_named_child (doc, _tmp11_, "errorCode", &_inner_error_);
#line 1379 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp10_ = _tmp12_;
#line 1379 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1379 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 10600 "RajcePublishing.c"
				goto __catch31_spit_publishing_publishing_error;
			}
#line 1379 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			_g_free0 (name);
#line 1379 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1379 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			g_clear_error (&_inner_error_);
#line 1379 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			return NULL;
#line 10611 "RajcePublishing.c"
		}
#line 1379 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		errcode = _tmp10_;
#line 1380 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp14_ = root;
#line 1380 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp15_ = publishing_rest_support_xml_document_get_named_child (doc, _tmp14_, "result", &_inner_error_);
#line 1380 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp13_ = _tmp15_;
#line 1380 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1380 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 10625 "RajcePublishing.c"
				goto __catch31_spit_publishing_publishing_error;
			}
#line 1380 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			_g_free0 (name);
#line 1380 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1380 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			g_clear_error (&_inner_error_);
#line 1380 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
			return NULL;
#line 10636 "RajcePublishing.c"
		}
#line 1380 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_result_ = _tmp13_;
#line 10640 "RajcePublishing.c"
	}
	goto __finally31;
	__catch31_spit_publishing_publishing_error:
	{
		GError* err = NULL;
#line 1377 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		err = _inner_error_;
#line 1377 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_inner_error_ = NULL;
#line 1384 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		result = NULL;
#line 1384 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_g_error_free0 (err);
#line 1384 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_g_free0 (name);
#line 1384 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		return result;
#line 10658 "RajcePublishing.c"
	}
	__finally31:
#line 1377 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1377 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_g_free0 (name);
#line 1377 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1377 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		g_clear_error (&_inner_error_);
#line 1377 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		return NULL;
#line 10671 "RajcePublishing.c"
	}
#line 1386 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp16_ = errcode;
#line 1386 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp17_ = (gchar*) xmlNodeGetContent (_tmp16_);
#line 1386 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp18_ = _tmp17_;
#line 1386 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp19_ = _result_;
#line 1386 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp20_ = (gchar*) xmlNodeGetContent (_tmp19_);
#line 1386 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp21_ = _tmp20_;
#line 1386 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp22_ = g_strdup_printf ("999 Rajce Error [%d]: %s", atoi (_tmp18_), _tmp21_);
#line 1386 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp23_ = _tmp22_;
#line 1386 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_free0 (_tmp21_);
#line 1386 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_free0 (_tmp18_);
#line 1386 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	result = _tmp23_;
#line 1386 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_free0 (name);
#line 1386 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	return result;
#line 10699 "RajcePublishing.c"
}


static void
publishing_rajce_transaction_class_init (PublishingRajceTransactionClass * klass)
{
#line 1354 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rajce_transaction_parent_class = g_type_class_peek_parent (klass);
#line 10708 "RajcePublishing.c"
}


static void
publishing_rajce_transaction_instance_init (PublishingRajceTransaction * self)
{
}


/**
 * Generic REST transaction class.
 *
 * This class implements the generic logic for all REST transactions used
 * by the Rajce publishing plugin.
 */
GType
publishing_rajce_transaction_get_type (void)
{
	static volatile gsize publishing_rajce_transaction_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_rajce_transaction_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingRajceTransactionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_rajce_transaction_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingRajceTransaction), 0, (GInstanceInitFunc) publishing_rajce_transaction_instance_init, NULL };
		GType publishing_rajce_transaction_type_id;
		publishing_rajce_transaction_type_id = g_type_register_static (PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, "PublishingRajceTransaction", &g_define_type_info, 0);
		g_once_init_leave (&publishing_rajce_transaction_type_id__volatile, publishing_rajce_transaction_type_id);
	}
	return publishing_rajce_transaction_type_id__volatile;
}


PublishingRajceSessionLoginTransaction*
publishing_rajce_session_login_transaction_construct (GType object_type,
                                                      PublishingRajceSession* session,
                                                      const gchar* url,
                                                      const gchar* username,
                                                      const gchar* token)
{
	PublishingRajceSessionLoginTransaction* self = NULL;
	PublishingRajceLiveApiRequest* req = NULL;
	PublishingRajceLiveApiRequest* _tmp0_;
	gchar* xml = NULL;
	gchar* _tmp1_;
#line 1395 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_val_if_fail (PUBLISHING_RAJCE_IS_SESSION (session), NULL);
#line 1395 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_val_if_fail (url != NULL, NULL);
#line 1395 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_val_if_fail (username != NULL, NULL);
#line 1395 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_val_if_fail (token != NULL, NULL);
#line 1397 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_debug ("RajcePublishing.vala:1397: SessionLoginTransaction: URL: %s", url);
#line 1398 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self = (PublishingRajceSessionLoginTransaction*) publishing_rest_support_transaction_construct_with_endpoint_url (object_type, G_TYPE_CHECK_INSTANCE_CAST (session, PUBLISHING_REST_SUPPORT_TYPE_SESSION, PublishingRESTSupportSession), url, PUBLISHING_REST_SUPPORT_HTTP_METHOD_POST);
#line 1399 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp0_ = publishing_rajce_live_api_request_new ("login");
#line 1399 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	req = _tmp0_;
#line 1400 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rajce_live_api_request_AddParam (req, "clientID", "RajceShotwellPlugin");
#line 1401 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rajce_live_api_request_AddParam (req, "currentVersion", "1.1.1.1");
#line 1402 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rajce_live_api_request_AddParam (req, "login", username);
#line 1403 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rajce_live_api_request_AddParam (req, "password", token);
#line 1404 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp1_ = publishing_rajce_live_api_request_Params2XmlString (req, TRUE);
#line 1404 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	xml = _tmp1_;
#line 1405 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rest_support_transaction_add_argument (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "data", xml);
#line 1395 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_free0 (xml);
#line 1395 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_publishing_rajce_live_api_request_unref0 (req);
#line 1395 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	return self;
#line 10786 "RajcePublishing.c"
}


PublishingRajceSessionLoginTransaction*
publishing_rajce_session_login_transaction_new (PublishingRajceSession* session,
                                                const gchar* url,
                                                const gchar* username,
                                                const gchar* token)
{
#line 1395 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	return publishing_rajce_session_login_transaction_construct (PUBLISHING_RAJCE_TYPE_SESSION_LOGIN_TRANSACTION, session, url, username, token);
#line 10798 "RajcePublishing.c"
}


static void
publishing_rajce_session_login_transaction_class_init (PublishingRajceSessionLoginTransactionClass * klass)
{
#line 1393 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rajce_session_login_transaction_parent_class = g_type_class_peek_parent (klass);
#line 10807 "RajcePublishing.c"
}


static void
publishing_rajce_session_login_transaction_instance_init (PublishingRajceSessionLoginTransaction * self)
{
}


/**
 * Transaction used to implement the network login interaction.
 */
GType
publishing_rajce_session_login_transaction_get_type (void)
{
	static volatile gsize publishing_rajce_session_login_transaction_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_rajce_session_login_transaction_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingRajceSessionLoginTransactionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_rajce_session_login_transaction_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingRajceSessionLoginTransaction), 0, (GInstanceInitFunc) publishing_rajce_session_login_transaction_instance_init, NULL };
		GType publishing_rajce_session_login_transaction_type_id;
		publishing_rajce_session_login_transaction_type_id = g_type_register_static (PUBLISHING_RAJCE_TYPE_TRANSACTION, "PublishingRajceSessionLoginTransaction", &g_define_type_info, 0);
		g_once_init_leave (&publishing_rajce_session_login_transaction_type_id__volatile, publishing_rajce_session_login_transaction_type_id);
	}
	return publishing_rajce_session_login_transaction_type_id__volatile;
}


static void
_vala_array_add9 (PublishingRajceArgItem** * array,
                  int* length,
                  int* size,
                  PublishingRajceArgItem* value)
{
#line 1420 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	if ((*length) == (*size)) {
#line 1420 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 1420 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		*array = g_renew (PublishingRajceArgItem*, *array, (*size) + 1);
#line 10846 "RajcePublishing.c"
	}
#line 1420 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	(*array)[(*length)++] = value;
#line 1420 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	(*array)[*length] = NULL;
#line 10852 "RajcePublishing.c"
}


static void
_vala_array_add10 (PublishingRajceArgItem** * array,
                   int* length,
                   int* size,
                   PublishingRajceArgItem* value)
{
#line 1421 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	if ((*length) == (*size)) {
#line 1421 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 1421 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		*array = g_renew (PublishingRajceArgItem*, *array, (*size) + 1);
#line 10868 "RajcePublishing.c"
	}
#line 1421 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	(*array)[(*length)++] = value;
#line 1421 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	(*array)[*length] = NULL;
#line 10874 "RajcePublishing.c"
}


static void
_vala_array_add11 (PublishingRajceArgItem** * array,
                   int* length,
                   int* size,
                   PublishingRajceArgItem* value)
{
#line 1422 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	if ((*length) == (*size)) {
#line 1422 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 1422 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		*array = g_renew (PublishingRajceArgItem*, *array, (*size) + 1);
#line 10890 "RajcePublishing.c"
	}
#line 1422 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	(*array)[(*length)++] = value;
#line 1422 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	(*array)[*length] = NULL;
#line 10896 "RajcePublishing.c"
}


static void
_vala_array_add12 (PublishingRajceArgItem** * array,
                   int* length,
                   int* size,
                   PublishingRajceArgItem* value)
{
#line 1423 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	if ((*length) == (*size)) {
#line 1423 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 1423 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		*array = g_renew (PublishingRajceArgItem*, *array, (*size) + 1);
#line 10912 "RajcePublishing.c"
	}
#line 1423 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	(*array)[(*length)++] = value;
#line 1423 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	(*array)[*length] = NULL;
#line 10918 "RajcePublishing.c"
}


static void
_vala_array_add13 (PublishingRajceArgItem** * array,
                   int* length,
                   int* size,
                   PublishingRajceArgItem* value)
{
#line 1424 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	if ((*length) == (*size)) {
#line 1424 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 1424 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		*array = g_renew (PublishingRajceArgItem*, *array, (*size) + 1);
#line 10934 "RajcePublishing.c"
	}
#line 1424 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	(*array)[(*length)++] = value;
#line 1424 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	(*array)[*length] = NULL;
#line 10940 "RajcePublishing.c"
}


PublishingRajceGetAlbumsTransaction*
publishing_rajce_get_albums_transaction_construct (GType object_type,
                                                   PublishingRajceSession* session,
                                                   const gchar* url)
{
	PublishingRajceGetAlbumsTransaction* self = NULL;
	PublishingRajceLiveApiRequest* req = NULL;
	PublishingRajceLiveApiRequest* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	PublishingRajceArgItem** columns = NULL;
	PublishingRajceArgItem** _tmp3_;
	gint columns_length1;
	gint _columns_size_;
	PublishingRajceArgItem** _tmp4_;
	gint _tmp4__length1;
	PublishingRajceArgItem* _tmp5_;
	PublishingRajceArgItem** _tmp6_;
	gint _tmp6__length1;
	PublishingRajceArgItem* _tmp7_;
	PublishingRajceArgItem** _tmp8_;
	gint _tmp8__length1;
	PublishingRajceArgItem* _tmp9_;
	PublishingRajceArgItem** _tmp10_;
	gint _tmp10__length1;
	PublishingRajceArgItem* _tmp11_;
	PublishingRajceArgItem** _tmp12_;
	gint _tmp12__length1;
	PublishingRajceArgItem* _tmp13_;
	PublishingRajceArgItem** _tmp14_;
	gint _tmp14__length1;
	gchar* xml = NULL;
	gchar* _tmp15_;
#line 1414 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_val_if_fail (PUBLISHING_RAJCE_IS_SESSION (session), NULL);
#line 1414 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_val_if_fail (url != NULL, NULL);
#line 1416 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self = (PublishingRajceGetAlbumsTransaction*) publishing_rest_support_transaction_construct_with_endpoint_url (object_type, G_TYPE_CHECK_INSTANCE_CAST (session, PUBLISHING_REST_SUPPORT_TYPE_SESSION, PublishingRESTSupportSession), url, PUBLISHING_REST_SUPPORT_HTTP_METHOD_POST);
#line 1417 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp0_ = publishing_rajce_live_api_request_new ("getAlbumList");
#line 1417 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	req = _tmp0_;
#line 1418 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp1_ = publishing_rajce_session_get_usertoken (session);
#line 1418 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp2_ = _tmp1_;
#line 1418 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rajce_live_api_request_AddParam (req, "token", _tmp2_);
#line 1418 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_free0 (_tmp2_);
#line 1419 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp3_ = g_new0 (PublishingRajceArgItem*, 0 + 1);
#line 1419 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	columns = _tmp3_;
#line 1419 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	columns_length1 = 0;
#line 1419 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_columns_size_ = columns_length1;
#line 1420 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp4_ = columns;
#line 1420 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp4__length1 = columns_length1;
#line 1420 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp5_ = publishing_rajce_arg_item_new ("column", "viewCount");
#line 1420 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_vala_array_add9 (&columns, &columns_length1, &_columns_size_, _tmp5_);
#line 1421 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp6_ = columns;
#line 1421 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp6__length1 = columns_length1;
#line 1421 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp7_ = publishing_rajce_arg_item_new ("column", "isFavourite");
#line 1421 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_vala_array_add10 (&columns, &columns_length1, &_columns_size_, _tmp7_);
#line 1422 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp8_ = columns;
#line 1422 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp8__length1 = columns_length1;
#line 1422 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp9_ = publishing_rajce_arg_item_new ("column", "descriptionHtml");
#line 1422 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_vala_array_add11 (&columns, &columns_length1, &_columns_size_, _tmp9_);
#line 1423 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp10_ = columns;
#line 1423 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp10__length1 = columns_length1;
#line 1423 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp11_ = publishing_rajce_arg_item_new ("column", "coverPhotoID");
#line 1423 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_vala_array_add12 (&columns, &columns_length1, &_columns_size_, _tmp11_);
#line 1424 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp12_ = columns;
#line 1424 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp12__length1 = columns_length1;
#line 1424 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp13_ = publishing_rajce_arg_item_new ("column", "localPath");
#line 1424 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_vala_array_add13 (&columns, &columns_length1, &_columns_size_, _tmp13_);
#line 1425 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp14_ = columns;
#line 1425 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp14__length1 = columns_length1;
#line 1425 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rajce_live_api_request_AddParamNode (req, "columns", _tmp14_, _tmp14__length1);
#line 1426 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp15_ = publishing_rajce_live_api_request_Params2XmlString (req, TRUE);
#line 1426 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	xml = _tmp15_;
#line 1427 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rest_support_transaction_add_argument (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "data", xml);
#line 1414 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_free0 (xml);
#line 1414 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	columns = (_vala_array_free (columns, columns_length1, (GDestroyNotify) publishing_rajce_arg_item_unref), NULL);
#line 1414 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_publishing_rajce_live_api_request_unref0 (req);
#line 1414 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	return self;
#line 11063 "RajcePublishing.c"
}


PublishingRajceGetAlbumsTransaction*
publishing_rajce_get_albums_transaction_new (PublishingRajceSession* session,
                                             const gchar* url)
{
#line 1414 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	return publishing_rajce_get_albums_transaction_construct (PUBLISHING_RAJCE_TYPE_GET_ALBUMS_TRANSACTION, session, url);
#line 11073 "RajcePublishing.c"
}


static void
publishing_rajce_get_albums_transaction_class_init (PublishingRajceGetAlbumsTransactionClass * klass)
{
#line 1412 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rajce_get_albums_transaction_parent_class = g_type_class_peek_parent (klass);
#line 11082 "RajcePublishing.c"
}


static void
publishing_rajce_get_albums_transaction_instance_init (PublishingRajceGetAlbumsTransaction * self)
{
}


/**
 * Transaction used to implement the get albums interaction.
 */
GType
publishing_rajce_get_albums_transaction_get_type (void)
{
	static volatile gsize publishing_rajce_get_albums_transaction_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_rajce_get_albums_transaction_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingRajceGetAlbumsTransactionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_rajce_get_albums_transaction_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingRajceGetAlbumsTransaction), 0, (GInstanceInitFunc) publishing_rajce_get_albums_transaction_instance_init, NULL };
		GType publishing_rajce_get_albums_transaction_type_id;
		publishing_rajce_get_albums_transaction_type_id = g_type_register_static (PUBLISHING_RAJCE_TYPE_TRANSACTION, "PublishingRajceGetAlbumsTransaction", &g_define_type_info, 0);
		g_once_init_leave (&publishing_rajce_get_albums_transaction_type_id__volatile, publishing_rajce_get_albums_transaction_type_id);
	}
	return publishing_rajce_get_albums_transaction_type_id__volatile;
}


PublishingRajceCreateAlbumTransaction*
publishing_rajce_create_album_transaction_construct (GType object_type,
                                                     PublishingRajceSession* session,
                                                     const gchar* url,
                                                     const gchar* albumName,
                                                     gboolean hidden)
{
	PublishingRajceCreateAlbumTransaction* self = NULL;
	PublishingRajceLiveApiRequest* req = NULL;
	PublishingRajceLiveApiRequest* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* xml = NULL;
	gchar* _tmp3_;
#line 1436 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_val_if_fail (PUBLISHING_RAJCE_IS_SESSION (session), NULL);
#line 1436 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_val_if_fail (url != NULL, NULL);
#line 1436 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_val_if_fail (albumName != NULL, NULL);
#line 1438 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self = (PublishingRajceCreateAlbumTransaction*) publishing_rest_support_transaction_construct_with_endpoint_url (object_type, G_TYPE_CHECK_INSTANCE_CAST (session, PUBLISHING_REST_SUPPORT_TYPE_SESSION, PublishingRESTSupportSession), url, PUBLISHING_REST_SUPPORT_HTTP_METHOD_POST);
#line 1439 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp0_ = publishing_rajce_live_api_request_new ("createAlbum");
#line 1439 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	req = _tmp0_;
#line 1440 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp1_ = publishing_rajce_session_get_usertoken (session);
#line 1440 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp2_ = _tmp1_;
#line 1440 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rajce_live_api_request_AddParam (req, "token", _tmp2_);
#line 1440 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_free0 (_tmp2_);
#line 1441 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rajce_live_api_request_AddParam (req, "albumName", albumName);
#line 1442 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rajce_live_api_request_AddParam (req, "albumDescription", "");
#line 1443 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rajce_live_api_request_AddParamBool (req, "albumVisible", !hidden);
#line 1444 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp3_ = publishing_rajce_live_api_request_Params2XmlString (req, TRUE);
#line 1444 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	xml = _tmp3_;
#line 1445 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rest_support_transaction_add_argument (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "data", xml);
#line 1436 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_free0 (xml);
#line 1436 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_publishing_rajce_live_api_request_unref0 (req);
#line 1436 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	return self;
#line 11161 "RajcePublishing.c"
}


PublishingRajceCreateAlbumTransaction*
publishing_rajce_create_album_transaction_new (PublishingRajceSession* session,
                                               const gchar* url,
                                               const gchar* albumName,
                                               gboolean hidden)
{
#line 1436 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	return publishing_rajce_create_album_transaction_construct (PUBLISHING_RAJCE_TYPE_CREATE_ALBUM_TRANSACTION, session, url, albumName, hidden);
#line 11173 "RajcePublishing.c"
}


static void
publishing_rajce_create_album_transaction_class_init (PublishingRajceCreateAlbumTransactionClass * klass)
{
#line 1434 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rajce_create_album_transaction_parent_class = g_type_class_peek_parent (klass);
#line 11182 "RajcePublishing.c"
}


static void
publishing_rajce_create_album_transaction_instance_init (PublishingRajceCreateAlbumTransaction * self)
{
}


/**
 * Transaction used to implement the create album interaction.
 */
GType
publishing_rajce_create_album_transaction_get_type (void)
{
	static volatile gsize publishing_rajce_create_album_transaction_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_rajce_create_album_transaction_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingRajceCreateAlbumTransactionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_rajce_create_album_transaction_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingRajceCreateAlbumTransaction), 0, (GInstanceInitFunc) publishing_rajce_create_album_transaction_instance_init, NULL };
		GType publishing_rajce_create_album_transaction_type_id;
		publishing_rajce_create_album_transaction_type_id = g_type_register_static (PUBLISHING_RAJCE_TYPE_TRANSACTION, "PublishingRajceCreateAlbumTransaction", &g_define_type_info, 0);
		g_once_init_leave (&publishing_rajce_create_album_transaction_type_id__volatile, publishing_rajce_create_album_transaction_type_id);
	}
	return publishing_rajce_create_album_transaction_type_id__volatile;
}


PublishingRajceOpenAlbumTransaction*
publishing_rajce_open_album_transaction_construct (GType object_type,
                                                   PublishingRajceSession* session,
                                                   const gchar* url,
                                                   gint albumID)
{
	PublishingRajceOpenAlbumTransaction* self = NULL;
	PublishingRajceLiveApiRequest* req = NULL;
	PublishingRajceLiveApiRequest* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* xml = NULL;
	gchar* _tmp3_;
#line 1454 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_val_if_fail (PUBLISHING_RAJCE_IS_SESSION (session), NULL);
#line 1454 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_val_if_fail (url != NULL, NULL);
#line 1456 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self = (PublishingRajceOpenAlbumTransaction*) publishing_rest_support_transaction_construct_with_endpoint_url (object_type, G_TYPE_CHECK_INSTANCE_CAST (session, PUBLISHING_REST_SUPPORT_TYPE_SESSION, PublishingRESTSupportSession), url, PUBLISHING_REST_SUPPORT_HTTP_METHOD_POST);
#line 1457 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp0_ = publishing_rajce_live_api_request_new ("openAlbum");
#line 1457 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	req = _tmp0_;
#line 1458 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp1_ = publishing_rajce_session_get_usertoken (session);
#line 1458 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp2_ = _tmp1_;
#line 1458 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rajce_live_api_request_AddParam (req, "token", _tmp2_);
#line 1458 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_free0 (_tmp2_);
#line 1459 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rajce_live_api_request_AddParamInt (req, "albumID", albumID);
#line 1460 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp3_ = publishing_rajce_live_api_request_Params2XmlString (req, TRUE);
#line 1460 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	xml = _tmp3_;
#line 1461 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rest_support_transaction_add_argument (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "data", xml);
#line 1454 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_free0 (xml);
#line 1454 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_publishing_rajce_live_api_request_unref0 (req);
#line 1454 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	return self;
#line 11254 "RajcePublishing.c"
}


PublishingRajceOpenAlbumTransaction*
publishing_rajce_open_album_transaction_new (PublishingRajceSession* session,
                                             const gchar* url,
                                             gint albumID)
{
#line 1454 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	return publishing_rajce_open_album_transaction_construct (PUBLISHING_RAJCE_TYPE_OPEN_ALBUM_TRANSACTION, session, url, albumID);
#line 11265 "RajcePublishing.c"
}


static void
publishing_rajce_open_album_transaction_class_init (PublishingRajceOpenAlbumTransactionClass * klass)
{
#line 1452 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rajce_open_album_transaction_parent_class = g_type_class_peek_parent (klass);
#line 11274 "RajcePublishing.c"
}


static void
publishing_rajce_open_album_transaction_instance_init (PublishingRajceOpenAlbumTransaction * self)
{
}


/**
 * Transaction used to implement the open album interaction.
 */
GType
publishing_rajce_open_album_transaction_get_type (void)
{
	static volatile gsize publishing_rajce_open_album_transaction_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_rajce_open_album_transaction_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingRajceOpenAlbumTransactionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_rajce_open_album_transaction_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingRajceOpenAlbumTransaction), 0, (GInstanceInitFunc) publishing_rajce_open_album_transaction_instance_init, NULL };
		GType publishing_rajce_open_album_transaction_type_id;
		publishing_rajce_open_album_transaction_type_id = g_type_register_static (PUBLISHING_RAJCE_TYPE_TRANSACTION, "PublishingRajceOpenAlbumTransaction", &g_define_type_info, 0);
		g_once_init_leave (&publishing_rajce_open_album_transaction_type_id__volatile, publishing_rajce_open_album_transaction_type_id);
	}
	return publishing_rajce_open_album_transaction_type_id__volatile;
}


PublishingRajceGetAlbumUrlTransaction*
publishing_rajce_get_album_url_transaction_construct (GType object_type,
                                                      PublishingRajceSession* session,
                                                      const gchar* url)
{
	PublishingRajceGetAlbumUrlTransaction* self = NULL;
	PublishingRajceLiveApiRequest* req = NULL;
	PublishingRajceLiveApiRequest* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	gchar* _tmp4_;
	gchar* xml = NULL;
	gchar* _tmp5_;
#line 1470 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_val_if_fail (PUBLISHING_RAJCE_IS_SESSION (session), NULL);
#line 1470 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_val_if_fail (url != NULL, NULL);
#line 1472 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self = (PublishingRajceGetAlbumUrlTransaction*) publishing_rest_support_transaction_construct_with_endpoint_url (object_type, G_TYPE_CHECK_INSTANCE_CAST (session, PUBLISHING_REST_SUPPORT_TYPE_SESSION, PublishingRESTSupportSession), url, PUBLISHING_REST_SUPPORT_HTTP_METHOD_POST);
#line 1473 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp0_ = publishing_rajce_live_api_request_new ("getAlbumUrl");
#line 1473 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	req = _tmp0_;
#line 1474 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp1_ = publishing_rajce_session_get_usertoken (session);
#line 1474 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp2_ = _tmp1_;
#line 1474 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rajce_live_api_request_AddParam (req, "token", _tmp2_);
#line 1474 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_free0 (_tmp2_);
#line 1475 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp3_ = publishing_rajce_session_get_albumtoken (session);
#line 1475 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp4_ = _tmp3_;
#line 1475 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rajce_live_api_request_AddParam (req, "albumToken", _tmp4_);
#line 1475 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_free0 (_tmp4_);
#line 1476 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp5_ = publishing_rajce_live_api_request_Params2XmlString (req, TRUE);
#line 1476 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	xml = _tmp5_;
#line 1477 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rest_support_transaction_add_argument (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "data", xml);
#line 1470 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_free0 (xml);
#line 1470 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_publishing_rajce_live_api_request_unref0 (req);
#line 1470 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	return self;
#line 11353 "RajcePublishing.c"
}


PublishingRajceGetAlbumUrlTransaction*
publishing_rajce_get_album_url_transaction_new (PublishingRajceSession* session,
                                                const gchar* url)
{
#line 1470 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	return publishing_rajce_get_album_url_transaction_construct (PUBLISHING_RAJCE_TYPE_GET_ALBUM_URL_TRANSACTION, session, url);
#line 11363 "RajcePublishing.c"
}


static void
publishing_rajce_get_album_url_transaction_class_init (PublishingRajceGetAlbumUrlTransactionClass * klass)
{
#line 1468 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rajce_get_album_url_transaction_parent_class = g_type_class_peek_parent (klass);
#line 11372 "RajcePublishing.c"
}


static void
publishing_rajce_get_album_url_transaction_instance_init (PublishingRajceGetAlbumUrlTransaction * self)
{
}


/**
 * Transaction used to implement the close album interaction.
 */
GType
publishing_rajce_get_album_url_transaction_get_type (void)
{
	static volatile gsize publishing_rajce_get_album_url_transaction_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_rajce_get_album_url_transaction_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingRajceGetAlbumUrlTransactionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_rajce_get_album_url_transaction_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingRajceGetAlbumUrlTransaction), 0, (GInstanceInitFunc) publishing_rajce_get_album_url_transaction_instance_init, NULL };
		GType publishing_rajce_get_album_url_transaction_type_id;
		publishing_rajce_get_album_url_transaction_type_id = g_type_register_static (PUBLISHING_RAJCE_TYPE_TRANSACTION, "PublishingRajceGetAlbumUrlTransaction", &g_define_type_info, 0);
		g_once_init_leave (&publishing_rajce_get_album_url_transaction_type_id__volatile, publishing_rajce_get_album_url_transaction_type_id);
	}
	return publishing_rajce_get_album_url_transaction_type_id__volatile;
}


PublishingRajceCloseAlbumTransaction*
publishing_rajce_close_album_transaction_construct (GType object_type,
                                                    PublishingRajceSession* session,
                                                    const gchar* url)
{
	PublishingRajceCloseAlbumTransaction* self = NULL;
	PublishingRajceLiveApiRequest* req = NULL;
	PublishingRajceLiveApiRequest* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	gchar* _tmp4_;
	gchar* xml = NULL;
	gchar* _tmp5_;
#line 1486 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_val_if_fail (PUBLISHING_RAJCE_IS_SESSION (session), NULL);
#line 1486 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_val_if_fail (url != NULL, NULL);
#line 1488 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self = (PublishingRajceCloseAlbumTransaction*) publishing_rest_support_transaction_construct_with_endpoint_url (object_type, G_TYPE_CHECK_INSTANCE_CAST (session, PUBLISHING_REST_SUPPORT_TYPE_SESSION, PublishingRESTSupportSession), url, PUBLISHING_REST_SUPPORT_HTTP_METHOD_POST);
#line 1489 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp0_ = publishing_rajce_live_api_request_new ("closeAlbum");
#line 1489 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	req = _tmp0_;
#line 1490 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp1_ = publishing_rajce_session_get_usertoken (session);
#line 1490 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp2_ = _tmp1_;
#line 1490 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rajce_live_api_request_AddParam (req, "token", _tmp2_);
#line 1490 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_free0 (_tmp2_);
#line 1491 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp3_ = publishing_rajce_session_get_albumtoken (session);
#line 1491 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp4_ = _tmp3_;
#line 1491 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rajce_live_api_request_AddParam (req, "albumToken", _tmp4_);
#line 1491 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_free0 (_tmp4_);
#line 1492 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp5_ = publishing_rajce_live_api_request_Params2XmlString (req, TRUE);
#line 1492 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	xml = _tmp5_;
#line 1493 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rest_support_transaction_add_argument (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "data", xml);
#line 1486 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_free0 (xml);
#line 1486 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_publishing_rajce_live_api_request_unref0 (req);
#line 1486 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	return self;
#line 11451 "RajcePublishing.c"
}


PublishingRajceCloseAlbumTransaction*
publishing_rajce_close_album_transaction_new (PublishingRajceSession* session,
                                              const gchar* url)
{
#line 1486 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	return publishing_rajce_close_album_transaction_construct (PUBLISHING_RAJCE_TYPE_CLOSE_ALBUM_TRANSACTION, session, url);
#line 11461 "RajcePublishing.c"
}


static void
publishing_rajce_close_album_transaction_class_init (PublishingRajceCloseAlbumTransactionClass * klass)
{
#line 1484 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rajce_close_album_transaction_parent_class = g_type_class_peek_parent (klass);
#line 11470 "RajcePublishing.c"
}


static void
publishing_rajce_close_album_transaction_instance_init (PublishingRajceCloseAlbumTransaction * self)
{
}


/**
 * Transaction used to implement the close album interaction.
 */
GType
publishing_rajce_close_album_transaction_get_type (void)
{
	static volatile gsize publishing_rajce_close_album_transaction_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_rajce_close_album_transaction_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingRajceCloseAlbumTransactionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_rajce_close_album_transaction_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingRajceCloseAlbumTransaction), 0, (GInstanceInitFunc) publishing_rajce_close_album_transaction_instance_init, NULL };
		GType publishing_rajce_close_album_transaction_type_id;
		publishing_rajce_close_album_transaction_type_id = g_type_register_static (PUBLISHING_RAJCE_TYPE_TRANSACTION, "PublishingRajceCloseAlbumTransaction", &g_define_type_info, 0);
		g_once_init_leave (&publishing_rajce_close_album_transaction_type_id__volatile, publishing_rajce_close_album_transaction_type_id);
	}
	return publishing_rajce_close_album_transaction_type_id__volatile;
}


PublishingRajceGetCategoriesTransaction*
publishing_rajce_get_categories_transaction_construct (GType object_type,
                                                       PublishingRajceSession* session,
                                                       const gchar* url)
{
	PublishingRajceGetCategoriesTransaction* self = NULL;
	PublishingRajceLiveApiRequest* req = NULL;
	PublishingRajceLiveApiRequest* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* xml = NULL;
	gchar* _tmp3_;
#line 1502 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_val_if_fail (PUBLISHING_RAJCE_IS_SESSION (session), NULL);
#line 1502 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_val_if_fail (url != NULL, NULL);
#line 1504 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self = (PublishingRajceGetCategoriesTransaction*) publishing_rest_support_transaction_construct_with_endpoint_url (object_type, G_TYPE_CHECK_INSTANCE_CAST (session, PUBLISHING_REST_SUPPORT_TYPE_SESSION, PublishingRESTSupportSession), url, PUBLISHING_REST_SUPPORT_HTTP_METHOD_POST);
#line 1505 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp0_ = publishing_rajce_live_api_request_new ("getCategories");
#line 1505 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	req = _tmp0_;
#line 1506 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp1_ = publishing_rajce_session_get_usertoken (session);
#line 1506 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp2_ = _tmp1_;
#line 1506 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rajce_live_api_request_AddParam (req, "token", _tmp2_);
#line 1506 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_free0 (_tmp2_);
#line 1507 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp3_ = publishing_rajce_live_api_request_Params2XmlString (req, TRUE);
#line 1507 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	xml = _tmp3_;
#line 1508 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rest_support_transaction_add_argument (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "data", xml);
#line 1502 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_free0 (xml);
#line 1502 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_publishing_rajce_live_api_request_unref0 (req);
#line 1502 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	return self;
#line 11539 "RajcePublishing.c"
}


PublishingRajceGetCategoriesTransaction*
publishing_rajce_get_categories_transaction_new (PublishingRajceSession* session,
                                                 const gchar* url)
{
#line 1502 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	return publishing_rajce_get_categories_transaction_construct (PUBLISHING_RAJCE_TYPE_GET_CATEGORIES_TRANSACTION, session, url);
#line 11549 "RajcePublishing.c"
}


static void
publishing_rajce_get_categories_transaction_class_init (PublishingRajceGetCategoriesTransactionClass * klass)
{
#line 1500 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rajce_get_categories_transaction_parent_class = g_type_class_peek_parent (klass);
#line 11558 "RajcePublishing.c"
}


static void
publishing_rajce_get_categories_transaction_instance_init (PublishingRajceGetCategoriesTransaction * self)
{
}


/**
 * Transaction used to implement the get categories interaction.
 */
GType
publishing_rajce_get_categories_transaction_get_type (void)
{
	static volatile gsize publishing_rajce_get_categories_transaction_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_rajce_get_categories_transaction_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingRajceGetCategoriesTransactionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_rajce_get_categories_transaction_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingRajceGetCategoriesTransaction), 0, (GInstanceInitFunc) publishing_rajce_get_categories_transaction_instance_init, NULL };
		GType publishing_rajce_get_categories_transaction_type_id;
		publishing_rajce_get_categories_transaction_type_id = g_type_register_static (PUBLISHING_RAJCE_TYPE_TRANSACTION, "PublishingRajceGetCategoriesTransaction", &g_define_type_info, 0);
		g_once_init_leave (&publishing_rajce_get_categories_transaction_type_id__volatile, publishing_rajce_get_categories_transaction_type_id);
	}
	return publishing_rajce_get_categories_transaction_type_id__volatile;
}


static void
_g_free0_ (gpointer var)
{
#line 1544 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	var = (g_free (var), NULL);
#line 11590 "RajcePublishing.c"
}


PublishingRajceAddPhotoTransaction*
publishing_rajce_add_photo_transaction_construct (GType object_type,
                                                  PublishingRajceSession* session,
                                                  const gchar* url,
                                                  PublishingRajcePublishingParameters* parameters,
                                                  SpitPublishingPublishable* publishable)
{
	PublishingRajceAddPhotoTransaction* self = NULL;
	PublishingRajcePublishingParameters* _tmp0_;
	const gchar* _tmp1_ = NULL;
	gint* _tmp2_;
	GFile* _tmp3_;
	GFile* _tmp4_;
	gchar* _tmp5_;
	gchar* _tmp6_;
	const gchar* _tmp7_;
	gchar* basename = NULL;
	gchar* _tmp8_;
	gchar* comment = NULL;
	gchar* _tmp9_;
	gchar* pubname = NULL;
	gchar* _tmp10_;
	gint width = 0;
	gint height = 0;
	PublishingRajceLiveApiRequest* req = NULL;
	PublishingRajceLiveApiRequest* _tmp11_;
	PublishingRajceLiveApiRequest* _tmp12_;
	gchar* _tmp13_;
	gchar* _tmp14_;
	PublishingRajceLiveApiRequest* _tmp15_;
	gint _tmp16_;
	PublishingRajceLiveApiRequest* _tmp17_;
	gint _tmp18_;
	PublishingRajceLiveApiRequest* _tmp19_;
	gchar* _tmp20_;
	gchar* _tmp21_;
	PublishingRajceLiveApiRequest* _tmp22_;
	const gchar* _tmp23_;
	PublishingRajceLiveApiRequest* _tmp24_;
	const gchar* _tmp25_;
	const gchar* _tmp26_ = NULL;
	const gchar* _tmp27_;
	PublishingRajceLiveApiRequest* _tmp29_;
	gchar* xml = NULL;
	PublishingRajceLiveApiRequest* _tmp30_;
	gchar* _tmp31_;
	GHashTable* disposition_table = NULL;
	GHashFunc _tmp32_;
	GEqualFunc _tmp33_;
	GHashTable* _tmp34_;
	gchar* _tmp35_;
	gchar* _tmp36_;
	gchar* _tmp37_;
	const gchar* _tmp38_;
	gchar* _tmp39_;
#line 1519 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_val_if_fail (PUBLISHING_RAJCE_IS_SESSION (session), NULL);
#line 1519 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_val_if_fail (url != NULL, NULL);
#line 1519 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_val_if_fail (PUBLISHING_RAJCE_IS_PUBLISHING_PARAMETERS (parameters), NULL);
#line 1519 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_return_val_if_fail (SPIT_PUBLISHING_IS_PUBLISHABLE (publishable), NULL);
#line 1521 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self = (PublishingRajceAddPhotoTransaction*) publishing_rest_support_upload_transaction_construct_with_endpoint_url (object_type, G_TYPE_CHECK_INSTANCE_CAST (session, PUBLISHING_REST_SUPPORT_TYPE_SESSION, PublishingRESTSupportSession), publishable, url);
#line 1522 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp0_ = _publishing_rajce_publishing_parameters_ref0 (parameters);
#line 1522 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_publishing_rajce_publishing_parameters_unref0 (self->priv->parameters);
#line 1522 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self->priv->parameters = _tmp0_;
#line 1524 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp2_ = parameters->album_id;
#line 1524 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	if ((*_tmp2_) > 0) {
#line 1524 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp1_ = "";
#line 11671 "RajcePublishing.c"
	} else {
#line 1524 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp1_ = " new";
#line 11675 "RajcePublishing.c"
	}
#line 1524 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp3_ = spit_publishing_publishable_get_serialized_file (publishable);
#line 1524 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp4_ = _tmp3_;
#line 1524 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp5_ = g_file_get_basename (_tmp4_);
#line 1524 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp6_ = _tmp5_;
#line 1524 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp7_ = parameters->album_name;
#line 1524 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_debug ("RajcePublishing.vala:1524: RajcePlugin: Uploading photo %s to%s album " \
"%s", _tmp6_, _tmp1_, _tmp7_);
#line 1524 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_free0 (_tmp6_);
#line 1524 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_object_unref0 (_tmp4_);
#line 1526 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp8_ = spit_publishing_publishable_get_param_string (publishable, SPIT_PUBLISHING_PUBLISHABLE_PARAM_STRING_BASENAME);
#line 1526 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	basename = _tmp8_;
#line 1527 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp9_ = spit_publishing_publishable_get_param_string (publishable, SPIT_PUBLISHING_PUBLISHABLE_PARAM_STRING_COMMENT);
#line 1527 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	comment = _tmp9_;
#line 1528 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp10_ = spit_publishing_publishable_get_publishing_name (publishable);
#line 1528 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	pubname = _tmp10_;
#line 1530 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	width = publishing_rajce_session_get_maxsize (session);
#line 1531 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	height = publishing_rajce_session_get_maxsize (session);
#line 1533 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp11_ = publishing_rajce_live_api_request_new ("addPhoto");
#line 1533 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	req = _tmp11_;
#line 1534 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp12_ = req;
#line 1534 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp13_ = publishing_rajce_session_get_usertoken (session);
#line 1534 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp14_ = _tmp13_;
#line 1534 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rajce_live_api_request_AddParam (_tmp12_, "token", _tmp14_);
#line 1534 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_free0 (_tmp14_);
#line 1535 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp15_ = req;
#line 1535 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp16_ = width;
#line 1535 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rajce_live_api_request_AddParamInt (_tmp15_, "width", _tmp16_);
#line 1536 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp17_ = req;
#line 1536 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp18_ = height;
#line 1536 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rajce_live_api_request_AddParamInt (_tmp17_, "height", _tmp18_);
#line 1537 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp19_ = req;
#line 1537 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp20_ = publishing_rajce_session_get_albumtoken (session);
#line 1537 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp21_ = _tmp20_;
#line 1537 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rajce_live_api_request_AddParam (_tmp19_, "albumToken", _tmp21_);
#line 1537 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_free0 (_tmp21_);
#line 1538 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp22_ = req;
#line 1538 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp23_ = pubname;
#line 1538 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rajce_live_api_request_AddParam (_tmp22_, "photoName", _tmp23_);
#line 1539 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp24_ = req;
#line 1539 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp25_ = basename;
#line 1539 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rajce_live_api_request_AddParam (_tmp24_, "fullFileName", _tmp25_);
#line 1540 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp27_ = comment;
#line 1540 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	if (_tmp27_ != NULL) {
#line 11761 "RajcePublishing.c"
		const gchar* _tmp28_;
#line 1540 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp28_ = comment;
#line 1540 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp26_ = _tmp28_;
#line 11767 "RajcePublishing.c"
	} else {
#line 1540 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
		_tmp26_ = "";
#line 11771 "RajcePublishing.c"
	}
#line 1540 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp29_ = req;
#line 1540 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rajce_live_api_request_AddParam (_tmp29_, "description", _tmp26_);
#line 1541 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp30_ = req;
#line 1541 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp31_ = publishing_rajce_live_api_request_Params2XmlString (_tmp30_, FALSE);
#line 1541 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	xml = _tmp31_;
#line 1542 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rest_support_transaction_add_argument (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "data", xml);
#line 1544 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp32_ = g_str_hash;
#line 1544 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp33_ = g_str_equal;
#line 1544 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp34_ = g_hash_table_new_full (_tmp32_, _tmp33_, _g_free0_, _g_free0_);
#line 1544 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	disposition_table = _tmp34_;
#line 1545 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp35_ = g_strdup ("name");
#line 1545 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp36_ = g_strdup ("photo");
#line 1545 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_hash_table_insert (disposition_table, _tmp35_, _tmp36_);
#line 1546 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp37_ = g_strdup ("filename");
#line 1546 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp38_ = basename;
#line 1546 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_tmp39_ = soup_uri_encode (_tmp38_, NULL);
#line 1546 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_hash_table_insert (disposition_table, _tmp37_, _tmp39_);
#line 1547 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rest_support_upload_transaction_set_binary_disposition_table (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_UPLOAD_TRANSACTION, PublishingRESTSupportUploadTransaction), disposition_table);
#line 1519 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_hash_table_unref0 (disposition_table);
#line 1519 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_free0 (xml);
#line 1519 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_publishing_rajce_live_api_request_unref0 (req);
#line 1519 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_free0 (pubname);
#line 1519 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_free0 (comment);
#line 1519 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_g_free0 (basename);
#line 1519 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	return self;
#line 11823 "RajcePublishing.c"
}


PublishingRajceAddPhotoTransaction*
publishing_rajce_add_photo_transaction_new (PublishingRajceSession* session,
                                            const gchar* url,
                                            PublishingRajcePublishingParameters* parameters,
                                            SpitPublishingPublishable* publishable)
{
#line 1519 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	return publishing_rajce_add_photo_transaction_construct (PUBLISHING_RAJCE_TYPE_ADD_PHOTO_TRANSACTION, session, url, parameters, publishable);
#line 11835 "RajcePublishing.c"
}


static void
publishing_rajce_add_photo_transaction_class_init (PublishingRajceAddPhotoTransactionClass * klass)
{
#line 1515 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	publishing_rajce_add_photo_transaction_parent_class = g_type_class_peek_parent (klass);
#line 1515 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	((PublishingRESTSupportTransactionClass *) klass)->finalize = publishing_rajce_add_photo_transaction_finalize;
#line 1515 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	g_type_class_add_private (klass, sizeof (PublishingRajceAddPhotoTransactionPrivate));
#line 11848 "RajcePublishing.c"
}


static void
publishing_rajce_add_photo_transaction_instance_init (PublishingRajceAddPhotoTransaction * self)
{
#line 1515 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self->priv = PUBLISHING_RAJCE_ADD_PHOTO_TRANSACTION_GET_PRIVATE (self);
#line 1517 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self->priv->parameters = NULL;
#line 11859 "RajcePublishing.c"
}


static void
publishing_rajce_add_photo_transaction_finalize (PublishingRESTSupportTransaction * obj)
{
	PublishingRajceAddPhotoTransaction * self;
#line 1515 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_RAJCE_TYPE_ADD_PHOTO_TRANSACTION, PublishingRajceAddPhotoTransaction);
#line 1517 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	_publishing_rajce_publishing_parameters_unref0 (self->priv->parameters);
#line 1515 "/home/jens/Source/shotwell/plugins/shotwell-publishing-extras/RajcePublishing.vala"
	PUBLISHING_REST_SUPPORT_TRANSACTION_CLASS (publishing_rajce_add_photo_transaction_parent_class)->finalize (obj);
#line 11873 "RajcePublishing.c"
}


/**
 * Transaction used to implement the upload photo.
 */
GType
publishing_rajce_add_photo_transaction_get_type (void)
{
	static volatile gsize publishing_rajce_add_photo_transaction_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_rajce_add_photo_transaction_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingRajceAddPhotoTransactionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_rajce_add_photo_transaction_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingRajceAddPhotoTransaction), 0, (GInstanceInitFunc) publishing_rajce_add_photo_transaction_instance_init, NULL };
		GType publishing_rajce_add_photo_transaction_type_id;
		publishing_rajce_add_photo_transaction_type_id = g_type_register_static (PUBLISHING_REST_SUPPORT_TYPE_UPLOAD_TRANSACTION, "PublishingRajceAddPhotoTransaction", &g_define_type_info, 0);
		g_once_init_leave (&publishing_rajce_add_photo_transaction_type_id__volatile, publishing_rajce_add_photo_transaction_type_id);
	}
	return publishing_rajce_add_photo_transaction_type_id__volatile;
}


static void
_vala_array_destroy (gpointer array,
                     gint array_length,
                     GDestroyNotify destroy_func)
{
	if ((array != NULL) && (destroy_func != NULL)) {
		int i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}


static void
_vala_array_free (gpointer array,
                  gint array_length,
                  GDestroyNotify destroy_func)
{
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}



