/* Tree.c generated by valac 0.40.4, the Vala compiler
 * generated from Tree.vala, do not modify */

/* Copyright 2016 Software Freedom Conservancy Inc.
 *
 * This software is licensed under the GNU Lesser General Public License
 * (version 2.1 or later).  See the COPYING file in this distribution.
 */


#include <glib.h>
#include <glib-object.h>
#include <gtk/gtk.h>
#include <gdk/gdk.h>
#include <stdlib.h>
#include <string.h>
#include <gee.h>
#include <gio/gio.h>
#include <pango/pango.h>
#include <float.h>
#include <math.h>


#define SIDEBAR_TYPE_TREE (sidebar_tree_get_type ())
#define SIDEBAR_TREE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SIDEBAR_TYPE_TREE, SidebarTree))
#define SIDEBAR_TREE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SIDEBAR_TYPE_TREE, SidebarTreeClass))
#define SIDEBAR_IS_TREE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SIDEBAR_TYPE_TREE))
#define SIDEBAR_IS_TREE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SIDEBAR_TYPE_TREE))
#define SIDEBAR_TREE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SIDEBAR_TYPE_TREE, SidebarTreeClass))

typedef struct _SidebarTree SidebarTree;
typedef struct _SidebarTreeClass SidebarTreeClass;
typedef struct _SidebarTreePrivate SidebarTreePrivate;

#define SIDEBAR_TYPE_ENTRY (sidebar_entry_get_type ())
#define SIDEBAR_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SIDEBAR_TYPE_ENTRY, SidebarEntry))
#define SIDEBAR_IS_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SIDEBAR_TYPE_ENTRY))
#define SIDEBAR_ENTRY_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), SIDEBAR_TYPE_ENTRY, SidebarEntryIface))

typedef struct _SidebarEntry SidebarEntry;
typedef struct _SidebarEntryIface SidebarEntryIface;

#define SIDEBAR_TREE_TYPE_ENTRY_WRAPPER (sidebar_tree_entry_wrapper_get_type ())
#define SIDEBAR_TREE_ENTRY_WRAPPER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SIDEBAR_TREE_TYPE_ENTRY_WRAPPER, SidebarTreeEntryWrapper))
#define SIDEBAR_TREE_ENTRY_WRAPPER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SIDEBAR_TREE_TYPE_ENTRY_WRAPPER, SidebarTreeEntryWrapperClass))
#define SIDEBAR_TREE_IS_ENTRY_WRAPPER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SIDEBAR_TREE_TYPE_ENTRY_WRAPPER))
#define SIDEBAR_TREE_IS_ENTRY_WRAPPER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SIDEBAR_TREE_TYPE_ENTRY_WRAPPER))
#define SIDEBAR_TREE_ENTRY_WRAPPER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SIDEBAR_TREE_TYPE_ENTRY_WRAPPER, SidebarTreeEntryWrapperClass))

typedef struct _SidebarTreeEntryWrapper SidebarTreeEntryWrapper;
typedef struct _SidebarTreeEntryWrapperClass SidebarTreeEntryWrapperClass;

#define SIDEBAR_TYPE_BRANCH (sidebar_branch_get_type ())
#define SIDEBAR_BRANCH(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SIDEBAR_TYPE_BRANCH, SidebarBranch))
#define SIDEBAR_BRANCH_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SIDEBAR_TYPE_BRANCH, SidebarBranchClass))
#define SIDEBAR_IS_BRANCH(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SIDEBAR_TYPE_BRANCH))
#define SIDEBAR_IS_BRANCH_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SIDEBAR_TYPE_BRANCH))
#define SIDEBAR_BRANCH_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SIDEBAR_TYPE_BRANCH, SidebarBranchClass))

typedef struct _SidebarBranch SidebarBranch;
typedef struct _SidebarBranchClass SidebarBranchClass;
enum  {
	SIDEBAR_TREE_0_PROPERTY,
	SIDEBAR_TREE_NUM_PROPERTIES
};
static GParamSpec* sidebar_tree_properties[SIDEBAR_TREE_NUM_PROPERTIES];

#define SIDEBAR_TREE_TYPE_COLUMNS (sidebar_tree_columns_get_type ())
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define __vala_GtkTreeRowReference_free0(var) ((var == NULL) ? NULL : (var = (_vala_GtkTreeRowReference_free (var), NULL)))

#define LIBRARY_WINDOW_TYPE_TARGET_TYPE (library_window_target_type_get_type ())
typedef struct _SidebarTreeEntryWrapperPrivate SidebarTreeEntryWrapperPrivate;

#define SIDEBAR_TYPE_GROUPING (sidebar_grouping_get_type ())
#define SIDEBAR_GROUPING(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SIDEBAR_TYPE_GROUPING, SidebarGrouping))
#define SIDEBAR_GROUPING_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SIDEBAR_TYPE_GROUPING, SidebarGroupingClass))
#define SIDEBAR_IS_GROUPING(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SIDEBAR_TYPE_GROUPING))
#define SIDEBAR_IS_GROUPING_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SIDEBAR_TYPE_GROUPING))
#define SIDEBAR_GROUPING_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SIDEBAR_TYPE_GROUPING, SidebarGroupingClass))

typedef struct _SidebarGrouping SidebarGrouping;
typedef struct _SidebarGroupingClass SidebarGroupingClass;

#define SIDEBAR_TYPE_HEADER (sidebar_header_get_type ())
#define SIDEBAR_HEADER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SIDEBAR_TYPE_HEADER, SidebarHeader))
#define SIDEBAR_HEADER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SIDEBAR_TYPE_HEADER, SidebarHeaderClass))
#define SIDEBAR_IS_HEADER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SIDEBAR_TYPE_HEADER))
#define SIDEBAR_IS_HEADER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SIDEBAR_TYPE_HEADER))
#define SIDEBAR_HEADER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SIDEBAR_TYPE_HEADER, SidebarHeaderClass))

typedef struct _SidebarHeader SidebarHeader;
typedef struct _SidebarHeaderClass SidebarHeaderClass;
#define __vala_GtkTreePath_free0(var) ((var == NULL) ? NULL : (var = (_vala_GtkTreePath_free (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))

#define TYPE_APPLICATION (application_get_type ())
#define APPLICATION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_APPLICATION, Application))
#define APPLICATION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_APPLICATION, ApplicationClass))
#define IS_APPLICATION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_APPLICATION))
#define IS_APPLICATION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_APPLICATION))
#define APPLICATION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_APPLICATION, ApplicationClass))

typedef struct _Application Application;
typedef struct _ApplicationClass ApplicationClass;
#define _application_unref0(var) ((var == NULL) ? NULL : (var = (application_unref (var), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
#define __g_list_free___vala_GtkTreePath_free0_0(var) ((var == NULL) ? NULL : (var = (_g_list_free___vala_GtkTreePath_free0_ (var), NULL)))

#define SIDEBAR_TYPE_EMPHASIZABLE_ENTRY (sidebar_emphasizable_entry_get_type ())
#define SIDEBAR_EMPHASIZABLE_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SIDEBAR_TYPE_EMPHASIZABLE_ENTRY, SidebarEmphasizableEntry))
#define SIDEBAR_IS_EMPHASIZABLE_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SIDEBAR_TYPE_EMPHASIZABLE_ENTRY))
#define SIDEBAR_EMPHASIZABLE_ENTRY_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), SIDEBAR_TYPE_EMPHASIZABLE_ENTRY, SidebarEmphasizableEntryIface))

typedef struct _SidebarEmphasizableEntry SidebarEmphasizableEntry;
typedef struct _SidebarEmphasizableEntryIface SidebarEmphasizableEntryIface;

#define SIDEBAR_TYPE_RENAMEABLE_ENTRY (sidebar_renameable_entry_get_type ())
#define SIDEBAR_RENAMEABLE_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SIDEBAR_TYPE_RENAMEABLE_ENTRY, SidebarRenameableEntry))
#define SIDEBAR_IS_RENAMEABLE_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SIDEBAR_TYPE_RENAMEABLE_ENTRY))
#define SIDEBAR_RENAMEABLE_ENTRY_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), SIDEBAR_TYPE_RENAMEABLE_ENTRY, SidebarRenameableEntryIface))

typedef struct _SidebarRenameableEntry SidebarRenameableEntry;
typedef struct _SidebarRenameableEntryIface SidebarRenameableEntryIface;

#define SIDEBAR_TYPE_SELECTABLE_ENTRY (sidebar_selectable_entry_get_type ())
#define SIDEBAR_SELECTABLE_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SIDEBAR_TYPE_SELECTABLE_ENTRY, SidebarSelectableEntry))
#define SIDEBAR_IS_SELECTABLE_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SIDEBAR_TYPE_SELECTABLE_ENTRY))
#define SIDEBAR_SELECTABLE_ENTRY_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), SIDEBAR_TYPE_SELECTABLE_ENTRY, SidebarSelectableEntryIface))

typedef struct _SidebarSelectableEntry SidebarSelectableEntry;
typedef struct _SidebarSelectableEntryIface SidebarSelectableEntryIface;

#define SIDEBAR_TREE_TYPE_ROOT_WRAPPER (sidebar_tree_root_wrapper_get_type ())
#define SIDEBAR_TREE_ROOT_WRAPPER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SIDEBAR_TREE_TYPE_ROOT_WRAPPER, SidebarTreeRootWrapper))
#define SIDEBAR_TREE_ROOT_WRAPPER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SIDEBAR_TREE_TYPE_ROOT_WRAPPER, SidebarTreeRootWrapperClass))
#define SIDEBAR_TREE_IS_ROOT_WRAPPER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SIDEBAR_TREE_TYPE_ROOT_WRAPPER))
#define SIDEBAR_TREE_IS_ROOT_WRAPPER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SIDEBAR_TREE_TYPE_ROOT_WRAPPER))
#define SIDEBAR_TREE_ROOT_WRAPPER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SIDEBAR_TREE_TYPE_ROOT_WRAPPER, SidebarTreeRootWrapperClass))

typedef struct _SidebarTreeRootWrapper SidebarTreeRootWrapper;
typedef struct _SidebarTreeRootWrapperClass SidebarTreeRootWrapperClass;
typedef struct _SidebarTreeRootWrapperPrivate SidebarTreeRootWrapperPrivate;

#define SIDEBAR_TYPE_PAGE_REPRESENTATIVE (sidebar_page_representative_get_type ())
#define SIDEBAR_PAGE_REPRESENTATIVE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SIDEBAR_TYPE_PAGE_REPRESENTATIVE, SidebarPageRepresentative))
#define SIDEBAR_IS_PAGE_REPRESENTATIVE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SIDEBAR_TYPE_PAGE_REPRESENTATIVE))
#define SIDEBAR_PAGE_REPRESENTATIVE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), SIDEBAR_TYPE_PAGE_REPRESENTATIVE, SidebarPageRepresentativeIface))

typedef struct _SidebarPageRepresentative SidebarPageRepresentative;
typedef struct _SidebarPageRepresentativeIface SidebarPageRepresentativeIface;

#define TYPE_PAGE (page_get_type ())
#define PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PAGE, Page))
#define PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PAGE, PageClass))
#define IS_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PAGE))
#define IS_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PAGE))
#define PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PAGE, PageClass))

typedef struct _Page Page;
typedef struct _PageClass PageClass;

#define SIDEBAR_TYPE_CONTEXTABLE (sidebar_contextable_get_type ())
#define SIDEBAR_CONTEXTABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SIDEBAR_TYPE_CONTEXTABLE, SidebarContextable))
#define SIDEBAR_IS_CONTEXTABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SIDEBAR_TYPE_CONTEXTABLE))
#define SIDEBAR_CONTEXTABLE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), SIDEBAR_TYPE_CONTEXTABLE, SidebarContextableIface))

typedef struct _SidebarContextable SidebarContextable;
typedef struct _SidebarContextableIface SidebarContextableIface;

#define SIDEBAR_TYPE_EXPANDABLE_ENTRY (sidebar_expandable_entry_get_type ())
#define SIDEBAR_EXPANDABLE_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SIDEBAR_TYPE_EXPANDABLE_ENTRY, SidebarExpandableEntry))
#define SIDEBAR_IS_EXPANDABLE_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SIDEBAR_TYPE_EXPANDABLE_ENTRY))
#define SIDEBAR_EXPANDABLE_ENTRY_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), SIDEBAR_TYPE_EXPANDABLE_ENTRY, SidebarExpandableEntryIface))

typedef struct _SidebarExpandableEntry SidebarExpandableEntry;
typedef struct _SidebarExpandableEntryIface SidebarExpandableEntryIface;

#define SIDEBAR_TYPE_INTERNAL_DROP_TARGET_ENTRY (sidebar_internal_drop_target_entry_get_type ())
#define SIDEBAR_INTERNAL_DROP_TARGET_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SIDEBAR_TYPE_INTERNAL_DROP_TARGET_ENTRY, SidebarInternalDropTargetEntry))
#define SIDEBAR_IS_INTERNAL_DROP_TARGET_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SIDEBAR_TYPE_INTERNAL_DROP_TARGET_ENTRY))
#define SIDEBAR_INTERNAL_DROP_TARGET_ENTRY_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), SIDEBAR_TYPE_INTERNAL_DROP_TARGET_ENTRY, SidebarInternalDropTargetEntryIface))

typedef struct _SidebarInternalDropTargetEntry SidebarInternalDropTargetEntry;
typedef struct _SidebarInternalDropTargetEntryIface SidebarInternalDropTargetEntryIface;

#define TYPE_DATA_OBJECT (data_object_get_type ())
#define DATA_OBJECT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DATA_OBJECT, DataObject))
#define DATA_OBJECT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DATA_OBJECT, DataObjectClass))
#define IS_DATA_OBJECT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DATA_OBJECT))
#define IS_DATA_OBJECT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DATA_OBJECT))
#define DATA_OBJECT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DATA_OBJECT, DataObjectClass))

typedef struct _DataObject DataObject;
typedef struct _DataObjectClass DataObjectClass;

#define TYPE_DATA_SOURCE (data_source_get_type ())
#define DATA_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DATA_SOURCE, DataSource))
#define DATA_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DATA_SOURCE, DataSourceClass))
#define IS_DATA_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DATA_SOURCE))
#define IS_DATA_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DATA_SOURCE))
#define DATA_SOURCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DATA_SOURCE, DataSourceClass))

typedef struct _DataSource DataSource;
typedef struct _DataSourceClass DataSourceClass;

#define TYPE_THUMBNAIL_SOURCE (thumbnail_source_get_type ())
#define THUMBNAIL_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_THUMBNAIL_SOURCE, ThumbnailSource))
#define THUMBNAIL_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_THUMBNAIL_SOURCE, ThumbnailSourceClass))
#define IS_THUMBNAIL_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_THUMBNAIL_SOURCE))
#define IS_THUMBNAIL_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_THUMBNAIL_SOURCE))
#define THUMBNAIL_SOURCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_THUMBNAIL_SOURCE, ThumbnailSourceClass))

typedef struct _ThumbnailSource ThumbnailSource;
typedef struct _ThumbnailSourceClass ThumbnailSourceClass;

#define TYPE_MEDIA_SOURCE (media_source_get_type ())
#define MEDIA_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_MEDIA_SOURCE, MediaSource))
#define MEDIA_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_MEDIA_SOURCE, MediaSourceClass))
#define IS_MEDIA_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_MEDIA_SOURCE))
#define IS_MEDIA_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_MEDIA_SOURCE))
#define MEDIA_SOURCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_MEDIA_SOURCE, MediaSourceClass))

typedef struct _MediaSource MediaSource;
typedef struct _MediaSourceClass MediaSourceClass;

#define SIDEBAR_TYPE_INTERNAL_DRAG_SOURCE_ENTRY (sidebar_internal_drag_source_entry_get_type ())
#define SIDEBAR_INTERNAL_DRAG_SOURCE_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SIDEBAR_TYPE_INTERNAL_DRAG_SOURCE_ENTRY, SidebarInternalDragSourceEntry))
#define SIDEBAR_IS_INTERNAL_DRAG_SOURCE_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SIDEBAR_TYPE_INTERNAL_DRAG_SOURCE_ENTRY))
#define SIDEBAR_INTERNAL_DRAG_SOURCE_ENTRY_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), SIDEBAR_TYPE_INTERNAL_DRAG_SOURCE_ENTRY, SidebarInternalDragSourceEntryIface))

typedef struct _SidebarInternalDragSourceEntry SidebarInternalDragSourceEntry;
typedef struct _SidebarInternalDragSourceEntryIface SidebarInternalDragSourceEntryIface;

#define SIDEBAR_TYPE_DESTROYABLE_ENTRY (sidebar_destroyable_entry_get_type ())
#define SIDEBAR_DESTROYABLE_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SIDEBAR_TYPE_DESTROYABLE_ENTRY, SidebarDestroyableEntry))
#define SIDEBAR_IS_DESTROYABLE_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SIDEBAR_TYPE_DESTROYABLE_ENTRY))
#define SIDEBAR_DESTROYABLE_ENTRY_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), SIDEBAR_TYPE_DESTROYABLE_ENTRY, SidebarDestroyableEntryIface))

typedef struct _SidebarDestroyableEntry SidebarDestroyableEntry;
typedef struct _SidebarDestroyableEntryIface SidebarDestroyableEntryIface;

#define TYPE_SAVED_SEARCH_DIALOG (saved_search_dialog_get_type ())
#define SAVED_SEARCH_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SAVED_SEARCH_DIALOG, SavedSearchDialog))
#define SAVED_SEARCH_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SAVED_SEARCH_DIALOG, SavedSearchDialogClass))
#define IS_SAVED_SEARCH_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SAVED_SEARCH_DIALOG))
#define IS_SAVED_SEARCH_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SAVED_SEARCH_DIALOG))
#define SAVED_SEARCH_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SAVED_SEARCH_DIALOG, SavedSearchDialogClass))

typedef struct _SavedSearchDialog SavedSearchDialog;
typedef struct _SavedSearchDialogClass SavedSearchDialogClass;

#define TYPE_COMMAND (command_get_type ())
#define COMMAND(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_COMMAND, Command))
#define COMMAND_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_COMMAND, CommandClass))
#define IS_COMMAND(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_COMMAND))
#define IS_COMMAND_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_COMMAND))
#define COMMAND_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_COMMAND, CommandClass))

typedef struct _Command Command;
typedef struct _CommandClass CommandClass;

#define TYPE_PAGE_COMMAND (page_command_get_type ())
#define PAGE_COMMAND(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PAGE_COMMAND, PageCommand))
#define PAGE_COMMAND_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PAGE_COMMAND, PageCommandClass))
#define IS_PAGE_COMMAND(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PAGE_COMMAND))
#define IS_PAGE_COMMAND_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PAGE_COMMAND))
#define PAGE_COMMAND_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PAGE_COMMAND, PageCommandClass))

typedef struct _PageCommand PageCommand;
typedef struct _PageCommandClass PageCommandClass;

#define TYPE_NEW_ROOT_TAG_COMMAND (new_root_tag_command_get_type ())
#define NEW_ROOT_TAG_COMMAND(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_NEW_ROOT_TAG_COMMAND, NewRootTagCommand))
#define NEW_ROOT_TAG_COMMAND_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_NEW_ROOT_TAG_COMMAND, NewRootTagCommandClass))
#define IS_NEW_ROOT_TAG_COMMAND(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_NEW_ROOT_TAG_COMMAND))
#define IS_NEW_ROOT_TAG_COMMAND_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_NEW_ROOT_TAG_COMMAND))
#define NEW_ROOT_TAG_COMMAND_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_NEW_ROOT_TAG_COMMAND, NewRootTagCommandClass))

typedef struct _NewRootTagCommand NewRootTagCommand;
typedef struct _NewRootTagCommandClass NewRootTagCommandClass;

#define TYPE_COMMAND_MANAGER (command_manager_get_type ())
#define COMMAND_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_COMMAND_MANAGER, CommandManager))
#define COMMAND_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_COMMAND_MANAGER, CommandManagerClass))
#define IS_COMMAND_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_COMMAND_MANAGER))
#define IS_COMMAND_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_COMMAND_MANAGER))
#define COMMAND_MANAGER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_COMMAND_MANAGER, CommandManagerClass))

typedef struct _CommandManager CommandManager;
typedef struct _CommandManagerClass CommandManagerClass;
#define _command_manager_unref0(var) ((var == NULL) ? NULL : (var = (command_manager_unref (var), NULL)))

#define TYPE_PAGE_WINDOW (page_window_get_type ())
#define PAGE_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PAGE_WINDOW, PageWindow))
#define PAGE_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PAGE_WINDOW, PageWindowClass))
#define IS_PAGE_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PAGE_WINDOW))
#define IS_PAGE_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PAGE_WINDOW))
#define PAGE_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PAGE_WINDOW, PageWindowClass))

typedef struct _PageWindow PageWindow;
typedef struct _PageWindowClass PageWindowClass;

#define TYPE_APP_WINDOW (app_window_get_type ())
#define APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_APP_WINDOW, AppWindow))
#define APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_APP_WINDOW, AppWindowClass))
#define IS_APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_APP_WINDOW))
#define IS_APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_APP_WINDOW))
#define APP_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_APP_WINDOW, AppWindowClass))

typedef struct _AppWindow AppWindow;
typedef struct _AppWindowClass AppWindowClass;

#define TYPE_LIBRARY_WINDOW (library_window_get_type ())
#define LIBRARY_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_LIBRARY_WINDOW, LibraryWindow))
#define LIBRARY_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_LIBRARY_WINDOW, LibraryWindowClass))
#define IS_LIBRARY_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_LIBRARY_WINDOW))
#define IS_LIBRARY_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_LIBRARY_WINDOW))
#define LIBRARY_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_LIBRARY_WINDOW, LibraryWindowClass))

typedef struct _LibraryWindow LibraryWindow;
typedef struct _LibraryWindowClass LibraryWindowClass;

#define TYPE_TAG (tag_get_type ())
#define TAG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_TAG, Tag))
#define TAG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_TAG, TagClass))
#define IS_TAG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_TAG))
#define IS_TAG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_TAG))
#define TAG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_TAG, TagClass))

typedef struct _Tag Tag;
typedef struct _TagClass TagClass;
enum  {
	SIDEBAR_TREE_ENTRY_WRAPPER_0_PROPERTY,
	SIDEBAR_TREE_ENTRY_WRAPPER_NUM_PROPERTIES
};
static GParamSpec* sidebar_tree_entry_wrapper_properties[SIDEBAR_TREE_ENTRY_WRAPPER_NUM_PROPERTIES];
enum  {
	SIDEBAR_TREE_ROOT_WRAPPER_0_PROPERTY,
	SIDEBAR_TREE_ROOT_WRAPPER_NUM_PROPERTIES
};
static GParamSpec* sidebar_tree_root_wrapper_properties[SIDEBAR_TREE_ROOT_WRAPPER_NUM_PROPERTIES];
enum  {
	SIDEBAR_TREE_ENTRY_SELECTED_SIGNAL,
	SIDEBAR_TREE_SELECTED_ENTRY_REMOVED_SIGNAL,
	SIDEBAR_TREE_BRANCH_ADDED_SIGNAL,
	SIDEBAR_TREE_BRANCH_REMOVED_SIGNAL,
	SIDEBAR_TREE_BRANCH_SHOWN_SIGNAL,
	SIDEBAR_TREE_PAGE_CREATED_SIGNAL,
	SIDEBAR_TREE_DESTROYING_PAGE_SIGNAL,
	SIDEBAR_TREE_NUM_SIGNALS
};
static guint sidebar_tree_signals[SIDEBAR_TREE_NUM_SIGNALS] = {0};
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);
#define _vala_return_if_fail(expr, msg) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return; }
#define _vala_return_val_if_fail(expr, msg, val) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return val; }
#define _vala_warn_if_fail(expr, msg) if G_LIKELY (expr) ; else g_warn_message (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _SidebarTree {
	GtkTreeView parent_instance;
	SidebarTreePrivate * priv;
};

struct _SidebarTreeClass {
	GtkTreeViewClass parent_class;
	gboolean (*accept_cursor_changed) (SidebarTree* self);
};

struct _SidebarEntryIface {
	GTypeInterface parent_iface;
	gchar* (*get_sidebar_name) (SidebarEntry* self);
	gchar* (*get_sidebar_tooltip) (SidebarEntry* self);
	gchar* (*get_sidebar_icon) (SidebarEntry* self);
	gchar* (*to_string) (SidebarEntry* self);
	void (*grafted) (SidebarEntry* self, SidebarTree* tree);
	void (*pruned) (SidebarEntry* self, SidebarTree* tree);
};

typedef void (*SidebarTreeExternalDropHandler) (GdkDragContext* context, SidebarEntry* entry, GtkSelectionData* data, guint info, guint time, void* user_data);
struct _SidebarTreePrivate {
	GtkTreeStore* store;
	GtkBuilder* builder;
	GtkCellRendererText* text_renderer;
	SidebarTreeExternalDropHandler drop_handler;
	gpointer drop_handler_target;
	GtkEntry* text_entry;
	GeeHashMap* entry_map;
	GeeHashMap* branches;
	gint editing_disabled;
	gboolean mask_entry_selected_signal;
	SidebarTreeEntryWrapper* selected_wrapper;
	GtkMenu* default_context_menu;
	gboolean expander_called_manually;
	gint expander_special_count;
	gboolean is_internal_drag_in_progress;
	SidebarEntry* internal_drag_source_entry;
	GtkTreeRowReference* old_path_ref;
};

typedef enum  {
	SIDEBAR_TREE_COLUMNS_NAME,
	SIDEBAR_TREE_COLUMNS_TOOLTIP,
	SIDEBAR_TREE_COLUMNS_WRAPPER,
	SIDEBAR_TREE_COLUMNS_ICON,
	SIDEBAR_TREE_COLUMNS_N_COLUMNS
} SidebarTreeColumns;

typedef enum  {
	LIBRARY_WINDOW_TARGET_TYPE_URI_LIST,
	LIBRARY_WINDOW_TARGET_TYPE_MEDIA_LIST,
	LIBRARY_WINDOW_TARGET_TYPE_TAG_PATH
} LibraryWindowTargetType;

struct _SidebarTreeEntryWrapper {
	GObject parent_instance;
	SidebarTreeEntryWrapperPrivate * priv;
	SidebarEntry* entry;
	GtkTreeRowReference* row;
};

struct _SidebarTreeEntryWrapperClass {
	GObjectClass parent_class;
};

struct _SidebarEmphasizableEntryIface {
	GTypeInterface parent_iface;
	gboolean (*is_emphasized) (SidebarEmphasizableEntry* self);
};

struct _SidebarRenameableEntryIface {
	GTypeInterface parent_iface;
	void (*rename) (SidebarRenameableEntry* self, const gchar* new_name);
	gboolean (*is_user_renameable) (SidebarRenameableEntry* self);
};

struct _SidebarSelectableEntryIface {
	GTypeInterface parent_iface;
};

struct _SidebarTreeRootWrapper {
	SidebarTreeEntryWrapper parent_instance;
	SidebarTreeRootWrapperPrivate * priv;
	gint root_position;
};

struct _SidebarTreeRootWrapperClass {
	SidebarTreeEntryWrapperClass parent_class;
};

struct _SidebarPageRepresentativeIface {
	GTypeInterface parent_iface;
	gboolean (*has_page) (SidebarPageRepresentative* self);
	Page* (*get_page) (SidebarPageRepresentative* self);
};

struct _SidebarContextableIface {
	GTypeInterface parent_iface;
	GtkMenu* (*get_sidebar_context_menu) (SidebarContextable* self, GdkEventButton* event);
};

struct _SidebarExpandableEntryIface {
	GTypeInterface parent_iface;
	gboolean (*expand_on_select) (SidebarExpandableEntry* self);
};

struct _SidebarInternalDropTargetEntryIface {
	GTypeInterface parent_iface;
	gboolean (*internal_drop_received) (SidebarInternalDropTargetEntry* self, GeeList* sources);
	gboolean (*internal_drop_received_arbitrary) (SidebarInternalDropTargetEntry* self, GtkSelectionData* data);
};

struct _SidebarInternalDragSourceEntryIface {
	GTypeInterface parent_iface;
	void (*prepare_selection_data) (SidebarInternalDragSourceEntry* self, GtkSelectionData* data);
};

struct _SidebarDestroyableEntryIface {
	GTypeInterface parent_iface;
	void (*destroy_source) (SidebarDestroyableEntry* self);
};


static gpointer sidebar_tree_parent_class = NULL;
static gpointer sidebar_tree_entry_wrapper_parent_class = NULL;
static gpointer sidebar_tree_root_wrapper_parent_class = NULL;

GType sidebar_tree_get_type (void) G_GNUC_CONST;
GType sidebar_entry_get_type (void) G_GNUC_CONST;
static GType sidebar_tree_entry_wrapper_get_type (void) G_GNUC_CONST G_GNUC_UNUSED;
GType sidebar_branch_get_type (void) G_GNUC_CONST;
#define SIDEBAR_TREE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), SIDEBAR_TYPE_TREE, SidebarTreePrivate))
static void sidebar_tree_on_editing_canceled (SidebarTree* self);
static void _sidebar_tree_on_editing_canceled_gtk_cell_renderer_editing_canceled (GtkCellRenderer* _sender,
                                                                           gpointer self);
static void sidebar_tree_on_editing_started (SidebarTree* self,
                                      GtkCellEditable* editable,
                                      const gchar* path);
static void _sidebar_tree_on_editing_started_gtk_cell_renderer_editing_started (GtkCellRenderer* _sender,
                                                                         GtkCellEditable* editable,
                                                                         const gchar* path,
                                                                         gpointer self);
static GType sidebar_tree_columns_get_type (void) G_GNUC_CONST G_GNUC_UNUSED;
static void _vala_GtkTreeRowReference_free (GtkTreeRowReference* self);
#define SIDEBAR_TREE_ICON_SIZE 16
static void sidebar_tree_on_new_tag (SidebarTree* self);
static void _sidebar_tree_on_new_tag_gsimple_action_activate_callback (GSimpleAction* action,
                                                                GVariant* parameter,
                                                                gpointer self);
static void sidebar_tree_on_new_search (SidebarTree* self);
static void _sidebar_tree_on_new_search_gsimple_action_activate_callback (GSimpleAction* action,
                                                                   GVariant* parameter,
                                                                   gpointer self);
SidebarTree* sidebar_tree_new (GtkTargetEntry* target_entries,
                               int target_entries_length1,
                               GdkDragAction actions,
                               SidebarTreeExternalDropHandler drop_handler,
                               void* drop_handler_target);
SidebarTree* sidebar_tree_construct (GType object_type,
                                     GtkTargetEntry* target_entries,
                                     int target_entries_length1,
                                     GdkDragAction actions,
                                     SidebarTreeExternalDropHandler drop_handler,
                                     void* drop_handler_target);
void sidebar_tree_icon_renderer_function (SidebarTree* self,
                                          GtkCellLayout* layout,
                                          GtkCellRenderer* renderer,
                                          GtkTreeModel* model,
                                          GtkTreeIter* iter);
static void _sidebar_tree_icon_renderer_function_gtk_cell_layout_data_func (GtkCellLayout* cell_layout,
                                                                     GtkCellRenderer* cell,
                                                                     GtkTreeModel* tree_model,
                                                                     GtkTreeIter* iter,
                                                                     gpointer self);
static gboolean sidebar_tree_on_selection (SidebarTree* self,
                                    GtkTreeSelection* selection,
                                    GtkTreeModel* model,
                                    GtkTreePath* path,
                                    gboolean path_currently_selected);
static gboolean _sidebar_tree_on_selection_gtk_tree_selection_func (GtkTreeSelection* selection,
                                                             GtkTreeModel* model,
                                                             GtkTreePath* path,
                                                             gboolean path_currently_selected,
                                                             gpointer self);
gboolean sidebar_tree_on_toggle_row (SidebarTree* self,
                                     GtkTreeIter* iter,
                                     GtkTreePath* path);
static gboolean _sidebar_tree_on_toggle_row_gtk_tree_view_test_expand_row (GtkTreeView* _sender,
                                                                    GtkTreeIter* iter,
                                                                    GtkTreePath* path,
                                                                    gpointer self);
static gboolean _sidebar_tree_on_toggle_row_gtk_tree_view_test_collapse_row (GtkTreeView* _sender,
                                                                      GtkTreeIter* iter,
                                                                      GtkTreePath* path,
                                                                      gpointer self);
GType library_window_target_type_get_type (void) G_GNUC_CONST;
static void _vala_array_add67 (GtkTargetEntry* * array,
                        int* length,
                        int* size,
                        const GtkTargetEntry* value);
static gboolean sidebar_tree_on_context_menu_keypress (SidebarTree* self);
static gboolean _sidebar_tree_on_context_menu_keypress_gtk_widget_popup_menu (GtkWidget* _sender,
                                                                       gpointer self);
static void sidebar_tree_setup_default_context_menu (SidebarTree* self);
static void sidebar_tree_on_drag_begin (SidebarTree* self,
                                 GdkDragContext* ctx);
static void _sidebar_tree_on_drag_begin_gtk_widget_drag_begin (GtkWidget* _sender,
                                                        GdkDragContext* context,
                                                        gpointer self);
static void sidebar_tree_on_drag_end (SidebarTree* self,
                               GdkDragContext* ctx);
static void _sidebar_tree_on_drag_end_gtk_widget_drag_end (GtkWidget* _sender,
                                                    GdkDragContext* context,
                                                    gpointer self);
static gboolean sidebar_tree_on_drag_motion (SidebarTree* self,
                                      GdkDragContext* context,
                                      gint x,
                                      gint y,
                                      guint time_);
static gboolean _sidebar_tree_on_drag_motion_gtk_widget_drag_motion (GtkWidget* _sender,
                                                              GdkDragContext* context,
                                                              gint x,
                                                              gint y,
                                                              guint time_,
                                                              gpointer self);
static SidebarTreeEntryWrapper* sidebar_tree_get_wrapper_at_iter (SidebarTree* self,
                                                           GtkTreeIter* iter);
GType sidebar_grouping_get_type (void) G_GNUC_CONST;
GType sidebar_header_get_type (void) G_GNUC_CONST;
static void _vala_GtkTreePath_free (GtkTreePath* self);
static SidebarTreeEntryWrapper* sidebar_tree_get_wrapper_at_path (SidebarTree* self,
                                                           GtkTreePath* path);
gchar* resources_get_ui (const gchar* filename);
void app_window_error_message (const gchar* message,
                               GtkWindow* parent);
gpointer application_ref (gpointer instance);
void application_unref (gpointer instance);
GParamSpec* param_spec_application (const gchar* name,
                                    const gchar* nick,
                                    const gchar* blurb,
                                    GType object_type,
                                    GParamFlags flags);
void value_set_application (GValue* value,
                            gpointer v_object);
void value_take_application (GValue* value,
                             gpointer v_object);
gpointer value_get_application (const GValue* value);
GType application_get_type (void) G_GNUC_CONST;
Application* application_get_instance (void);
void application_panic (Application* self);
static gboolean sidebar_tree_has_wrapper (SidebarTree* self,
                                   SidebarEntry* entry);
static SidebarTreeEntryWrapper* sidebar_tree_get_wrapper (SidebarTree* self,
                                                   SidebarEntry* entry);
gchar* sidebar_entry_to_string (SidebarEntry* self);
gboolean sidebar_tree_place_cursor (SidebarTree* self,
                                    SidebarEntry* entry,
                                    gboolean mask_signal);
gboolean sidebar_tree_expand_to_entry (SidebarTree* self,
                                       SidebarEntry* entry);
static GtkTreePath* sidebar_tree_entry_wrapper_get_path (SidebarTreeEntryWrapper* self);
gboolean sidebar_tree_scroll_to_entry (SidebarTree* self,
                                       SidebarEntry* entry);
gboolean sidebar_tree_is_selected (SidebarTree* self,
                                   SidebarEntry* entry);
gboolean sidebar_tree_is_any_selected (SidebarTree* self);
static GtkTreePath* sidebar_tree_get_selected_path (SidebarTree* self);
static GtkTreePath* _vala_GtkTreePath_copy (GtkTreePath* self);
static void __vala_GtkTreePath_free0_ (gpointer var);
static inline void _g_list_free___vala_GtkTreePath_free0_ (GList* self);
static gchar* sidebar_tree_get_name_for_entry (SidebarTree* self,
                                        SidebarEntry* entry);
gchar* guarded_markup_escape_text (const gchar* plain);
gchar* sidebar_entry_get_sidebar_name (SidebarEntry* self);
GType sidebar_emphasizable_entry_get_type (void) G_GNUC_CONST;
gboolean sidebar_emphasizable_entry_is_emphasized (SidebarEmphasizableEntry* self);
gboolean sidebar_tree_accept_cursor_changed (SidebarTree* self);
static gboolean sidebar_tree_real_accept_cursor_changed (SidebarTree* self);
static void sidebar_tree_real_cursor_changed (GtkTreeView* base);
GType sidebar_renameable_entry_get_type (void) G_GNUC_CONST;
gboolean sidebar_renameable_entry_is_user_renameable (SidebarRenameableEntry* self);
GType sidebar_selectable_entry_get_type (void) G_GNUC_CONST;
void sidebar_tree_disable_editing (SidebarTree* self);
void sidebar_tree_enable_editing (SidebarTree* self);
void sidebar_tree_toggle_branch_expansion (SidebarTree* self,
                                           GtkTreePath* path,
                                           gboolean expand_all);
void sidebar_tree_expand_to_first_child (SidebarTree* self,
                                         SidebarEntry* entry);
void sidebar_tree_graft (SidebarTree* self,
                         SidebarBranch* branch,
                         gint position);
gboolean sidebar_branch_get_show_branch (SidebarBranch* self);
static void sidebar_tree_associate_branch (SidebarTree* self,
                                    SidebarBranch* branch);
gboolean sidebar_branch_is_startup_expand_to_first_child (SidebarBranch* self);
SidebarEntry* sidebar_branch_get_root (SidebarBranch* self);
gboolean sidebar_branch_is_startup_open_grouping (SidebarBranch* self);
static void sidebar_tree_on_branch_entry_added (SidebarTree* self,
                                         SidebarBranch* branch,
                                         SidebarEntry* entry);
static void _sidebar_tree_on_branch_entry_added_sidebar_branch_entry_added (SidebarBranch* _sender,
                                                                     SidebarEntry* entry,
                                                                     gpointer self);
static void sidebar_tree_on_branch_entry_removed (SidebarTree* self,
                                           SidebarBranch* branch,
                                           SidebarEntry* entry);
static void _sidebar_tree_on_branch_entry_removed_sidebar_branch_entry_removed (SidebarBranch* _sender,
                                                                         SidebarEntry* entry,
                                                                         gpointer self);
static void sidebar_tree_on_branch_entry_moved (SidebarTree* self,
                                         SidebarBranch* branch,
                                         SidebarEntry* entry);
static void _sidebar_tree_on_branch_entry_moved_sidebar_branch_entry_moved (SidebarBranch* _sender,
                                                                     SidebarEntry* entry,
                                                                     gpointer self);
static void sidebar_tree_on_branch_entry_reparented (SidebarTree* self,
                                              SidebarBranch* branch,
                                              SidebarEntry* entry,
                                              SidebarEntry* old_parent);
static void _sidebar_tree_on_branch_entry_reparented_sidebar_branch_entry_reparented (SidebarBranch* _sender,
                                                                               SidebarEntry* entry,
                                                                               SidebarEntry* old_parent,
                                                                               gpointer self);
static void sidebar_tree_on_branch_children_reordered (SidebarTree* self,
                                                SidebarBranch* branch,
                                                SidebarEntry* entry);
static void _sidebar_tree_on_branch_children_reordered_sidebar_branch_children_reordered (SidebarBranch* _sender,
                                                                                   SidebarEntry* entry,
                                                                                   gpointer self);
static void sidebar_tree_on_show_branch (SidebarTree* self,
                                  SidebarBranch* branch,
                                  gboolean shown);
static void _sidebar_tree_on_show_branch_sidebar_branch_show_branch (SidebarBranch* _sender,
                                                              gboolean show,
                                                              gpointer self);
static GType sidebar_tree_root_wrapper_get_type (void) G_GNUC_CONST G_GNUC_UNUSED;
static GtkTreeIter* _gtk_tree_iter_dup (GtkTreeIter* self);
static void sidebar_tree_associate_wrapper (SidebarTree* self,
                                     GtkTreeIter* assoc_iter,
                                     SidebarTreeEntryWrapper* wrapper);
static SidebarTreeRootWrapper* sidebar_tree_root_wrapper_new (GtkTreeModel* model,
                                                       SidebarEntry* entry,
                                                       GtkTreePath* path,
                                                       gint root_position);
static SidebarTreeRootWrapper* sidebar_tree_root_wrapper_construct (GType object_type,
                                                             GtkTreeModel* model,
                                                             SidebarEntry* entry,
                                                             GtkTreePath* path,
                                                             gint root_position);
static void sidebar_tree_associate_children (SidebarTree* self,
                                      SidebarBranch* branch,
                                      SidebarEntry* parent,
                                      GtkTreeIter* parent_iter);
GeeList* sidebar_branch_get_children (SidebarBranch* self,
                                      SidebarEntry* parent);
static void sidebar_tree_associate_entry (SidebarTree* self,
                                   GtkTreeIter* assoc_iter,
                                   SidebarEntry* entry);
static SidebarTreeEntryWrapper* sidebar_tree_entry_wrapper_new (GtkTreeModel* model,
                                                         SidebarEntry* entry,
                                                         GtkTreePath* path);
static SidebarTreeEntryWrapper* sidebar_tree_entry_wrapper_construct (GType object_type,
                                                               GtkTreeModel* model,
                                                               SidebarEntry* entry,
                                                               GtkTreePath* path);
gchar* sidebar_entry_get_sidebar_tooltip (SidebarEntry* self);
static void sidebar_tree_load_entry_icons (SidebarTree* self,
                                    GtkTreeIter* iter);
static void sidebar_tree_on_sidebar_tooltip_changed (SidebarTree* self,
                                              SidebarEntry* entry,
                                              const gchar* tooltip);
static void _sidebar_tree_on_sidebar_tooltip_changed_sidebar_entry_sidebar_tooltip_changed (SidebarEntry* _sender,
                                                                                     const gchar* tooltip,
                                                                                     gpointer self);
static void sidebar_tree_on_sidebar_icon_changed (SidebarTree* self,
                                           SidebarEntry* entry,
                                           const gchar* icon_name);
static void _sidebar_tree_on_sidebar_icon_changed_sidebar_entry_sidebar_icon_changed (SidebarEntry* _sender,
                                                                               const gchar* icon,
                                                                               gpointer self);
GType page_get_type (void) G_GNUC_CONST;
GType sidebar_page_representative_get_type (void) G_GNUC_CONST;
static void sidebar_tree_on_sidebar_page_created (SidebarTree* self,
                                           SidebarPageRepresentative* entry,
                                           Page* page);
static void _sidebar_tree_on_sidebar_page_created_sidebar_page_representative_page_created (SidebarPageRepresentative* _sender,
                                                                                     Page* page,
                                                                                     gpointer self);
static void sidebar_tree_on_sidebar_destroying_page (SidebarTree* self,
                                              SidebarPageRepresentative* entry,
                                              Page* page);
static void _sidebar_tree_on_sidebar_destroying_page_sidebar_page_representative_destroying_page (SidebarPageRepresentative* _sender,
                                                                                           Page* page,
                                                                                           gpointer self);
static void sidebar_tree_on_is_emphasized_changed (SidebarTree* self,
                                            SidebarEmphasizableEntry* entry,
                                            gboolean is_emphasized);
static void _sidebar_tree_on_is_emphasized_changed_sidebar_emphasizable_entry_is_emphasized_changed (SidebarEmphasizableEntry* _sender,
                                                                                              gboolean emphasized,
                                                                                              gpointer self);
static void sidebar_tree_on_sidebar_name_changed (SidebarTree* self,
                                           SidebarEntry* entry,
                                           const gchar* name);
static void _sidebar_tree_on_sidebar_name_changed_sidebar_renameable_entry_sidebar_name_changed (SidebarRenameableEntry* _sender,
                                                                                          const gchar* name,
                                                                                          gpointer self);
void sidebar_entry_grafted (SidebarEntry* self,
                            SidebarTree* tree);
static SidebarTreeEntryWrapper* sidebar_tree_reparent_wrapper (SidebarTree* self,
                                                        GtkTreeIter* new_iter,
                                                        SidebarTreeEntryWrapper* current_wrapper);
void sidebar_tree_prune (SidebarTree* self,
                         SidebarBranch* branch);
static void sidebar_tree_disassociate_branch (SidebarTree* self,
                                       SidebarBranch* branch);
static void sidebar_tree_disassociate_wrapper_and_signal (SidebarTree* self,
                                                   SidebarTreeEntryWrapper* wrapper,
                                                   gboolean only_children);
static void sidebar_tree_disassociate_wrapper (SidebarTree* self,
                                        SidebarTreeEntryWrapper* wrapper,
                                        gboolean only_children);
static void sidebar_tree_entry_wrapper_get_iter (SidebarTreeEntryWrapper* self,
                                          GtkTreeIter* result);
void sidebar_entry_pruned (SidebarEntry* self,
                           SidebarTree* tree);
SidebarEntry* sidebar_branch_get_parent (SidebarBranch* self,
                                         SidebarEntry* entry);
SidebarEntry* sidebar_branch_get_next_sibling (SidebarBranch* self,
                                               SidebarEntry* entry);
gboolean sidebar_branch_is_auto_open_on_new_child (SidebarBranch* self);
SidebarEntry* sidebar_branch_get_previous_sibling (SidebarBranch* self,
                                                   SidebarEntry* entry);
static GtkTreePath* sidebar_tree_get_current_path (SidebarTree* self);
static void sidebar_tree_rename_entry (SidebarTree* self,
                                SidebarEntry* entry);
gchar* sidebar_entry_get_sidebar_icon (SidebarEntry* self);
static void sidebar_tree_load_branch_icons (SidebarTree* self,
                                     GtkTreeIter* iter);
static GtkTreePath* sidebar_tree_get_path_from_event (SidebarTree* self,
                                               GdkEventButton* event);
static gboolean sidebar_tree_popup_context_menu (SidebarTree* self,
                                          GtkTreePath* path,
                                          GdkEventButton* event);
GType sidebar_contextable_get_type (void) G_GNUC_CONST;
GtkMenu* sidebar_contextable_get_sidebar_context_menu (SidebarContextable* self,
                                                       GdkEventButton* event);
static gboolean sidebar_tree_popup_default_context_menu (SidebarTree* self,
                                                  GdkEventButton* event);
static gboolean sidebar_tree_real_button_press_event (GtkWidget* base,
                                               GdkEventButton* event);
GType sidebar_expandable_entry_get_type (void) G_GNUC_CONST;
GType data_object_get_type (void) G_GNUC_CONST;
GType data_source_get_type (void) G_GNUC_CONST;
GType thumbnail_source_get_type (void) G_GNUC_CONST;
GType media_source_get_type (void) G_GNUC_CONST;
GType sidebar_internal_drop_target_entry_get_type (void) G_GNUC_CONST;
gboolean sidebar_tree_is_keypress_interpreted (SidebarTree* self,
                                               GdkEventKey* event);
static gboolean sidebar_tree_real_key_press_event (GtkWidget* base,
                                            GdkEventKey* event);
static gboolean sidebar_tree_rename_in_place (SidebarTree* self);
static gboolean sidebar_tree_destroy_path (SidebarTree* self,
                                    GtkTreePath* path);
gboolean sidebar_tree_rename_entry_in_place (SidebarTree* self,
                                             SidebarEntry* entry);
static gboolean sidebar_tree_can_rename_path (SidebarTree* self,
                                       GtkTreePath* path);
static void sidebar_tree_real_drag_data_get (GtkWidget* base,
                                      GdkDragContext* context,
                                      GtkSelectionData* selection_data,
                                      guint info,
                                      guint time);
GType sidebar_internal_drag_source_entry_get_type (void) G_GNUC_CONST;
void sidebar_internal_drag_source_entry_prepare_selection_data (SidebarInternalDragSourceEntry* self,
                                                                GtkSelectionData* data);
static void sidebar_tree_real_drag_data_received (GtkWidget* base,
                                           GdkDragContext* context,
                                           gint x,
                                           gint y,
                                           GtkSelectionData* selection_data,
                                           guint info,
                                           guint time);
#define LIBRARY_WINDOW_TAG_PATH_MIME_TYPE "shotwell/tag-path"
gboolean sidebar_internal_drop_target_entry_internal_drop_received_arbitrary (SidebarInternalDropTargetEntry* self,
                                                                              GtkSelectionData* data);
GeeList* unserialize_media_sources (guchar* serialized,
                                    gint size);
gboolean sidebar_internal_drop_target_entry_internal_drop_received (SidebarInternalDropTargetEntry* self,
                                                                    GeeList* sources);
static gboolean sidebar_tree_real_drag_motion (GtkWidget* base,
                                        GdkDragContext* context,
                                        gint x,
                                        gint y,
                                        guint time);
GType sidebar_destroyable_entry_get_type (void) G_GNUC_CONST;
void sidebar_destroyable_entry_destroy_source (SidebarDestroyableEntry* self);
static void sidebar_tree_on_editing_done (SidebarTree* self);
static void _sidebar_tree_on_editing_done_gtk_cell_editable_editing_done (GtkCellEditable* _sender,
                                                                   gpointer self);
static gboolean sidebar_tree_on_editing_focus_out (SidebarTree* self,
                                            GdkEventFocus* event);
static gboolean _sidebar_tree_on_editing_focus_out_gtk_widget_focus_out_event (GtkWidget* _sender,
                                                                        GdkEventFocus* event,
                                                                        gpointer self);
void sidebar_renameable_entry_rename (SidebarRenameableEntry* self,
                                      const gchar* new_name);
SavedSearchDialog* saved_search_dialog_new (void);
SavedSearchDialog* saved_search_dialog_construct (GType object_type);
GType saved_search_dialog_get_type (void) G_GNUC_CONST;
void saved_search_dialog_show (SavedSearchDialog* self);
GType command_get_type (void) G_GNUC_CONST;
GType page_command_get_type (void) G_GNUC_CONST;
GType new_root_tag_command_get_type (void) G_GNUC_CONST;
NewRootTagCommand* new_root_tag_command_new (void);
NewRootTagCommand* new_root_tag_command_construct (GType object_type);
gpointer command_manager_ref (gpointer instance);
void command_manager_unref (gpointer instance);
GParamSpec* param_spec_command_manager (const gchar* name,
                                        const gchar* nick,
                                        const gchar* blurb,
                                        GType object_type,
                                        GParamFlags flags);
void value_set_command_manager (GValue* value,
                                gpointer v_object);
void value_take_command_manager (GValue* value,
                                 gpointer v_object);
gpointer value_get_command_manager (const GValue* value);
GType command_manager_get_type (void) G_GNUC_CONST;
CommandManager* app_window_get_command_manager (void);
void command_manager_execute (CommandManager* self,
                              Command* command);
GType page_window_get_type (void) G_GNUC_CONST;
GType app_window_get_type (void) G_GNUC_CONST;
GType library_window_get_type (void) G_GNUC_CONST;
LibraryWindow* library_window_get_app (void);
GType tag_get_type (void) G_GNUC_CONST;
void library_window_rename_tag_in_sidebar (LibraryWindow* self,
                                           Tag* tag);
Tag* new_root_tag_command_get_created_tag (NewRootTagCommand* self);
static void g_cclosure_user_marshal_VOID__OBJECT_BOOLEAN (GClosure * closure,
                                                   GValue * return_value,
                                                   guint n_param_values,
                                                   const GValue * param_values,
                                                   gpointer invocation_hint,
                                                   gpointer marshal_data);
static void g_cclosure_user_marshal_VOID__OBJECT_OBJECT (GClosure * closure,
                                                  GValue * return_value,
                                                  guint n_param_values,
                                                  const GValue * param_values,
                                                  gpointer invocation_hint,
                                                  gpointer marshal_data);
static void sidebar_tree_entry_wrapper_finalize (GObject * obj);
static void sidebar_tree_root_wrapper_finalize (GObject * obj);
static void sidebar_tree_finalize (GObject * obj);

static const GActionEntry SIDEBAR_TREE_entries[2] = {{"tag.new", _sidebar_tree_on_new_tag_gsimple_action_activate_callback}, {"search.new", _sidebar_tree_on_new_search_gsimple_action_activate_callback}};

static void
_sidebar_tree_on_editing_canceled_gtk_cell_renderer_editing_canceled (GtkCellRenderer* _sender,
                                                                      gpointer self)
{
#line 155 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	sidebar_tree_on_editing_canceled ((SidebarTree*) self);
#line 925 "Tree.c"
}


static void
_sidebar_tree_on_editing_started_gtk_cell_renderer_editing_started (GtkCellRenderer* _sender,
                                                                    GtkCellEditable* editable,
                                                                    const gchar* path,
                                                                    gpointer self)
{
#line 156 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	sidebar_tree_on_editing_started ((SidebarTree*) self, editable, path);
#line 937 "Tree.c"
}


static GType
sidebar_tree_columns_get_type (void)
{
	static volatile gsize sidebar_tree_columns_type_id__volatile = 0;
	if (g_once_init_enter (&sidebar_tree_columns_type_id__volatile)) {
		static const GEnumValue values[] = {{SIDEBAR_TREE_COLUMNS_NAME, "SIDEBAR_TREE_COLUMNS_NAME", "name"}, {SIDEBAR_TREE_COLUMNS_TOOLTIP, "SIDEBAR_TREE_COLUMNS_TOOLTIP", "tooltip"}, {SIDEBAR_TREE_COLUMNS_WRAPPER, "SIDEBAR_TREE_COLUMNS_WRAPPER", "wrapper"}, {SIDEBAR_TREE_COLUMNS_ICON, "SIDEBAR_TREE_COLUMNS_ICON", "icon"}, {SIDEBAR_TREE_COLUMNS_N_COLUMNS, "SIDEBAR_TREE_COLUMNS_N_COLUMNS", "n-columns"}, {0, NULL, NULL}};
		GType sidebar_tree_columns_type_id;
		sidebar_tree_columns_type_id = g_enum_register_static ("SidebarTreeColumns", values);
		g_once_init_leave (&sidebar_tree_columns_type_id__volatile, sidebar_tree_columns_type_id);
	}
	return sidebar_tree_columns_type_id__volatile;
}


static void
_vala_GtkTreeRowReference_free (GtkTreeRowReference* self)
{
#line 77 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_boxed_free (gtk_tree_row_reference_get_type (), self);
#line 960 "Tree.c"
}


static void
_sidebar_tree_on_new_tag_gsimple_action_activate_callback (GSimpleAction* action,
                                                           GVariant* parameter,
                                                           gpointer self)
{
#line 192 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	sidebar_tree_on_new_tag ((SidebarTree*) self);
#line 971 "Tree.c"
}


static void
_sidebar_tree_on_new_search_gsimple_action_activate_callback (GSimpleAction* action,
                                                              GVariant* parameter,
                                                              gpointer self)
{
#line 192 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	sidebar_tree_on_new_search ((SidebarTree*) self);
#line 982 "Tree.c"
}


static void
_sidebar_tree_icon_renderer_function_gtk_cell_layout_data_func (GtkCellLayout* cell_layout,
                                                                GtkCellRenderer* cell,
                                                                GtkTreeModel* tree_model,
                                                                GtkTreeIter* iter,
                                                                gpointer self)
{
#line 103 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	sidebar_tree_icon_renderer_function ((SidebarTree*) self, cell_layout, cell, tree_model, iter);
#line 995 "Tree.c"
}


static gpointer
_g_object_ref0 (gpointer self)
{
#line 126 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	return self ? g_object_ref (self) : NULL;
#line 1004 "Tree.c"
}


static gboolean
_sidebar_tree_on_selection_gtk_tree_selection_func (GtkTreeSelection* selection,
                                                    GtkTreeModel* model,
                                                    GtkTreePath* path,
                                                    gboolean path_currently_selected,
                                                    gpointer self)
{
	gboolean result;
	result = sidebar_tree_on_selection ((SidebarTree*) self, selection, model, path, path_currently_selected);
#line 128 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	return result;
#line 1019 "Tree.c"
}


static gboolean
_sidebar_tree_on_toggle_row_gtk_tree_view_test_expand_row (GtkTreeView* _sender,
                                                           GtkTreeIter* iter,
                                                           GtkTreePath* path,
                                                           gpointer self)
{
	gboolean result;
	result = sidebar_tree_on_toggle_row ((SidebarTree*) self, iter, path);
#line 130 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	return result;
#line 1033 "Tree.c"
}


static gboolean
_sidebar_tree_on_toggle_row_gtk_tree_view_test_collapse_row (GtkTreeView* _sender,
                                                             GtkTreeIter* iter,
                                                             GtkTreePath* path,
                                                             gpointer self)
{
	gboolean result;
	result = sidebar_tree_on_toggle_row ((SidebarTree*) self, iter, path);
#line 131 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	return result;
#line 1047 "Tree.c"
}


static void
_vala_array_add67 (GtkTargetEntry* * array,
                   int* length,
                   int* size,
                   const GtkTargetEntry* value)
{
#line 139 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if ((*length) == (*size)) {
#line 139 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 139 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		*array = g_renew (GtkTargetEntry, *array, *size);
#line 1063 "Tree.c"
	}
#line 139 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	(*array)[(*length)++] = *value;
#line 1067 "Tree.c"
}


static gboolean
_sidebar_tree_on_context_menu_keypress_gtk_widget_popup_menu (GtkWidget* _sender,
                                                              gpointer self)
{
	gboolean result;
	result = sidebar_tree_on_context_menu_keypress ((SidebarTree*) self);
#line 145 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	return result;
#line 1079 "Tree.c"
}


static void
_sidebar_tree_on_drag_begin_gtk_widget_drag_begin (GtkWidget* _sender,
                                                   GdkDragContext* context,
                                                   gpointer self)
{
#line 149 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	sidebar_tree_on_drag_begin ((SidebarTree*) self, context);
#line 1090 "Tree.c"
}


static void
_sidebar_tree_on_drag_end_gtk_widget_drag_end (GtkWidget* _sender,
                                               GdkDragContext* context,
                                               gpointer self)
{
#line 150 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	sidebar_tree_on_drag_end ((SidebarTree*) self, context);
#line 1101 "Tree.c"
}


static gboolean
_sidebar_tree_on_drag_motion_gtk_widget_drag_motion (GtkWidget* _sender,
                                                     GdkDragContext* context,
                                                     gint x,
                                                     gint y,
                                                     guint time_,
                                                     gpointer self)
{
	gboolean result;
	result = sidebar_tree_on_drag_motion ((SidebarTree*) self, context, x, y, time_);
#line 151 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	return result;
#line 1117 "Tree.c"
}


SidebarTree*
sidebar_tree_construct (GType object_type,
                        GtkTargetEntry* target_entries,
                        int target_entries_length1,
                        GdkDragAction actions,
                        SidebarTreeExternalDropHandler drop_handler,
                        void* drop_handler_target)
{
	SidebarTree * self = NULL;
	GtkTreeStore* _tmp0_;
	GtkTreeViewColumn* text_column = NULL;
	GtkTreeViewColumn* _tmp1_;
	GtkCellRendererPixbuf* icon_renderer = NULL;
	GtkCellRendererPixbuf* _tmp2_;
	GtkCellRendererText* _tmp3_;
	GtkCellRendererText* _tmp4_;
	GtkCellRendererText* _tmp5_;
	GtkCellRendererText* _tmp6_;
	GtkCellRendererText* _tmp7_;
	GtkCellRendererText* _tmp8_;
	GtkCellRendererText* invisitext = NULL;
	GtkCellRendererText* _tmp9_;
	GtkTreeViewColumn* page_holder = NULL;
	GtkTreeViewColumn* _tmp10_;
	GtkTreeSelection* selection = NULL;
	GtkTreeSelection* _tmp11_;
	GtkTreeSelection* _tmp12_;
	GtkTargetEntry* source_entries = NULL;
	GtkTargetEntry* _tmp13_;
	gint source_entries_length1;
	gint _source_entries_size_;
	GtkTargetEntry* _tmp14_;
	gint _tmp14__length1;
	GtkTargetEntry _tmp15_;
	GtkTargetEntry* _tmp16_;
	gint _tmp16__length1;
#line 93 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	self = (SidebarTree*) g_object_new (object_type, NULL);
#line 95 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = self->priv->store;
#line 95 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	gtk_tree_view_set_model (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_view_get_type (), GtkTreeView), G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, gtk_tree_model_get_type (), GtkTreeModel));
#line 97 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp1_ = gtk_tree_view_column_new ();
#line 97 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_object_ref_sink (_tmp1_);
#line 97 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	text_column = _tmp1_;
#line 98 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	gtk_tree_view_column_set_expand (text_column, TRUE);
#line 99 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp2_ = (GtkCellRendererPixbuf*) gtk_cell_renderer_pixbuf_new ();
#line 99 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_object_ref_sink (_tmp2_);
#line 99 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	icon_renderer = _tmp2_;
#line 100 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_object_set (icon_renderer, "follow-state", TRUE, NULL);
#line 101 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	gtk_cell_layout_pack_start (G_TYPE_CHECK_INSTANCE_CAST (text_column, gtk_cell_layout_get_type (), GtkCellLayout), G_TYPE_CHECK_INSTANCE_CAST (icon_renderer, gtk_cell_renderer_get_type (), GtkCellRenderer), FALSE);
#line 102 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	gtk_cell_layout_add_attribute (G_TYPE_CHECK_INSTANCE_CAST (text_column, gtk_cell_layout_get_type (), GtkCellLayout), G_TYPE_CHECK_INSTANCE_CAST (icon_renderer, gtk_cell_renderer_get_type (), GtkCellRenderer), "gicon", (gint) SIDEBAR_TREE_COLUMNS_ICON);
#line 103 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	gtk_cell_layout_set_cell_data_func (G_TYPE_CHECK_INSTANCE_CAST (text_column, gtk_cell_layout_get_type (), GtkCellLayout), G_TYPE_CHECK_INSTANCE_CAST (icon_renderer, gtk_cell_renderer_get_type (), GtkCellRenderer), _sidebar_tree_icon_renderer_function_gtk_cell_layout_data_func, g_object_ref (self), g_object_unref);
#line 104 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp3_ = (GtkCellRendererText*) gtk_cell_renderer_text_new ();
#line 104 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_object_ref_sink (_tmp3_);
#line 104 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (self->priv->text_renderer);
#line 104 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	self->priv->text_renderer = _tmp3_;
#line 105 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp4_ = self->priv->text_renderer;
#line 105 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_object_set (_tmp4_, "ellipsize", PANGO_ELLIPSIZE_END, NULL);
#line 106 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp5_ = self->priv->text_renderer;
#line 106 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, gtk_cell_renderer_get_type (), GtkCellRenderer), "editing-canceled", (GCallback) _sidebar_tree_on_editing_canceled_gtk_cell_renderer_editing_canceled, self, 0);
#line 107 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp6_ = self->priv->text_renderer;
#line 107 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, gtk_cell_renderer_get_type (), GtkCellRenderer), "editing-started", (GCallback) _sidebar_tree_on_editing_started_gtk_cell_renderer_editing_started, self, 0);
#line 108 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp7_ = self->priv->text_renderer;
#line 108 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	gtk_cell_layout_pack_start (G_TYPE_CHECK_INSTANCE_CAST (text_column, gtk_cell_layout_get_type (), GtkCellLayout), G_TYPE_CHECK_INSTANCE_CAST (_tmp7_, gtk_cell_renderer_get_type (), GtkCellRenderer), TRUE);
#line 109 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp8_ = self->priv->text_renderer;
#line 109 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	gtk_cell_layout_add_attribute (G_TYPE_CHECK_INSTANCE_CAST (text_column, gtk_cell_layout_get_type (), GtkCellLayout), G_TYPE_CHECK_INSTANCE_CAST (_tmp8_, gtk_cell_renderer_get_type (), GtkCellRenderer), "markup", (gint) SIDEBAR_TREE_COLUMNS_NAME);
#line 110 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	gtk_tree_view_append_column (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_view_get_type (), GtkTreeView), text_column);
#line 112 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp9_ = (GtkCellRendererText*) gtk_cell_renderer_text_new ();
#line 112 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_object_ref_sink (_tmp9_);
#line 112 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	invisitext = _tmp9_;
#line 113 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp10_ = gtk_tree_view_column_new ();
#line 113 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_object_ref_sink (_tmp10_);
#line 113 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	page_holder = _tmp10_;
#line 114 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	gtk_cell_layout_pack_start (G_TYPE_CHECK_INSTANCE_CAST (page_holder, gtk_cell_layout_get_type (), GtkCellLayout), G_TYPE_CHECK_INSTANCE_CAST (invisitext, gtk_cell_renderer_get_type (), GtkCellRenderer), TRUE);
#line 115 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	gtk_tree_view_column_set_visible (page_holder, FALSE);
#line 116 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	gtk_tree_view_append_column (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_view_get_type (), GtkTreeView), page_holder);
#line 118 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	gtk_tree_view_set_headers_visible (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_view_get_type (), GtkTreeView), FALSE);
#line 119 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	gtk_tree_view_set_enable_search (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_view_get_type (), GtkTreeView), FALSE);
#line 120 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	gtk_tree_view_set_show_expanders (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_view_get_type (), GtkTreeView), TRUE);
#line 121 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	gtk_tree_view_set_reorderable (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_view_get_type (), GtkTreeView), FALSE);
#line 122 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	gtk_tree_view_set_enable_tree_lines (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_view_get_type (), GtkTreeView), FALSE);
#line 123 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	gtk_tree_view_set_grid_lines (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_view_get_type (), GtkTreeView), GTK_TREE_VIEW_GRID_LINES_NONE);
#line 124 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	gtk_tree_view_set_tooltip_column (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_view_get_type (), GtkTreeView), (gint) SIDEBAR_TREE_COLUMNS_TOOLTIP);
#line 126 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp11_ = gtk_tree_view_get_selection (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_view_get_type (), GtkTreeView));
#line 126 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp12_ = _g_object_ref0 (_tmp11_);
#line 126 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	selection = _tmp12_;
#line 127 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	gtk_tree_selection_set_mode (selection, GTK_SELECTION_BROWSE);
#line 128 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	gtk_tree_selection_set_select_function (selection, _sidebar_tree_on_selection_gtk_tree_selection_func, g_object_ref (self), g_object_unref);
#line 130 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_view_get_type (), GtkTreeView), "test-expand-row", (GCallback) _sidebar_tree_on_toggle_row_gtk_tree_view_test_expand_row, self, 0);
#line 131 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_view_get_type (), GtkTreeView), "test-collapse-row", (GCallback) _sidebar_tree_on_toggle_row_gtk_tree_view_test_collapse_row, self, 0);
#line 136 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	gtk_tree_view_enable_model_drag_dest (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_view_get_type (), GtkTreeView), target_entries, target_entries_length1, actions);
#line 138 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp13_ = g_new0 (GtkTargetEntry, 0);
#line 138 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	source_entries = _tmp13_;
#line 138 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	source_entries_length1 = 0;
#line 138 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_source_entries_size_ = source_entries_length1;
#line 139 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp14_ = source_entries;
#line 139 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp14__length1 = source_entries_length1;
#line 139 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp15_ = target_entries[LIBRARY_WINDOW_TARGET_TYPE_TAG_PATH];
#line 139 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_vala_array_add67 (&source_entries, &source_entries_length1, &_source_entries_size_, &_tmp15_);
#line 140 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp16_ = source_entries;
#line 140 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp16__length1 = source_entries_length1;
#line 140 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	gtk_tree_view_enable_model_drag_source (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_view_get_type (), GtkTreeView), GDK_BUTTON1_MASK, _tmp16_, _tmp16__length1, GDK_ACTION_COPY);
#line 143 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	self->priv->drop_handler = drop_handler;
#line 143 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	self->priv->drop_handler_target = drop_handler_target;
#line 145 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget), "popup-menu", (GCallback) _sidebar_tree_on_context_menu_keypress_gtk_widget_popup_menu, self, 0);
#line 147 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	sidebar_tree_setup_default_context_menu (self);
#line 149 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget), "drag-begin", (GCallback) _sidebar_tree_on_drag_begin_gtk_widget_drag_begin, self, 0);
#line 150 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget), "drag-end", (GCallback) _sidebar_tree_on_drag_end_gtk_widget_drag_end, self, 0);
#line 151 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget), "drag-motion", (GCallback) _sidebar_tree_on_drag_motion_gtk_widget_drag_motion, self, 0);
#line 93 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	source_entries = (g_free (source_entries), NULL);
#line 93 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (selection);
#line 93 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (page_holder);
#line 93 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (invisitext);
#line 93 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (icon_renderer);
#line 93 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (text_column);
#line 93 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	return self;
#line 1313 "Tree.c"
}


SidebarTree*
sidebar_tree_new (GtkTargetEntry* target_entries,
                  int target_entries_length1,
                  GdkDragAction actions,
                  SidebarTreeExternalDropHandler drop_handler,
                  void* drop_handler_target)
{
#line 93 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	return sidebar_tree_construct (SIDEBAR_TYPE_TREE, target_entries, target_entries_length1, actions, drop_handler, drop_handler_target);
#line 1326 "Tree.c"
}


void
sidebar_tree_icon_renderer_function (SidebarTree* self,
                                     GtkCellLayout* layout,
                                     GtkCellRenderer* renderer,
                                     GtkTreeModel* model,
                                     GtkTreeIter* iter)
{
	SidebarTreeEntryWrapper* wrapper = NULL;
	GtkTreeIter _tmp0_;
	SidebarTreeEntryWrapper* _tmp1_;
	SidebarTreeEntryWrapper* _tmp2_;
	SidebarTreeEntryWrapper* _tmp3_;
	SidebarEntry* _tmp4_;
#line 159 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_TREE (self));
#line 159 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (GTK_IS_CELL_LAYOUT (layout));
#line 159 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (GTK_IS_CELL_RENDERER (renderer));
#line 159 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (GTK_IS_TREE_MODEL (model));
#line 159 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (iter != NULL);
#line 160 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = *iter;
#line 160 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp1_ = sidebar_tree_get_wrapper_at_iter (self, &_tmp0_);
#line 160 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	wrapper = _tmp1_;
#line 161 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp2_ = wrapper;
#line 161 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp2_ == NULL) {
#line 162 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (wrapper);
#line 162 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		return;
#line 1367 "Tree.c"
	}
#line 164 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp3_ = wrapper;
#line 164 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp4_ = _tmp3_->entry;
#line 164 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	gtk_cell_renderer_set_visible (renderer, !G_TYPE_CHECK_INSTANCE_TYPE (_tmp4_, SIDEBAR_TYPE_HEADER));
#line 159 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (wrapper);
#line 1377 "Tree.c"
}


static void
sidebar_tree_on_drag_begin (SidebarTree* self,
                            GdkDragContext* ctx)
{
#line 167 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_TREE (self));
#line 167 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (GDK_IS_DRAG_CONTEXT (ctx));
#line 168 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	self->priv->is_internal_drag_in_progress = TRUE;
#line 1391 "Tree.c"
}


static void
sidebar_tree_on_drag_end (SidebarTree* self,
                          GdkDragContext* ctx)
{
#line 171 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_TREE (self));
#line 171 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (GDK_IS_DRAG_CONTEXT (ctx));
#line 172 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	self->priv->is_internal_drag_in_progress = FALSE;
#line 173 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (self->priv->internal_drag_source_entry);
#line 173 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	self->priv->internal_drag_source_entry = NULL;
#line 1409 "Tree.c"
}


static void
_vala_GtkTreePath_free (GtkTreePath* self)
{
#line 180 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_boxed_free (gtk_tree_path_get_type (), self);
#line 1418 "Tree.c"
}


static gboolean
sidebar_tree_on_drag_motion (SidebarTree* self,
                             GdkDragContext* context,
                             gint x,
                             gint y,
                             guint time_)
{
	gboolean result = FALSE;
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_;
#line 176 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (SIDEBAR_IS_TREE (self), FALSE);
#line 176 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (GDK_IS_DRAG_CONTEXT (context), FALSE);
#line 177 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp1_ = self->priv->is_internal_drag_in_progress;
#line 177 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp1_) {
#line 1440 "Tree.c"
		SidebarEntry* _tmp2_;
#line 177 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp2_ = self->priv->internal_drag_source_entry;
#line 177 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp0_ = _tmp2_ == NULL;
#line 1446 "Tree.c"
	} else {
#line 177 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp0_ = FALSE;
#line 1450 "Tree.c"
	}
#line 177 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp0_) {
#line 1454 "Tree.c"
		GtkTreePath* path = NULL;
		GtkTreeViewDropPosition position = 0;
		GtkTreePath* _tmp3_ = NULL;
		GtkTreeViewDropPosition _tmp4_ = 0;
		GtkTreePath* _tmp5_;
#line 180 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		gtk_tree_view_get_dest_row_at_pos (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_view_get_type (), GtkTreeView), x, y, &_tmp3_, &_tmp4_);
#line 180 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		__vala_GtkTreePath_free0 (path);
#line 180 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		path = _tmp3_;
#line 180 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		position = _tmp4_;
#line 182 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp5_ = path;
#line 182 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		if (_tmp5_ != NULL) {
#line 1472 "Tree.c"
			SidebarTreeEntryWrapper* wrapper = NULL;
			GtkTreePath* _tmp6_;
			SidebarTreeEntryWrapper* _tmp7_;
			SidebarTreeEntryWrapper* _tmp8_;
#line 183 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp6_ = path;
#line 183 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp7_ = sidebar_tree_get_wrapper_at_path (self, _tmp6_);
#line 183 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			wrapper = _tmp7_;
#line 184 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp8_ = wrapper;
#line 184 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			if (_tmp8_ != NULL) {
#line 1487 "Tree.c"
				SidebarTreeEntryWrapper* _tmp9_;
				SidebarEntry* _tmp10_;
				SidebarEntry* _tmp11_;
#line 185 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				_tmp9_ = wrapper;
#line 185 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				_tmp10_ = _tmp9_->entry;
#line 185 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				_tmp11_ = _g_object_ref0 (_tmp10_);
#line 185 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				_g_object_unref0 (self->priv->internal_drag_source_entry);
#line 185 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				self->priv->internal_drag_source_entry = _tmp11_;
#line 1501 "Tree.c"
			}
#line 182 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_g_object_unref0 (wrapper);
#line 1505 "Tree.c"
		}
#line 177 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		__vala_GtkTreePath_free0 (path);
#line 1509 "Tree.c"
	}
#line 189 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	result = FALSE;
#line 189 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	return result;
#line 1515 "Tree.c"
}


static void
sidebar_tree_setup_default_context_menu (SidebarTree* self)
{
	GError * _inner_error_ = NULL;
#line 197 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_TREE (self));
#line 1525 "Tree.c"
	{
		GtkBuilder* _tmp0_;
		gchar* _tmp1_;
		gchar* _tmp2_;
		GMenuModel* model = NULL;
		GtkBuilder* _tmp3_;
		GObject* _tmp4_;
		GMenuModel* _tmp5_;
		GMenuModel* _tmp6_;
		GtkMenu* _tmp7_;
		GSimpleActionGroup* group = NULL;
		GSimpleActionGroup* _tmp8_;
		GSimpleActionGroup* _tmp9_;
		GSimpleActionGroup* _tmp10_;
		GtkMenu* _tmp11_;
#line 199 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp0_ = self->priv->builder;
#line 199 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp1_ = resources_get_ui ("sidebar_default_context.ui");
#line 199 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp2_ = _tmp1_;
#line 199 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		gtk_builder_add_from_resource (_tmp0_, _tmp2_, &_inner_error_);
#line 199 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_free0 (_tmp2_);
#line 199 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1553 "Tree.c"
			goto __catch55_g_error;
		}
#line 200 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp3_ = self->priv->builder;
#line 200 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp4_ = gtk_builder_get_object (_tmp3_, "popup-menu");
#line 200 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp5_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp4_, g_menu_model_get_type ()) ? ((GMenuModel*) _tmp4_) : NULL);
#line 200 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		model = _tmp5_;
#line 201 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp6_ = model;
#line 201 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp7_ = (GtkMenu*) gtk_menu_new_from_model (_tmp6_);
#line 201 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		g_object_ref_sink (_tmp7_);
#line 201 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (self->priv->default_context_menu);
#line 201 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		self->priv->default_context_menu = _tmp7_;
#line 202 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp8_ = g_simple_action_group_new ();
#line 202 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		group = _tmp8_;
#line 203 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp9_ = group;
#line 203 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		g_action_map_add_action_entries (G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, g_action_map_get_type (), GActionMap), SIDEBAR_TREE_entries, G_N_ELEMENTS (SIDEBAR_TREE_entries), self);
#line 204 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp10_ = group;
#line 204 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		gtk_widget_insert_action_group (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget), "sidebar", G_TYPE_CHECK_INSTANCE_CAST (_tmp10_, g_action_group_get_type (), GActionGroup));
#line 205 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp11_ = self->priv->default_context_menu;
#line 205 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		gtk_menu_attach_to_widget (_tmp11_, G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget), NULL);
#line 198 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (group);
#line 198 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (model);
#line 1594 "Tree.c"
	}
	goto __finally55;
	__catch55_g_error:
	{
		GError* _error_ = NULL;
		GError* _tmp12_;
		const gchar* _tmp13_;
		gchar* _tmp14_;
		gchar* _tmp15_;
		Application* _tmp16_;
		Application* _tmp17_;
#line 198 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_error_ = _inner_error_;
#line 198 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_inner_error_ = NULL;
#line 207 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp12_ = _error_;
#line 207 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp13_ = _tmp12_->message;
#line 207 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp14_ = g_strdup_printf ("Error loading UI resource: %s", _tmp13_);
#line 207 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp15_ = _tmp14_;
#line 207 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		app_window_error_message (_tmp15_, NULL);
#line 207 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_free0 (_tmp15_);
#line 209 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp16_ = application_get_instance ();
#line 209 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp17_ = _tmp16_;
#line 209 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		application_panic (_tmp17_);
#line 209 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_application_unref0 (_tmp17_);
#line 198 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_error_free0 (_error_);
#line 1632 "Tree.c"
	}
	__finally55:
#line 198 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 198 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 198 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		g_clear_error (&_inner_error_);
#line 198 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		return;
#line 1643 "Tree.c"
	}
}


static gboolean
sidebar_tree_has_wrapper (SidebarTree* self,
                          SidebarEntry* entry)
{
	gboolean result = FALSE;
	GeeHashMap* _tmp0_;
#line 213 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (SIDEBAR_IS_TREE (self), FALSE);
#line 213 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (SIDEBAR_IS_ENTRY (entry), FALSE);
#line 214 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = self->priv->entry_map;
#line 214 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	result = gee_abstract_map_has_key (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), entry);
#line 214 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	return result;
#line 1664 "Tree.c"
}


static SidebarTreeEntryWrapper*
sidebar_tree_get_wrapper (SidebarTree* self,
                          SidebarEntry* entry)
{
	SidebarTreeEntryWrapper* result = NULL;
	SidebarTreeEntryWrapper* wrapper = NULL;
	GeeHashMap* _tmp0_;
	gpointer _tmp1_;
	SidebarTreeEntryWrapper* _tmp2_;
#line 217 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (SIDEBAR_IS_TREE (self), NULL);
#line 217 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (SIDEBAR_IS_ENTRY (entry), NULL);
#line 218 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = self->priv->entry_map;
#line 218 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp1_ = gee_abstract_map_get (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), entry);
#line 218 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	wrapper = (SidebarTreeEntryWrapper*) _tmp1_;
#line 219 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp2_ = wrapper;
#line 219 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp2_ == NULL) {
#line 1691 "Tree.c"
		gchar* _tmp3_;
		gchar* _tmp4_;
#line 220 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp3_ = sidebar_entry_to_string (entry);
#line 220 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp4_ = _tmp3_;
#line 220 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		g_warning ("Tree.vala:220: Entry %s not found in sidebar", _tmp4_);
#line 220 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_free0 (_tmp4_);
#line 1702 "Tree.c"
	}
#line 222 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	result = wrapper;
#line 222 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	return result;
#line 1708 "Tree.c"
}


static SidebarTreeEntryWrapper*
sidebar_tree_get_wrapper_at_iter (SidebarTree* self,
                                  GtkTreeIter* iter)
{
	SidebarTreeEntryWrapper* result = NULL;
	GValue val = {0};
	GtkTreeStore* _tmp0_;
	GtkTreeIter _tmp1_;
	GValue _tmp2_ = {0};
	SidebarTreeEntryWrapper* wrapper = NULL;
	GValue _tmp3_;
	SidebarTreeEntryWrapper* _tmp4_;
	SidebarTreeEntryWrapper* _tmp5_;
#line 225 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (SIDEBAR_IS_TREE (self), NULL);
#line 225 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (iter != NULL, NULL);
#line 227 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = self->priv->store;
#line 227 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp1_ = *iter;
#line 227 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	gtk_tree_model_get_value (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, gtk_tree_model_get_type (), GtkTreeModel), &_tmp1_, (gint) SIDEBAR_TREE_COLUMNS_WRAPPER, &_tmp2_);
#line 227 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	G_IS_VALUE (&val) ? (g_value_unset (&val), NULL) : NULL;
#line 227 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	val = _tmp2_;
#line 229 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp3_ = val;
#line 229 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp4_ = _g_object_ref0 (g_value_get_object (&_tmp3_));
#line 229 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	wrapper = _tmp4_;
#line 230 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp5_ = wrapper;
#line 230 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp5_ == NULL) {
#line 1749 "Tree.c"
		GtkTreeStore* _tmp6_;
		GtkTreeIter _tmp7_;
		GtkTreePath* _tmp8_;
		GtkTreePath* _tmp9_;
		gchar* _tmp10_;
		gchar* _tmp11_;
#line 231 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp6_ = self->priv->store;
#line 231 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp7_ = *iter;
#line 231 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp8_ = gtk_tree_model_get_path (G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, gtk_tree_model_get_type (), GtkTreeModel), &_tmp7_);
#line 231 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp9_ = _tmp8_;
#line 231 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp10_ = gtk_tree_path_to_string (_tmp9_);
#line 231 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp11_ = _tmp10_;
#line 231 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		g_message ("Tree.vala:231: No entry found in sidebar at %s", _tmp11_);
#line 231 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_free0 (_tmp11_);
#line 231 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		__vala_GtkTreePath_free0 (_tmp9_);
#line 1774 "Tree.c"
	}
#line 233 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	result = wrapper;
#line 233 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	G_IS_VALUE (&val) ? (g_value_unset (&val), NULL) : NULL;
#line 233 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	return result;
#line 1782 "Tree.c"
}


static SidebarTreeEntryWrapper*
sidebar_tree_get_wrapper_at_path (SidebarTree* self,
                                  GtkTreePath* path)
{
	SidebarTreeEntryWrapper* result = NULL;
	GtkTreeIter iter = {0};
	GtkTreeStore* _tmp0_;
	GtkTreeIter _tmp1_ = {0};
	gboolean _tmp2_;
	GtkTreeIter _tmp5_;
	SidebarTreeEntryWrapper* _tmp6_;
#line 236 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (SIDEBAR_IS_TREE (self), NULL);
#line 236 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (path != NULL, NULL);
#line 238 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = self->priv->store;
#line 238 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp2_ = gtk_tree_model_get_iter (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, gtk_tree_model_get_type (), GtkTreeModel), &_tmp1_, path);
#line 238 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	iter = _tmp1_;
#line 238 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (!_tmp2_) {
#line 1809 "Tree.c"
		gchar* _tmp3_;
		gchar* _tmp4_;
#line 239 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp3_ = gtk_tree_path_to_string (path);
#line 239 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp4_ = _tmp3_;
#line 239 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		g_message ("Tree.vala:239: No entry found in sidebar at %s", _tmp4_);
#line 239 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_free0 (_tmp4_);
#line 241 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		result = NULL;
#line 241 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		return result;
#line 1824 "Tree.c"
	}
#line 244 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp5_ = iter;
#line 244 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp6_ = sidebar_tree_get_wrapper_at_iter (self, &_tmp5_);
#line 244 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	result = _tmp6_;
#line 244 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	return result;
#line 1834 "Tree.c"
}


gboolean
sidebar_tree_place_cursor (SidebarTree* self,
                           SidebarEntry* entry,
                           gboolean mask_signal)
{
	gboolean result = FALSE;
	SidebarTreeEntryWrapper* wrapper = NULL;
	SidebarTreeEntryWrapper* _tmp0_;
	SidebarTreeEntryWrapper* _tmp1_;
	GtkTreeSelection* _tmp2_;
	SidebarTreeEntryWrapper* _tmp3_;
	GtkTreePath* _tmp4_;
	GtkTreePath* _tmp5_;
	SidebarTreeEntryWrapper* _tmp6_;
	GtkTreePath* _tmp7_;
	GtkTreePath* _tmp8_;
#line 249 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (SIDEBAR_IS_TREE (self), FALSE);
#line 249 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (SIDEBAR_IS_ENTRY (entry), FALSE);
#line 250 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (!sidebar_tree_expand_to_entry (self, entry)) {
#line 251 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		result = FALSE;
#line 251 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		return result;
#line 1864 "Tree.c"
	}
#line 253 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = sidebar_tree_get_wrapper (self, entry);
#line 253 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	wrapper = _tmp0_;
#line 254 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp1_ = wrapper;
#line 254 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp1_ == NULL) {
#line 255 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		result = FALSE;
#line 255 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (wrapper);
#line 255 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		return result;
#line 1880 "Tree.c"
	}
#line 257 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp2_ = gtk_tree_view_get_selection (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_view_get_type (), GtkTreeView));
#line 257 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp3_ = wrapper;
#line 257 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp4_ = sidebar_tree_entry_wrapper_get_path (_tmp3_);
#line 257 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp5_ = _tmp4_;
#line 257 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	gtk_tree_selection_select_path (_tmp2_, _tmp5_);
#line 257 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	__vala_GtkTreePath_free0 (_tmp5_);
#line 259 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	self->priv->mask_entry_selected_signal = mask_signal;
#line 260 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp6_ = wrapper;
#line 260 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp7_ = sidebar_tree_entry_wrapper_get_path (_tmp6_);
#line 260 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp8_ = _tmp7_;
#line 260 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	gtk_tree_view_set_cursor (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_view_get_type (), GtkTreeView), _tmp8_, NULL, FALSE);
#line 260 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	__vala_GtkTreePath_free0 (_tmp8_);
#line 261 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	self->priv->mask_entry_selected_signal = FALSE;
#line 263 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	result = sidebar_tree_scroll_to_entry (self, entry);
#line 263 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (wrapper);
#line 263 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	return result;
#line 1914 "Tree.c"
}


gboolean
sidebar_tree_is_selected (SidebarTree* self,
                          SidebarEntry* entry)
{
	gboolean result = FALSE;
	SidebarTreeEntryWrapper* wrapper = NULL;
	SidebarTreeEntryWrapper* _tmp0_;
	GtkTreeSelection* selection = NULL;
	GtkTreeSelection* _tmp1_;
	GtkTreeSelection* _tmp2_;
	GtkTreeSelection* _tmp3_;
	gboolean _tmp4_ = FALSE;
	SidebarTreeEntryWrapper* _tmp5_;
#line 266 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (SIDEBAR_IS_TREE (self), FALSE);
#line 266 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (SIDEBAR_IS_ENTRY (entry), FALSE);
#line 267 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = sidebar_tree_get_wrapper (self, entry);
#line 267 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	wrapper = _tmp0_;
#line 271 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp1_ = gtk_tree_view_get_selection (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_view_get_type (), GtkTreeView));
#line 271 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 271 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	selection = _tmp2_;
#line 272 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp3_ = selection;
#line 272 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp3_ == NULL) {
#line 273 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		result = FALSE;
#line 273 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (selection);
#line 273 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (wrapper);
#line 273 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		return result;
#line 1957 "Tree.c"
	}
#line 275 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp5_ = wrapper;
#line 275 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp5_ != NULL) {
#line 1963 "Tree.c"
		GtkTreeSelection* _tmp6_;
		SidebarTreeEntryWrapper* _tmp7_;
		GtkTreePath* _tmp8_;
		GtkTreePath* _tmp9_;
#line 275 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp6_ = selection;
#line 275 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp7_ = wrapper;
#line 275 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp8_ = sidebar_tree_entry_wrapper_get_path (_tmp7_);
#line 275 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp9_ = _tmp8_;
#line 275 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp4_ = gtk_tree_selection_path_is_selected (_tmp6_, _tmp9_);
#line 275 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		__vala_GtkTreePath_free0 (_tmp9_);
#line 1980 "Tree.c"
	} else {
#line 275 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp4_ = FALSE;
#line 1984 "Tree.c"
	}
#line 275 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	result = _tmp4_;
#line 275 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (selection);
#line 275 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (wrapper);
#line 275 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	return result;
#line 1994 "Tree.c"
}


gboolean
sidebar_tree_is_any_selected (SidebarTree* self)
{
	gboolean result = FALSE;
	GtkTreeSelection* _tmp0_;
#line 278 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (SIDEBAR_IS_TREE (self), FALSE);
#line 279 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = gtk_tree_view_get_selection (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_view_get_type (), GtkTreeView));
#line 279 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	result = gtk_tree_selection_count_selected_rows (_tmp0_) != 0;
#line 279 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	return result;
#line 2011 "Tree.c"
}


static GtkTreePath*
_vala_GtkTreePath_copy (GtkTreePath* self)
{
#line 291 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	return g_boxed_copy (gtk_tree_path_get_type (), self);
#line 2020 "Tree.c"
}


static gpointer
__vala_GtkTreePath_copy0 (gpointer self)
{
#line 291 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	return self ? _vala_GtkTreePath_copy (self) : NULL;
#line 2029 "Tree.c"
}


static void
__vala_GtkTreePath_free0_ (gpointer var)
{
#line 291 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	(var == NULL) ? NULL : (var = (_vala_GtkTreePath_free (var), NULL));
#line 2038 "Tree.c"
}


static inline void
_g_list_free___vala_GtkTreePath_free0_ (GList* self)
{
#line 291 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_list_free_full (self, (GDestroyNotify) __vala_GtkTreePath_free0_);
#line 2047 "Tree.c"
}


static GtkTreePath*
sidebar_tree_get_selected_path (SidebarTree* self)
{
	GtkTreePath* result = NULL;
	GtkTreeModel* model = NULL;
	GtkTreeSelection* selection = NULL;
	GtkTreeSelection* _tmp0_;
	GtkTreeSelection* _tmp1_;
	GtkTreeSelection* _tmp2_;
	GList* rows = NULL;
	GtkTreeSelection* _tmp3_;
	GtkTreeModel* _tmp4_ = NULL;
	GList* _tmp5_;
	GtkTreeModel* _tmp6_;
	gboolean _tmp7_ = FALSE;
	GList* _tmp8_;
	GtkTreePath* _tmp10_ = NULL;
	GList* _tmp11_;
	GtkTreePath* _tmp14_;
#line 282 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (SIDEBAR_IS_TREE (self), NULL);
#line 284 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = gtk_tree_view_get_selection (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_view_get_type (), GtkTreeView));
#line 284 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 284 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	selection = _tmp1_;
#line 285 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp2_ = selection;
#line 285 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp2_ == NULL) {
#line 286 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		result = NULL;
#line 286 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (selection);
#line 286 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (model);
#line 286 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		return result;
#line 2090 "Tree.c"
	}
#line 288 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp3_ = selection;
#line 288 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp5_ = gtk_tree_selection_get_selected_rows (_tmp3_, &_tmp4_);
#line 288 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (model);
#line 288 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp6_ = _g_object_ref0 (_tmp4_);
#line 288 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	model = _tmp6_;
#line 288 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	rows = _tmp5_;
#line 289 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp8_ = rows;
#line 289 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (g_list_length (_tmp8_) == ((guint) 0)) {
#line 289 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp7_ = TRUE;
#line 2110 "Tree.c"
	} else {
		GList* _tmp9_;
#line 289 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp9_ = rows;
#line 289 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp7_ = g_list_length (_tmp9_) == ((guint) 1);
#line 2117 "Tree.c"
	}
#line 289 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_vala_assert (_tmp7_, "rows.length() == 0 || rows.length() == 1");
#line 291 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp11_ = rows;
#line 291 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (g_list_length (_tmp11_) != ((guint) 0)) {
#line 2125 "Tree.c"
		GList* _tmp12_;
		gconstpointer _tmp13_;
#line 291 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp12_ = rows;
#line 291 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp13_ = g_list_nth_data (_tmp12_, (guint) 0);
#line 291 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp10_ = (GtkTreePath*) _tmp13_;
#line 2134 "Tree.c"
	} else {
#line 291 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp10_ = NULL;
#line 2138 "Tree.c"
	}
#line 291 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp14_ = __vala_GtkTreePath_copy0 (_tmp10_);
#line 291 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	result = _tmp14_;
#line 291 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	__g_list_free___vala_GtkTreePath_free0_0 (rows);
#line 291 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (selection);
#line 291 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (model);
#line 291 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	return result;
#line 2152 "Tree.c"
}


static gchar*
sidebar_tree_get_name_for_entry (SidebarTree* self,
                                 SidebarEntry* entry)
{
	gchar* result = NULL;
	gchar* name = NULL;
	gchar* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	SidebarEmphasizableEntry* emphasizable_entry = NULL;
	SidebarEmphasizableEntry* _tmp4_;
	gboolean _tmp5_ = FALSE;
	SidebarEmphasizableEntry* _tmp6_;
#line 294 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (SIDEBAR_IS_TREE (self), NULL);
#line 294 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (SIDEBAR_IS_ENTRY (entry), NULL);
#line 295 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = sidebar_entry_get_sidebar_name (entry);
#line 295 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp1_ = _tmp0_;
#line 295 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp2_ = guarded_markup_escape_text (_tmp1_);
#line 295 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp3_ = _tmp2_;
#line 295 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_free0 (_tmp1_);
#line 295 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	name = _tmp3_;
#line 297 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp4_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (entry, SIDEBAR_TYPE_EMPHASIZABLE_ENTRY) ? ((SidebarEmphasizableEntry*) entry) : NULL);
#line 297 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	emphasizable_entry = _tmp4_;
#line 298 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp6_ = emphasizable_entry;
#line 298 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp6_ != NULL) {
#line 2194 "Tree.c"
		SidebarEmphasizableEntry* _tmp7_;
#line 298 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp7_ = emphasizable_entry;
#line 298 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp5_ = sidebar_emphasizable_entry_is_emphasized (_tmp7_);
#line 2200 "Tree.c"
	} else {
#line 298 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp5_ = FALSE;
#line 2204 "Tree.c"
	}
#line 298 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp5_) {
#line 2208 "Tree.c"
		const gchar* _tmp8_;
		gchar* _tmp9_;
#line 299 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp8_ = name;
#line 299 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp9_ = g_strdup_printf ("<b>%s</b>", _tmp8_);
#line 299 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_free0 (name);
#line 299 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		name = _tmp9_;
#line 2219 "Tree.c"
	}
#line 301 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	result = name;
#line 301 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (emphasizable_entry);
#line 301 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	return result;
#line 2227 "Tree.c"
}


static gboolean
sidebar_tree_real_accept_cursor_changed (SidebarTree* self)
{
	gboolean result = FALSE;
#line 305 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	result = TRUE;
#line 305 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	return result;
#line 2239 "Tree.c"
}


gboolean
sidebar_tree_accept_cursor_changed (SidebarTree* self)
{
#line 304 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (SIDEBAR_IS_TREE (self), FALSE);
#line 304 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	return SIDEBAR_TREE_GET_CLASS (self)->accept_cursor_changed (self);
#line 2250 "Tree.c"
}


static void
sidebar_tree_real_cursor_changed (GtkTreeView* base)
{
	SidebarTree * self;
	GtkTreePath* path = NULL;
	GtkTreePath* _tmp0_;
	GtkTreePath* _tmp1_;
	SidebarTreeEntryWrapper* wrapper = NULL;
	GtkTreePath* _tmp2_;
	SidebarTreeEntryWrapper* _tmp3_;
	SidebarTreeEntryWrapper* _tmp4_;
	SidebarTreeEntryWrapper* _tmp5_;
#line 308 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, SIDEBAR_TYPE_TREE, SidebarTree);
#line 309 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = sidebar_tree_get_selected_path (self);
#line 309 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	path = _tmp0_;
#line 310 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp1_ = path;
#line 310 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp1_ == NULL) {
#line 311 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		if (GTK_TREE_VIEW_CLASS (sidebar_tree_parent_class)->cursor_changed != NULL) {
#line 312 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			GTK_TREE_VIEW_CLASS (sidebar_tree_parent_class)->cursor_changed (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_view_get_type (), GtkTreeView));
#line 2280 "Tree.c"
		}
#line 313 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		__vala_GtkTreePath_free0 (path);
#line 313 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		return;
#line 2286 "Tree.c"
	}
#line 316 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp2_ = path;
#line 316 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp3_ = sidebar_tree_get_wrapper_at_path (self, _tmp2_);
#line 316 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	wrapper = _tmp3_;
#line 318 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp4_ = self->priv->selected_wrapper;
#line 318 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp5_ = wrapper;
#line 318 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp4_ != _tmp5_) {
#line 2300 "Tree.c"
		SidebarTreeEntryWrapper* old_wrapper = NULL;
		SidebarTreeEntryWrapper* _tmp6_;
		SidebarTreeEntryWrapper* _tmp7_;
		SidebarTreeEntryWrapper* _tmp8_;
		gboolean _tmp9_ = FALSE;
		gboolean _tmp10_ = FALSE;
		gint _tmp11_;
		gboolean _tmp18_ = FALSE;
		SidebarTreeEntryWrapper* _tmp19_;
#line 319 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp6_ = self->priv->selected_wrapper;
#line 319 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp7_ = _g_object_ref0 (_tmp6_);
#line 319 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		old_wrapper = _tmp7_;
#line 320 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp8_ = wrapper;
#line 320 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		self->priv->selected_wrapper = _tmp8_;
#line 322 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp11_ = self->priv->editing_disabled;
#line 322 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		if (_tmp11_ == 0) {
#line 2324 "Tree.c"
			SidebarTreeEntryWrapper* _tmp12_;
#line 322 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp12_ = wrapper;
#line 322 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp10_ = _tmp12_ != NULL;
#line 2330 "Tree.c"
		} else {
#line 322 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp10_ = FALSE;
#line 2334 "Tree.c"
		}
#line 322 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		if (_tmp10_) {
#line 2338 "Tree.c"
			SidebarTreeEntryWrapper* _tmp13_;
			SidebarEntry* _tmp14_;
#line 322 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp13_ = wrapper;
#line 322 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp14_ = _tmp13_->entry;
#line 322 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp9_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp14_, SIDEBAR_TYPE_RENAMEABLE_ENTRY);
#line 2347 "Tree.c"
		} else {
#line 322 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp9_ = FALSE;
#line 2351 "Tree.c"
		}
#line 322 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		if (_tmp9_) {
#line 2355 "Tree.c"
			GtkCellRendererText* _tmp15_;
			SidebarTreeEntryWrapper* _tmp16_;
			SidebarEntry* _tmp17_;
#line 323 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp15_ = self->priv->text_renderer;
#line 323 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp16_ = wrapper;
#line 323 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp17_ = _tmp16_->entry;
#line 323 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			g_object_set (_tmp15_, "editable", sidebar_renameable_entry_is_user_renameable (G_TYPE_CHECK_INSTANCE_CAST (_tmp17_, SIDEBAR_TYPE_RENAMEABLE_ENTRY, SidebarRenameableEntry)), NULL);
#line 2367 "Tree.c"
		}
#line 325 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp19_ = wrapper;
#line 325 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		if (_tmp19_ != NULL) {
#line 2373 "Tree.c"
			gboolean _tmp20_;
#line 325 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp20_ = self->priv->mask_entry_selected_signal;
#line 325 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp18_ = !_tmp20_;
#line 2379 "Tree.c"
		} else {
#line 325 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp18_ = FALSE;
#line 2383 "Tree.c"
		}
#line 325 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		if (_tmp18_) {
#line 2387 "Tree.c"
			SidebarSelectableEntry* selectable = NULL;
			SidebarTreeEntryWrapper* _tmp21_;
			SidebarEntry* _tmp22_;
			SidebarSelectableEntry* _tmp23_;
			SidebarSelectableEntry* _tmp24_;
#line 326 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp21_ = wrapper;
#line 326 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp22_ = _tmp21_->entry;
#line 326 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp23_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp22_, SIDEBAR_TYPE_SELECTABLE_ENTRY) ? ((SidebarSelectableEntry*) _tmp22_) : NULL);
#line 326 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			selectable = _tmp23_;
#line 327 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp24_ = selectable;
#line 327 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			if (_tmp24_ != NULL) {
#line 328 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				if (sidebar_tree_accept_cursor_changed (self)) {
#line 2407 "Tree.c"
					SidebarSelectableEntry* _tmp25_;
#line 329 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
					_tmp25_ = selectable;
#line 329 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
					g_signal_emit (self, sidebar_tree_signals[SIDEBAR_TREE_ENTRY_SELECTED_SIGNAL], 0, _tmp25_);
#line 2413 "Tree.c"
				} else {
					SidebarTreeEntryWrapper* _tmp26_;
					SidebarEntry* _tmp27_;
#line 331 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
					_tmp26_ = old_wrapper;
#line 331 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
					_tmp27_ = _tmp26_->entry;
#line 331 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
					sidebar_tree_place_cursor (self, _tmp27_, TRUE);
#line 2423 "Tree.c"
				}
			}
#line 325 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_g_object_unref0 (selectable);
#line 2428 "Tree.c"
		}
#line 318 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (old_wrapper);
#line 2432 "Tree.c"
	}
#line 337 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (GTK_TREE_VIEW_CLASS (sidebar_tree_parent_class)->cursor_changed != NULL) {
#line 338 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		GTK_TREE_VIEW_CLASS (sidebar_tree_parent_class)->cursor_changed (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_view_get_type (), GtkTreeView));
#line 2438 "Tree.c"
	}
#line 308 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (wrapper);
#line 308 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	__vala_GtkTreePath_free0 (path);
#line 2444 "Tree.c"
}


void
sidebar_tree_disable_editing (SidebarTree* self)
{
	gint _tmp0_;
#line 341 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_TREE (self));
#line 342 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = self->priv->editing_disabled;
#line 342 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	self->priv->editing_disabled = _tmp0_ + 1;
#line 342 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp0_ == 0) {
#line 2460 "Tree.c"
		GtkCellRendererText* _tmp1_;
#line 343 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp1_ = self->priv->text_renderer;
#line 343 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		g_object_set (_tmp1_, "editable", FALSE, NULL);
#line 2466 "Tree.c"
	}
}


void
sidebar_tree_enable_editing (SidebarTree* self)
{
	GtkTreePath* path = NULL;
	GtkTreePath* _tmp0_;
	gboolean _tmp1_ = FALSE;
	gboolean _tmp2_ = FALSE;
	GtkTreePath* _tmp3_;
#line 346 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_TREE (self));
#line 347 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = sidebar_tree_get_selected_path (self);
#line 347 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	path = _tmp0_;
#line 348 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp3_ = path;
#line 348 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp3_ != NULL) {
#line 2489 "Tree.c"
		gint _tmp4_;
#line 348 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp4_ = self->priv->editing_disabled;
#line 348 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp2_ = _tmp4_ > 0;
#line 2495 "Tree.c"
	} else {
#line 348 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp2_ = FALSE;
#line 2499 "Tree.c"
	}
#line 348 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp2_) {
#line 2503 "Tree.c"
		gint _tmp5_;
		gint _tmp6_;
#line 348 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp5_ = self->priv->editing_disabled;
#line 348 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		self->priv->editing_disabled = _tmp5_ - 1;
#line 348 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp6_ = self->priv->editing_disabled;
#line 348 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp1_ = _tmp6_ == 0;
#line 2514 "Tree.c"
	} else {
#line 348 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp1_ = FALSE;
#line 2518 "Tree.c"
	}
#line 348 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp1_) {
#line 2522 "Tree.c"
		SidebarTreeEntryWrapper* wrapper = NULL;
		GtkTreePath* _tmp7_;
		SidebarTreeEntryWrapper* _tmp8_;
		gboolean _tmp9_ = FALSE;
		SidebarTreeEntryWrapper* _tmp10_;
#line 349 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp7_ = path;
#line 349 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp8_ = sidebar_tree_get_wrapper_at_path (self, _tmp7_);
#line 349 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		wrapper = _tmp8_;
#line 350 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp10_ = wrapper;
#line 350 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		if (_tmp10_ != NULL) {
#line 2538 "Tree.c"
			SidebarTreeEntryWrapper* _tmp11_;
			SidebarEntry* _tmp12_;
#line 350 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp11_ = wrapper;
#line 350 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp12_ = _tmp11_->entry;
#line 350 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp9_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp12_, SIDEBAR_TYPE_RENAMEABLE_ENTRY);
#line 2547 "Tree.c"
		} else {
#line 350 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp9_ = FALSE;
#line 2551 "Tree.c"
		}
#line 350 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		if (_tmp9_) {
#line 2555 "Tree.c"
			GtkCellRendererText* _tmp13_;
			SidebarTreeEntryWrapper* _tmp14_;
			SidebarEntry* _tmp15_;
#line 351 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp13_ = self->priv->text_renderer;
#line 351 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp14_ = wrapper;
#line 351 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp15_ = _tmp14_->entry;
#line 351 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			g_object_set (_tmp13_, "editable", sidebar_renameable_entry_is_user_renameable (G_TYPE_CHECK_INSTANCE_CAST (_tmp15_, SIDEBAR_TYPE_RENAMEABLE_ENTRY, SidebarRenameableEntry)), NULL);
#line 2567 "Tree.c"
		}
#line 348 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (wrapper);
#line 2571 "Tree.c"
	}
#line 346 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	__vala_GtkTreePath_free0 (path);
#line 2575 "Tree.c"
}


void
sidebar_tree_toggle_branch_expansion (SidebarTree* self,
                                      GtkTreePath* path,
                                      gboolean expand_all)
{
#line 356 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_TREE (self));
#line 356 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (path != NULL);
#line 357 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	self->priv->expander_called_manually = TRUE;
#line 358 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (gtk_tree_view_row_expanded (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_view_get_type (), GtkTreeView), path)) {
#line 359 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		gtk_tree_view_collapse_row (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_view_get_type (), GtkTreeView), path);
#line 2594 "Tree.c"
	} else {
#line 361 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		gtk_tree_view_expand_row (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_view_get_type (), GtkTreeView), path, expand_all);
#line 2598 "Tree.c"
	}
}


gboolean
sidebar_tree_expand_to_entry (SidebarTree* self,
                              SidebarEntry* entry)
{
	gboolean result = FALSE;
	SidebarTreeEntryWrapper* wrapper = NULL;
	SidebarTreeEntryWrapper* _tmp0_;
	SidebarTreeEntryWrapper* _tmp1_;
	SidebarTreeEntryWrapper* _tmp2_;
	GtkTreePath* _tmp3_;
	GtkTreePath* _tmp4_;
#line 364 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (SIDEBAR_IS_TREE (self), FALSE);
#line 364 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (SIDEBAR_IS_ENTRY (entry), FALSE);
#line 365 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	self->priv->expander_called_manually = TRUE;
#line 366 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = sidebar_tree_get_wrapper (self, entry);
#line 366 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	wrapper = _tmp0_;
#line 367 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp1_ = wrapper;
#line 367 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp1_ == NULL) {
#line 368 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		result = FALSE;
#line 368 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (wrapper);
#line 368 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		return result;
#line 2634 "Tree.c"
	}
#line 370 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp2_ = wrapper;
#line 370 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp3_ = sidebar_tree_entry_wrapper_get_path (_tmp2_);
#line 370 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp4_ = _tmp3_;
#line 370 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	gtk_tree_view_expand_to_path (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_view_get_type (), GtkTreeView), _tmp4_);
#line 370 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	__vala_GtkTreePath_free0 (_tmp4_);
#line 372 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	result = TRUE;
#line 372 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (wrapper);
#line 372 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	return result;
#line 2652 "Tree.c"
}


void
sidebar_tree_expand_to_first_child (SidebarTree* self,
                                    SidebarEntry* entry)
{
	SidebarTreeEntryWrapper* wrapper = NULL;
	SidebarTreeEntryWrapper* _tmp0_;
	SidebarTreeEntryWrapper* _tmp1_;
	GtkTreePath* path = NULL;
	SidebarTreeEntryWrapper* _tmp2_;
	GtkTreePath* _tmp3_;
	GtkTreeIter iter = {0};
	GtkTreePath* _tmp11_;
#line 375 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_TREE (self));
#line 375 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_ENTRY (entry));
#line 376 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	self->priv->expander_called_manually = TRUE;
#line 377 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = sidebar_tree_get_wrapper (self, entry);
#line 377 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	wrapper = _tmp0_;
#line 378 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp1_ = wrapper;
#line 378 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp1_ == NULL) {
#line 379 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (wrapper);
#line 379 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		return;
#line 2686 "Tree.c"
	}
#line 381 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp2_ = wrapper;
#line 381 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp3_ = sidebar_tree_entry_wrapper_get_path (_tmp2_);
#line 381 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	path = _tmp3_;
#line 384 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	while (TRUE) {
#line 2696 "Tree.c"
		GtkTreeStore* _tmp4_;
		GtkTreePath* _tmp5_;
		GtkTreeIter _tmp6_ = {0};
		gboolean _tmp7_;
		GtkTreeStore* _tmp8_;
		GtkTreeIter _tmp9_;
		GtkTreePath* _tmp10_;
#line 384 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp4_ = self->priv->store;
#line 384 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp5_ = path;
#line 384 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp7_ = gtk_tree_model_get_iter (G_TYPE_CHECK_INSTANCE_CAST (_tmp4_, gtk_tree_model_get_type (), GtkTreeModel), &_tmp6_, _tmp5_);
#line 384 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		iter = _tmp6_;
#line 384 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		if (!_tmp7_) {
#line 384 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			break;
#line 2716 "Tree.c"
		}
#line 385 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp8_ = self->priv->store;
#line 385 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp9_ = iter;
#line 385 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		if (!gtk_tree_model_iter_has_child (G_TYPE_CHECK_INSTANCE_CAST (_tmp8_, gtk_tree_model_get_type (), GtkTreeModel), &_tmp9_)) {
#line 386 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			break;
#line 2726 "Tree.c"
		}
#line 388 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp10_ = path;
#line 388 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		gtk_tree_path_down (_tmp10_);
#line 2732 "Tree.c"
	}
#line 391 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp11_ = path;
#line 391 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	gtk_tree_view_expand_to_path (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_view_get_type (), GtkTreeView), _tmp11_);
#line 375 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	__vala_GtkTreePath_free0 (path);
#line 375 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (wrapper);
#line 2742 "Tree.c"
}


static void
_sidebar_tree_on_branch_entry_added_sidebar_branch_entry_added (SidebarBranch* _sender,
                                                                SidebarEntry* entry,
                                                                gpointer self)
{
#line 409 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	sidebar_tree_on_branch_entry_added ((SidebarTree*) self, _sender, entry);
#line 2753 "Tree.c"
}


static void
_sidebar_tree_on_branch_entry_removed_sidebar_branch_entry_removed (SidebarBranch* _sender,
                                                                    SidebarEntry* entry,
                                                                    gpointer self)
{
#line 410 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	sidebar_tree_on_branch_entry_removed ((SidebarTree*) self, _sender, entry);
#line 2764 "Tree.c"
}


static void
_sidebar_tree_on_branch_entry_moved_sidebar_branch_entry_moved (SidebarBranch* _sender,
                                                                SidebarEntry* entry,
                                                                gpointer self)
{
#line 411 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	sidebar_tree_on_branch_entry_moved ((SidebarTree*) self, _sender, entry);
#line 2775 "Tree.c"
}


static void
_sidebar_tree_on_branch_entry_reparented_sidebar_branch_entry_reparented (SidebarBranch* _sender,
                                                                          SidebarEntry* entry,
                                                                          SidebarEntry* old_parent,
                                                                          gpointer self)
{
#line 412 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	sidebar_tree_on_branch_entry_reparented ((SidebarTree*) self, _sender, entry, old_parent);
#line 2787 "Tree.c"
}


static void
_sidebar_tree_on_branch_children_reordered_sidebar_branch_children_reordered (SidebarBranch* _sender,
                                                                              SidebarEntry* entry,
                                                                              gpointer self)
{
#line 413 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	sidebar_tree_on_branch_children_reordered ((SidebarTree*) self, _sender, entry);
#line 2798 "Tree.c"
}


static void
_sidebar_tree_on_show_branch_sidebar_branch_show_branch (SidebarBranch* _sender,
                                                         gboolean show,
                                                         gpointer self)
{
#line 414 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	sidebar_tree_on_show_branch ((SidebarTree*) self, _sender, show);
#line 2809 "Tree.c"
}


void
sidebar_tree_graft (SidebarTree* self,
                    SidebarBranch* branch,
                    gint position)
{
	GeeHashMap* _tmp0_;
	GeeHashMap* _tmp1_;
#line 394 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_TREE (self));
#line 394 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_BRANCH (branch));
#line 394 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_vala_return_if_fail (position >= 0, "position >= 0");
#line 395 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = self->priv->branches;
#line 395 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_vala_assert (!gee_abstract_map_has_key (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), branch), "!branches.has_key(branch)");
#line 397 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp1_ = self->priv->branches;
#line 397 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	gee_abstract_map_set (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), branch, (gpointer) ((gintptr) position));
#line 399 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (sidebar_branch_get_show_branch (branch)) {
#line 400 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		sidebar_tree_associate_branch (self, branch);
#line 402 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		if (sidebar_branch_is_startup_expand_to_first_child (branch)) {
#line 2840 "Tree.c"
			SidebarEntry* _tmp2_;
			SidebarEntry* _tmp3_;
#line 403 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp2_ = sidebar_branch_get_root (branch);
#line 403 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp3_ = _tmp2_;
#line 403 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			sidebar_tree_expand_to_first_child (self, _tmp3_);
#line 403 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_g_object_unref0 (_tmp3_);
#line 2851 "Tree.c"
		}
#line 405 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		if (sidebar_branch_is_startup_open_grouping (branch)) {
#line 2855 "Tree.c"
			SidebarEntry* _tmp4_;
			SidebarEntry* _tmp5_;
#line 406 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp4_ = sidebar_branch_get_root (branch);
#line 406 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp5_ = _tmp4_;
#line 406 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			sidebar_tree_expand_to_entry (self, _tmp5_);
#line 406 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_g_object_unref0 (_tmp5_);
#line 2866 "Tree.c"
		}
	}
#line 409 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_signal_connect_object (branch, "entry-added", (GCallback) _sidebar_tree_on_branch_entry_added_sidebar_branch_entry_added, self, 0);
#line 410 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_signal_connect_object (branch, "entry-removed", (GCallback) _sidebar_tree_on_branch_entry_removed_sidebar_branch_entry_removed, self, 0);
#line 411 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_signal_connect_object (branch, "entry-moved", (GCallback) _sidebar_tree_on_branch_entry_moved_sidebar_branch_entry_moved, self, 0);
#line 412 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_signal_connect_object (branch, "entry-reparented", (GCallback) _sidebar_tree_on_branch_entry_reparented_sidebar_branch_entry_reparented, self, 0);
#line 413 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_signal_connect_object (branch, "children-reordered", (GCallback) _sidebar_tree_on_branch_children_reordered_sidebar_branch_children_reordered, self, 0);
#line 414 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_signal_connect_object (branch, "show-branch", (GCallback) _sidebar_tree_on_show_branch_sidebar_branch_show_branch, self, 0);
#line 416 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_signal_emit (self, sidebar_tree_signals[SIDEBAR_TREE_BRANCH_ADDED_SIGNAL], 0, branch);
#line 2883 "Tree.c"
}


static GtkTreeIter*
_gtk_tree_iter_dup (GtkTreeIter* self)
{
	GtkTreeIter* dup;
#line 435 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	dup = g_new0 (GtkTreeIter, 1);
#line 435 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	memcpy (dup, self, sizeof (GtkTreeIter));
#line 435 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	return dup;
#line 2897 "Tree.c"
}


static gpointer
__gtk_tree_iter_dup0 (gpointer self)
{
#line 435 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	return self ? _gtk_tree_iter_dup (self) : NULL;
#line 2906 "Tree.c"
}


static void
sidebar_tree_associate_branch (SidebarTree* self,
                               SidebarBranch* branch)
{
	GeeHashMap* _tmp0_;
	gint position = 0;
	GeeHashMap* _tmp1_;
	gpointer _tmp2_;
	GtkTreeIter* insertion_iter = NULL;
	GtkTreeIter iter = {0};
	gboolean found = FALSE;
	GtkTreeStore* _tmp3_;
	GtkTreeIter _tmp4_ = {0};
	gboolean _tmp5_;
	GtkTreeIter* _tmp21_;
	GtkTreeIter* _tmp26_;
	GtkTreeStore* _tmp27_;
	SidebarEntry* _tmp28_;
	SidebarEntry* _tmp29_;
	GtkTreeStore* _tmp30_;
	GtkTreeIter* _tmp31_;
	GtkTreeIter _tmp32_;
	GtkTreePath* _tmp33_;
	GtkTreePath* _tmp34_;
	gint _tmp35_;
	SidebarTreeRootWrapper* _tmp36_;
	SidebarTreeRootWrapper* _tmp37_;
	GtkTreeIter _tmp38_;
	SidebarEntry* _tmp39_;
	SidebarEntry* _tmp40_;
	GtkTreeIter* _tmp41_;
	GtkTreeIter _tmp42_;
#line 420 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_TREE (self));
#line 420 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_BRANCH (branch));
#line 421 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = self->priv->branches;
#line 421 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_vala_assert (gee_abstract_map_has_key (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), branch), "branches.has_key(branch)");
#line 423 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp1_ = self->priv->branches;
#line 423 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp2_ = gee_abstract_map_get (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), branch);
#line 423 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	position = (gint) ((gintptr) _tmp2_);
#line 425 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	insertion_iter = NULL;
#line 429 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp3_ = self->priv->store;
#line 429 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp5_ = gtk_tree_model_get_iter_first (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, gtk_tree_model_get_type (), GtkTreeModel), &_tmp4_);
#line 429 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	iter = _tmp4_;
#line 429 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	found = _tmp5_;
#line 430 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	while (TRUE) {
#line 2968 "Tree.c"
		gboolean _tmp6_;
		SidebarTreeRootWrapper* root_wrapper = NULL;
		GtkTreeIter _tmp7_;
		SidebarTreeEntryWrapper* _tmp8_;
		SidebarTreeRootWrapper* _tmp9_;
		SidebarTreeRootWrapper* _tmp10_;
		gint _tmp11_;
		SidebarTreeRootWrapper* _tmp12_;
		gint _tmp13_;
		GtkTreeStore* _tmp19_;
		gboolean _tmp20_;
#line 430 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp6_ = found;
#line 430 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		if (!_tmp6_) {
#line 430 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			break;
#line 2986 "Tree.c"
		}
#line 431 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp7_ = iter;
#line 431 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp8_ = sidebar_tree_get_wrapper_at_iter (self, &_tmp7_);
#line 431 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp9_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp8_, SIDEBAR_TREE_TYPE_ROOT_WRAPPER) ? ((SidebarTreeRootWrapper*) _tmp8_) : NULL;
#line 431 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		if (_tmp9_ == NULL) {
#line 431 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_g_object_unref0 (_tmp8_);
#line 2998 "Tree.c"
		}
#line 431 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		root_wrapper = _tmp9_;
#line 432 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp10_ = root_wrapper;
#line 432 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_vala_assert (_tmp10_ != NULL, "root_wrapper != null");
#line 434 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp11_ = position;
#line 434 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp12_ = root_wrapper;
#line 434 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp13_ = _tmp12_->root_position;
#line 434 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		if (_tmp11_ < _tmp13_) {
#line 3014 "Tree.c"
			GtkTreeStore* _tmp14_;
			GtkTreeIter _tmp15_;
			GtkTreeIter _tmp16_ = {0};
			GtkTreeIter _tmp17_;
			GtkTreeIter* _tmp18_;
#line 435 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp14_ = self->priv->store;
#line 435 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp15_ = iter;
#line 435 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			gtk_tree_store_insert_before (_tmp14_, &_tmp16_, NULL, &_tmp15_);
#line 435 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_g_free0 (insertion_iter);
#line 435 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp17_ = _tmp16_;
#line 435 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp18_ = __gtk_tree_iter_dup0 (&_tmp17_);
#line 435 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			insertion_iter = _tmp18_;
#line 437 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_g_object_unref0 (root_wrapper);
#line 437 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			break;
#line 3038 "Tree.c"
		}
#line 440 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp19_ = self->priv->store;
#line 440 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp20_ = gtk_tree_model_iter_next (G_TYPE_CHECK_INSTANCE_CAST (_tmp19_, gtk_tree_model_get_type (), GtkTreeModel), &iter);
#line 440 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		found = _tmp20_;
#line 430 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (root_wrapper);
#line 3048 "Tree.c"
	}
#line 444 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp21_ = insertion_iter;
#line 444 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp21_ == NULL) {
#line 3054 "Tree.c"
		GtkTreeStore* _tmp22_;
		GtkTreeIter _tmp23_ = {0};
		GtkTreeIter _tmp24_;
		GtkTreeIter* _tmp25_;
#line 445 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp22_ = self->priv->store;
#line 445 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		gtk_tree_store_append (_tmp22_, &_tmp23_, NULL);
#line 445 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_free0 (insertion_iter);
#line 445 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp24_ = _tmp23_;
#line 445 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp25_ = __gtk_tree_iter_dup0 (&_tmp24_);
#line 445 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		insertion_iter = _tmp25_;
#line 3071 "Tree.c"
	}
#line 447 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp26_ = insertion_iter;
#line 447 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp27_ = self->priv->store;
#line 447 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp28_ = sidebar_branch_get_root (branch);
#line 447 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp29_ = _tmp28_;
#line 447 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp30_ = self->priv->store;
#line 447 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp31_ = insertion_iter;
#line 447 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp32_ = *_tmp31_;
#line 447 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp33_ = gtk_tree_model_get_path (G_TYPE_CHECK_INSTANCE_CAST (_tmp30_, gtk_tree_model_get_type (), GtkTreeModel), &_tmp32_);
#line 447 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp34_ = _tmp33_;
#line 447 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp35_ = position;
#line 447 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp36_ = sidebar_tree_root_wrapper_new (G_TYPE_CHECK_INSTANCE_CAST (_tmp27_, gtk_tree_model_get_type (), GtkTreeModel), _tmp29_, _tmp34_, _tmp35_);
#line 447 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp37_ = _tmp36_;
#line 447 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp38_ = *_tmp26_;
#line 447 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	sidebar_tree_associate_wrapper (self, &_tmp38_, G_TYPE_CHECK_INSTANCE_CAST (_tmp37_, SIDEBAR_TREE_TYPE_ENTRY_WRAPPER, SidebarTreeEntryWrapper));
#line 447 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (_tmp37_);
#line 447 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	__vala_GtkTreePath_free0 (_tmp34_);
#line 447 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (_tmp29_);
#line 452 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp39_ = sidebar_branch_get_root (branch);
#line 452 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp40_ = _tmp39_;
#line 452 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp41_ = insertion_iter;
#line 452 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp42_ = *_tmp41_;
#line 452 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	sidebar_tree_associate_children (self, branch, _tmp40_, &_tmp42_);
#line 452 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (_tmp40_);
#line 420 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_free0 (insertion_iter);
#line 3121 "Tree.c"
}


static void
sidebar_tree_associate_children (SidebarTree* self,
                                 SidebarBranch* branch,
                                 SidebarEntry* parent,
                                 GtkTreeIter* parent_iter)
{
	GeeList* children = NULL;
	GeeList* _tmp0_;
	GeeList* _tmp1_;
#line 455 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_TREE (self));
#line 455 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_BRANCH (branch));
#line 455 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_ENTRY (parent));
#line 455 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (parent_iter != NULL);
#line 457 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = sidebar_branch_get_children (branch, parent);
#line 457 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	children = _tmp0_;
#line 458 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp1_ = children;
#line 458 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp1_ == NULL) {
#line 459 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (children);
#line 459 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		return;
#line 3154 "Tree.c"
	}
	{
		GeeList* _child_list = NULL;
		GeeList* _tmp2_;
		GeeList* _tmp3_;
		gint _child_size = 0;
		GeeList* _tmp4_;
		gint _tmp5_;
		gint _tmp6_;
		gint _child_index = 0;
#line 461 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp2_ = children;
#line 461 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp3_ = _g_object_ref0 (_tmp2_);
#line 461 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_child_list = _tmp3_;
#line 461 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp4_ = _child_list;
#line 461 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp5_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp4_, GEE_TYPE_COLLECTION, GeeCollection));
#line 461 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp6_ = _tmp5_;
#line 461 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_child_size = _tmp6_;
#line 461 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_child_index = -1;
#line 461 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		while (TRUE) {
#line 3183 "Tree.c"
			gint _tmp7_;
			gint _tmp8_;
			gint _tmp9_;
			SidebarEntry* child = NULL;
			GeeList* _tmp10_;
			gint _tmp11_;
			gpointer _tmp12_;
			GtkTreeIter append_iter = {0};
			GtkTreeStore* _tmp13_;
			GtkTreeIter _tmp14_;
			GtkTreeIter _tmp15_ = {0};
			GtkTreeIter _tmp16_;
			SidebarEntry* _tmp17_;
			SidebarEntry* _tmp18_;
			GtkTreeIter _tmp19_;
#line 461 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp7_ = _child_index;
#line 461 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_child_index = _tmp7_ + 1;
#line 461 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp8_ = _child_index;
#line 461 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp9_ = _child_size;
#line 461 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			if (!(_tmp8_ < _tmp9_)) {
#line 461 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				break;
#line 3211 "Tree.c"
			}
#line 461 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp10_ = _child_list;
#line 461 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp11_ = _child_index;
#line 461 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp12_ = gee_list_get (_tmp10_, _tmp11_);
#line 461 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			child = (SidebarEntry*) _tmp12_;
#line 463 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp13_ = self->priv->store;
#line 463 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp14_ = *parent_iter;
#line 463 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			gtk_tree_store_append (_tmp13_, &_tmp15_, &_tmp14_);
#line 463 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			append_iter = _tmp15_;
#line 465 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp16_ = append_iter;
#line 465 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp17_ = child;
#line 465 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			sidebar_tree_associate_entry (self, &_tmp16_, _tmp17_);
#line 466 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp18_ = child;
#line 466 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp19_ = append_iter;
#line 466 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			sidebar_tree_associate_children (self, branch, _tmp18_, &_tmp19_);
#line 461 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_g_object_unref0 (child);
#line 3243 "Tree.c"
		}
#line 461 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (_child_list);
#line 3247 "Tree.c"
	}
#line 455 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (children);
#line 3251 "Tree.c"
}


static void
sidebar_tree_associate_entry (SidebarTree* self,
                              GtkTreeIter* assoc_iter,
                              SidebarEntry* entry)
{
	GtkTreeIter _tmp0_;
	GtkTreeStore* _tmp1_;
	GtkTreeStore* _tmp2_;
	GtkTreeIter _tmp3_;
	GtkTreePath* _tmp4_;
	GtkTreePath* _tmp5_;
	SidebarTreeEntryWrapper* _tmp6_;
	SidebarTreeEntryWrapper* _tmp7_;
#line 470 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_TREE (self));
#line 470 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (assoc_iter != NULL);
#line 470 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_ENTRY (entry));
#line 471 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = *assoc_iter;
#line 471 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp1_ = self->priv->store;
#line 471 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp2_ = self->priv->store;
#line 471 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp3_ = *assoc_iter;
#line 471 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp4_ = gtk_tree_model_get_path (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, gtk_tree_model_get_type (), GtkTreeModel), &_tmp3_);
#line 471 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp5_ = _tmp4_;
#line 471 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp6_ = sidebar_tree_entry_wrapper_new (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, gtk_tree_model_get_type (), GtkTreeModel), entry, _tmp5_);
#line 471 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp7_ = _tmp6_;
#line 471 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	sidebar_tree_associate_wrapper (self, &_tmp0_, _tmp7_);
#line 471 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (_tmp7_);
#line 471 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	__vala_GtkTreePath_free0 (_tmp5_);
#line 3296 "Tree.c"
}


static void
_sidebar_tree_on_sidebar_tooltip_changed_sidebar_entry_sidebar_tooltip_changed (SidebarEntry* _sender,
                                                                                const gchar* tooltip,
                                                                                gpointer self)
{
#line 485 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	sidebar_tree_on_sidebar_tooltip_changed ((SidebarTree*) self, _sender, tooltip);
#line 3307 "Tree.c"
}


static void
_sidebar_tree_on_sidebar_icon_changed_sidebar_entry_sidebar_icon_changed (SidebarEntry* _sender,
                                                                          const gchar* icon,
                                                                          gpointer self)
{
#line 486 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	sidebar_tree_on_sidebar_icon_changed ((SidebarTree*) self, _sender, icon);
#line 3318 "Tree.c"
}


static void
_sidebar_tree_on_sidebar_page_created_sidebar_page_representative_page_created (SidebarPageRepresentative* _sender,
                                                                                Page* page,
                                                                                gpointer self)
{
#line 490 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	sidebar_tree_on_sidebar_page_created ((SidebarTree*) self, _sender, page);
#line 3329 "Tree.c"
}


static void
_sidebar_tree_on_sidebar_destroying_page_sidebar_page_representative_destroying_page (SidebarPageRepresentative* _sender,
                                                                                      Page* page,
                                                                                      gpointer self)
{
#line 491 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	sidebar_tree_on_sidebar_destroying_page ((SidebarTree*) self, _sender, page);
#line 3340 "Tree.c"
}


static void
_sidebar_tree_on_is_emphasized_changed_sidebar_emphasizable_entry_is_emphasized_changed (SidebarEmphasizableEntry* _sender,
                                                                                         gboolean emphasized,
                                                                                         gpointer self)
{
#line 496 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	sidebar_tree_on_is_emphasized_changed ((SidebarTree*) self, _sender, emphasized);
#line 3351 "Tree.c"
}


static void
_sidebar_tree_on_sidebar_name_changed_sidebar_renameable_entry_sidebar_name_changed (SidebarRenameableEntry* _sender,
                                                                                     const gchar* name,
                                                                                     gpointer self)
{
#line 500 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	sidebar_tree_on_sidebar_name_changed ((SidebarTree*) self, _sender, name);
#line 3362 "Tree.c"
}


static void
sidebar_tree_associate_wrapper (SidebarTree* self,
                                GtkTreeIter* assoc_iter,
                                SidebarTreeEntryWrapper* wrapper)
{
	SidebarEntry* entry = NULL;
	SidebarEntry* _tmp0_;
	SidebarEntry* _tmp1_;
	GeeHashMap* _tmp2_;
	SidebarEntry* _tmp3_;
	GeeHashMap* _tmp4_;
	SidebarEntry* _tmp5_;
	GtkTreeStore* _tmp6_;
	GtkTreeIter _tmp7_;
	SidebarEntry* _tmp8_;
	gchar* _tmp9_;
	gchar* _tmp10_;
	GtkTreeStore* _tmp11_;
	GtkTreeIter _tmp12_;
	SidebarEntry* _tmp13_;
	gchar* _tmp14_;
	gchar* _tmp15_;
	gchar* _tmp16_;
	gchar* _tmp17_;
	GtkTreeStore* _tmp18_;
	GtkTreeIter _tmp19_;
	GtkTreeIter _tmp20_;
	SidebarEntry* _tmp21_;
	SidebarEntry* _tmp22_;
	SidebarPageRepresentative* pageable = NULL;
	SidebarEntry* _tmp23_;
	SidebarPageRepresentative* _tmp24_;
	SidebarPageRepresentative* _tmp25_;
	SidebarEmphasizableEntry* emphasizable = NULL;
	SidebarEntry* _tmp28_;
	SidebarEmphasizableEntry* _tmp29_;
	SidebarEmphasizableEntry* _tmp30_;
	SidebarRenameableEntry* renameable = NULL;
	SidebarEntry* _tmp32_;
	SidebarRenameableEntry* _tmp33_;
	SidebarRenameableEntry* _tmp34_;
	SidebarEntry* _tmp36_;
#line 474 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_TREE (self));
#line 474 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (assoc_iter != NULL);
#line 474 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_TREE_IS_ENTRY_WRAPPER (wrapper));
#line 475 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = wrapper->entry;
#line 475 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 475 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	entry = _tmp1_;
#line 477 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp2_ = self->priv->entry_map;
#line 477 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp3_ = entry;
#line 477 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_vala_assert (!gee_abstract_map_has_key (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), _tmp3_), "!entry_map.has_key(entry)");
#line 478 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp4_ = self->priv->entry_map;
#line 478 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp5_ = entry;
#line 478 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	gee_abstract_map_set (G_TYPE_CHECK_INSTANCE_CAST (_tmp4_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), _tmp5_, wrapper);
#line 480 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp6_ = self->priv->store;
#line 480 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp7_ = *assoc_iter;
#line 480 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp8_ = entry;
#line 480 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp9_ = sidebar_tree_get_name_for_entry (self, _tmp8_);
#line 480 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp10_ = _tmp9_;
#line 480 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	gtk_tree_store_set (_tmp6_, &_tmp7_, SIDEBAR_TREE_COLUMNS_NAME, _tmp10_, -1);
#line 480 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_free0 (_tmp10_);
#line 481 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp11_ = self->priv->store;
#line 481 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp12_ = *assoc_iter;
#line 481 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp13_ = entry;
#line 481 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp14_ = sidebar_entry_get_sidebar_tooltip (_tmp13_);
#line 481 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp15_ = _tmp14_;
#line 481 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp16_ = guarded_markup_escape_text (_tmp15_);
#line 481 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp17_ = _tmp16_;
#line 481 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	gtk_tree_store_set (_tmp11_, &_tmp12_, SIDEBAR_TREE_COLUMNS_TOOLTIP, _tmp17_, -1);
#line 481 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_free0 (_tmp17_);
#line 481 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_free0 (_tmp15_);
#line 482 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp18_ = self->priv->store;
#line 482 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp19_ = *assoc_iter;
#line 482 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	gtk_tree_store_set (_tmp18_, &_tmp19_, SIDEBAR_TREE_COLUMNS_WRAPPER, wrapper, -1);
#line 483 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp20_ = *assoc_iter;
#line 483 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	sidebar_tree_load_entry_icons (self, &_tmp20_);
#line 485 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp21_ = entry;
#line 485 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_signal_connect_object (_tmp21_, "sidebar-tooltip-changed", (GCallback) _sidebar_tree_on_sidebar_tooltip_changed_sidebar_entry_sidebar_tooltip_changed, self, 0);
#line 486 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp22_ = entry;
#line 486 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_signal_connect_object (_tmp22_, "sidebar-icon-changed", (GCallback) _sidebar_tree_on_sidebar_icon_changed_sidebar_entry_sidebar_icon_changed, self, 0);
#line 488 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp23_ = entry;
#line 488 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp24_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp23_, SIDEBAR_TYPE_PAGE_REPRESENTATIVE) ? ((SidebarPageRepresentative*) _tmp23_) : NULL);
#line 488 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	pageable = _tmp24_;
#line 489 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp25_ = pageable;
#line 489 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp25_ != NULL) {
#line 3494 "Tree.c"
		SidebarPageRepresentative* _tmp26_;
		SidebarPageRepresentative* _tmp27_;
#line 490 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp26_ = pageable;
#line 490 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		g_signal_connect_object (_tmp26_, "page-created", (GCallback) _sidebar_tree_on_sidebar_page_created_sidebar_page_representative_page_created, self, 0);
#line 491 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp27_ = pageable;
#line 491 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		g_signal_connect_object (_tmp27_, "destroying-page", (GCallback) _sidebar_tree_on_sidebar_destroying_page_sidebar_page_representative_destroying_page, self, 0);
#line 3505 "Tree.c"
	}
#line 494 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp28_ = entry;
#line 494 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp29_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp28_, SIDEBAR_TYPE_EMPHASIZABLE_ENTRY) ? ((SidebarEmphasizableEntry*) _tmp28_) : NULL);
#line 494 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	emphasizable = _tmp29_;
#line 495 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp30_ = emphasizable;
#line 495 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp30_ != NULL) {
#line 3517 "Tree.c"
		SidebarEmphasizableEntry* _tmp31_;
#line 496 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp31_ = emphasizable;
#line 496 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		g_signal_connect_object (_tmp31_, "is-emphasized-changed", (GCallback) _sidebar_tree_on_is_emphasized_changed_sidebar_emphasizable_entry_is_emphasized_changed, self, 0);
#line 3523 "Tree.c"
	}
#line 498 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp32_ = entry;
#line 498 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp33_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp32_, SIDEBAR_TYPE_RENAMEABLE_ENTRY) ? ((SidebarRenameableEntry*) _tmp32_) : NULL);
#line 498 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	renameable = _tmp33_;
#line 499 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp34_ = renameable;
#line 499 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp34_ != NULL) {
#line 3535 "Tree.c"
		SidebarRenameableEntry* _tmp35_;
#line 500 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp35_ = renameable;
#line 500 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		g_signal_connect_object (_tmp35_, "sidebar-name-changed", (GCallback) _sidebar_tree_on_sidebar_name_changed_sidebar_renameable_entry_sidebar_name_changed, self, 0);
#line 3541 "Tree.c"
	}
#line 502 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp36_ = entry;
#line 502 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	sidebar_entry_grafted (_tmp36_, self);
#line 474 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (renameable);
#line 474 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (emphasizable);
#line 474 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (pageable);
#line 474 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (entry);
#line 3555 "Tree.c"
}


static SidebarTreeEntryWrapper*
sidebar_tree_reparent_wrapper (SidebarTree* self,
                               GtkTreeIter* new_iter,
                               SidebarTreeEntryWrapper* current_wrapper)
{
	SidebarTreeEntryWrapper* result = NULL;
	SidebarEntry* entry = NULL;
	SidebarEntry* _tmp0_;
	SidebarEntry* _tmp1_;
	gboolean removed = FALSE;
	GeeHashMap* _tmp2_;
	gboolean _tmp3_;
	SidebarTreeEntryWrapper* new_wrapper = NULL;
	GtkTreeStore* _tmp4_;
	GtkTreeStore* _tmp5_;
	GtkTreeIter _tmp6_;
	GtkTreePath* _tmp7_;
	GtkTreePath* _tmp8_;
	SidebarTreeEntryWrapper* _tmp9_;
	SidebarTreeEntryWrapper* _tmp10_;
	GeeHashMap* _tmp11_;
	GtkTreeStore* _tmp12_;
	GtkTreeIter _tmp13_;
	gchar* _tmp14_;
	gchar* _tmp15_;
	GtkTreeStore* _tmp16_;
	GtkTreeIter _tmp17_;
	gchar* _tmp18_;
	gchar* _tmp19_;
	gchar* _tmp20_;
	gchar* _tmp21_;
	GtkTreeStore* _tmp22_;
	GtkTreeIter _tmp23_;
	GtkTreeIter _tmp24_;
#line 505 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (SIDEBAR_IS_TREE (self), NULL);
#line 505 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (new_iter != NULL, NULL);
#line 505 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (SIDEBAR_TREE_IS_ENTRY_WRAPPER (current_wrapper), NULL);
#line 506 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = current_wrapper->entry;
#line 506 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 506 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	entry = _tmp1_;
#line 508 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp2_ = self->priv->entry_map;
#line 508 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp3_ = gee_abstract_map_unset (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), entry, NULL);
#line 508 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	removed = _tmp3_;
#line 509 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_vala_assert (removed, "removed");
#line 511 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp4_ = self->priv->store;
#line 511 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp5_ = self->priv->store;
#line 511 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp6_ = *new_iter;
#line 511 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp7_ = gtk_tree_model_get_path (G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, gtk_tree_model_get_type (), GtkTreeModel), &_tmp6_);
#line 511 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp8_ = _tmp7_;
#line 511 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp9_ = sidebar_tree_entry_wrapper_new (G_TYPE_CHECK_INSTANCE_CAST (_tmp4_, gtk_tree_model_get_type (), GtkTreeModel), entry, _tmp8_);
#line 511 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp10_ = _tmp9_;
#line 511 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	__vala_GtkTreePath_free0 (_tmp8_);
#line 511 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	new_wrapper = _tmp10_;
#line 512 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp11_ = self->priv->entry_map;
#line 512 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	gee_abstract_map_set (G_TYPE_CHECK_INSTANCE_CAST (_tmp11_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), entry, new_wrapper);
#line 514 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp12_ = self->priv->store;
#line 514 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp13_ = *new_iter;
#line 514 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp14_ = sidebar_tree_get_name_for_entry (self, entry);
#line 514 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp15_ = _tmp14_;
#line 514 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	gtk_tree_store_set (_tmp12_, &_tmp13_, SIDEBAR_TREE_COLUMNS_NAME, _tmp15_, -1);
#line 514 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_free0 (_tmp15_);
#line 515 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp16_ = self->priv->store;
#line 515 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp17_ = *new_iter;
#line 515 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp18_ = sidebar_entry_get_sidebar_tooltip (entry);
#line 515 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp19_ = _tmp18_;
#line 515 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp20_ = guarded_markup_escape_text (_tmp19_);
#line 515 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp21_ = _tmp20_;
#line 515 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	gtk_tree_store_set (_tmp16_, &_tmp17_, SIDEBAR_TREE_COLUMNS_TOOLTIP, _tmp21_, -1);
#line 515 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_free0 (_tmp21_);
#line 515 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_free0 (_tmp19_);
#line 516 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp22_ = self->priv->store;
#line 516 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp23_ = *new_iter;
#line 516 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	gtk_tree_store_set (_tmp22_, &_tmp23_, SIDEBAR_TREE_COLUMNS_WRAPPER, new_wrapper, -1);
#line 517 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp24_ = *new_iter;
#line 517 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	sidebar_tree_load_entry_icons (self, &_tmp24_);
#line 519 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	result = new_wrapper;
#line 519 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (entry);
#line 519 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	return result;
#line 3681 "Tree.c"
}


void
sidebar_tree_prune (SidebarTree* self,
                    SidebarBranch* branch)
{
	GeeHashMap* _tmp0_;
	SidebarEntry* _tmp1_;
	SidebarEntry* _tmp2_;
	gboolean _tmp3_;
	guint _tmp4_;
	guint _tmp5_;
	guint _tmp6_;
	guint _tmp7_;
	guint _tmp8_;
	guint _tmp9_;
	gboolean removed = FALSE;
	GeeHashMap* _tmp10_;
	gboolean _tmp11_;
#line 522 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_TREE (self));
#line 522 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_BRANCH (branch));
#line 523 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = self->priv->branches;
#line 523 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_vala_assert (gee_abstract_map_has_key (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), branch), "branches.has_key(branch)");
#line 525 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp1_ = sidebar_branch_get_root (branch);
#line 525 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp2_ = _tmp1_;
#line 525 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp3_ = sidebar_tree_has_wrapper (self, _tmp2_);
#line 525 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (_tmp2_);
#line 525 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp3_) {
#line 526 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		sidebar_tree_disassociate_branch (self, branch);
#line 3722 "Tree.c"
	}
#line 528 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_signal_parse_name ("entry-added", SIDEBAR_TYPE_BRANCH, &_tmp4_, NULL, FALSE);
#line 528 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_signal_handlers_disconnect_matched (branch, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp4_, 0, NULL, (GCallback) _sidebar_tree_on_branch_entry_added_sidebar_branch_entry_added, self);
#line 529 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_signal_parse_name ("entry-removed", SIDEBAR_TYPE_BRANCH, &_tmp5_, NULL, FALSE);
#line 529 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_signal_handlers_disconnect_matched (branch, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp5_, 0, NULL, (GCallback) _sidebar_tree_on_branch_entry_removed_sidebar_branch_entry_removed, self);
#line 530 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_signal_parse_name ("entry-moved", SIDEBAR_TYPE_BRANCH, &_tmp6_, NULL, FALSE);
#line 530 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_signal_handlers_disconnect_matched (branch, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp6_, 0, NULL, (GCallback) _sidebar_tree_on_branch_entry_moved_sidebar_branch_entry_moved, self);
#line 531 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_signal_parse_name ("entry-reparented", SIDEBAR_TYPE_BRANCH, &_tmp7_, NULL, FALSE);
#line 531 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_signal_handlers_disconnect_matched (branch, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp7_, 0, NULL, (GCallback) _sidebar_tree_on_branch_entry_reparented_sidebar_branch_entry_reparented, self);
#line 532 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_signal_parse_name ("children-reordered", SIDEBAR_TYPE_BRANCH, &_tmp8_, NULL, FALSE);
#line 532 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_signal_handlers_disconnect_matched (branch, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp8_, 0, NULL, (GCallback) _sidebar_tree_on_branch_children_reordered_sidebar_branch_children_reordered, self);
#line 533 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_signal_parse_name ("show-branch", SIDEBAR_TYPE_BRANCH, &_tmp9_, NULL, FALSE);
#line 533 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_signal_handlers_disconnect_matched (branch, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp9_, 0, NULL, (GCallback) _sidebar_tree_on_show_branch_sidebar_branch_show_branch, self);
#line 535 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp10_ = self->priv->branches;
#line 535 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp11_ = gee_abstract_map_unset (G_TYPE_CHECK_INSTANCE_CAST (_tmp10_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), branch, NULL);
#line 535 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	removed = _tmp11_;
#line 536 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_vala_assert (removed, "removed");
#line 538 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_signal_emit (self, sidebar_tree_signals[SIDEBAR_TREE_BRANCH_REMOVED_SIGNAL], 0, branch);
#line 3758 "Tree.c"
}


static void
sidebar_tree_disassociate_branch (SidebarTree* self,
                                  SidebarBranch* branch)
{
	SidebarTreeRootWrapper* root_wrapper = NULL;
	SidebarEntry* _tmp0_;
	SidebarEntry* _tmp1_;
	SidebarTreeEntryWrapper* _tmp2_;
	SidebarTreeRootWrapper* _tmp3_;
	SidebarTreeRootWrapper* _tmp4_;
#line 541 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_TREE (self));
#line 541 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_BRANCH (branch));
#line 542 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = sidebar_branch_get_root (branch);
#line 542 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp1_ = _tmp0_;
#line 542 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp2_ = sidebar_tree_get_wrapper (self, _tmp1_);
#line 542 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp3_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp2_, SIDEBAR_TREE_TYPE_ROOT_WRAPPER) ? ((SidebarTreeRootWrapper*) _tmp2_) : NULL;
#line 542 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp3_ == NULL) {
#line 542 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (_tmp2_);
#line 3788 "Tree.c"
	}
#line 542 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp4_ = _tmp3_;
#line 542 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (_tmp1_);
#line 542 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	root_wrapper = _tmp4_;
#line 543 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_vala_assert (root_wrapper != NULL, "root_wrapper != null");
#line 545 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	sidebar_tree_disassociate_wrapper_and_signal (self, G_TYPE_CHECK_INSTANCE_CAST (root_wrapper, SIDEBAR_TREE_TYPE_ENTRY_WRAPPER, SidebarTreeEntryWrapper), FALSE);
#line 541 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (root_wrapper);
#line 3802 "Tree.c"
}


static void
sidebar_tree_disassociate_wrapper_and_signal (SidebarTree* self,
                                              SidebarTreeEntryWrapper* wrapper,
                                              gboolean only_children)
{
	gboolean selected = FALSE;
	SidebarEntry* _tmp0_;
	gboolean _tmp1_;
#line 550 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_TREE (self));
#line 550 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_TREE_IS_ENTRY_WRAPPER (wrapper));
#line 551 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = wrapper->entry;
#line 551 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	selected = sidebar_tree_is_selected (self, _tmp0_);
#line 553 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	sidebar_tree_disassociate_wrapper (self, wrapper, only_children);
#line 555 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp1_ = selected;
#line 555 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp1_) {
#line 3828 "Tree.c"
		SidebarSelectableEntry* selectable = NULL;
		SidebarEntry* _tmp2_;
		SidebarSelectableEntry* _tmp3_;
		SidebarSelectableEntry* _tmp4_;
		SidebarSelectableEntry* _tmp5_;
#line 556 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp2_ = wrapper->entry;
#line 556 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp3_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp2_, SIDEBAR_TYPE_SELECTABLE_ENTRY) ? ((SidebarSelectableEntry*) _tmp2_) : NULL);
#line 556 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		selectable = _tmp3_;
#line 557 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp4_ = selectable;
#line 557 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_vala_assert (_tmp4_ != NULL, "selectable != null");
#line 559 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp5_ = selectable;
#line 559 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		g_signal_emit (self, sidebar_tree_signals[SIDEBAR_TREE_SELECTED_ENTRY_REMOVED_SIGNAL], 0, _tmp5_);
#line 555 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (selectable);
#line 3850 "Tree.c"
	}
}


static void
sidebar_tree_disassociate_wrapper (SidebarTree* self,
                                   SidebarTreeEntryWrapper* wrapper,
                                   gboolean only_children)
{
	GeeArrayList* children = NULL;
	GeeArrayList* _tmp0_;
	GtkTreeIter child_iter = {0};
	gboolean found = FALSE;
	GtkTreeStore* _tmp1_;
	GtkTreeIter _tmp2_ = {0};
	GtkTreeIter _tmp3_ = {0};
	gboolean _tmp4_;
	GtkTreeIter iter = {0};
	GtkTreeIter _tmp25_ = {0};
	GtkTreeStore* _tmp26_;
	SidebarTreeEntryWrapper* _tmp27_;
	SidebarEntry* entry = NULL;
	SidebarEntry* _tmp28_;
	SidebarEntry* _tmp29_;
	SidebarEntry* _tmp30_;
	SidebarEntry* _tmp31_;
	guint _tmp32_;
	SidebarEntry* _tmp33_;
	guint _tmp34_;
	SidebarPageRepresentative* pageable = NULL;
	SidebarEntry* _tmp35_;
	SidebarPageRepresentative* _tmp36_;
	SidebarPageRepresentative* _tmp37_;
	SidebarRenameableEntry* renameable = NULL;
	SidebarEntry* _tmp42_;
	SidebarRenameableEntry* _tmp43_;
	SidebarRenameableEntry* _tmp44_;
	SidebarEmphasizableEntry* emphasizable = NULL;
	SidebarEntry* _tmp47_;
	SidebarEmphasizableEntry* _tmp48_;
	SidebarEmphasizableEntry* _tmp49_;
	gboolean removed = FALSE;
	GeeHashMap* _tmp52_;
	SidebarEntry* _tmp53_;
	gboolean _tmp54_;
	gboolean _tmp55_;
#line 563 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_TREE (self));
#line 563 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_TREE_IS_ENTRY_WRAPPER (wrapper));
#line 564 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = gee_array_list_new (SIDEBAR_TREE_TYPE_ENTRY_WRAPPER, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, NULL, NULL, NULL);
#line 564 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	children = _tmp0_;
#line 567 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp1_ = self->priv->store;
#line 567 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	sidebar_tree_entry_wrapper_get_iter (wrapper, &_tmp2_);
#line 567 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp4_ = gtk_tree_model_iter_children (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, gtk_tree_model_get_type (), GtkTreeModel), &_tmp3_, &_tmp2_);
#line 567 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	child_iter = _tmp3_;
#line 567 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	found = _tmp4_;
#line 568 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	while (TRUE) {
#line 3917 "Tree.c"
		gboolean _tmp5_;
		SidebarTreeEntryWrapper* child_wrapper = NULL;
		GtkTreeIter _tmp6_;
		SidebarTreeEntryWrapper* _tmp7_;
		SidebarTreeEntryWrapper* _tmp8_;
		GeeArrayList* _tmp9_;
		SidebarTreeEntryWrapper* _tmp10_;
		GtkTreeStore* _tmp11_;
		gboolean _tmp12_;
#line 568 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp5_ = found;
#line 568 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		if (!_tmp5_) {
#line 568 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			break;
#line 3933 "Tree.c"
		}
#line 569 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp6_ = child_iter;
#line 569 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp7_ = sidebar_tree_get_wrapper_at_iter (self, &_tmp6_);
#line 569 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		child_wrapper = _tmp7_;
#line 570 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp8_ = child_wrapper;
#line 570 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_vala_assert (_tmp8_ != NULL, "child_wrapper != null");
#line 572 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp9_ = children;
#line 572 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp10_ = child_wrapper;
#line 572 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		gee_abstract_collection_add (G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection), _tmp10_);
#line 574 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp11_ = self->priv->store;
#line 574 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp12_ = gtk_tree_model_iter_next (G_TYPE_CHECK_INSTANCE_CAST (_tmp11_, gtk_tree_model_get_type (), GtkTreeModel), &child_iter);
#line 574 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		found = _tmp12_;
#line 568 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (child_wrapper);
#line 3959 "Tree.c"
	}
	{
		GeeArrayList* _child_wrapper_list = NULL;
		GeeArrayList* _tmp13_;
		GeeArrayList* _tmp14_;
		gint _child_wrapper_size = 0;
		GeeArrayList* _tmp15_;
		gint _tmp16_;
		gint _tmp17_;
		gint _child_wrapper_index = 0;
#line 577 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp13_ = children;
#line 577 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp14_ = _g_object_ref0 (_tmp13_);
#line 577 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_child_wrapper_list = _tmp14_;
#line 577 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp15_ = _child_wrapper_list;
#line 577 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp16_ = gee_abstract_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp15_, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection));
#line 577 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp17_ = _tmp16_;
#line 577 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_child_wrapper_size = _tmp17_;
#line 577 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_child_wrapper_index = -1;
#line 577 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		while (TRUE) {
#line 3988 "Tree.c"
			gint _tmp18_;
			gint _tmp19_;
			gint _tmp20_;
			SidebarTreeEntryWrapper* child_wrapper = NULL;
			GeeArrayList* _tmp21_;
			gint _tmp22_;
			gpointer _tmp23_;
			SidebarTreeEntryWrapper* _tmp24_;
#line 577 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp18_ = _child_wrapper_index;
#line 577 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_child_wrapper_index = _tmp18_ + 1;
#line 577 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp19_ = _child_wrapper_index;
#line 577 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp20_ = _child_wrapper_size;
#line 577 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			if (!(_tmp19_ < _tmp20_)) {
#line 577 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				break;
#line 4009 "Tree.c"
			}
#line 577 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp21_ = _child_wrapper_list;
#line 577 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp22_ = _child_wrapper_index;
#line 577 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp23_ = gee_abstract_list_get (G_TYPE_CHECK_INSTANCE_CAST (_tmp21_, GEE_TYPE_ABSTRACT_LIST, GeeAbstractList), _tmp22_);
#line 577 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			child_wrapper = (SidebarTreeEntryWrapper*) _tmp23_;
#line 578 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp24_ = child_wrapper;
#line 578 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			sidebar_tree_disassociate_wrapper (self, _tmp24_, FALSE);
#line 577 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_g_object_unref0 (child_wrapper);
#line 4025 "Tree.c"
		}
#line 577 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (_child_wrapper_list);
#line 4029 "Tree.c"
	}
#line 580 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (only_children) {
#line 581 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (children);
#line 581 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		return;
#line 4037 "Tree.c"
	}
#line 583 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	sidebar_tree_entry_wrapper_get_iter (wrapper, &_tmp25_);
#line 583 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	iter = _tmp25_;
#line 584 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp26_ = self->priv->store;
#line 584 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	gtk_tree_store_remove (_tmp26_, &iter);
#line 586 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp27_ = self->priv->selected_wrapper;
#line 586 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp27_ == wrapper) {
#line 587 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		self->priv->selected_wrapper = NULL;
#line 4053 "Tree.c"
	}
#line 589 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp28_ = wrapper->entry;
#line 589 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp29_ = _g_object_ref0 (_tmp28_);
#line 589 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	entry = _tmp29_;
#line 591 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp30_ = entry;
#line 591 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	sidebar_entry_pruned (_tmp30_, self);
#line 593 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp31_ = entry;
#line 593 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_signal_parse_name ("sidebar-tooltip-changed", SIDEBAR_TYPE_ENTRY, &_tmp32_, NULL, FALSE);
#line 593 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_signal_handlers_disconnect_matched (_tmp31_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp32_, 0, NULL, (GCallback) _sidebar_tree_on_sidebar_tooltip_changed_sidebar_entry_sidebar_tooltip_changed, self);
#line 594 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp33_ = entry;
#line 594 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_signal_parse_name ("sidebar-icon-changed", SIDEBAR_TYPE_ENTRY, &_tmp34_, NULL, FALSE);
#line 594 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_signal_handlers_disconnect_matched (_tmp33_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp34_, 0, NULL, (GCallback) _sidebar_tree_on_sidebar_icon_changed_sidebar_entry_sidebar_icon_changed, self);
#line 596 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp35_ = entry;
#line 596 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp36_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp35_, SIDEBAR_TYPE_PAGE_REPRESENTATIVE) ? ((SidebarPageRepresentative*) _tmp35_) : NULL);
#line 596 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	pageable = _tmp36_;
#line 597 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp37_ = pageable;
#line 597 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp37_ != NULL) {
#line 4087 "Tree.c"
		SidebarPageRepresentative* _tmp38_;
		guint _tmp39_;
		SidebarPageRepresentative* _tmp40_;
		guint _tmp41_;
#line 598 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp38_ = pageable;
#line 598 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		g_signal_parse_name ("page-created", SIDEBAR_TYPE_PAGE_REPRESENTATIVE, &_tmp39_, NULL, FALSE);
#line 598 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		g_signal_handlers_disconnect_matched (_tmp38_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp39_, 0, NULL, (GCallback) _sidebar_tree_on_sidebar_page_created_sidebar_page_representative_page_created, self);
#line 599 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp40_ = pageable;
#line 599 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		g_signal_parse_name ("destroying-page", SIDEBAR_TYPE_PAGE_REPRESENTATIVE, &_tmp41_, NULL, FALSE);
#line 599 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		g_signal_handlers_disconnect_matched (_tmp40_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp41_, 0, NULL, (GCallback) _sidebar_tree_on_sidebar_destroying_page_sidebar_page_representative_destroying_page, self);
#line 4104 "Tree.c"
	}
#line 602 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp42_ = entry;
#line 602 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp43_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp42_, SIDEBAR_TYPE_RENAMEABLE_ENTRY) ? ((SidebarRenameableEntry*) _tmp42_) : NULL);
#line 602 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	renameable = _tmp43_;
#line 603 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp44_ = renameable;
#line 603 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp44_ != NULL) {
#line 4116 "Tree.c"
		SidebarRenameableEntry* _tmp45_;
		guint _tmp46_;
#line 604 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp45_ = renameable;
#line 604 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		g_signal_parse_name ("sidebar-name-changed", SIDEBAR_TYPE_RENAMEABLE_ENTRY, &_tmp46_, NULL, FALSE);
#line 604 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		g_signal_handlers_disconnect_matched (_tmp45_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp46_, 0, NULL, (GCallback) _sidebar_tree_on_sidebar_name_changed_sidebar_renameable_entry_sidebar_name_changed, self);
#line 4125 "Tree.c"
	}
#line 606 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp47_ = entry;
#line 606 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp48_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp47_, SIDEBAR_TYPE_EMPHASIZABLE_ENTRY) ? ((SidebarEmphasizableEntry*) _tmp47_) : NULL);
#line 606 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	emphasizable = _tmp48_;
#line 607 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp49_ = emphasizable;
#line 607 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp49_ != NULL) {
#line 4137 "Tree.c"
		SidebarEmphasizableEntry* _tmp50_;
		guint _tmp51_;
#line 608 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp50_ = emphasizable;
#line 608 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		g_signal_parse_name ("is-emphasized-changed", SIDEBAR_TYPE_EMPHASIZABLE_ENTRY, &_tmp51_, NULL, FALSE);
#line 608 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		g_signal_handlers_disconnect_matched (_tmp50_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp51_, 0, NULL, (GCallback) _sidebar_tree_on_is_emphasized_changed_sidebar_emphasizable_entry_is_emphasized_changed, self);
#line 4146 "Tree.c"
	}
#line 610 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp52_ = self->priv->entry_map;
#line 610 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp53_ = entry;
#line 610 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp54_ = gee_abstract_map_unset (G_TYPE_CHECK_INSTANCE_CAST (_tmp52_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), _tmp53_, NULL);
#line 610 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	removed = _tmp54_;
#line 611 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp55_ = removed;
#line 611 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_vala_assert (_tmp55_, "removed");
#line 563 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (emphasizable);
#line 563 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (renameable);
#line 563 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (pageable);
#line 563 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (entry);
#line 563 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (children);
#line 4170 "Tree.c"
}


static void
sidebar_tree_on_branch_entry_added (SidebarTree* self,
                                    SidebarBranch* branch,
                                    SidebarEntry* entry)
{
	SidebarEntry* parent = NULL;
	SidebarEntry* _tmp0_;
	SidebarEntry* _tmp1_;
	SidebarTreeEntryWrapper* parent_wrapper = NULL;
	SidebarEntry* _tmp2_;
	SidebarTreeEntryWrapper* _tmp3_;
	SidebarTreeEntryWrapper* _tmp4_;
	GtkTreeIter insertion_iter = {0};
	SidebarEntry* next = NULL;
	SidebarEntry* _tmp5_;
	SidebarEntry* _tmp6_;
	GtkTreeIter _tmp19_;
	GtkTreeIter _tmp20_;
#line 614 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_TREE (self));
#line 614 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_BRANCH (branch));
#line 614 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_ENTRY (entry));
#line 615 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = sidebar_branch_get_parent (branch, entry);
#line 615 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	parent = _tmp0_;
#line 616 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp1_ = parent;
#line 616 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_vala_assert (_tmp1_ != NULL, "parent != null");
#line 618 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp2_ = parent;
#line 618 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp3_ = sidebar_tree_get_wrapper (self, _tmp2_);
#line 618 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	parent_wrapper = _tmp3_;
#line 619 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp4_ = parent_wrapper;
#line 619 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_vala_assert (_tmp4_ != NULL, "parent_wrapper != null");
#line 622 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp5_ = sidebar_branch_get_next_sibling (branch, entry);
#line 622 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	next = _tmp5_;
#line 623 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp6_ = next;
#line 623 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp6_ != NULL) {
#line 4224 "Tree.c"
		SidebarTreeEntryWrapper* next_wrapper = NULL;
		SidebarEntry* _tmp7_;
		SidebarTreeEntryWrapper* _tmp8_;
		GtkTreeStore* _tmp9_;
		SidebarTreeEntryWrapper* _tmp10_;
		GtkTreeIter _tmp11_ = {0};
		SidebarTreeEntryWrapper* _tmp12_;
		GtkTreeIter _tmp13_ = {0};
		GtkTreeIter _tmp14_ = {0};
#line 624 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp7_ = next;
#line 624 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp8_ = sidebar_tree_get_wrapper (self, _tmp7_);
#line 624 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		next_wrapper = _tmp8_;
#line 627 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp9_ = self->priv->store;
#line 627 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp10_ = parent_wrapper;
#line 627 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		sidebar_tree_entry_wrapper_get_iter (_tmp10_, &_tmp11_);
#line 627 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp12_ = next_wrapper;
#line 627 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		sidebar_tree_entry_wrapper_get_iter (_tmp12_, &_tmp13_);
#line 627 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		gtk_tree_store_insert_before (_tmp9_, &_tmp14_, &_tmp11_, &_tmp13_);
#line 627 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		insertion_iter = _tmp14_;
#line 623 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (next_wrapper);
#line 4256 "Tree.c"
	} else {
		GtkTreeStore* _tmp15_;
		SidebarTreeEntryWrapper* _tmp16_;
		GtkTreeIter _tmp17_ = {0};
		GtkTreeIter _tmp18_ = {0};
#line 630 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp15_ = self->priv->store;
#line 630 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp16_ = parent_wrapper;
#line 630 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		sidebar_tree_entry_wrapper_get_iter (_tmp16_, &_tmp17_);
#line 630 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		gtk_tree_store_append (_tmp15_, &_tmp18_, &_tmp17_);
#line 630 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		insertion_iter = _tmp18_;
#line 4272 "Tree.c"
	}
#line 633 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp19_ = insertion_iter;
#line 633 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	sidebar_tree_associate_entry (self, &_tmp19_, entry);
#line 634 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp20_ = insertion_iter;
#line 634 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	sidebar_tree_associate_children (self, branch, entry, &_tmp20_);
#line 636 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (sidebar_branch_is_auto_open_on_new_child (branch)) {
#line 637 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		sidebar_tree_expand_to_entry (self, entry);
#line 4286 "Tree.c"
	}
#line 614 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (next);
#line 614 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (parent_wrapper);
#line 614 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (parent);
#line 4294 "Tree.c"
}


static void
sidebar_tree_on_branch_entry_removed (SidebarTree* self,
                                      SidebarBranch* branch,
                                      SidebarEntry* entry)
{
	SidebarTreeEntryWrapper* wrapper = NULL;
	SidebarTreeEntryWrapper* _tmp0_;
#line 640 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_TREE (self));
#line 640 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_BRANCH (branch));
#line 640 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_ENTRY (entry));
#line 641 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = sidebar_tree_get_wrapper (self, entry);
#line 641 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	wrapper = _tmp0_;
#line 642 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_vala_assert (wrapper != NULL, "wrapper != null");
#line 643 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_vala_assert (!G_TYPE_CHECK_INSTANCE_TYPE (wrapper, SIDEBAR_TREE_TYPE_ROOT_WRAPPER), "!(wrapper is RootWrapper)");
#line 645 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	sidebar_tree_disassociate_wrapper_and_signal (self, wrapper, FALSE);
#line 640 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (wrapper);
#line 4323 "Tree.c"
}


static void
sidebar_tree_on_branch_entry_moved (SidebarTree* self,
                                    SidebarBranch* branch,
                                    SidebarEntry* entry)
{
	SidebarTreeEntryWrapper* wrapper = NULL;
	SidebarTreeEntryWrapper* _tmp0_;
	SidebarTreeEntryWrapper* _tmp1_;
	SidebarTreeEntryWrapper* _tmp2_;
	GtkTreeIter* prev_iter = NULL;
	SidebarEntry* prev = NULL;
	SidebarEntry* _tmp3_;
	SidebarEntry* _tmp4_;
	GtkTreeIter entry_iter = {0};
	SidebarTreeEntryWrapper* _tmp11_;
	GtkTreeIter _tmp12_ = {0};
	GtkTreeStore* _tmp13_;
	GtkTreeIter* _tmp14_;
#line 648 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_TREE (self));
#line 648 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_BRANCH (branch));
#line 648 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_ENTRY (entry));
#line 649 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = sidebar_tree_get_wrapper (self, entry);
#line 649 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	wrapper = _tmp0_;
#line 650 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp1_ = wrapper;
#line 650 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_vala_assert (_tmp1_ != NULL, "wrapper != null");
#line 651 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp2_ = wrapper;
#line 651 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_vala_assert (!G_TYPE_CHECK_INSTANCE_TYPE (_tmp2_, SIDEBAR_TREE_TYPE_ROOT_WRAPPER), "!(wrapper is RootWrapper)");
#line 654 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	prev_iter = NULL;
#line 655 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp3_ = sidebar_branch_get_previous_sibling (branch, entry);
#line 655 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	prev = _tmp3_;
#line 656 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp4_ = prev;
#line 656 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp4_ != NULL) {
#line 4373 "Tree.c"
		SidebarTreeEntryWrapper* prev_wrapper = NULL;
		SidebarEntry* _tmp5_;
		SidebarTreeEntryWrapper* _tmp6_;
		SidebarTreeEntryWrapper* _tmp7_;
		SidebarTreeEntryWrapper* _tmp8_;
		GtkTreeIter _tmp9_ = {0};
		GtkTreeIter* _tmp10_;
#line 657 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp5_ = prev;
#line 657 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp6_ = sidebar_tree_get_wrapper (self, _tmp5_);
#line 657 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		prev_wrapper = _tmp6_;
#line 658 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp7_ = prev_wrapper;
#line 658 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_vala_assert (_tmp7_ != NULL, "prev_wrapper != null");
#line 660 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp8_ = prev_wrapper;
#line 660 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		sidebar_tree_entry_wrapper_get_iter (_tmp8_, &_tmp9_);
#line 660 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp10_ = __gtk_tree_iter_dup0 (&_tmp9_);
#line 660 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_free0 (prev_iter);
#line 660 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		prev_iter = _tmp10_;
#line 656 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (prev_wrapper);
#line 4403 "Tree.c"
	}
#line 663 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp11_ = wrapper;
#line 663 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	sidebar_tree_entry_wrapper_get_iter (_tmp11_, &_tmp12_);
#line 663 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	entry_iter = _tmp12_;
#line 664 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp13_ = self->priv->store;
#line 664 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp14_ = prev_iter;
#line 664 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	gtk_tree_store_move_after (_tmp13_, &entry_iter, _tmp14_);
#line 648 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (prev);
#line 648 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_free0 (prev_iter);
#line 648 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (wrapper);
#line 4423 "Tree.c"
}


static void
sidebar_tree_on_branch_entry_reparented (SidebarTree* self,
                                         SidebarBranch* branch,
                                         SidebarEntry* entry,
                                         SidebarEntry* old_parent)
{
	SidebarTreeEntryWrapper* wrapper = NULL;
	SidebarTreeEntryWrapper* _tmp0_;
	SidebarTreeEntryWrapper* _tmp1_;
	SidebarTreeEntryWrapper* _tmp2_;
	gboolean selected = FALSE;
	GtkTreePath* _tmp3_;
	GtkTreePath* _tmp4_;
	SidebarTreeEntryWrapper* _tmp5_;
	GtkTreePath* _tmp6_;
	GtkTreePath* _tmp7_;
	gboolean _tmp8_;
	GtkTreeIter iter = {0};
	SidebarTreeEntryWrapper* _tmp9_;
	GtkTreeIter _tmp10_ = {0};
	GtkTreeStore* _tmp11_;
	SidebarEntry* parent = NULL;
	SidebarEntry* _tmp12_;
	SidebarEntry* _tmp13_;
	SidebarTreeEntryWrapper* parent_wrapper = NULL;
	SidebarEntry* _tmp14_;
	SidebarTreeEntryWrapper* _tmp15_;
	SidebarTreeEntryWrapper* _tmp16_;
	GtkTreeIter* prev_iter = NULL;
	SidebarEntry* prev = NULL;
	SidebarEntry* _tmp17_;
	SidebarEntry* _tmp18_;
	GtkTreeIter new_iter = {0};
	GtkTreeStore* _tmp25_;
	SidebarTreeEntryWrapper* _tmp26_;
	GtkTreeIter _tmp27_ = {0};
	GtkTreeIter* _tmp28_;
	GtkTreeIter _tmp29_ = {0};
	SidebarTreeEntryWrapper* new_wrapper = NULL;
	GtkTreeIter _tmp30_;
	SidebarTreeEntryWrapper* _tmp31_;
	SidebarTreeEntryWrapper* _tmp32_;
	gboolean _tmp33_;
#line 667 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_TREE (self));
#line 667 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_BRANCH (branch));
#line 667 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_ENTRY (entry));
#line 667 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_ENTRY (old_parent));
#line 669 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = sidebar_tree_get_wrapper (self, entry);
#line 669 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	wrapper = _tmp0_;
#line 670 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp1_ = wrapper;
#line 670 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_vala_assert (_tmp1_ != NULL, "wrapper != null");
#line 671 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp2_ = wrapper;
#line 671 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_vala_assert (!G_TYPE_CHECK_INSTANCE_TYPE (_tmp2_, SIDEBAR_TREE_TYPE_ROOT_WRAPPER), "!(wrapper is RootWrapper)");
#line 673 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp3_ = sidebar_tree_get_current_path (self);
#line 673 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp4_ = _tmp3_;
#line 673 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp5_ = wrapper;
#line 673 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp6_ = sidebar_tree_entry_wrapper_get_path (_tmp5_);
#line 673 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp7_ = _tmp6_;
#line 673 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp8_ = gtk_tree_path_compare (_tmp4_, _tmp7_) == 0;
#line 673 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	__vala_GtkTreePath_free0 (_tmp7_);
#line 673 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	__vala_GtkTreePath_free0 (_tmp4_);
#line 673 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	selected = _tmp8_;
#line 676 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp9_ = wrapper;
#line 676 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	sidebar_tree_entry_wrapper_get_iter (_tmp9_, &_tmp10_);
#line 676 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	iter = _tmp10_;
#line 677 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp11_ = self->priv->store;
#line 677 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	gtk_tree_store_remove (_tmp11_, &iter);
#line 679 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp12_ = sidebar_branch_get_parent (branch, entry);
#line 679 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	parent = _tmp12_;
#line 680 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp13_ = parent;
#line 680 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_vala_assert (_tmp13_ != NULL, "parent != null");
#line 682 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp14_ = parent;
#line 682 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp15_ = sidebar_tree_get_wrapper (self, _tmp14_);
#line 682 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	parent_wrapper = _tmp15_;
#line 683 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp16_ = parent_wrapper;
#line 683 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_vala_assert (_tmp16_ != NULL, "parent_wrapper != null");
#line 686 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	prev_iter = NULL;
#line 687 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp17_ = sidebar_branch_get_previous_sibling (branch, entry);
#line 687 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	prev = _tmp17_;
#line 688 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp18_ = prev;
#line 688 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp18_ != NULL) {
#line 4546 "Tree.c"
		SidebarTreeEntryWrapper* prev_wrapper = NULL;
		SidebarEntry* _tmp19_;
		SidebarTreeEntryWrapper* _tmp20_;
		SidebarTreeEntryWrapper* _tmp21_;
		SidebarTreeEntryWrapper* _tmp22_;
		GtkTreeIter _tmp23_ = {0};
		GtkTreeIter* _tmp24_;
#line 689 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp19_ = prev;
#line 689 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp20_ = sidebar_tree_get_wrapper (self, _tmp19_);
#line 689 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		prev_wrapper = _tmp20_;
#line 690 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp21_ = prev_wrapper;
#line 690 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_vala_assert (_tmp21_ != NULL, "prev_wrapper != null");
#line 692 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp22_ = prev_wrapper;
#line 692 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		sidebar_tree_entry_wrapper_get_iter (_tmp22_, &_tmp23_);
#line 692 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp24_ = __gtk_tree_iter_dup0 (&_tmp23_);
#line 692 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_free0 (prev_iter);
#line 692 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		prev_iter = _tmp24_;
#line 688 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (prev_wrapper);
#line 4576 "Tree.c"
	}
#line 696 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp25_ = self->priv->store;
#line 696 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp26_ = parent_wrapper;
#line 696 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	sidebar_tree_entry_wrapper_get_iter (_tmp26_, &_tmp27_);
#line 696 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp28_ = prev_iter;
#line 696 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	gtk_tree_store_insert_after (_tmp25_, &_tmp29_, &_tmp27_, _tmp28_);
#line 696 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	new_iter = _tmp29_;
#line 698 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp30_ = new_iter;
#line 698 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp31_ = wrapper;
#line 698 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp32_ = sidebar_tree_reparent_wrapper (self, &_tmp30_, _tmp31_);
#line 698 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	new_wrapper = _tmp32_;
#line 700 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp33_ = selected;
#line 700 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp33_) {
#line 4602 "Tree.c"
		SidebarTreeEntryWrapper* _tmp34_;
		SidebarEntry* _tmp35_;
		SidebarTreeEntryWrapper* _tmp36_;
		SidebarEntry* _tmp37_;
#line 701 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp34_ = new_wrapper;
#line 701 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp35_ = _tmp34_->entry;
#line 701 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		sidebar_tree_expand_to_entry (self, _tmp35_);
#line 702 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp36_ = new_wrapper;
#line 702 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp37_ = _tmp36_->entry;
#line 702 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		sidebar_tree_place_cursor (self, _tmp37_, FALSE);
#line 4619 "Tree.c"
	}
#line 667 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (new_wrapper);
#line 667 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (prev);
#line 667 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_free0 (prev_iter);
#line 667 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (parent_wrapper);
#line 667 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (parent);
#line 667 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (wrapper);
#line 4633 "Tree.c"
}


static void
sidebar_tree_on_branch_children_reordered (SidebarTree* self,
                                           SidebarBranch* branch,
                                           SidebarEntry* entry)
{
	GeeList* children = NULL;
	GeeList* _tmp0_;
	GeeList* _tmp1_;
#line 706 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_TREE (self));
#line 706 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_BRANCH (branch));
#line 706 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_ENTRY (entry));
#line 707 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = sidebar_branch_get_children (branch, entry);
#line 707 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	children = _tmp0_;
#line 708 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp1_ = children;
#line 708 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp1_ == NULL) {
#line 709 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (children);
#line 709 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		return;
#line 4663 "Tree.c"
	}
	{
		GeeList* _child_list = NULL;
		GeeList* _tmp2_;
		GeeList* _tmp3_;
		gint _child_size = 0;
		GeeList* _tmp4_;
		gint _tmp5_;
		gint _tmp6_;
		gint _child_index = 0;
#line 713 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp2_ = children;
#line 713 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp3_ = _g_object_ref0 (_tmp2_);
#line 713 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_child_list = _tmp3_;
#line 713 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp4_ = _child_list;
#line 713 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp5_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp4_, GEE_TYPE_COLLECTION, GeeCollection));
#line 713 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp6_ = _tmp5_;
#line 713 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_child_size = _tmp6_;
#line 713 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_child_index = -1;
#line 713 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		while (TRUE) {
#line 4692 "Tree.c"
			gint _tmp7_;
			gint _tmp8_;
			gint _tmp9_;
			SidebarEntry* child = NULL;
			GeeList* _tmp10_;
			gint _tmp11_;
			gpointer _tmp12_;
			SidebarTreeEntryWrapper* child_wrapper = NULL;
			SidebarEntry* _tmp13_;
			SidebarTreeEntryWrapper* _tmp14_;
			SidebarTreeEntryWrapper* _tmp15_;
			GtkTreeIter child_iter = {0};
			SidebarTreeEntryWrapper* _tmp16_;
			GtkTreeIter _tmp17_ = {0};
			GtkTreeStore* _tmp18_;
#line 713 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp7_ = _child_index;
#line 713 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_child_index = _tmp7_ + 1;
#line 713 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp8_ = _child_index;
#line 713 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp9_ = _child_size;
#line 713 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			if (!(_tmp8_ < _tmp9_)) {
#line 713 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				break;
#line 4720 "Tree.c"
			}
#line 713 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp10_ = _child_list;
#line 713 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp11_ = _child_index;
#line 713 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp12_ = gee_list_get (_tmp10_, _tmp11_);
#line 713 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			child = (SidebarEntry*) _tmp12_;
#line 714 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp13_ = child;
#line 714 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp14_ = sidebar_tree_get_wrapper (self, _tmp13_);
#line 714 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			child_wrapper = _tmp14_;
#line 715 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp15_ = child_wrapper;
#line 715 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_vala_assert (_tmp15_ != NULL, "child_wrapper != null");
#line 717 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp16_ = child_wrapper;
#line 717 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			sidebar_tree_entry_wrapper_get_iter (_tmp16_, &_tmp17_);
#line 717 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			child_iter = _tmp17_;
#line 718 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp18_ = self->priv->store;
#line 718 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			gtk_tree_store_move_before (_tmp18_, &child_iter, NULL);
#line 713 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_g_object_unref0 (child_wrapper);
#line 713 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_g_object_unref0 (child);
#line 4754 "Tree.c"
		}
#line 713 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (_child_list);
#line 4758 "Tree.c"
	}
#line 706 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (children);
#line 4762 "Tree.c"
}


static void
sidebar_tree_on_show_branch (SidebarTree* self,
                             SidebarBranch* branch,
                             gboolean shown)
{
#line 722 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_TREE (self));
#line 722 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_BRANCH (branch));
#line 723 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (shown) {
#line 724 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		sidebar_tree_associate_branch (self, branch);
#line 4779 "Tree.c"
	} else {
#line 726 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		sidebar_tree_disassociate_branch (self, branch);
#line 4783 "Tree.c"
	}
#line 728 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_signal_emit (self, sidebar_tree_signals[SIDEBAR_TREE_BRANCH_SHOWN_SIGNAL], 0, branch, shown);
#line 4787 "Tree.c"
}


static void
sidebar_tree_on_sidebar_tooltip_changed (SidebarTree* self,
                                         SidebarEntry* entry,
                                         const gchar* tooltip)
{
	SidebarTreeEntryWrapper* wrapper = NULL;
	SidebarTreeEntryWrapper* _tmp0_;
	GtkTreeStore* _tmp1_;
	GtkTreeIter _tmp2_ = {0};
	gchar* _tmp3_;
	gchar* _tmp4_;
#line 731 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_TREE (self));
#line 731 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_ENTRY (entry));
#line 732 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = sidebar_tree_get_wrapper (self, entry);
#line 732 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	wrapper = _tmp0_;
#line 733 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_vala_assert (wrapper != NULL, "wrapper != null");
#line 735 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp1_ = self->priv->store;
#line 735 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	sidebar_tree_entry_wrapper_get_iter (wrapper, &_tmp2_);
#line 735 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp3_ = guarded_markup_escape_text (tooltip);
#line 735 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp4_ = _tmp3_;
#line 735 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	gtk_tree_store_set (_tmp1_, &_tmp2_, SIDEBAR_TREE_COLUMNS_TOOLTIP, _tmp4_, -1);
#line 735 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_free0 (_tmp4_);
#line 731 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (wrapper);
#line 4826 "Tree.c"
}


static void
sidebar_tree_on_sidebar_icon_changed (SidebarTree* self,
                                      SidebarEntry* entry,
                                      const gchar* icon_name)
{
	SidebarTreeEntryWrapper* wrapper = NULL;
	SidebarTreeEntryWrapper* _tmp0_;
	SidebarTreeEntryWrapper* _tmp1_;
	GIcon* icon = NULL;
	GtkTreeStore* _tmp5_;
	SidebarTreeEntryWrapper* _tmp6_;
	GtkTreeIter _tmp7_ = {0};
	GIcon* _tmp8_;
	GError * _inner_error_ = NULL;
#line 738 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_TREE (self));
#line 738 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_ENTRY (entry));
#line 739 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = sidebar_tree_get_wrapper (self, entry);
#line 739 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	wrapper = _tmp0_;
#line 740 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp1_ = wrapper;
#line 740 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_vala_assert (_tmp1_ != NULL, "wrapper != null");
#line 741 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	icon = NULL;
#line 4858 "Tree.c"
	{
#line 744 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		if (icon_name != NULL) {
#line 4862 "Tree.c"
			GIcon* _tmp2_ = NULL;
			GIcon* _tmp3_;
			GIcon* _tmp4_;
#line 745 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp3_ = g_icon_new_for_string (icon_name, &_inner_error_);
#line 745 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp2_ = _tmp3_;
#line 745 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 4872 "Tree.c"
				goto __catch56_g_error;
			}
#line 745 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp4_ = _tmp2_;
#line 745 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp2_ = NULL;
#line 745 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_g_object_unref0 (icon);
#line 745 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			icon = _tmp4_;
#line 744 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_g_object_unref0 (_tmp2_);
#line 4885 "Tree.c"
		}
	}
	goto __finally56;
	__catch56_g_error:
	{
		GError* e = NULL;
#line 743 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		e = _inner_error_;
#line 743 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_inner_error_ = NULL;
#line 743 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_error_free0 (e);
#line 4898 "Tree.c"
	}
	__finally56:
#line 743 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 743 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (icon);
#line 743 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (wrapper);
#line 743 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 743 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		g_clear_error (&_inner_error_);
#line 743 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		return;
#line 4913 "Tree.c"
	}
#line 749 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp5_ = self->priv->store;
#line 749 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp6_ = wrapper;
#line 749 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	sidebar_tree_entry_wrapper_get_iter (_tmp6_, &_tmp7_);
#line 749 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp8_ = icon;
#line 749 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	gtk_tree_store_set (_tmp5_, &_tmp7_, SIDEBAR_TREE_COLUMNS_ICON, _tmp8_, -1);
#line 738 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (icon);
#line 738 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (wrapper);
#line 4929 "Tree.c"
}


static void
sidebar_tree_rename_entry (SidebarTree* self,
                           SidebarEntry* entry)
{
	SidebarTreeEntryWrapper* wrapper = NULL;
	SidebarTreeEntryWrapper* _tmp0_;
	GtkTreeStore* _tmp1_;
	GtkTreeIter _tmp2_ = {0};
	gchar* _tmp3_;
	gchar* _tmp4_;
#line 752 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_TREE (self));
#line 752 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_ENTRY (entry));
#line 753 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = sidebar_tree_get_wrapper (self, entry);
#line 753 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	wrapper = _tmp0_;
#line 754 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_vala_assert (wrapper != NULL, "wrapper != null");
#line 756 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp1_ = self->priv->store;
#line 756 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	sidebar_tree_entry_wrapper_get_iter (wrapper, &_tmp2_);
#line 756 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp3_ = sidebar_tree_get_name_for_entry (self, entry);
#line 756 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp4_ = _tmp3_;
#line 756 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	gtk_tree_store_set (_tmp1_, &_tmp2_, SIDEBAR_TREE_COLUMNS_NAME, _tmp4_, -1);
#line 756 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_free0 (_tmp4_);
#line 752 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (wrapper);
#line 4967 "Tree.c"
}


static void
sidebar_tree_on_sidebar_name_changed (SidebarTree* self,
                                      SidebarEntry* entry,
                                      const gchar* name)
{
#line 759 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_TREE (self));
#line 759 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_ENTRY (entry));
#line 759 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (name != NULL);
#line 760 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	sidebar_tree_rename_entry (self, entry);
#line 4984 "Tree.c"
}


static void
sidebar_tree_on_sidebar_page_created (SidebarTree* self,
                                      SidebarPageRepresentative* entry,
                                      Page* page)
{
#line 763 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_TREE (self));
#line 763 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_PAGE_REPRESENTATIVE (entry));
#line 763 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (IS_PAGE (page));
#line 764 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_signal_emit (self, sidebar_tree_signals[SIDEBAR_TREE_PAGE_CREATED_SIGNAL], 0, entry, page);
#line 5001 "Tree.c"
}


static void
sidebar_tree_on_is_emphasized_changed (SidebarTree* self,
                                       SidebarEmphasizableEntry* entry,
                                       gboolean is_emphasized)
{
#line 767 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_TREE (self));
#line 767 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_EMPHASIZABLE_ENTRY (entry));
#line 768 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	sidebar_tree_rename_entry (self, G_TYPE_CHECK_INSTANCE_CAST (entry, SIDEBAR_TYPE_ENTRY, SidebarEntry));
#line 5016 "Tree.c"
}


static void
sidebar_tree_on_sidebar_destroying_page (SidebarTree* self,
                                         SidebarPageRepresentative* entry,
                                         Page* page)
{
#line 771 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_TREE (self));
#line 771 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_PAGE_REPRESENTATIVE (entry));
#line 771 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (IS_PAGE (page));
#line 772 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_signal_emit (self, sidebar_tree_signals[SIDEBAR_TREE_DESTROYING_PAGE_SIGNAL], 0, entry, page);
#line 5033 "Tree.c"
}


static void
sidebar_tree_load_entry_icons (SidebarTree* self,
                               GtkTreeIter* iter)
{
	SidebarTreeEntryWrapper* wrapper = NULL;
	GtkTreeIter _tmp0_;
	SidebarTreeEntryWrapper* _tmp1_;
	GIcon* icon = NULL;
	SidebarTreeEntryWrapper* _tmp2_;
	GtkTreeStore* _tmp11_;
	GtkTreeIter _tmp12_;
	GIcon* _tmp13_;
	GError * _inner_error_ = NULL;
#line 775 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_TREE (self));
#line 775 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (iter != NULL);
#line 776 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = *iter;
#line 776 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp1_ = sidebar_tree_get_wrapper_at_iter (self, &_tmp0_);
#line 776 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	wrapper = _tmp1_;
#line 777 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	icon = NULL;
#line 778 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp2_ = wrapper;
#line 778 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp2_ == NULL) {
#line 779 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (icon);
#line 779 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (wrapper);
#line 779 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		return;
#line 5072 "Tree.c"
	}
	{
		gchar* name = NULL;
		SidebarTreeEntryWrapper* _tmp3_;
		SidebarEntry* _tmp4_;
		gchar* _tmp5_;
		const gchar* _tmp6_;
#line 782 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp3_ = wrapper;
#line 782 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp4_ = _tmp3_->entry;
#line 782 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp5_ = sidebar_entry_get_sidebar_icon (_tmp4_);
#line 782 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		name = _tmp5_;
#line 783 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp6_ = name;
#line 783 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		if (_tmp6_ != NULL) {
#line 5092 "Tree.c"
			GIcon* _tmp7_ = NULL;
			const gchar* _tmp8_;
			GIcon* _tmp9_;
			GIcon* _tmp10_;
#line 784 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp8_ = name;
#line 784 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp9_ = g_icon_new_for_string (_tmp8_, &_inner_error_);
#line 784 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp7_ = _tmp9_;
#line 784 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 784 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				_g_free0 (name);
#line 5107 "Tree.c"
				goto __catch57_g_error;
			}
#line 784 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp10_ = _tmp7_;
#line 784 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp7_ = NULL;
#line 784 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_g_object_unref0 (icon);
#line 784 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			icon = _tmp10_;
#line 783 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_g_object_unref0 (_tmp7_);
#line 5120 "Tree.c"
		}
#line 781 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_free0 (name);
#line 5124 "Tree.c"
	}
	goto __finally57;
	__catch57_g_error:
	{
		GError* e = NULL;
#line 781 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		e = _inner_error_;
#line 781 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_inner_error_ = NULL;
#line 781 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_error_free0 (e);
#line 5136 "Tree.c"
	}
	__finally57:
#line 781 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 781 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (icon);
#line 781 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (wrapper);
#line 781 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 781 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		g_clear_error (&_inner_error_);
#line 781 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		return;
#line 5151 "Tree.c"
	}
#line 789 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp11_ = self->priv->store;
#line 789 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp12_ = *iter;
#line 789 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp13_ = icon;
#line 789 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	gtk_tree_store_set (_tmp11_, &_tmp12_, SIDEBAR_TREE_COLUMNS_ICON, _tmp13_, -1);
#line 775 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (icon);
#line 775 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (wrapper);
#line 5165 "Tree.c"
}


static void
sidebar_tree_load_branch_icons (SidebarTree* self,
                                GtkTreeIter* iter)
{
	GtkTreeIter _tmp0_;
	GtkTreeIter child_iter = {0};
	GtkTreeStore* _tmp1_;
	GtkTreeIter _tmp2_;
	GtkTreeIter _tmp3_ = {0};
	gboolean _tmp4_;
#line 792 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_TREE (self));
#line 792 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (iter != NULL);
#line 793 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = *iter;
#line 793 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	sidebar_tree_load_entry_icons (self, &_tmp0_);
#line 796 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp1_ = self->priv->store;
#line 796 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp2_ = *iter;
#line 796 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp4_ = gtk_tree_model_iter_children (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, gtk_tree_model_get_type (), GtkTreeModel), &_tmp3_, &_tmp2_);
#line 796 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	child_iter = _tmp3_;
#line 796 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp4_) {
#line 5197 "Tree.c"
		{
			gboolean _tmp5_ = FALSE;
#line 797 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp5_ = TRUE;
#line 797 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			while (TRUE) {
#line 5204 "Tree.c"
				GtkTreeIter _tmp8_;
#line 797 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				if (!_tmp5_) {
#line 5208 "Tree.c"
					GtkTreeStore* _tmp6_;
					gboolean _tmp7_;
#line 799 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
					_tmp6_ = self->priv->store;
#line 799 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
					_tmp7_ = gtk_tree_model_iter_next (G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, gtk_tree_model_get_type (), GtkTreeModel), &child_iter);
#line 799 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
					if (!_tmp7_) {
#line 799 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
						break;
#line 5219 "Tree.c"
					}
				}
#line 797 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				_tmp5_ = FALSE;
#line 798 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				_tmp8_ = child_iter;
#line 798 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				sidebar_tree_load_branch_icons (self, &_tmp8_);
#line 5228 "Tree.c"
			}
		}
	}
}


static gboolean
sidebar_tree_on_selection (SidebarTree* self,
                           GtkTreeSelection* selection,
                           GtkTreeModel* model,
                           GtkTreePath* path,
                           gboolean path_currently_selected)
{
	gboolean result = FALSE;
	SidebarTreeEntryWrapper* wrapper = NULL;
	SidebarTreeEntryWrapper* _tmp0_;
	gboolean _tmp1_ = FALSE;
	SidebarTreeEntryWrapper* _tmp2_;
#line 803 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (SIDEBAR_IS_TREE (self), FALSE);
#line 803 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (GTK_IS_TREE_SELECTION (selection), FALSE);
#line 803 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (GTK_IS_TREE_MODEL (model), FALSE);
#line 803 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (path != NULL, FALSE);
#line 806 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = sidebar_tree_get_wrapper_at_path (self, path);
#line 806 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	wrapper = _tmp0_;
#line 808 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp2_ = wrapper;
#line 808 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp2_ != NULL) {
#line 5263 "Tree.c"
		SidebarTreeEntryWrapper* _tmp3_;
		SidebarEntry* _tmp4_;
#line 808 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp3_ = wrapper;
#line 808 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp4_ = _tmp3_->entry;
#line 808 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp1_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp4_, SIDEBAR_TYPE_SELECTABLE_ENTRY);
#line 5272 "Tree.c"
	} else {
#line 808 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp1_ = FALSE;
#line 5276 "Tree.c"
	}
#line 808 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	result = _tmp1_;
#line 808 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (wrapper);
#line 808 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	return result;
#line 5284 "Tree.c"
}


static GtkTreePath*
sidebar_tree_get_path_from_event (SidebarTree* self,
                                  GdkEventButton* event)
{
	GtkTreePath* result = NULL;
	gint x = 0;
	gint y = 0;
	GdkModifierType mask = 0;
	GdkWindow* _tmp0_;
	GdkDisplay* _tmp1_;
	GdkDeviceManager* _tmp2_;
	GdkDevice* _tmp3_;
	gint _tmp4_ = 0;
	gint _tmp5_ = 0;
	GdkModifierType _tmp6_ = 0;
	gint cell_x = 0;
	gint cell_y = 0;
	GtkTreePath* path = NULL;
	GtkTreePath* _tmp7_ = NULL;
	gint _tmp8_;
	gint _tmp9_;
	GtkTreePath* _tmp10_ = NULL;
	gint _tmp11_ = 0;
	gint _tmp12_ = 0;
	gboolean _tmp13_;
	GtkTreePath* _tmp15_;
#line 811 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (SIDEBAR_IS_TREE (self), NULL);
#line 811 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (event != NULL, NULL);
#line 814 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = event->window;
#line 814 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp1_ = gdk_display_get_default ();
#line 814 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp2_ = gdk_display_get_device_manager (_tmp1_);
#line 814 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp3_ = gdk_device_manager_get_client_pointer (_tmp2_);
#line 814 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	gdk_window_get_device_position (_tmp0_, _tmp3_, &_tmp4_, &_tmp5_, &_tmp6_);
#line 814 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	x = _tmp4_;
#line 814 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	y = _tmp5_;
#line 814 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	mask = _tmp6_;
#line 819 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp8_ = x;
#line 819 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp9_ = y;
#line 819 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp13_ = gtk_tree_view_get_path_at_pos (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_view_get_type (), GtkTreeView), _tmp8_, _tmp9_, &_tmp10_, NULL, &_tmp11_, &_tmp12_);
#line 819 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	__vala_GtkTreePath_free0 (path);
#line 819 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	path = _tmp10_;
#line 819 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	cell_x = _tmp11_;
#line 819 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	cell_y = _tmp12_;
#line 819 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp13_) {
#line 5350 "Tree.c"
		GtkTreePath* _tmp14_;
#line 819 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp14_ = path;
#line 819 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp7_ = _tmp14_;
#line 5356 "Tree.c"
	} else {
#line 819 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp7_ = NULL;
#line 5360 "Tree.c"
	}
#line 819 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp15_ = __vala_GtkTreePath_copy0 (_tmp7_);
#line 819 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	result = _tmp15_;
#line 819 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	__vala_GtkTreePath_free0 (path);
#line 819 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	return result;
#line 5370 "Tree.c"
}


static GtkTreePath*
sidebar_tree_get_current_path (SidebarTree* self)
{
	GtkTreePath* result = NULL;
	GtkTreeModel* model = NULL;
	GList* rows = NULL;
	GtkTreeSelection* _tmp0_;
	GtkTreeModel* _tmp1_ = NULL;
	GList* _tmp2_;
	GtkTreeModel* _tmp3_;
	gboolean _tmp4_ = FALSE;
	GList* _tmp5_;
	GtkTreePath* _tmp7_ = NULL;
	GList* _tmp8_;
	GtkTreePath* _tmp11_;
#line 822 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (SIDEBAR_IS_TREE (self), NULL);
#line 824 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = gtk_tree_view_get_selection (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_view_get_type (), GtkTreeView));
#line 824 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp2_ = gtk_tree_selection_get_selected_rows (_tmp0_, &_tmp1_);
#line 824 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (model);
#line 824 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp3_ = _g_object_ref0 (_tmp1_);
#line 824 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	model = _tmp3_;
#line 824 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	rows = _tmp2_;
#line 825 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp5_ = rows;
#line 825 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (g_list_length (_tmp5_) == ((guint) 0)) {
#line 825 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp4_ = TRUE;
#line 5409 "Tree.c"
	} else {
		GList* _tmp6_;
#line 825 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp6_ = rows;
#line 825 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp4_ = g_list_length (_tmp6_) == ((guint) 1);
#line 5416 "Tree.c"
	}
#line 825 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_vala_assert (_tmp4_, "rows.length() == 0 || rows.length() == 1");
#line 827 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp8_ = rows;
#line 827 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (g_list_length (_tmp8_) != ((guint) 0)) {
#line 5424 "Tree.c"
		GList* _tmp9_;
		gconstpointer _tmp10_;
#line 827 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp9_ = rows;
#line 827 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp10_ = g_list_nth_data (_tmp9_, (guint) 0);
#line 827 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp7_ = (GtkTreePath*) _tmp10_;
#line 5433 "Tree.c"
	} else {
#line 827 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp7_ = NULL;
#line 5437 "Tree.c"
	}
#line 827 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp11_ = __vala_GtkTreePath_copy0 (_tmp7_);
#line 827 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	result = _tmp11_;
#line 827 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	__g_list_free___vala_GtkTreePath_free0_0 (rows);
#line 827 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (model);
#line 827 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	return result;
#line 5449 "Tree.c"
}


static gboolean
sidebar_tree_on_context_menu_keypress (SidebarTree* self)
{
	gboolean result = FALSE;
	GList* rows = NULL;
	GtkTreeSelection* _tmp0_;
	GList* _tmp1_;
	GList* _tmp2_;
	GtkTreePath* path = NULL;
	GList* _tmp3_;
	gconstpointer _tmp4_;
	GtkTreePath* _tmp5_;
	GtkTreePath* _tmp6_;
	GtkTreePath* _tmp7_;
	GtkTreePath* _tmp8_;
#line 830 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (SIDEBAR_IS_TREE (self), FALSE);
#line 831 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = gtk_tree_view_get_selection (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_view_get_type (), GtkTreeView));
#line 831 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp1_ = gtk_tree_selection_get_selected_rows (_tmp0_, NULL);
#line 831 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	rows = _tmp1_;
#line 832 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp2_ = rows;
#line 832 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp2_ == NULL) {
#line 833 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		result = FALSE;
#line 833 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		__g_list_free___vala_GtkTreePath_free0_0 (rows);
#line 833 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		return result;
#line 5486 "Tree.c"
	}
#line 835 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp3_ = rows;
#line 835 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp4_ = _tmp3_->data;
#line 835 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp5_ = __vala_GtkTreePath_copy0 ((GtkTreePath*) _tmp4_);
#line 835 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	path = _tmp5_;
#line 836 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp6_ = path;
#line 836 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp6_ == NULL) {
#line 837 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		result = FALSE;
#line 837 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		__vala_GtkTreePath_free0 (path);
#line 837 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		__g_list_free___vala_GtkTreePath_free0_0 (rows);
#line 837 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		return result;
#line 5508 "Tree.c"
	}
#line 839 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp7_ = path;
#line 839 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	gtk_tree_view_scroll_to_cell (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_view_get_type (), GtkTreeView), _tmp7_, NULL, FALSE, (gfloat) 0, (gfloat) 0);
#line 841 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp8_ = path;
#line 841 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	result = sidebar_tree_popup_context_menu (self, _tmp8_, NULL);
#line 841 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	__vala_GtkTreePath_free0 (path);
#line 841 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	__g_list_free___vala_GtkTreePath_free0_0 (rows);
#line 841 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	return result;
#line 5524 "Tree.c"
}


static gboolean
sidebar_tree_popup_context_menu (SidebarTree* self,
                                 GtkTreePath* path,
                                 GdkEventButton* event)
{
	gboolean result = FALSE;
	SidebarTreeEntryWrapper* wrapper = NULL;
	SidebarTreeEntryWrapper* _tmp0_;
	SidebarTreeEntryWrapper* _tmp1_;
	SidebarContextable* contextable = NULL;
	SidebarTreeEntryWrapper* _tmp2_;
	SidebarEntry* _tmp3_;
	SidebarContextable* _tmp4_;
	SidebarContextable* _tmp5_;
	SidebarSelectableEntry* selectable = NULL;
	SidebarTreeEntryWrapper* _tmp6_;
	SidebarEntry* _tmp7_;
	SidebarSelectableEntry* _tmp8_;
	SidebarSelectableEntry* _tmp9_;
	GtkMenu* context_menu = NULL;
	SidebarContextable* _tmp11_;
	GtkMenu* _tmp12_;
	GtkMenu* _tmp13_;
	GtkMenu* _tmp14_;
	GtkWidget* _tmp15_;
#line 844 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (SIDEBAR_IS_TREE (self), FALSE);
#line 844 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (path != NULL, FALSE);
#line 845 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = sidebar_tree_get_wrapper_at_path (self, path);
#line 845 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	wrapper = _tmp0_;
#line 846 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp1_ = wrapper;
#line 846 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp1_ == NULL) {
#line 847 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		result = FALSE;
#line 847 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (wrapper);
#line 847 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		return result;
#line 5571 "Tree.c"
	}
#line 849 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp2_ = wrapper;
#line 849 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp3_ = _tmp2_->entry;
#line 849 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp4_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp3_, SIDEBAR_TYPE_CONTEXTABLE) ? ((SidebarContextable*) _tmp3_) : NULL);
#line 849 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	contextable = _tmp4_;
#line 850 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp5_ = contextable;
#line 850 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp5_ == NULL) {
#line 851 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		result = FALSE;
#line 851 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (contextable);
#line 851 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (wrapper);
#line 851 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		return result;
#line 5593 "Tree.c"
	}
#line 854 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp6_ = wrapper;
#line 854 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp7_ = _tmp6_->entry;
#line 854 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp8_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp7_, SIDEBAR_TYPE_SELECTABLE_ENTRY) ? ((SidebarSelectableEntry*) _tmp7_) : NULL);
#line 854 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	selectable = _tmp8_;
#line 855 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp9_ = selectable;
#line 855 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp9_ != NULL) {
#line 5607 "Tree.c"
		SidebarSelectableEntry* _tmp10_;
#line 856 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp10_ = selectable;
#line 856 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		g_signal_emit (self, sidebar_tree_signals[SIDEBAR_TREE_ENTRY_SELECTED_SIGNAL], 0, _tmp10_);
#line 5613 "Tree.c"
	}
#line 858 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp11_ = contextable;
#line 858 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp12_ = sidebar_contextable_get_sidebar_context_menu (_tmp11_, event);
#line 858 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	context_menu = _tmp12_;
#line 859 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp13_ = context_menu;
#line 859 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp13_ == NULL) {
#line 860 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		result = FALSE;
#line 860 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (context_menu);
#line 860 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (selectable);
#line 860 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (contextable);
#line 860 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (wrapper);
#line 860 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		return result;
#line 5637 "Tree.c"
	}
#line 862 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp14_ = context_menu;
#line 862 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp15_ = gtk_menu_get_attach_widget (_tmp14_);
#line 862 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp15_ == NULL) {
#line 5645 "Tree.c"
		GtkMenu* _tmp16_;
#line 863 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp16_ = context_menu;
#line 863 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		gtk_menu_attach_to_widget (_tmp16_, G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget), NULL);
#line 5651 "Tree.c"
	}
#line 866 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (event != NULL) {
#line 5655 "Tree.c"
		GtkMenu* _tmp17_;
		guint _tmp18_;
		guint32 _tmp19_;
#line 867 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp17_ = context_menu;
#line 867 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp18_ = event->button;
#line 867 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp19_ = event->time;
#line 867 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		gtk_menu_popup (_tmp17_, NULL, NULL, NULL, NULL, _tmp18_, _tmp19_);
#line 5667 "Tree.c"
	} else {
		GtkMenu* _tmp20_;
#line 869 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp20_ = context_menu;
#line 869 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		gtk_menu_popup (_tmp20_, NULL, NULL, NULL, NULL, (guint) 0, gtk_get_current_event_time ());
#line 5674 "Tree.c"
	}
#line 871 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	result = TRUE;
#line 871 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (context_menu);
#line 871 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (selectable);
#line 871 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (contextable);
#line 871 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (wrapper);
#line 871 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	return result;
#line 5688 "Tree.c"
}


static gboolean
sidebar_tree_popup_default_context_menu (SidebarTree* self,
                                         GdkEventButton* event)
{
	gboolean result = FALSE;
	GtkMenu* _tmp0_;
	guint _tmp1_;
	guint32 _tmp2_;
#line 874 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (SIDEBAR_IS_TREE (self), FALSE);
#line 874 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 875 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = self->priv->default_context_menu;
#line 875 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp1_ = event->button;
#line 875 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp2_ = event->time;
#line 875 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	gtk_menu_popup (_tmp0_, NULL, NULL, NULL, NULL, _tmp1_, _tmp2_);
#line 876 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	result = TRUE;
#line 876 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	return result;
#line 5716 "Tree.c"
}


gboolean
sidebar_tree_on_toggle_row (SidebarTree* self,
                            GtkTreeIter* iter,
                            GtkTreePath* path)
{
	gboolean result = FALSE;
	SidebarTreeEntryWrapper* wrapper = NULL;
	GtkTreeIter _tmp0_;
	SidebarTreeEntryWrapper* _tmp1_;
	SidebarTreeEntryWrapper* _tmp2_;
	gboolean should_allow_toggle = FALSE;
	gboolean _tmp3_;
	gboolean _tmp4_ = FALSE;
	gboolean _tmp5_ = FALSE;
	gboolean _tmp13_;
#line 879 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (SIDEBAR_IS_TREE (self), FALSE);
#line 879 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (iter != NULL, FALSE);
#line 879 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (path != NULL, FALSE);
#line 881 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = *iter;
#line 881 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp1_ = sidebar_tree_get_wrapper_at_iter (self, &_tmp0_);
#line 881 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	wrapper = _tmp1_;
#line 882 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp2_ = wrapper;
#line 882 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp2_ == NULL) {
#line 883 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		result = FALSE;
#line 883 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (wrapper);
#line 883 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		return result;
#line 5757 "Tree.c"
	}
#line 887 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp3_ = self->priv->expander_called_manually;
#line 887 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	should_allow_toggle = _tmp3_;
#line 890 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	self->priv->expander_called_manually = FALSE;
#line 893 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (gtk_tree_view_row_expanded (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_view_get_type (), GtkTreeView), path)) {
#line 5767 "Tree.c"
		GtkTreeStore* _tmp6_;
		GtkTreeIter _tmp7_;
#line 893 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp6_ = self->priv->store;
#line 893 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp7_ = *iter;
#line 893 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp5_ = gtk_tree_model_iter_has_child (G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, gtk_tree_model_get_type (), GtkTreeModel), &_tmp7_);
#line 5776 "Tree.c"
	} else {
#line 893 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp5_ = FALSE;
#line 5780 "Tree.c"
	}
#line 893 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp5_) {
#line 5784 "Tree.c"
		SidebarTreeEntryWrapper* _tmp8_;
		SidebarEntry* _tmp9_;
#line 893 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp8_ = wrapper;
#line 893 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp9_ = _tmp8_->entry;
#line 893 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp4_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp9_, SIDEBAR_TYPE_SELECTABLE_ENTRY);
#line 5793 "Tree.c"
	} else {
#line 893 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp4_ = FALSE;
#line 5797 "Tree.c"
	}
#line 893 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp4_) {
#line 5801 "Tree.c"
		gint _tmp10_;
		gint _tmp11_;
#line 895 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp10_ = self->priv->expander_special_count;
#line 895 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		self->priv->expander_special_count = _tmp10_ + 1;
#line 896 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp11_ = self->priv->expander_special_count;
#line 896 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		if (_tmp11_ == 1) {
#line 898 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			result = TRUE;
#line 898 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_g_object_unref0 (wrapper);
#line 898 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			return result;
#line 5818 "Tree.c"
		} else {
			gboolean _tmp12_;
#line 901 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp12_ = should_allow_toggle;
#line 901 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			should_allow_toggle = !_tmp12_;
#line 5825 "Tree.c"
		}
	} else {
#line 905 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		self->priv->expander_special_count = 0;
#line 5830 "Tree.c"
	}
#line 908 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp13_ = should_allow_toggle;
#line 908 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp13_) {
#line 909 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		result = FALSE;
#line 909 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (wrapper);
#line 909 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		return result;
#line 5842 "Tree.c"
	}
#line 912 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	result = TRUE;
#line 912 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (wrapper);
#line 912 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	return result;
#line 5850 "Tree.c"
}


static gboolean
sidebar_tree_real_button_press_event (GtkWidget* base,
                                      GdkEventButton* event)
{
	SidebarTree * self;
	gboolean result = FALSE;
	GtkTreePath* path = NULL;
	GtkTreePath* _tmp0_;
	gboolean _tmp1_ = FALSE;
	GtkTreePath* _tmp2_;
	gboolean _tmp4_ = FALSE;
	guint _tmp5_;
#line 915 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, SIDEBAR_TYPE_TREE, SidebarTree);
#line 915 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 916 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = sidebar_tree_get_path_from_event (self, event);
#line 916 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	path = _tmp0_;
#line 919 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp2_ = path;
#line 919 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp2_ == NULL) {
#line 5878 "Tree.c"
		guint _tmp3_;
#line 919 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp3_ = event->button;
#line 919 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp1_ = _tmp3_ != ((guint) 3);
#line 5884 "Tree.c"
	} else {
#line 919 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp1_ = FALSE;
#line 5888 "Tree.c"
	}
#line 919 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp1_) {
#line 920 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		result = TRUE;
#line 920 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		__vala_GtkTreePath_free0 (path);
#line 920 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		return result;
#line 5898 "Tree.c"
	}
#line 923 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp5_ = event->button;
#line 923 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp5_ == ((guint) 3)) {
#line 5904 "Tree.c"
		GdkEventType _tmp6_;
#line 923 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp6_ = event->type;
#line 923 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp4_ = _tmp6_ == GDK_BUTTON_PRESS;
#line 5910 "Tree.c"
	} else {
#line 923 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp4_ = FALSE;
#line 5914 "Tree.c"
	}
#line 923 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp4_) {
#line 5918 "Tree.c"
		GtkTreePath* _tmp7_;
#line 925 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp7_ = path;
#line 925 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		if (_tmp7_ != NULL) {
#line 5924 "Tree.c"
			GtkTreePath* _tmp8_;
#line 926 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp8_ = path;
#line 926 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			sidebar_tree_popup_context_menu (self, _tmp8_, event);
#line 5930 "Tree.c"
		} else {
#line 928 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			sidebar_tree_popup_default_context_menu (self, event);
#line 5934 "Tree.c"
		}
	} else {
		gboolean _tmp9_ = FALSE;
		guint _tmp10_;
#line 929 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp10_ = event->button;
#line 929 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		if (_tmp10_ == ((guint) 1)) {
#line 5943 "Tree.c"
			GdkEventType _tmp11_;
#line 929 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp11_ = event->type;
#line 929 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp9_ = _tmp11_ == GDK_BUTTON_PRESS;
#line 5949 "Tree.c"
		} else {
#line 929 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp9_ = FALSE;
#line 5953 "Tree.c"
		}
#line 929 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		if (_tmp9_) {
#line 5957 "Tree.c"
			GtkTreePath* _tmp12_;
			SidebarTreeEntryWrapper* wrapper = NULL;
			GtkTreePath* _tmp13_;
			SidebarTreeEntryWrapper* _tmp14_;
			SidebarTreeEntryWrapper* _tmp15_;
			gboolean _tmp16_ = FALSE;
			SidebarTreeEntryWrapper* _tmp17_;
			SidebarEntry* _tmp18_;
			gboolean _tmp22_ = FALSE;
			gboolean _tmp23_ = FALSE;
			GtkTreeRowReference* _tmp24_;
			gboolean _tmp33_ = FALSE;
			SidebarTreeEntryWrapper* _tmp34_;
			SidebarEntry* _tmp35_;
			GtkTreeStore* _tmp39_;
			GtkTreePath* _tmp40_;
			GtkTreeRowReference* _tmp41_;
#line 930 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp12_ = path;
#line 930 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			if (_tmp12_ == NULL) {
#line 931 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				__vala_GtkTreeRowReference_free0 (self->priv->old_path_ref);
#line 931 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				self->priv->old_path_ref = NULL;
#line 932 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				result = GTK_WIDGET_CLASS (sidebar_tree_parent_class)->button_press_event (G_TYPE_CHECK_INSTANCE_CAST (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_view_get_type (), GtkTreeView), gtk_widget_get_type (), GtkWidget), event);
#line 932 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				__vala_GtkTreePath_free0 (path);
#line 932 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				return result;
#line 5989 "Tree.c"
			}
#line 935 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp13_ = path;
#line 935 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp14_ = sidebar_tree_get_wrapper_at_path (self, _tmp13_);
#line 935 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			wrapper = _tmp14_;
#line 937 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp15_ = wrapper;
#line 937 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			if (_tmp15_ == NULL) {
#line 938 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				__vala_GtkTreeRowReference_free0 (self->priv->old_path_ref);
#line 938 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				self->priv->old_path_ref = NULL;
#line 939 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				result = GTK_WIDGET_CLASS (sidebar_tree_parent_class)->button_press_event (G_TYPE_CHECK_INSTANCE_CAST (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_view_get_type (), GtkTreeView), gtk_widget_get_type (), GtkWidget), event);
#line 939 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				_g_object_unref0 (wrapper);
#line 939 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				__vala_GtkTreePath_free0 (path);
#line 939 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				return result;
#line 6013 "Tree.c"
			}
#line 943 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp17_ = wrapper;
#line 943 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp18_ = _tmp17_->entry;
#line 943 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp18_, SIDEBAR_TYPE_EXPANDABLE_ENTRY)) {
#line 943 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				_tmp16_ = TRUE;
#line 6023 "Tree.c"
			} else {
				SidebarTreeEntryWrapper* _tmp19_;
				SidebarEntry* _tmp20_;
#line 944 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				_tmp19_ = wrapper;
#line 944 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				_tmp20_ = _tmp19_->entry;
#line 944 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				_tmp16_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp20_, SIDEBAR_TYPE_INTERNAL_DROP_TARGET_ENTRY);
#line 6033 "Tree.c"
			}
#line 943 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			if (_tmp16_) {
#line 6037 "Tree.c"
				GtkTreePath* _tmp21_;
#line 946 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				_tmp21_ = path;
#line 946 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				sidebar_tree_toggle_branch_expansion (self, _tmp21_, FALSE);
#line 6043 "Tree.c"
			}
#line 950 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp24_ = self->priv->old_path_ref;
#line 950 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			if (_tmp24_ != NULL) {
#line 6049 "Tree.c"
				GtkTreeRowReference* _tmp25_;
				GtkTreePath* _tmp26_;
				GtkTreePath* _tmp27_;
#line 950 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				_tmp25_ = self->priv->old_path_ref;
#line 950 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				_tmp26_ = gtk_tree_row_reference_get_path (_tmp25_);
#line 950 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				_tmp27_ = _tmp26_;
#line 950 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				_tmp23_ = _tmp27_ != NULL;
#line 950 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				__vala_GtkTreePath_free0 (_tmp27_);
#line 6063 "Tree.c"
			} else {
#line 950 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				_tmp23_ = FALSE;
#line 6067 "Tree.c"
			}
#line 950 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			if (_tmp23_) {
#line 6071 "Tree.c"
				GtkTreeRowReference* _tmp28_;
				GtkTreePath* _tmp29_;
				GtkTreePath* _tmp30_;
				GtkTreePath* _tmp31_;
#line 951 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				_tmp28_ = self->priv->old_path_ref;
#line 951 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				_tmp29_ = gtk_tree_row_reference_get_path (_tmp28_);
#line 951 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				_tmp30_ = _tmp29_;
#line 951 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				_tmp31_ = path;
#line 951 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				_tmp22_ = gtk_tree_path_compare (_tmp30_, _tmp31_) == 0;
#line 951 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				__vala_GtkTreePath_free0 (_tmp30_);
#line 6088 "Tree.c"
			} else {
#line 950 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				_tmp22_ = FALSE;
#line 6092 "Tree.c"
			}
#line 950 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			if (_tmp22_) {
#line 6096 "Tree.c"
				GtkCellRendererText* _tmp32_;
#line 954 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				_tmp32_ = self->priv->text_renderer;
#line 954 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				g_object_set (_tmp32_, "editable", FALSE, NULL);
#line 955 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				result = GTK_WIDGET_CLASS (sidebar_tree_parent_class)->button_press_event (G_TYPE_CHECK_INSTANCE_CAST (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_view_get_type (), GtkTreeView), gtk_widget_get_type (), GtkWidget), event);
#line 955 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				_g_object_unref0 (wrapper);
#line 955 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				__vala_GtkTreePath_free0 (path);
#line 955 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				return result;
#line 6110 "Tree.c"
			}
#line 960 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp34_ = wrapper;
#line 960 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp35_ = _tmp34_->entry;
#line 960 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp35_, SIDEBAR_TYPE_RENAMEABLE_ENTRY)) {
#line 6118 "Tree.c"
				SidebarTreeEntryWrapper* _tmp36_;
				SidebarEntry* _tmp37_;
#line 961 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				_tmp36_ = wrapper;
#line 961 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				_tmp37_ = _tmp36_->entry;
#line 961 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				_tmp33_ = sidebar_renameable_entry_is_user_renameable (G_TYPE_CHECK_INSTANCE_CAST (_tmp37_, SIDEBAR_TYPE_RENAMEABLE_ENTRY, SidebarRenameableEntry));
#line 6127 "Tree.c"
			} else {
#line 960 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				_tmp33_ = FALSE;
#line 6131 "Tree.c"
			}
#line 960 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			if (_tmp33_) {
#line 6135 "Tree.c"
				GtkCellRendererText* _tmp38_;
#line 962 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				_tmp38_ = self->priv->text_renderer;
#line 962 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				g_object_set (_tmp38_, "editable", TRUE, NULL);
#line 6141 "Tree.c"
			}
#line 966 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp39_ = self->priv->store;
#line 966 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp40_ = path;
#line 966 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp41_ = gtk_tree_row_reference_new (G_TYPE_CHECK_INSTANCE_CAST (_tmp39_, gtk_tree_model_get_type (), GtkTreeModel), _tmp40_);
#line 966 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			__vala_GtkTreeRowReference_free0 (self->priv->old_path_ref);
#line 966 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			self->priv->old_path_ref = _tmp41_;
#line 929 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_g_object_unref0 (wrapper);
#line 6155 "Tree.c"
		}
	}
#line 969 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	result = GTK_WIDGET_CLASS (sidebar_tree_parent_class)->button_press_event (G_TYPE_CHECK_INSTANCE_CAST (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_view_get_type (), GtkTreeView), gtk_widget_get_type (), GtkWidget), event);
#line 969 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	__vala_GtkTreePath_free0 (path);
#line 969 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	return result;
#line 6164 "Tree.c"
}


gboolean
sidebar_tree_is_keypress_interpreted (SidebarTree* self,
                                      GdkEventKey* event)
{
	gboolean result = FALSE;
	guint _tmp0_;
	const gchar* _tmp1_;
	const gchar* _tmp2_;
	GQuark _tmp4_ = 0U;
#line 973 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	static GQuark _tmp3_label0 = 0;
#line 973 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	static GQuark _tmp3_label1 = 0;
#line 973 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	static GQuark _tmp3_label2 = 0;
#line 973 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	static GQuark _tmp3_label3 = 0;
#line 972 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (SIDEBAR_IS_TREE (self), FALSE);
#line 972 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 973 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = event->keyval;
#line 973 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp1_ = gdk_keyval_name (_tmp0_);
#line 973 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp2_ = _tmp1_;
#line 973 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp4_ = (NULL == _tmp2_) ? 0 : g_quark_from_string (_tmp2_);
#line 973 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if ((((_tmp4_ == ((0 != _tmp3_label0) ? _tmp3_label0 : (_tmp3_label0 = g_quark_from_static_string ("F2")))) || (_tmp4_ == ((0 != _tmp3_label1) ? _tmp3_label1 : (_tmp3_label1 = g_quark_from_static_string ("Delete"))))) || (_tmp4_ == ((0 != _tmp3_label2) ? _tmp3_label2 : (_tmp3_label2 = g_quark_from_static_string ("Return"))))) || (_tmp4_ == ((0 != _tmp3_label3) ? _tmp3_label3 : (_tmp3_label3 = g_quark_from_static_string ("KP_Enter"))))) {
#line 973 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		switch (0) {
#line 6201 "Tree.c"
			default:
			{
#line 978 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				result = TRUE;
#line 978 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				return result;
#line 6208 "Tree.c"
			}
		}
	} else {
#line 973 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		switch (0) {
#line 6214 "Tree.c"
			default:
			{
#line 981 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				result = FALSE;
#line 981 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				return result;
#line 6221 "Tree.c"
			}
		}
	}
}


static gboolean
sidebar_tree_real_key_press_event (GtkWidget* base,
                                   GdkEventKey* event)
{
	SidebarTree * self;
	gboolean result = FALSE;
	guint _tmp0_;
	const gchar* _tmp1_;
	const gchar* _tmp2_;
	GQuark _tmp4_ = 0U;
#line 986 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	static GQuark _tmp3_label0 = 0;
#line 986 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	static GQuark _tmp3_label1 = 0;
#line 986 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	static GQuark _tmp3_label2 = 0;
#line 986 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	static GQuark _tmp3_label3 = 0;
#line 985 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, SIDEBAR_TYPE_TREE, SidebarTree);
#line 985 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 986 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = event->keyval;
#line 986 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp1_ = gdk_keyval_name (_tmp0_);
#line 986 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp2_ = _tmp1_;
#line 986 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp4_ = (NULL == _tmp2_) ? 0 : g_quark_from_string (_tmp2_);
#line 986 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if ((_tmp4_ == ((0 != _tmp3_label0) ? _tmp3_label0 : (_tmp3_label0 = g_quark_from_static_string ("Return")))) || (_tmp4_ == ((0 != _tmp3_label1) ? _tmp3_label1 : (_tmp3_label1 = g_quark_from_static_string ("KP_Enter"))))) {
#line 986 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		switch (0) {
#line 6262 "Tree.c"
			default:
			{
				GtkTreePath* path = NULL;
				GtkTreePath* _tmp5_;
				GtkTreePath* _tmp6_;
#line 989 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				_tmp5_ = sidebar_tree_get_current_path (self);
#line 989 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				path = _tmp5_;
#line 990 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				_tmp6_ = path;
#line 990 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				if (_tmp6_ != NULL) {
#line 6276 "Tree.c"
					GtkTreePath* _tmp7_;
#line 991 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
					_tmp7_ = path;
#line 991 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
					sidebar_tree_toggle_branch_expansion (self, _tmp7_, FALSE);
#line 6282 "Tree.c"
				}
#line 993 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				result = TRUE;
#line 993 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				__vala_GtkTreePath_free0 (path);
#line 993 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				return result;
#line 6290 "Tree.c"
			}
		}
	} else if (_tmp4_ == ((0 != _tmp3_label2) ? _tmp3_label2 : (_tmp3_label2 = g_quark_from_static_string ("F2")))) {
#line 986 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		switch (0) {
#line 6296 "Tree.c"
			default:
			{
#line 996 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				result = sidebar_tree_rename_in_place (self);
#line 996 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				return result;
#line 6303 "Tree.c"
			}
		}
	} else if (_tmp4_ == ((0 != _tmp3_label3) ? _tmp3_label3 : (_tmp3_label3 = g_quark_from_static_string ("Delete")))) {
#line 986 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		switch (0) {
#line 6309 "Tree.c"
			default:
			{
				GtkTreePath* path = NULL;
				GtkTreePath* _tmp8_;
				gboolean _tmp9_ = FALSE;
				GtkTreePath* _tmp10_;
#line 999 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				_tmp8_ = sidebar_tree_get_current_path (self);
#line 999 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				path = _tmp8_;
#line 1001 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				_tmp10_ = path;
#line 1001 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				if (_tmp10_ != NULL) {
#line 6324 "Tree.c"
					GtkTreePath* _tmp11_;
#line 1001 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
					_tmp11_ = path;
#line 1001 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
					_tmp9_ = sidebar_tree_destroy_path (self, _tmp11_);
#line 6330 "Tree.c"
				} else {
#line 1001 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
					_tmp9_ = FALSE;
#line 6334 "Tree.c"
				}
#line 1001 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				result = _tmp9_;
#line 1001 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				__vala_GtkTreePath_free0 (path);
#line 1001 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				return result;
#line 6342 "Tree.c"
			}
		}
	}
#line 1004 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	result = GTK_WIDGET_CLASS (sidebar_tree_parent_class)->key_press_event (G_TYPE_CHECK_INSTANCE_CAST (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_view_get_type (), GtkTreeView), gtk_widget_get_type (), GtkWidget), event);
#line 1004 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	return result;
#line 6350 "Tree.c"
}


gboolean
sidebar_tree_rename_entry_in_place (SidebarTree* self,
                                    SidebarEntry* entry)
{
	gboolean result = FALSE;
#line 1007 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (SIDEBAR_IS_TREE (self), FALSE);
#line 1007 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (SIDEBAR_IS_ENTRY (entry), FALSE);
#line 1008 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (!sidebar_tree_expand_to_entry (self, entry)) {
#line 1009 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		result = FALSE;
#line 1009 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		return result;
#line 6369 "Tree.c"
	}
#line 1011 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (!sidebar_tree_place_cursor (self, entry, FALSE)) {
#line 1012 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		result = FALSE;
#line 1012 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		return result;
#line 6377 "Tree.c"
	}
#line 1014 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	result = sidebar_tree_rename_in_place (self);
#line 1014 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	return result;
#line 6383 "Tree.c"
}


static gboolean
sidebar_tree_rename_in_place (SidebarTree* self)
{
	gboolean result = FALSE;
	GtkTreePath* cursor_path = NULL;
	GtkTreeViewColumn* cursor_column = NULL;
	GtkTreePath* _tmp0_ = NULL;
	GtkTreeViewColumn* _tmp1_ = NULL;
	GtkTreeViewColumn* _tmp2_;
	GtkTreePath* _tmp3_;
#line 1017 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (SIDEBAR_IS_TREE (self), FALSE);
#line 1020 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	gtk_tree_view_get_cursor (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_view_get_type (), GtkTreeView), &_tmp0_, &_tmp1_);
#line 1020 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	__vala_GtkTreePath_free0 (cursor_path);
#line 1020 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	cursor_path = _tmp0_;
#line 1020 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (cursor_column);
#line 1020 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 1020 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	cursor_column = _tmp2_;
#line 1022 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp3_ = cursor_path;
#line 1022 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (sidebar_tree_can_rename_path (self, _tmp3_)) {
#line 6415 "Tree.c"
		GtkTreePath* _tmp4_;
		GtkTreeViewColumn* _tmp5_;
		GtkCellRendererText* _tmp6_;
#line 1023 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp4_ = cursor_path;
#line 1023 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp5_ = cursor_column;
#line 1023 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp6_ = self->priv->text_renderer;
#line 1023 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		gtk_tree_view_set_cursor_on_cell (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_view_get_type (), GtkTreeView), _tmp4_, _tmp5_, G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, gtk_cell_renderer_get_type (), GtkCellRenderer), TRUE);
#line 1025 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		result = TRUE;
#line 1025 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (cursor_column);
#line 1025 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		__vala_GtkTreePath_free0 (cursor_path);
#line 1025 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		return result;
#line 6435 "Tree.c"
	}
#line 1028 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	result = FALSE;
#line 1028 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (cursor_column);
#line 1028 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	__vala_GtkTreePath_free0 (cursor_path);
#line 1028 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	return result;
#line 6445 "Tree.c"
}


gboolean
sidebar_tree_scroll_to_entry (SidebarTree* self,
                              SidebarEntry* entry)
{
	gboolean result = FALSE;
	SidebarTreeEntryWrapper* wrapper = NULL;
	SidebarTreeEntryWrapper* _tmp0_;
	SidebarTreeEntryWrapper* _tmp1_;
	SidebarTreeEntryWrapper* _tmp2_;
	GtkTreePath* _tmp3_;
	GtkTreePath* _tmp4_;
#line 1031 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (SIDEBAR_IS_TREE (self), FALSE);
#line 1031 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (SIDEBAR_IS_ENTRY (entry), FALSE);
#line 1032 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = sidebar_tree_get_wrapper (self, entry);
#line 1032 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	wrapper = _tmp0_;
#line 1033 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp1_ = wrapper;
#line 1033 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp1_ == NULL) {
#line 1034 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		result = FALSE;
#line 1034 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (wrapper);
#line 1034 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		return result;
#line 6478 "Tree.c"
	}
#line 1036 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp2_ = wrapper;
#line 1036 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp3_ = sidebar_tree_entry_wrapper_get_path (_tmp2_);
#line 1036 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp4_ = _tmp3_;
#line 1036 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	gtk_tree_view_scroll_to_cell (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_view_get_type (), GtkTreeView), _tmp4_, NULL, FALSE, (gfloat) 0, (gfloat) 0);
#line 1036 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	__vala_GtkTreePath_free0 (_tmp4_);
#line 1038 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	result = TRUE;
#line 1038 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (wrapper);
#line 1038 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	return result;
#line 6496 "Tree.c"
}


static void
sidebar_tree_real_drag_data_get (GtkWidget* base,
                                 GdkDragContext* context,
                                 GtkSelectionData* selection_data,
                                 guint info,
                                 guint time)
{
	SidebarTree * self;
	SidebarInternalDragSourceEntry* drag_source = NULL;
	SidebarEntry* _tmp0_;
	SidebarInternalDragSourceEntry* _tmp6_;
	SidebarInternalDragSourceEntry* _tmp16_;
#line 1041 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, SIDEBAR_TYPE_TREE, SidebarTree);
#line 1041 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (GDK_IS_DRAG_CONTEXT (context));
#line 1041 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (selection_data != NULL);
#line 1043 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	drag_source = NULL;
#line 1045 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = self->priv->internal_drag_source_entry;
#line 1045 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp0_ != NULL) {
#line 6524 "Tree.c"
		SidebarSelectableEntry* selectable = NULL;
		SidebarEntry* _tmp1_;
		SidebarSelectableEntry* _tmp2_;
		SidebarSelectableEntry* _tmp3_;
#line 1046 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp1_ = self->priv->internal_drag_source_entry;
#line 1046 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp2_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp1_, SIDEBAR_TYPE_SELECTABLE_ENTRY) ? ((SidebarSelectableEntry*) _tmp1_) : NULL);
#line 1046 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		selectable = _tmp2_;
#line 1048 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp3_ = selectable;
#line 1048 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		if (_tmp3_ == NULL) {
#line 6539 "Tree.c"
			SidebarEntry* _tmp4_;
			SidebarInternalDragSourceEntry* _tmp5_;
#line 1049 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp4_ = self->priv->internal_drag_source_entry;
#line 1049 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp5_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp4_, SIDEBAR_TYPE_INTERNAL_DRAG_SOURCE_ENTRY) ? ((SidebarInternalDragSourceEntry*) _tmp4_) : NULL);
#line 1049 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_g_object_unref0 (drag_source);
#line 1049 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			drag_source = _tmp5_;
#line 6550 "Tree.c"
		}
#line 1045 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (selectable);
#line 6554 "Tree.c"
	}
#line 1053 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp6_ = drag_source;
#line 1053 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp6_ == NULL) {
#line 6560 "Tree.c"
		GtkTreePath* selected_path = NULL;
		GtkTreePath* _tmp7_;
		GtkTreePath* _tmp8_;
		SidebarTreeEntryWrapper* wrapper = NULL;
		GtkTreePath* _tmp9_;
		SidebarTreeEntryWrapper* _tmp10_;
		SidebarTreeEntryWrapper* _tmp11_;
		SidebarTreeEntryWrapper* _tmp12_;
		SidebarEntry* _tmp13_;
		SidebarInternalDragSourceEntry* _tmp14_;
		SidebarInternalDragSourceEntry* _tmp15_;
#line 1054 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp7_ = sidebar_tree_get_selected_path (self);
#line 1054 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		selected_path = _tmp7_;
#line 1055 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp8_ = selected_path;
#line 1055 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		if (_tmp8_ == NULL) {
#line 1056 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			__vala_GtkTreePath_free0 (selected_path);
#line 1056 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_g_object_unref0 (drag_source);
#line 1056 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			return;
#line 6586 "Tree.c"
		}
#line 1058 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp9_ = selected_path;
#line 1058 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp10_ = sidebar_tree_get_wrapper_at_path (self, _tmp9_);
#line 1058 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		wrapper = _tmp10_;
#line 1059 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp11_ = wrapper;
#line 1059 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		if (_tmp11_ == NULL) {
#line 1060 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_g_object_unref0 (wrapper);
#line 1060 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			__vala_GtkTreePath_free0 (selected_path);
#line 1060 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_g_object_unref0 (drag_source);
#line 1060 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			return;
#line 6606 "Tree.c"
		}
#line 1062 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp12_ = wrapper;
#line 1062 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp13_ = _tmp12_->entry;
#line 1062 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp14_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp13_, SIDEBAR_TYPE_INTERNAL_DRAG_SOURCE_ENTRY) ? ((SidebarInternalDragSourceEntry*) _tmp13_) : NULL);
#line 1062 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (drag_source);
#line 1062 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		drag_source = _tmp14_;
#line 1063 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp15_ = drag_source;
#line 1063 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		if (_tmp15_ == NULL) {
#line 1064 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_g_object_unref0 (wrapper);
#line 1064 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			__vala_GtkTreePath_free0 (selected_path);
#line 1064 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_g_object_unref0 (drag_source);
#line 1064 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			return;
#line 6630 "Tree.c"
		}
#line 1053 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (wrapper);
#line 1053 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		__vala_GtkTreePath_free0 (selected_path);
#line 6636 "Tree.c"
	}
#line 1067 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp16_ = drag_source;
#line 1067 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	sidebar_internal_drag_source_entry_prepare_selection_data (_tmp16_, selection_data);
#line 1041 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (drag_source);
#line 6644 "Tree.c"
}


static void
sidebar_tree_real_drag_data_received (GtkWidget* base,
                                      GdkDragContext* context,
                                      gint x,
                                      gint y,
                                      GtkSelectionData* selection_data,
                                      guint info,
                                      guint time)
{
	SidebarTree * self;
	GtkTreePath* path = NULL;
	GtkTreeViewDropPosition pos = 0;
	GtkTreePath* _tmp0_ = NULL;
	GtkTreeViewDropPosition _tmp1_ = 0;
	gboolean _tmp2_;
	SidebarTreeEntryWrapper* wrapper = NULL;
	GtkTreePath* _tmp5_;
	SidebarTreeEntryWrapper* _tmp6_;
	GtkWidget* _tmp7_;
	SidebarTreeEntryWrapper* _tmp13_;
	SidebarInternalDropTargetEntry* targetable = NULL;
	SidebarTreeEntryWrapper* _tmp14_;
	SidebarEntry* _tmp15_;
	SidebarInternalDropTargetEntry* _tmp16_;
	SidebarInternalDropTargetEntry* _tmp17_;
	gboolean success = FALSE;
	gchar* _tmp18_;
	gchar* _tmp19_;
	gboolean _tmp20_;
	gboolean _tmp31_;
#line 1070 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, SIDEBAR_TYPE_TREE, SidebarTree);
#line 1070 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (GDK_IS_DRAG_CONTEXT (context));
#line 1070 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (selection_data != NULL);
#line 1075 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp2_ = gtk_tree_view_get_dest_row_at_pos (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_view_get_type (), GtkTreeView), x, y, &_tmp0_, &_tmp1_);
#line 1075 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	__vala_GtkTreePath_free0 (path);
#line 1075 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	path = _tmp0_;
#line 1075 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	pos = _tmp1_;
#line 1075 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (!_tmp2_) {
#line 6694 "Tree.c"
		GtkWidget* _tmp3_;
#line 1077 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp3_ = gtk_drag_get_source_widget (context);
#line 1077 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		if (_tmp3_ == NULL) {
#line 6700 "Tree.c"
			SidebarTreeExternalDropHandler _tmp4_;
			void* _tmp4__target;
#line 1078 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp4_ = self->priv->drop_handler;
#line 1078 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp4__target = self->priv->drop_handler_target;
#line 1078 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp4_ (context, NULL, selection_data, info, time, _tmp4__target);
#line 6709 "Tree.c"
		} else {
#line 1080 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			gtk_drag_finish (context, FALSE, FALSE, (guint32) time);
#line 6713 "Tree.c"
		}
#line 1082 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		__vala_GtkTreePath_free0 (path);
#line 1082 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		return;
#line 6719 "Tree.c"
	}
#line 1086 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp5_ = path;
#line 1086 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp6_ = sidebar_tree_get_wrapper_at_path (self, _tmp5_);
#line 1086 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	wrapper = _tmp6_;
#line 1089 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp7_ = gtk_drag_get_source_widget (context);
#line 1089 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp7_ == NULL) {
#line 6731 "Tree.c"
		SidebarEntry* _tmp8_ = NULL;
		SidebarTreeEntryWrapper* _tmp9_;
		SidebarTreeExternalDropHandler _tmp12_;
		void* _tmp12__target;
#line 1090 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp9_ = wrapper;
#line 1090 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		if (_tmp9_ != NULL) {
#line 6740 "Tree.c"
			SidebarTreeEntryWrapper* _tmp10_;
			SidebarEntry* _tmp11_;
#line 1090 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp10_ = wrapper;
#line 1090 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp11_ = _tmp10_->entry;
#line 1090 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp8_ = _tmp11_;
#line 6749 "Tree.c"
		} else {
#line 1090 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp8_ = NULL;
#line 6753 "Tree.c"
		}
#line 1090 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp12_ = self->priv->drop_handler;
#line 1090 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp12__target = self->priv->drop_handler_target;
#line 1090 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp12_ (context, _tmp8_, selection_data, info, time, _tmp12__target);
#line 1093 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (wrapper);
#line 1093 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		__vala_GtkTreePath_free0 (path);
#line 1093 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		return;
#line 6767 "Tree.c"
	}
#line 1097 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp13_ = wrapper;
#line 1097 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp13_ == NULL) {
#line 1098 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		gtk_drag_finish (context, FALSE, FALSE, (guint32) time);
#line 1100 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (wrapper);
#line 1100 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		__vala_GtkTreePath_free0 (path);
#line 1100 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		return;
#line 6781 "Tree.c"
	}
#line 1103 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp14_ = wrapper;
#line 1103 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp15_ = _tmp14_->entry;
#line 1103 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp16_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp15_, SIDEBAR_TYPE_INTERNAL_DROP_TARGET_ENTRY) ? ((SidebarInternalDropTargetEntry*) _tmp15_) : NULL);
#line 1103 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	targetable = _tmp16_;
#line 1104 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp17_ = targetable;
#line 1104 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp17_ == NULL) {
#line 1105 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		gtk_drag_finish (context, FALSE, FALSE, (guint32) time);
#line 1107 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (targetable);
#line 1107 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (wrapper);
#line 1107 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		__vala_GtkTreePath_free0 (path);
#line 1107 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		return;
#line 6805 "Tree.c"
	}
#line 1110 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	success = FALSE;
#line 1112 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp18_ = gdk_atom_name (gtk_selection_data_get_data_type (selection_data));
#line 1112 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp19_ = _tmp18_;
#line 1112 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp20_ = g_strcmp0 (_tmp19_, LIBRARY_WINDOW_TAG_PATH_MIME_TYPE) == 0;
#line 1112 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_free0 (_tmp19_);
#line 1112 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp20_) {
#line 6819 "Tree.c"
		SidebarInternalDropTargetEntry* _tmp21_;
#line 1113 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp21_ = targetable;
#line 1113 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		success = sidebar_internal_drop_target_entry_internal_drop_received_arbitrary (_tmp21_, selection_data);
#line 6825 "Tree.c"
	} else {
		GeeList* media = NULL;
		guint8* _tmp22_;
		GeeList* _tmp23_;
		gboolean _tmp24_ = FALSE;
		GeeList* _tmp25_;
#line 1115 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp22_ = gtk_selection_data_get_data (selection_data);
#line 1115 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp23_ = unserialize_media_sources (_tmp22_, gtk_selection_data_get_length (selection_data));
#line 1115 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		media = _tmp23_;
#line 1117 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp25_ = media;
#line 1117 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		if (_tmp25_ != NULL) {
#line 6842 "Tree.c"
			GeeList* _tmp26_;
			gint _tmp27_;
			gint _tmp28_;
#line 1117 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp26_ = media;
#line 1117 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp27_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp26_, GEE_TYPE_COLLECTION, GeeCollection));
#line 1117 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp28_ = _tmp27_;
#line 1117 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp24_ = _tmp28_ > 0;
#line 6854 "Tree.c"
		} else {
#line 1117 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp24_ = FALSE;
#line 6858 "Tree.c"
		}
#line 1117 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		if (_tmp24_) {
#line 6862 "Tree.c"
			SidebarInternalDropTargetEntry* _tmp29_;
			GeeList* _tmp30_;
#line 1118 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp29_ = targetable;
#line 1118 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp30_ = media;
#line 1118 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			success = sidebar_internal_drop_target_entry_internal_drop_received (_tmp29_, _tmp30_);
#line 6871 "Tree.c"
		}
#line 1112 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (media);
#line 6875 "Tree.c"
	}
#line 1121 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp31_ = success;
#line 1121 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	gtk_drag_finish (context, _tmp31_, FALSE, (guint32) time);
#line 1070 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (targetable);
#line 1070 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (wrapper);
#line 1070 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	__vala_GtkTreePath_free0 (path);
#line 6887 "Tree.c"
}


static gboolean
sidebar_tree_real_drag_motion (GtkWidget* base,
                               GdkDragContext* context,
                               gint x,
                               gint y,
                               guint time)
{
	SidebarTree * self;
	gboolean result = FALSE;
	GtkTreePath* path = NULL;
	GtkTreeViewDropPosition pos = 0;
	gboolean has_dest = FALSE;
	GtkTreePath* _tmp0_ = NULL;
	GtkTreeViewDropPosition _tmp1_ = 0;
	gboolean _tmp2_;
	gboolean _tmp3_ = FALSE;
	gboolean _tmp4_;
#line 1124 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, SIDEBAR_TYPE_TREE, SidebarTree);
#line 1124 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (GDK_IS_DRAG_CONTEXT (context), FALSE);
#line 1126 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	GTK_WIDGET_CLASS (sidebar_tree_parent_class)->drag_motion (G_TYPE_CHECK_INSTANCE_CAST (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_view_get_type (), GtkTreeView), gtk_widget_get_type (), GtkWidget), context, x, y, time);
#line 1130 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp2_ = gtk_tree_view_get_dest_row_at_pos (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_view_get_type (), GtkTreeView), x, y, &_tmp0_, &_tmp1_);
#line 1130 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	__vala_GtkTreePath_free0 (path);
#line 1130 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	path = _tmp0_;
#line 1130 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	pos = _tmp1_;
#line 1130 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	has_dest = _tmp2_;
#line 1133 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp4_ = has_dest;
#line 1133 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (!_tmp4_) {
#line 1133 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp3_ = TRUE;
#line 6930 "Tree.c"
	} else {
		GtkTreeViewDropPosition _tmp5_;
#line 1133 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp5_ = pos;
#line 1133 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp3_ = _tmp5_ == GTK_TREE_VIEW_DROP_BEFORE;
#line 6937 "Tree.c"
	}
#line 1133 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp3_) {
#line 6941 "Tree.c"
		GtkTreePath* _tmp6_;
#line 1134 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp6_ = path;
#line 1134 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		gtk_tree_view_set_drag_dest_row (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_view_get_type (), GtkTreeView), _tmp6_, GTK_TREE_VIEW_DROP_INTO_OR_BEFORE);
#line 6947 "Tree.c"
	} else {
		GtkTreeViewDropPosition _tmp7_;
#line 1135 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp7_ = pos;
#line 1135 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		if (_tmp7_ == GTK_TREE_VIEW_DROP_AFTER) {
#line 6954 "Tree.c"
			GtkTreePath* _tmp8_;
#line 1136 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp8_ = path;
#line 1136 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			gtk_tree_view_set_drag_dest_row (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_view_get_type (), GtkTreeView), _tmp8_, GTK_TREE_VIEW_DROP_INTO_OR_AFTER);
#line 6960 "Tree.c"
		}
	}
#line 1138 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	gdk_drag_status (context, gdk_drag_context_get_suggested_action (context), (guint32) time);
#line 1140 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	result = has_dest;
#line 1140 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	__vala_GtkTreePath_free0 (path);
#line 1140 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	return result;
#line 6971 "Tree.c"
}


static gboolean
sidebar_tree_can_rename_path (SidebarTree* self,
                              GtkTreePath* path)
{
	gboolean result = FALSE;
	gint _tmp0_;
	SidebarTreeEntryWrapper* wrapper = NULL;
	SidebarTreeEntryWrapper* _tmp1_;
	SidebarTreeEntryWrapper* _tmp2_;
	SidebarRenameableEntry* renameable = NULL;
	SidebarTreeEntryWrapper* _tmp3_;
	SidebarEntry* _tmp4_;
	SidebarRenameableEntry* _tmp5_;
	SidebarRenameableEntry* _tmp6_;
	SidebarTreeEntryWrapper* _tmp7_;
	SidebarEntry* _tmp8_;
	GtkTreeSelection* _tmp9_;
#line 1144 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (SIDEBAR_IS_TREE (self), FALSE);
#line 1144 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (path != NULL, FALSE);
#line 1145 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = self->priv->editing_disabled;
#line 1145 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp0_ > 0) {
#line 1146 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		result = FALSE;
#line 1146 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		return result;
#line 7004 "Tree.c"
	}
#line 1148 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp1_ = sidebar_tree_get_wrapper_at_path (self, path);
#line 1148 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	wrapper = _tmp1_;
#line 1149 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp2_ = wrapper;
#line 1149 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp2_ == NULL) {
#line 1150 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		result = FALSE;
#line 1150 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (wrapper);
#line 1150 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		return result;
#line 7020 "Tree.c"
	}
#line 1152 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp3_ = wrapper;
#line 1152 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp4_ = _tmp3_->entry;
#line 1152 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp5_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp4_, SIDEBAR_TYPE_RENAMEABLE_ENTRY) ? ((SidebarRenameableEntry*) _tmp4_) : NULL);
#line 1152 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	renameable = _tmp5_;
#line 1153 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp6_ = renameable;
#line 1153 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp6_ == NULL) {
#line 1154 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		result = FALSE;
#line 1154 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (renameable);
#line 1154 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (wrapper);
#line 1154 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		return result;
#line 7042 "Tree.c"
	}
#line 1156 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp7_ = wrapper;
#line 1156 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp8_ = _tmp7_->entry;
#line 1156 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp8_, SIDEBAR_TYPE_HEADER)) {
#line 1157 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		result = FALSE;
#line 1157 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (renameable);
#line 1157 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (wrapper);
#line 1157 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		return result;
#line 7058 "Tree.c"
	}
#line 1159 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp9_ = gtk_tree_view_get_selection (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_view_get_type (), GtkTreeView));
#line 1159 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	gtk_tree_selection_select_path (_tmp9_, path);
#line 1161 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	result = TRUE;
#line 1161 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (renameable);
#line 1161 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (wrapper);
#line 1161 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	return result;
#line 7072 "Tree.c"
}


static gboolean
sidebar_tree_destroy_path (SidebarTree* self,
                           GtkTreePath* path)
{
	gboolean result = FALSE;
	SidebarTreeEntryWrapper* wrapper = NULL;
	SidebarTreeEntryWrapper* _tmp0_;
	SidebarTreeEntryWrapper* _tmp1_;
	SidebarDestroyableEntry* destroyable = NULL;
	SidebarTreeEntryWrapper* _tmp2_;
	SidebarEntry* _tmp3_;
	SidebarDestroyableEntry* _tmp4_;
	SidebarDestroyableEntry* _tmp5_;
	SidebarDestroyableEntry* _tmp6_;
#line 1164 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (SIDEBAR_IS_TREE (self), FALSE);
#line 1164 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (path != NULL, FALSE);
#line 1165 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = sidebar_tree_get_wrapper_at_path (self, path);
#line 1165 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	wrapper = _tmp0_;
#line 1166 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp1_ = wrapper;
#line 1166 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp1_ == NULL) {
#line 1167 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		result = FALSE;
#line 1167 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (wrapper);
#line 1167 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		return result;
#line 7108 "Tree.c"
	}
#line 1169 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp2_ = wrapper;
#line 1169 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp3_ = _tmp2_->entry;
#line 1169 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp4_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp3_, SIDEBAR_TYPE_DESTROYABLE_ENTRY) ? ((SidebarDestroyableEntry*) _tmp3_) : NULL);
#line 1169 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	destroyable = _tmp4_;
#line 1170 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp5_ = destroyable;
#line 1170 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp5_ == NULL) {
#line 1171 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		result = FALSE;
#line 1171 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (destroyable);
#line 1171 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (wrapper);
#line 1171 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		return result;
#line 7130 "Tree.c"
	}
#line 1173 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp6_ = destroyable;
#line 1173 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	sidebar_destroyable_entry_destroy_source (_tmp6_);
#line 1175 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	result = TRUE;
#line 1175 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (destroyable);
#line 1175 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (wrapper);
#line 1175 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	return result;
#line 7144 "Tree.c"
}


static void
_sidebar_tree_on_editing_done_gtk_cell_editable_editing_done (GtkCellEditable* _sender,
                                                              gpointer self)
{
#line 1181 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	sidebar_tree_on_editing_done ((SidebarTree*) self);
#line 7154 "Tree.c"
}


static gboolean
_sidebar_tree_on_editing_focus_out_gtk_widget_focus_out_event (GtkWidget* _sender,
                                                               GdkEventFocus* event,
                                                               gpointer self)
{
	gboolean result;
	result = sidebar_tree_on_editing_focus_out ((SidebarTree*) self, event);
#line 1182 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	return result;
#line 7167 "Tree.c"
}


static void
sidebar_tree_on_editing_started (SidebarTree* self,
                                 GtkCellEditable* editable,
                                 const gchar* path)
{
#line 1178 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_TREE (self));
#line 1178 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (GTK_IS_CELL_EDITABLE (editable));
#line 1178 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (path != NULL);
#line 1179 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (G_TYPE_CHECK_INSTANCE_TYPE (editable, gtk_entry_get_type ())) {
#line 7184 "Tree.c"
		GtkEntry* _tmp0_;
		GtkEntry* _tmp1_;
		GtkEntry* _tmp2_;
		GtkEntry* _tmp3_;
#line 1180 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp0_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (editable, gtk_entry_get_type (), GtkEntry));
#line 1180 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (self->priv->text_entry);
#line 1180 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		self->priv->text_entry = _tmp0_;
#line 1181 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp1_ = self->priv->text_entry;
#line 1181 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, gtk_cell_editable_get_type (), GtkCellEditable), "editing-done", (GCallback) _sidebar_tree_on_editing_done_gtk_cell_editable_editing_done, self, 0);
#line 1182 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp2_ = self->priv->text_entry;
#line 1182 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, gtk_widget_get_type (), GtkWidget), "focus-out-event", (GCallback) _sidebar_tree_on_editing_focus_out_gtk_widget_focus_out_event, self, 0);
#line 1183 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp3_ = self->priv->text_entry;
#line 1183 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		g_object_set (_tmp3_, "editable", TRUE, NULL);
#line 7207 "Tree.c"
	}
}


static void
sidebar_tree_on_editing_canceled (SidebarTree* self)
{
	GtkEntry* _tmp0_;
	GtkEntry* _tmp1_;
	guint _tmp2_;
	GtkEntry* _tmp3_;
	guint _tmp4_;
#line 1187 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_TREE (self));
#line 1188 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = self->priv->text_entry;
#line 1188 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_object_set (_tmp0_, "editable", FALSE, NULL);
#line 1190 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp1_ = self->priv->text_entry;
#line 1190 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_signal_parse_name ("editing-done", gtk_cell_editable_get_type (), &_tmp2_, NULL, FALSE);
#line 1190 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_signal_handlers_disconnect_matched (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, gtk_cell_editable_get_type (), GtkCellEditable), G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp2_, 0, NULL, (GCallback) _sidebar_tree_on_editing_done_gtk_cell_editable_editing_done, self);
#line 1191 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp3_ = self->priv->text_entry;
#line 1191 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_signal_parse_name ("focus-out-event", gtk_widget_get_type (), &_tmp4_, NULL, FALSE);
#line 1191 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_signal_handlers_disconnect_matched (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, gtk_widget_get_type (), GtkWidget), G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp4_, 0, NULL, (GCallback) _sidebar_tree_on_editing_focus_out_gtk_widget_focus_out_event, self);
#line 7238 "Tree.c"
}


static void
sidebar_tree_on_editing_done (SidebarTree* self)
{
	GtkEntry* _tmp0_;
	SidebarTreeEntryWrapper* wrapper = NULL;
	GtkTreePath* _tmp1_;
	GtkTreePath* _tmp2_;
	SidebarTreeEntryWrapper* _tmp3_;
	SidebarTreeEntryWrapper* _tmp4_;
	SidebarTreeEntryWrapper* _tmp5_;
	GtkEntry* _tmp13_;
	guint _tmp14_;
	GtkEntry* _tmp15_;
	guint _tmp16_;
#line 1194 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_TREE (self));
#line 1195 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = self->priv->text_entry;
#line 1195 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_object_set (_tmp0_, "editable", FALSE, NULL);
#line 1197 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp1_ = sidebar_tree_get_current_path (self);
#line 1197 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp2_ = _tmp1_;
#line 1197 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp3_ = sidebar_tree_get_wrapper_at_path (self, _tmp2_);
#line 1197 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp4_ = _tmp3_;
#line 1197 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	__vala_GtkTreePath_free0 (_tmp2_);
#line 1197 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	wrapper = _tmp4_;
#line 1198 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp5_ = wrapper;
#line 1198 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp5_ != NULL) {
#line 7278 "Tree.c"
		SidebarRenameableEntry* renameable = NULL;
		SidebarTreeEntryWrapper* _tmp6_;
		SidebarEntry* _tmp7_;
		SidebarRenameableEntry* _tmp8_;
		SidebarRenameableEntry* _tmp9_;
#line 1199 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp6_ = wrapper;
#line 1199 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp7_ = _tmp6_->entry;
#line 1199 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp8_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp7_, SIDEBAR_TYPE_RENAMEABLE_ENTRY) ? ((SidebarRenameableEntry*) _tmp7_) : NULL);
#line 1199 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		renameable = _tmp8_;
#line 1200 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp9_ = renameable;
#line 1200 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		if (_tmp9_ != NULL) {
#line 7296 "Tree.c"
			SidebarRenameableEntry* _tmp10_;
			GtkEntry* _tmp11_;
			const gchar* _tmp12_;
#line 1201 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp10_ = renameable;
#line 1201 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp11_ = self->priv->text_entry;
#line 1201 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp12_ = gtk_entry_get_text (_tmp11_);
#line 1201 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			sidebar_renameable_entry_rename (_tmp10_, _tmp12_);
#line 7308 "Tree.c"
		}
#line 1198 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (renameable);
#line 7312 "Tree.c"
	}
#line 1204 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp13_ = self->priv->text_entry;
#line 1204 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_signal_parse_name ("editing-done", gtk_cell_editable_get_type (), &_tmp14_, NULL, FALSE);
#line 1204 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_signal_handlers_disconnect_matched (G_TYPE_CHECK_INSTANCE_CAST (_tmp13_, gtk_cell_editable_get_type (), GtkCellEditable), G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp14_, 0, NULL, (GCallback) _sidebar_tree_on_editing_done_gtk_cell_editable_editing_done, self);
#line 1205 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp15_ = self->priv->text_entry;
#line 1205 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_signal_parse_name ("focus-out-event", gtk_widget_get_type (), &_tmp16_, NULL, FALSE);
#line 1205 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_signal_handlers_disconnect_matched (G_TYPE_CHECK_INSTANCE_CAST (_tmp15_, gtk_widget_get_type (), GtkWidget), G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp16_, 0, NULL, (GCallback) _sidebar_tree_on_editing_focus_out_gtk_widget_focus_out_event, self);
#line 1194 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (wrapper);
#line 7328 "Tree.c"
}


static gboolean
sidebar_tree_on_editing_focus_out (SidebarTree* self,
                                   GdkEventFocus* event)
{
	gboolean result = FALSE;
#line 1208 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (SIDEBAR_IS_TREE (self), FALSE);
#line 1208 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 1212 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	result = FALSE;
#line 1212 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	return result;
#line 7345 "Tree.c"
}


static void
sidebar_tree_on_new_search (SidebarTree* self)
{
	SavedSearchDialog* _tmp0_;
	SavedSearchDialog* _tmp1_;
#line 1215 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_TREE (self));
#line 1216 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = saved_search_dialog_new ();
#line 1216 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_object_ref_sink (_tmp0_);
#line 1216 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp1_ = _tmp0_;
#line 1216 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	saved_search_dialog_show (_tmp1_);
#line 1216 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (_tmp1_);
#line 7366 "Tree.c"
}


static void
sidebar_tree_on_new_tag (SidebarTree* self)
{
	NewRootTagCommand* creation_command = NULL;
	NewRootTagCommand* _tmp0_;
	CommandManager* _tmp1_;
	CommandManager* _tmp2_;
	LibraryWindow* _tmp3_;
	LibraryWindow* _tmp4_;
	Tag* _tmp5_;
	Tag* _tmp6_;
#line 1219 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_TREE (self));
#line 1220 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = new_root_tag_command_new ();
#line 1220 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	creation_command = _tmp0_;
#line 1221 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp1_ = app_window_get_command_manager ();
#line 1221 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp2_ = _tmp1_;
#line 1221 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	command_manager_execute (_tmp2_, G_TYPE_CHECK_INSTANCE_CAST (creation_command, TYPE_COMMAND, Command));
#line 1221 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_command_manager_unref0 (_tmp2_);
#line 1222 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp3_ = library_window_get_app ();
#line 1222 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp4_ = _tmp3_;
#line 1222 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp5_ = new_root_tag_command_get_created_tag (creation_command);
#line 1222 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp6_ = _tmp5_;
#line 1222 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	library_window_rename_tag_in_sidebar (_tmp4_, _tmp6_);
#line 1222 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (_tmp6_);
#line 1222 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (_tmp4_);
#line 1219 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (creation_command);
#line 7411 "Tree.c"
}


static void
g_cclosure_user_marshal_VOID__OBJECT_BOOLEAN (GClosure * closure,
                                              GValue * return_value,
                                              guint n_param_values,
                                              const GValue * param_values,
                                              gpointer invocation_hint,
                                              gpointer marshal_data)
{
	typedef void (*GMarshalFunc_VOID__OBJECT_BOOLEAN) (gpointer data1, gpointer arg_1, gboolean arg_2, gpointer data2);
	register GMarshalFunc_VOID__OBJECT_BOOLEAN callback;
	register GCClosure * cc;
	register gpointer data1;
	register gpointer data2;
	cc = (GCClosure *) closure;
#line 7 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (n_param_values == 3);
#line 7 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (G_CCLOSURE_SWAP_DATA (closure)) {
#line 7 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		data1 = closure->data;
#line 7 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		data2 = param_values->data[0].v_pointer;
#line 7437 "Tree.c"
	} else {
#line 7 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		data1 = param_values->data[0].v_pointer;
#line 7 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		data2 = closure->data;
#line 7443 "Tree.c"
	}
#line 7 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	callback = (GMarshalFunc_VOID__OBJECT_BOOLEAN) (marshal_data ? marshal_data : cc->callback);
#line 7 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	callback (data1, g_value_get_object (param_values + 1), g_value_get_boolean (param_values + 2), data2);
#line 7449 "Tree.c"
}


static void
g_cclosure_user_marshal_VOID__OBJECT_OBJECT (GClosure * closure,
                                             GValue * return_value,
                                             guint n_param_values,
                                             const GValue * param_values,
                                             gpointer invocation_hint,
                                             gpointer marshal_data)
{
	typedef void (*GMarshalFunc_VOID__OBJECT_OBJECT) (gpointer data1, gpointer arg_1, gpointer arg_2, gpointer data2);
	register GMarshalFunc_VOID__OBJECT_OBJECT callback;
	register GCClosure * cc;
	register gpointer data1;
	register gpointer data2;
	cc = (GCClosure *) closure;
#line 7 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (n_param_values == 3);
#line 7 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (G_CCLOSURE_SWAP_DATA (closure)) {
#line 7 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		data1 = closure->data;
#line 7 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		data2 = param_values->data[0].v_pointer;
#line 7475 "Tree.c"
	} else {
#line 7 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		data1 = param_values->data[0].v_pointer;
#line 7 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		data2 = closure->data;
#line 7481 "Tree.c"
	}
#line 7 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	callback = (GMarshalFunc_VOID__OBJECT_OBJECT) (marshal_data ? marshal_data : cc->callback);
#line 7 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	callback (data1, g_value_get_object (param_values + 1), g_value_get_object (param_values + 2), data2);
#line 7487 "Tree.c"
}


static SidebarTreeEntryWrapper*
sidebar_tree_entry_wrapper_construct (GType object_type,
                                      GtkTreeModel* model,
                                      SidebarEntry* entry,
                                      GtkTreePath* path)
{
	SidebarTreeEntryWrapper * self = NULL;
	SidebarEntry* _tmp0_;
	GtkTreeRowReference* _tmp1_;
#line 19 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (GTK_IS_TREE_MODEL (model), NULL);
#line 19 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (SIDEBAR_IS_ENTRY (entry), NULL);
#line 19 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (path != NULL, NULL);
#line 19 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	self = (SidebarTreeEntryWrapper*) g_object_new (object_type, NULL);
#line 20 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = _g_object_ref0 (entry);
#line 20 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (self->entry);
#line 20 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	self->entry = _tmp0_;
#line 21 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp1_ = gtk_tree_row_reference_new (model, path);
#line 21 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	__vala_GtkTreeRowReference_free0 (self->row);
#line 21 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	self->row = _tmp1_;
#line 19 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	return self;
#line 7522 "Tree.c"
}


static SidebarTreeEntryWrapper*
sidebar_tree_entry_wrapper_new (GtkTreeModel* model,
                                SidebarEntry* entry,
                                GtkTreePath* path)
{
#line 19 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	return sidebar_tree_entry_wrapper_construct (SIDEBAR_TREE_TYPE_ENTRY_WRAPPER, model, entry, path);
#line 7533 "Tree.c"
}


static GtkTreePath*
sidebar_tree_entry_wrapper_get_path (SidebarTreeEntryWrapper* self)
{
	GtkTreePath* result = NULL;
	GtkTreeRowReference* _tmp0_;
	GtkTreePath* _tmp1_;
#line 24 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (SIDEBAR_TREE_IS_ENTRY_WRAPPER (self), NULL);
#line 25 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = self->row;
#line 25 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp1_ = gtk_tree_row_reference_get_path (_tmp0_);
#line 25 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	result = _tmp1_;
#line 25 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	return result;
#line 7553 "Tree.c"
}


static void
sidebar_tree_entry_wrapper_get_iter (SidebarTreeEntryWrapper* self,
                                     GtkTreeIter* result)
{
	GtkTreeIter iter = {0};
	gboolean valid = FALSE;
	GtkTreeRowReference* _tmp0_;
	GtkTreeModel* _tmp1_;
	GtkTreePath* _tmp2_;
	GtkTreePath* _tmp3_;
	GtkTreeIter _tmp4_ = {0};
	gboolean _tmp5_;
	gboolean _tmp6_;
#line 28 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_TREE_IS_ENTRY_WRAPPER (self));
#line 30 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = self->row;
#line 30 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp1_ = gtk_tree_row_reference_get_model (_tmp0_);
#line 30 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp2_ = sidebar_tree_entry_wrapper_get_path (self);
#line 30 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp3_ = _tmp2_;
#line 30 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp5_ = gtk_tree_model_get_iter (_tmp1_, &_tmp4_, _tmp3_);
#line 30 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	iter = _tmp4_;
#line 30 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp6_ = _tmp5_;
#line 30 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	__vala_GtkTreePath_free0 (_tmp3_);
#line 30 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	valid = _tmp6_;
#line 31 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_vala_assert (valid, "valid");
#line 33 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	*result = iter;
#line 33 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	return;
#line 7596 "Tree.c"
}


static void
sidebar_tree_entry_wrapper_class_init (SidebarTreeEntryWrapperClass * klass)
{
#line 15 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	sidebar_tree_entry_wrapper_parent_class = g_type_class_peek_parent (klass);
#line 15 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	G_OBJECT_CLASS (klass)->finalize = sidebar_tree_entry_wrapper_finalize;
#line 7607 "Tree.c"
}


static void
sidebar_tree_entry_wrapper_instance_init (SidebarTreeEntryWrapper * self)
{
}


static void
sidebar_tree_entry_wrapper_finalize (GObject * obj)
{
	SidebarTreeEntryWrapper * self;
#line 15 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, SIDEBAR_TREE_TYPE_ENTRY_WRAPPER, SidebarTreeEntryWrapper);
#line 16 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (self->entry);
#line 17 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	__vala_GtkTreeRowReference_free0 (self->row);
#line 15 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	G_OBJECT_CLASS (sidebar_tree_entry_wrapper_parent_class)->finalize (obj);
#line 7629 "Tree.c"
}


static GType
sidebar_tree_entry_wrapper_get_type (void)
{
	static volatile gsize sidebar_tree_entry_wrapper_type_id__volatile = 0;
	if (g_once_init_enter (&sidebar_tree_entry_wrapper_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SidebarTreeEntryWrapperClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) sidebar_tree_entry_wrapper_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SidebarTreeEntryWrapper), 0, (GInstanceInitFunc) sidebar_tree_entry_wrapper_instance_init, NULL };
		GType sidebar_tree_entry_wrapper_type_id;
		sidebar_tree_entry_wrapper_type_id = g_type_register_static (G_TYPE_OBJECT, "SidebarTreeEntryWrapper", &g_define_type_info, 0);
		g_once_init_leave (&sidebar_tree_entry_wrapper_type_id__volatile, sidebar_tree_entry_wrapper_type_id);
	}
	return sidebar_tree_entry_wrapper_type_id__volatile;
}


static SidebarTreeRootWrapper*
sidebar_tree_root_wrapper_construct (GType object_type,
                                     GtkTreeModel* model,
                                     SidebarEntry* entry,
                                     GtkTreePath* path,
                                     gint root_position)
{
	SidebarTreeRootWrapper * self = NULL;
#line 40 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (GTK_IS_TREE_MODEL (model), NULL);
#line 40 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (SIDEBAR_IS_ENTRY (entry), NULL);
#line 40 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (path != NULL, NULL);
#line 41 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	self = (SidebarTreeRootWrapper*) sidebar_tree_entry_wrapper_construct (object_type, model, entry, path);
#line 43 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	self->root_position = root_position;
#line 40 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	return self;
#line 7667 "Tree.c"
}


static SidebarTreeRootWrapper*
sidebar_tree_root_wrapper_new (GtkTreeModel* model,
                               SidebarEntry* entry,
                               GtkTreePath* path,
                               gint root_position)
{
#line 40 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	return sidebar_tree_root_wrapper_construct (SIDEBAR_TREE_TYPE_ROOT_WRAPPER, model, entry, path, root_position);
#line 7679 "Tree.c"
}


static void
sidebar_tree_root_wrapper_class_init (SidebarTreeRootWrapperClass * klass)
{
#line 37 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	sidebar_tree_root_wrapper_parent_class = g_type_class_peek_parent (klass);
#line 37 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	G_OBJECT_CLASS (klass)->finalize = sidebar_tree_root_wrapper_finalize;
#line 7690 "Tree.c"
}


static void
sidebar_tree_root_wrapper_instance_init (SidebarTreeRootWrapper * self)
{
}


static void
sidebar_tree_root_wrapper_finalize (GObject * obj)
{
	SidebarTreeRootWrapper * self;
#line 37 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, SIDEBAR_TREE_TYPE_ROOT_WRAPPER, SidebarTreeRootWrapper);
#line 37 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	G_OBJECT_CLASS (sidebar_tree_root_wrapper_parent_class)->finalize (obj);
#line 7708 "Tree.c"
}


static GType
sidebar_tree_root_wrapper_get_type (void)
{
	static volatile gsize sidebar_tree_root_wrapper_type_id__volatile = 0;
	if (g_once_init_enter (&sidebar_tree_root_wrapper_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SidebarTreeRootWrapperClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) sidebar_tree_root_wrapper_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SidebarTreeRootWrapper), 0, (GInstanceInitFunc) sidebar_tree_root_wrapper_instance_init, NULL };
		GType sidebar_tree_root_wrapper_type_id;
		sidebar_tree_root_wrapper_type_id = g_type_register_static (SIDEBAR_TREE_TYPE_ENTRY_WRAPPER, "SidebarTreeRootWrapper", &g_define_type_info, 0);
		g_once_init_leave (&sidebar_tree_root_wrapper_type_id__volatile, sidebar_tree_root_wrapper_type_id);
	}
	return sidebar_tree_root_wrapper_type_id__volatile;
}


static void
sidebar_tree_class_init (SidebarTreeClass * klass)
{
#line 7 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	sidebar_tree_parent_class = g_type_class_peek_parent (klass);
#line 7 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_type_class_add_private (klass, sizeof (SidebarTreePrivate));
#line 7 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	((SidebarTreeClass *) klass)->accept_cursor_changed = (gboolean (*) (SidebarTree *)) sidebar_tree_real_accept_cursor_changed;
#line 7 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	((GtkTreeViewClass *) klass)->cursor_changed = (void (*) (GtkTreeView *)) sidebar_tree_real_cursor_changed;
#line 7 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	((GtkWidgetClass *) klass)->button_press_event = (gboolean (*) (GtkWidget *, GdkEventButton*)) sidebar_tree_real_button_press_event;
#line 7 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	((GtkWidgetClass *) klass)->key_press_event = (gboolean (*) (GtkWidget *, GdkEventKey*)) sidebar_tree_real_key_press_event;
#line 7 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	((GtkWidgetClass *) klass)->drag_data_get = (void (*) (GtkWidget *, GdkDragContext*, GtkSelectionData*, guint, guint)) sidebar_tree_real_drag_data_get;
#line 7 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	((GtkWidgetClass *) klass)->drag_data_received = (void (*) (GtkWidget *, GdkDragContext*, gint, gint, GtkSelectionData*, guint, guint)) sidebar_tree_real_drag_data_received;
#line 7 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	((GtkWidgetClass *) klass)->drag_motion = (gboolean (*) (GtkWidget *, GdkDragContext*, gint, gint, guint)) sidebar_tree_real_drag_motion;
#line 7 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	G_OBJECT_CLASS (klass)->finalize = sidebar_tree_finalize;
#line 7 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	sidebar_tree_signals[SIDEBAR_TREE_ENTRY_SELECTED_SIGNAL] = g_signal_new ("entry-selected", SIDEBAR_TYPE_TREE, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__OBJECT, G_TYPE_NONE, 1, SIDEBAR_TYPE_SELECTABLE_ENTRY);
#line 7 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	sidebar_tree_signals[SIDEBAR_TREE_SELECTED_ENTRY_REMOVED_SIGNAL] = g_signal_new ("selected-entry-removed", SIDEBAR_TYPE_TREE, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__OBJECT, G_TYPE_NONE, 1, SIDEBAR_TYPE_SELECTABLE_ENTRY);
#line 7 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	sidebar_tree_signals[SIDEBAR_TREE_BRANCH_ADDED_SIGNAL] = g_signal_new ("branch-added", SIDEBAR_TYPE_TREE, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__OBJECT, G_TYPE_NONE, 1, SIDEBAR_TYPE_BRANCH);
#line 7 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	sidebar_tree_signals[SIDEBAR_TREE_BRANCH_REMOVED_SIGNAL] = g_signal_new ("branch-removed", SIDEBAR_TYPE_TREE, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__OBJECT, G_TYPE_NONE, 1, SIDEBAR_TYPE_BRANCH);
#line 7 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	sidebar_tree_signals[SIDEBAR_TREE_BRANCH_SHOWN_SIGNAL] = g_signal_new ("branch-shown", SIDEBAR_TYPE_TREE, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_user_marshal_VOID__OBJECT_BOOLEAN, G_TYPE_NONE, 2, SIDEBAR_TYPE_BRANCH, G_TYPE_BOOLEAN);
#line 7 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	sidebar_tree_signals[SIDEBAR_TREE_PAGE_CREATED_SIGNAL] = g_signal_new ("page-created", SIDEBAR_TYPE_TREE, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_user_marshal_VOID__OBJECT_OBJECT, G_TYPE_NONE, 2, SIDEBAR_TYPE_PAGE_REPRESENTATIVE, TYPE_PAGE);
#line 7 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	sidebar_tree_signals[SIDEBAR_TREE_DESTROYING_PAGE_SIGNAL] = g_signal_new ("destroying-page", SIDEBAR_TYPE_TREE, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_user_marshal_VOID__OBJECT_OBJECT, G_TYPE_NONE, 2, SIDEBAR_TYPE_PAGE_REPRESENTATIVE, TYPE_PAGE);
#line 7763 "Tree.c"
}


static void
sidebar_tree_instance_init (SidebarTree * self)
{
	GtkTreeStore* _tmp0_;
	GtkBuilder* _tmp1_;
	GeeHashMap* _tmp2_;
	GeeHashMap* _tmp3_;
#line 7 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	self->priv = SIDEBAR_TREE_GET_PRIVATE (self);
#line 55 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = gtk_tree_store_new ((gint) SIDEBAR_TREE_COLUMNS_N_COLUMNS, G_TYPE_STRING, G_TYPE_STRING, SIDEBAR_TREE_TYPE_ENTRY_WRAPPER, g_icon_get_type ());
#line 55 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	self->priv->store = _tmp0_;
#line 62 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp1_ = gtk_builder_new ();
#line 62 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	self->priv->builder = _tmp1_;
#line 65 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	self->priv->text_entry = NULL;
#line 66 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp2_ = gee_hash_map_new (SIDEBAR_TYPE_ENTRY, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, SIDEBAR_TREE_TYPE_ENTRY_WRAPPER, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
#line 66 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	self->priv->entry_map = _tmp2_;
#line 68 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp3_ = gee_hash_map_new (SIDEBAR_TYPE_BRANCH, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, G_TYPE_INT, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
#line 68 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	self->priv->branches = _tmp3_;
#line 69 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	self->priv->editing_disabled = 0;
#line 70 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	self->priv->mask_entry_selected_signal = FALSE;
#line 71 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	self->priv->selected_wrapper = NULL;
#line 72 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	self->priv->default_context_menu = NULL;
#line 73 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	self->priv->expander_called_manually = FALSE;
#line 74 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	self->priv->expander_special_count = 0;
#line 75 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	self->priv->is_internal_drag_in_progress = FALSE;
#line 76 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	self->priv->internal_drag_source_entry = NULL;
#line 77 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	self->priv->old_path_ref = NULL;
#line 7812 "Tree.c"
}


static void
sidebar_tree_finalize (GObject * obj)
{
	SidebarTree * self;
	GtkCellRendererText* _tmp0_;
	guint _tmp1_;
	GtkCellRendererText* _tmp2_;
	guint _tmp3_;
#line 7 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, SIDEBAR_TYPE_TREE, SidebarTree);
#line 155 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = self->priv->text_renderer;
#line 155 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_signal_parse_name ("editing-canceled", gtk_cell_renderer_get_type (), &_tmp1_, NULL, FALSE);
#line 155 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_signal_handlers_disconnect_matched (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, gtk_cell_renderer_get_type (), GtkCellRenderer), G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _sidebar_tree_on_editing_canceled_gtk_cell_renderer_editing_canceled, self);
#line 156 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp2_ = self->priv->text_renderer;
#line 156 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_signal_parse_name ("editing-started", gtk_cell_renderer_get_type (), &_tmp3_, NULL, FALSE);
#line 156 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_signal_handlers_disconnect_matched (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, gtk_cell_renderer_get_type (), GtkCellRenderer), G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp3_, 0, NULL, (GCallback) _sidebar_tree_on_editing_started_gtk_cell_renderer_editing_started, self);
#line 55 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (self->priv->store);
#line 62 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (self->priv->builder);
#line 63 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (self->priv->text_renderer);
#line 65 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (self->priv->text_entry);
#line 66 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (self->priv->entry_map);
#line 68 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (self->priv->branches);
#line 72 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (self->priv->default_context_menu);
#line 76 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (self->priv->internal_drag_source_entry);
#line 77 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	__vala_GtkTreeRowReference_free0 (self->priv->old_path_ref);
#line 7 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	G_OBJECT_CLASS (sidebar_tree_parent_class)->finalize (obj);
#line 7858 "Tree.c"
}


GType
sidebar_tree_get_type (void)
{
	static volatile gsize sidebar_tree_type_id__volatile = 0;
	if (g_once_init_enter (&sidebar_tree_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SidebarTreeClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) sidebar_tree_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SidebarTree), 0, (GInstanceInitFunc) sidebar_tree_instance_init, NULL };
		GType sidebar_tree_type_id;
		sidebar_tree_type_id = g_type_register_static (gtk_tree_view_get_type (), "SidebarTree", &g_define_type_info, 0);
		g_once_init_leave (&sidebar_tree_type_id__volatile, sidebar_tree_type_id);
	}
	return sidebar_tree_type_id__volatile;
}



