/* GSettingsEngine.c generated by valac 0.40.4, the Vala compiler
 * generated from GSettingsEngine.vala, do not modify */

/* Copyright 2016 Software Freedom Conservancy Inc.
 *
 * This software is licensed under the GNU LGPL (version 2.1 or later).
 * See the COPYING file in this distribution.
 */


#include <glib.h>
#include <glib-object.h>
#include <stdlib.h>
#include <string.h>
#include <float.h>
#include <math.h>
#include <gio/gio.h>


#define TYPE_CONFIGURATION_ENGINE (configuration_engine_get_type ())
#define CONFIGURATION_ENGINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_CONFIGURATION_ENGINE, ConfigurationEngine))
#define IS_CONFIGURATION_ENGINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_CONFIGURATION_ENGINE))
#define CONFIGURATION_ENGINE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), TYPE_CONFIGURATION_ENGINE, ConfigurationEngineIface))

typedef struct _ConfigurationEngine ConfigurationEngine;
typedef struct _ConfigurationEngineIface ConfigurationEngineIface;

#define TYPE_CONFIGURABLE_PROPERTY (configurable_property_get_type ())

#define TYPE_FUZZY_PROPERTY_STATE (fuzzy_property_state_get_type ())

#define TYPE_GSETTINGS_CONFIGURATION_ENGINE (gsettings_configuration_engine_get_type ())
#define GSETTINGS_CONFIGURATION_ENGINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_GSETTINGS_CONFIGURATION_ENGINE, GSettingsConfigurationEngine))
#define GSETTINGS_CONFIGURATION_ENGINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_GSETTINGS_CONFIGURATION_ENGINE, GSettingsConfigurationEngineClass))
#define IS_GSETTINGS_CONFIGURATION_ENGINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_GSETTINGS_CONFIGURATION_ENGINE))
#define IS_GSETTINGS_CONFIGURATION_ENGINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_GSETTINGS_CONFIGURATION_ENGINE))
#define GSETTINGS_CONFIGURATION_ENGINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_GSETTINGS_CONFIGURATION_ENGINE, GSettingsConfigurationEngineClass))

typedef struct _GSettingsConfigurationEngine GSettingsConfigurationEngine;
typedef struct _GSettingsConfigurationEngineClass GSettingsConfigurationEngineClass;
typedef struct _GSettingsConfigurationEnginePrivate GSettingsConfigurationEnginePrivate;
enum  {
	GSETTINGS_CONFIGURATION_ENGINE_0_PROPERTY,
	GSETTINGS_CONFIGURATION_ENGINE_NUM_PROPERTIES
};
static GParamSpec* gsettings_configuration_engine_properties[GSETTINGS_CONFIGURATION_ENGINE_NUM_PROPERTIES];
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_settings_schema_unref0(var) ((var == NULL) ? NULL : (var = (g_settings_schema_unref (var), NULL)))
#define _g_settings_schema_source_unref0(var) ((var == NULL) ? NULL : (var = (g_settings_schema_source_unref (var), NULL)))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_regex_unref0(var) ((var == NULL) ? NULL : (var = (g_regex_unref (var), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))

typedef enum  {
	CONFIGURABLE_PROPERTY_AUTO_IMPORT_FROM_LIBRARY = 0,
	CONFIGURABLE_PROPERTY_BG_COLOR_NAME,
	CONFIGURABLE_PROPERTY_TRANSPARENT_BACKGROUND_TYPE,
	CONFIGURABLE_PROPERTY_TRANSPARENT_BACKGROUND_COLOR,
	CONFIGURABLE_PROPERTY_COMMIT_METADATA_TO_MASTERS,
	CONFIGURABLE_PROPERTY_DESKTOP_BACKGROUND_FILE,
	CONFIGURABLE_PROPERTY_DESKTOP_BACKGROUND_MODE,
	CONFIGURABLE_PROPERTY_SCREENSAVER_FILE,
	CONFIGURABLE_PROPERTY_SCREENSAVER_MODE,
	CONFIGURABLE_PROPERTY_DIRECTORY_PATTERN,
	CONFIGURABLE_PROPERTY_DIRECTORY_PATTERN_CUSTOM,
	CONFIGURABLE_PROPERTY_DIRECT_WINDOW_HEIGHT,
	CONFIGURABLE_PROPERTY_DIRECT_WINDOW_MAXIMIZE,
	CONFIGURABLE_PROPERTY_DIRECT_WINDOW_WIDTH,
	CONFIGURABLE_PROPERTY_DISPLAY_BASIC_PROPERTIES,
	CONFIGURABLE_PROPERTY_DISPLAY_EVENT_COMMENTS,
	CONFIGURABLE_PROPERTY_DISPLAY_EXTENDED_PROPERTIES,
	CONFIGURABLE_PROPERTY_DISPLAY_SIDEBAR,
	CONFIGURABLE_PROPERTY_DISPLAY_TOOLBAR,
	CONFIGURABLE_PROPERTY_DISPLAY_SEARCH_BAR,
	CONFIGURABLE_PROPERTY_DISPLAY_PHOTO_RATINGS,
	CONFIGURABLE_PROPERTY_DISPLAY_PHOTO_TAGS,
	CONFIGURABLE_PROPERTY_DISPLAY_PHOTO_TITLES,
	CONFIGURABLE_PROPERTY_DISPLAY_PHOTO_COMMENTS,
	CONFIGURABLE_PROPERTY_EVENT_PHOTOS_SORT_ASCENDING,
	CONFIGURABLE_PROPERTY_EVENT_PHOTOS_SORT_BY,
	CONFIGURABLE_PROPERTY_EVENTS_SORT_ASCENDING,
	CONFIGURABLE_PROPERTY_EXPORT_CONSTRAINT,
	CONFIGURABLE_PROPERTY_EXPORT_EXPORT_FORMAT_MODE,
	CONFIGURABLE_PROPERTY_EXPORT_EXPORT_METADATA,
	CONFIGURABLE_PROPERTY_EXPORT_PHOTO_FILE_FORMAT,
	CONFIGURABLE_PROPERTY_EXPORT_QUALITY,
	CONFIGURABLE_PROPERTY_EXPORT_SCALE,
	CONFIGURABLE_PROPERTY_EXTERNAL_PHOTO_APP,
	CONFIGURABLE_PROPERTY_EXTERNAL_RAW_APP,
	CONFIGURABLE_PROPERTY_HIDE_PHOTOS_ALREADY_IMPORTED,
	CONFIGURABLE_PROPERTY_IMPORT_DIR,
	CONFIGURABLE_PROPERTY_KEEP_RELATIVITY,
	CONFIGURABLE_PROPERTY_LAST_CROP_HEIGHT,
	CONFIGURABLE_PROPERTY_LAST_CROP_MENU_CHOICE,
	CONFIGURABLE_PROPERTY_LAST_CROP_WIDTH,
	CONFIGURABLE_PROPERTY_LAST_USED_SERVICE,
	CONFIGURABLE_PROPERTY_LAST_USED_DATAIMPORTS_SERVICE,
	CONFIGURABLE_PROPERTY_LIBRARY_PHOTOS_SORT_ASCENDING,
	CONFIGURABLE_PROPERTY_LIBRARY_PHOTOS_SORT_BY,
	CONFIGURABLE_PROPERTY_LIBRARY_WINDOW_HEIGHT,
	CONFIGURABLE_PROPERTY_LIBRARY_WINDOW_MAXIMIZE,
	CONFIGURABLE_PROPERTY_LIBRARY_WINDOW_WIDTH,
	CONFIGURABLE_PROPERTY_MODIFY_ORIGINALS,
	CONFIGURABLE_PROPERTY_PHOTO_THUMBNAIL_SCALE,
	CONFIGURABLE_PROPERTY_PIN_TOOLBAR_STATE,
	CONFIGURABLE_PROPERTY_PRINTING_CONTENT_HEIGHT,
	CONFIGURABLE_PROPERTY_PRINTING_CONTENT_LAYOUT,
	CONFIGURABLE_PROPERTY_PRINTING_CONTENT_PPI,
	CONFIGURABLE_PROPERTY_PRINTING_CONTENT_UNITS,
	CONFIGURABLE_PROPERTY_PRINTING_CONTENT_WIDTH,
	CONFIGURABLE_PROPERTY_PRINTING_IMAGES_PER_PAGE,
	CONFIGURABLE_PROPERTY_PRINTING_MATCH_ASPECT_RATIO,
	CONFIGURABLE_PROPERTY_PRINTING_PRINT_TITLES,
	CONFIGURABLE_PROPERTY_PRINTING_SIZE_SELECTION,
	CONFIGURABLE_PROPERTY_PRINTING_TITLES_FONT,
	CONFIGURABLE_PROPERTY_RAW_DEVELOPER_DEFAULT,
	CONFIGURABLE_PROPERTY_SHOW_WELCOME_DIALOG,
	CONFIGURABLE_PROPERTY_SIDEBAR_POSITION,
	CONFIGURABLE_PROPERTY_SLIDESHOW_DELAY,
	CONFIGURABLE_PROPERTY_SLIDESHOW_TRANSITION_DELAY,
	CONFIGURABLE_PROPERTY_SLIDESHOW_TRANSITION_EFFECT_ID,
	CONFIGURABLE_PROPERTY_SLIDESHOW_SHOW_TITLE,
	CONFIGURABLE_PROPERTY_USE_24_HOUR_TIME,
	CONFIGURABLE_PROPERTY_USE_LOWERCASE_FILENAMES,
	CONFIGURABLE_PROPERTY_VIDEO_INTERPRETER_STATE_COOKIE,
	CONFIGURABLE_PROPERTY_NUM_PROPERTIES
} ConfigurableProperty;

typedef enum  {
	CONFIGURATION_ERROR_PROPERTY_HAS_NO_VALUE,
	CONFIGURATION_ERROR_ENGINE_ERROR
} ConfigurationError;
#define CONFIGURATION_ERROR configuration_error_quark ()
typedef enum  {
	FUZZY_PROPERTY_STATE_ENABLED,
	FUZZY_PROPERTY_STATE_DISABLED,
	FUZZY_PROPERTY_STATE_UNKNOWN
} FuzzyPropertyState;

struct _ConfigurationEngineIface {
	GTypeInterface parent_iface;
	gchar* (*get_name) (ConfigurationEngine* self);
	gint (*get_int_property) (ConfigurationEngine* self, ConfigurableProperty p, GError** error);
	void (*set_int_property) (ConfigurationEngine* self, ConfigurableProperty p, gint val, GError** error);
	gint (*get_enum_property) (ConfigurationEngine* self, ConfigurableProperty p, GError** error);
	void (*set_enum_property) (ConfigurationEngine* self, ConfigurableProperty p, gint val, GError** error);
	gchar* (*get_string_property) (ConfigurationEngine* self, ConfigurableProperty p, GError** error);
	void (*set_string_property) (ConfigurationEngine* self, ConfigurableProperty p, const gchar* val, GError** error);
	gboolean (*get_bool_property) (ConfigurationEngine* self, ConfigurableProperty p, GError** error);
	void (*set_bool_property) (ConfigurationEngine* self, ConfigurableProperty p, gboolean val, GError** error);
	gdouble (*get_double_property) (ConfigurationEngine* self, ConfigurableProperty p, GError** error);
	void (*set_double_property) (ConfigurationEngine* self, ConfigurableProperty p, gdouble val, GError** error);
	gboolean (*get_plugin_bool) (ConfigurationEngine* self, const gchar* domain, const gchar* id, const gchar* key, gboolean def);
	void (*set_plugin_bool) (ConfigurationEngine* self, const gchar* domain, const gchar* id, const gchar* key, gboolean val);
	gdouble (*get_plugin_double) (ConfigurationEngine* self, const gchar* domain, const gchar* id, const gchar* key, gdouble def);
	void (*set_plugin_double) (ConfigurationEngine* self, const gchar* domain, const gchar* id, const gchar* key, gdouble val);
	gint (*get_plugin_int) (ConfigurationEngine* self, const gchar* domain, const gchar* id, const gchar* key, gint def);
	void (*set_plugin_int) (ConfigurationEngine* self, const gchar* domain, const gchar* id, const gchar* key, gint val);
	gchar* (*get_plugin_string) (ConfigurationEngine* self, const gchar* domain, const gchar* id, const gchar* key, const gchar* def);
	void (*set_plugin_string) (ConfigurationEngine* self, const gchar* domain, const gchar* id, const gchar* key, const gchar* val);
	void (*unset_plugin_key) (ConfigurationEngine* self, const gchar* domain, const gchar* id, const gchar* key);
	FuzzyPropertyState (*is_plugin_enabled) (ConfigurationEngine* self, const gchar* id);
	void (*set_plugin_enabled) (ConfigurationEngine* self, const gchar* id, gboolean enabled);
};

struct _GSettingsConfigurationEngine {
	GObject parent_instance;
	GSettingsConfigurationEnginePrivate * priv;
};

struct _GSettingsConfigurationEngineClass {
	GObjectClass parent_class;
};

struct _GSettingsConfigurationEnginePrivate {
	gchar** schema_names;
	gint schema_names_length1;
	gint _schema_names_size_;
	gchar** key_names;
	gint key_names_length1;
	gint _key_names_size_;
};


static gpointer gsettings_configuration_engine_parent_class = NULL;
static ConfigurationEngineIface * gsettings_configuration_engine_configuration_engine_parent_iface = NULL;

GType configurable_property_get_type (void) G_GNUC_CONST;
GQuark configuration_error_quark (void);
GType fuzzy_property_state_get_type (void) G_GNUC_CONST;
GType configuration_engine_get_type (void) G_GNUC_CONST;
GType gsettings_configuration_engine_get_type (void) G_GNUC_CONST;
#define GSETTINGS_CONFIGURATION_ENGINE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_GSETTINGS_CONFIGURATION_ENGINE, GSettingsConfigurationEnginePrivate))
#define GSETTINGS_CONFIGURATION_ENGINE_ROOT_SCHEMA_NAME "org.yorba.shotwell"
#define GSETTINGS_CONFIGURATION_ENGINE_PREFS_SCHEMA_NAME GSETTINGS_CONFIGURATION_ENGINE_ROOT_SCHEMA_NAME ".preferences"
#define GSETTINGS_CONFIGURATION_ENGINE_UI_PREFS_SCHEMA_NAME GSETTINGS_CONFIGURATION_ENGINE_PREFS_SCHEMA_NAME ".ui"
#define GSETTINGS_CONFIGURATION_ENGINE_SLIDESHOW_PREFS_SCHEMA_NAME GSETTINGS_CONFIGURATION_ENGINE_PREFS_SCHEMA_NAME ".slideshow"
#define GSETTINGS_CONFIGURATION_ENGINE_WINDOW_PREFS_SCHEMA_NAME GSETTINGS_CONFIGURATION_ENGINE_PREFS_SCHEMA_NAME ".window"
#define GSETTINGS_CONFIGURATION_ENGINE_FILES_PREFS_SCHEMA_NAME GSETTINGS_CONFIGURATION_ENGINE_PREFS_SCHEMA_NAME ".files"
#define GSETTINGS_CONFIGURATION_ENGINE_EDITING_PREFS_SCHEMA_NAME GSETTINGS_CONFIGURATION_ENGINE_PREFS_SCHEMA_NAME ".editing"
#define GSETTINGS_CONFIGURATION_ENGINE_EXPORT_PREFS_SCHEMA_NAME GSETTINGS_CONFIGURATION_ENGINE_PREFS_SCHEMA_NAME ".export"
#define GSETTINGS_CONFIGURATION_ENGINE_VIDEO_SCHEMA_NAME GSETTINGS_CONFIGURATION_ENGINE_ROOT_SCHEMA_NAME ".video"
#define GSETTINGS_CONFIGURATION_ENGINE_PRINTING_SCHEMA_NAME GSETTINGS_CONFIGURATION_ENGINE_ROOT_SCHEMA_NAME ".printing"
#define GSETTINGS_CONFIGURATION_ENGINE_SHARING_SCHEMA_NAME GSETTINGS_CONFIGURATION_ENGINE_ROOT_SCHEMA_NAME ".sharing"
#define GSETTINGS_CONFIGURATION_ENGINE_IMPORTING_SCHEMA_NAME GSETTINGS_CONFIGURATION_ENGINE_ROOT_SCHEMA_NAME ".dataimports"
#define GSETTINGS_CONFIGURATION_ENGINE_CROP_SCHEMA_NAME GSETTINGS_CONFIGURATION_ENGINE_ROOT_SCHEMA_NAME ".crop-settings"
#define GSETTINGS_CONFIGURATION_ENGINE_SYSTEM_DESKTOP_SCHEMA_NAME "org.gnome.desktop.background"
#define GSETTINGS_CONFIGURATION_ENGINE_SYSTEM_SCREENSAVER_SCHEMA_NAME "org.gnome.desktop.screensaver"
#define GSETTINGS_CONFIGURATION_ENGINE_PLUGINS_ENABLE_DISABLE_SCHEMA_NAME GSETTINGS_CONFIGURATION_ENGINE_ROOT_SCHEMA_NAME ".plugins.enable-state"
GSettingsConfigurationEngine* gsettings_configuration_engine_new (void);
GSettingsConfigurationEngine* gsettings_configuration_engine_construct (GType object_type);
static void gsettings_configuration_engine_check_key_valid (GSettingsConfigurationEngine* self,
                                                     const gchar* schema,
                                                     const gchar* key,
                                                     GError** error);
static gboolean gsettings_configuration_engine_get_gs_bool (GSettingsConfigurationEngine* self,
                                                     const gchar* schema,
                                                     const gchar* key,
                                                     GError** error);
static void gsettings_configuration_engine_set_gs_bool (GSettingsConfigurationEngine* self,
                                                 const gchar* schema,
                                                 const gchar* key,
                                                 gboolean value,
                                                 GError** error);
static void gsettings_configuration_engine_set_gs_enum (GSettingsConfigurationEngine* self,
                                                 const gchar* schema,
                                                 const gchar* key,
                                                 gint value,
                                                 GError** error);
static gint gsettings_configuration_engine_get_gs_enum (GSettingsConfigurationEngine* self,
                                                 const gchar* schema,
                                                 const gchar* key,
                                                 GError** error);
static gint gsettings_configuration_engine_get_gs_int (GSettingsConfigurationEngine* self,
                                                const gchar* schema,
                                                const gchar* key,
                                                GError** error);
static void gsettings_configuration_engine_set_gs_int (GSettingsConfigurationEngine* self,
                                                const gchar* schema,
                                                const gchar* key,
                                                gint value,
                                                GError** error);
static gdouble gsettings_configuration_engine_get_gs_double (GSettingsConfigurationEngine* self,
                                                      const gchar* schema,
                                                      const gchar* key,
                                                      GError** error);
static void gsettings_configuration_engine_set_gs_double (GSettingsConfigurationEngine* self,
                                                   const gchar* schema,
                                                   const gchar* key,
                                                   gdouble value,
                                                   GError** error);
static gchar* gsettings_configuration_engine_get_gs_string (GSettingsConfigurationEngine* self,
                                                     const gchar* schema,
                                                     const gchar* key,
                                                     GError** error);
static void gsettings_configuration_engine_set_gs_string (GSettingsConfigurationEngine* self,
                                                   const gchar* schema,
                                                   const gchar* key,
                                                   const gchar* value,
                                                   GError** error);
static void gsettings_configuration_engine_reset_gs_to_default (GSettingsConfigurationEngine* self,
                                                         const gchar* schema,
                                                         const gchar* key,
                                                         GError** error);
static gchar* gsettings_configuration_engine_clean_plugin_id (const gchar* id);
gboolean is_string_empty (const gchar* s);
static gchar* gsettings_configuration_engine_get_plugin_enable_disable_name (const gchar* id);
static gchar* gsettings_configuration_engine_make_plugin_schema_name (const gchar* domain,
                                                               const gchar* id);
static gchar* gsettings_configuration_engine_make_gsettings_key (const gchar* gconf_key);
static gchar* gsettings_configuration_engine_real_get_name (ConfigurationEngine* base);
static gint gsettings_configuration_engine_real_get_enum_property (ConfigurationEngine* base,
                                                            ConfigurableProperty p,
                                                            GError** error);
static void gsettings_configuration_engine_real_set_enum_property (ConfigurationEngine* base,
                                                            ConfigurableProperty p,
                                                            gint val,
                                                            GError** error);
static gint gsettings_configuration_engine_real_get_int_property (ConfigurationEngine* base,
                                                           ConfigurableProperty p,
                                                           GError** error);
static void gsettings_configuration_engine_real_set_int_property (ConfigurationEngine* base,
                                                           ConfigurableProperty p,
                                                           gint val,
                                                           GError** error);
static gchar* gsettings_configuration_engine_real_get_string_property (ConfigurationEngine* base,
                                                                ConfigurableProperty p,
                                                                GError** error);
static void gsettings_configuration_engine_real_set_string_property (ConfigurationEngine* base,
                                                              ConfigurableProperty p,
                                                              const gchar* val,
                                                              GError** error);
static gboolean gsettings_configuration_engine_real_get_bool_property (ConfigurationEngine* base,
                                                                ConfigurableProperty p,
                                                                GError** error);
static void gsettings_configuration_engine_real_set_bool_property (ConfigurationEngine* base,
                                                            ConfigurableProperty p,
                                                            gboolean val,
                                                            GError** error);
static gdouble gsettings_configuration_engine_real_get_double_property (ConfigurationEngine* base,
                                                                 ConfigurableProperty p,
                                                                 GError** error);
static void gsettings_configuration_engine_real_set_double_property (ConfigurationEngine* base,
                                                              ConfigurableProperty p,
                                                              gdouble val,
                                                              GError** error);
static gboolean gsettings_configuration_engine_real_get_plugin_bool (ConfigurationEngine* base,
                                                              const gchar* domain,
                                                              const gchar* id,
                                                              const gchar* key,
                                                              gboolean def);
static void gsettings_configuration_engine_real_set_plugin_bool (ConfigurationEngine* base,
                                                          const gchar* domain,
                                                          const gchar* id,
                                                          const gchar* key,
                                                          gboolean val);
static gdouble gsettings_configuration_engine_real_get_plugin_double (ConfigurationEngine* base,
                                                               const gchar* domain,
                                                               const gchar* id,
                                                               const gchar* key,
                                                               gdouble def);
static void gsettings_configuration_engine_real_set_plugin_double (ConfigurationEngine* base,
                                                            const gchar* domain,
                                                            const gchar* id,
                                                            const gchar* key,
                                                            gdouble val);
static gint gsettings_configuration_engine_real_get_plugin_int (ConfigurationEngine* base,
                                                         const gchar* domain,
                                                         const gchar* id,
                                                         const gchar* key,
                                                         gint def);
static void gsettings_configuration_engine_real_set_plugin_int (ConfigurationEngine* base,
                                                         const gchar* domain,
                                                         const gchar* id,
                                                         const gchar* key,
                                                         gint val);
static gchar* gsettings_configuration_engine_real_get_plugin_string (ConfigurationEngine* base,
                                                              const gchar* domain,
                                                              const gchar* id,
                                                              const gchar* key,
                                                              const gchar* def);
static void gsettings_configuration_engine_real_set_plugin_string (ConfigurationEngine* base,
                                                            const gchar* domain,
                                                            const gchar* id,
                                                            const gchar* key,
                                                            const gchar* val);
static void gsettings_configuration_engine_real_unset_plugin_key (ConfigurationEngine* base,
                                                           const gchar* domain,
                                                           const gchar* id,
                                                           const gchar* key);
static FuzzyPropertyState gsettings_configuration_engine_real_is_plugin_enabled (ConfigurationEngine* base,
                                                                          const gchar* id);
static void gsettings_configuration_engine_real_set_plugin_enabled (ConfigurationEngine* base,
                                                             const gchar* id,
                                                             gboolean enabled);
void gsettings_configuration_engine_run_gsettings_migrator (void);
GFile* app_dirs_get_settings_migrator_bin (void);
static void gsettings_configuration_engine_finalize (GObject * obj);
static void _vala_array_destroy (gpointer array,
                          gint array_length,
                          GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array,
                       gint array_length,
                       GDestroyNotify destroy_func);


GSettingsConfigurationEngine*
gsettings_configuration_engine_construct (GType object_type)
{
	GSettingsConfigurationEngine * self = NULL;
	gchar** _tmp0_;
	gchar** _tmp1_;
	gint _tmp1__length1;
	gchar* _tmp2_;
	gchar* _tmp3_;
	gchar** _tmp4_;
	gint _tmp4__length1;
	gchar* _tmp5_;
	gchar* _tmp6_;
	gchar** _tmp7_;
	gint _tmp7__length1;
	gchar* _tmp8_;
	gchar* _tmp9_;
	gchar** _tmp10_;
	gint _tmp10__length1;
	gchar* _tmp11_;
	gchar* _tmp12_;
	gchar** _tmp13_;
	gint _tmp13__length1;
	gchar* _tmp14_;
	gchar* _tmp15_;
	gchar** _tmp16_;
	gint _tmp16__length1;
	gchar* _tmp17_;
	gchar* _tmp18_;
	gchar** _tmp19_;
	gint _tmp19__length1;
	gchar* _tmp20_;
	gchar* _tmp21_;
	gchar** _tmp22_;
	gint _tmp22__length1;
	gchar* _tmp23_;
	gchar* _tmp24_;
	gchar** _tmp25_;
	gint _tmp25__length1;
	gchar* _tmp26_;
	gchar* _tmp27_;
	gchar** _tmp28_;
	gint _tmp28__length1;
	gchar* _tmp29_;
	gchar* _tmp30_;
	gchar** _tmp31_;
	gint _tmp31__length1;
	gchar* _tmp32_;
	gchar* _tmp33_;
	gchar** _tmp34_;
	gint _tmp34__length1;
	gchar* _tmp35_;
	gchar* _tmp36_;
	gchar** _tmp37_;
	gint _tmp37__length1;
	gchar* _tmp38_;
	gchar* _tmp39_;
	gchar** _tmp40_;
	gint _tmp40__length1;
	gchar* _tmp41_;
	gchar* _tmp42_;
	gchar** _tmp43_;
	gint _tmp43__length1;
	gchar* _tmp44_;
	gchar* _tmp45_;
	gchar** _tmp46_;
	gint _tmp46__length1;
	gchar* _tmp47_;
	gchar* _tmp48_;
	gchar** _tmp49_;
	gint _tmp49__length1;
	gchar* _tmp50_;
	gchar* _tmp51_;
	gchar** _tmp52_;
	gint _tmp52__length1;
	gchar* _tmp53_;
	gchar* _tmp54_;
	gchar** _tmp55_;
	gint _tmp55__length1;
	gchar* _tmp56_;
	gchar* _tmp57_;
	gchar** _tmp58_;
	gint _tmp58__length1;
	gchar* _tmp59_;
	gchar* _tmp60_;
	gchar** _tmp61_;
	gint _tmp61__length1;
	gchar* _tmp62_;
	gchar* _tmp63_;
	gchar** _tmp64_;
	gint _tmp64__length1;
	gchar* _tmp65_;
	gchar* _tmp66_;
	gchar** _tmp67_;
	gint _tmp67__length1;
	gchar* _tmp68_;
	gchar* _tmp69_;
	gchar** _tmp70_;
	gint _tmp70__length1;
	gchar* _tmp71_;
	gchar* _tmp72_;
	gchar** _tmp73_;
	gint _tmp73__length1;
	gchar* _tmp74_;
	gchar* _tmp75_;
	gchar** _tmp76_;
	gint _tmp76__length1;
	gchar* _tmp77_;
	gchar* _tmp78_;
	gchar** _tmp79_;
	gint _tmp79__length1;
	gchar* _tmp80_;
	gchar* _tmp81_;
	gchar** _tmp82_;
	gint _tmp82__length1;
	gchar* _tmp83_;
	gchar* _tmp84_;
	gchar** _tmp85_;
	gint _tmp85__length1;
	gchar* _tmp86_;
	gchar* _tmp87_;
	gchar** _tmp88_;
	gint _tmp88__length1;
	gchar* _tmp89_;
	gchar* _tmp90_;
	gchar** _tmp91_;
	gint _tmp91__length1;
	gchar* _tmp92_;
	gchar* _tmp93_;
	gchar** _tmp94_;
	gint _tmp94__length1;
	gchar* _tmp95_;
	gchar* _tmp96_;
	gchar** _tmp97_;
	gint _tmp97__length1;
	gchar* _tmp98_;
	gchar* _tmp99_;
	gchar** _tmp100_;
	gint _tmp100__length1;
	gchar* _tmp101_;
	gchar* _tmp102_;
	gchar** _tmp103_;
	gint _tmp103__length1;
	gchar* _tmp104_;
	gchar* _tmp105_;
	gchar** _tmp106_;
	gint _tmp106__length1;
	gchar* _tmp107_;
	gchar* _tmp108_;
	gchar** _tmp109_;
	gint _tmp109__length1;
	gchar* _tmp110_;
	gchar* _tmp111_;
	gchar** _tmp112_;
	gint _tmp112__length1;
	gchar* _tmp113_;
	gchar* _tmp114_;
	gchar** _tmp115_;
	gint _tmp115__length1;
	gchar* _tmp116_;
	gchar* _tmp117_;
	gchar** _tmp118_;
	gint _tmp118__length1;
	gchar* _tmp119_;
	gchar* _tmp120_;
	gchar** _tmp121_;
	gint _tmp121__length1;
	gchar* _tmp122_;
	gchar* _tmp123_;
	gchar** _tmp124_;
	gint _tmp124__length1;
	gchar* _tmp125_;
	gchar* _tmp126_;
	gchar** _tmp127_;
	gint _tmp127__length1;
	gchar* _tmp128_;
	gchar* _tmp129_;
	gchar** _tmp130_;
	gint _tmp130__length1;
	gchar* _tmp131_;
	gchar* _tmp132_;
	gchar** _tmp133_;
	gint _tmp133__length1;
	gchar* _tmp134_;
	gchar* _tmp135_;
	gchar** _tmp136_;
	gint _tmp136__length1;
	gchar* _tmp137_;
	gchar* _tmp138_;
	gchar** _tmp139_;
	gint _tmp139__length1;
	gchar* _tmp140_;
	gchar* _tmp141_;
	gchar** _tmp142_;
	gint _tmp142__length1;
	gchar* _tmp143_;
	gchar* _tmp144_;
	gchar** _tmp145_;
	gint _tmp145__length1;
	gchar* _tmp146_;
	gchar* _tmp147_;
	gchar** _tmp148_;
	gint _tmp148__length1;
	gchar* _tmp149_;
	gchar* _tmp150_;
	gchar** _tmp151_;
	gint _tmp151__length1;
	gchar* _tmp152_;
	gchar* _tmp153_;
	gchar** _tmp154_;
	gint _tmp154__length1;
	gchar* _tmp155_;
	gchar* _tmp156_;
	gchar** _tmp157_;
	gint _tmp157__length1;
	gchar* _tmp158_;
	gchar* _tmp159_;
	gchar** _tmp160_;
	gint _tmp160__length1;
	gchar* _tmp161_;
	gchar* _tmp162_;
	gchar** _tmp163_;
	gint _tmp163__length1;
	gchar* _tmp164_;
	gchar* _tmp165_;
	gchar** _tmp166_;
	gint _tmp166__length1;
	gchar* _tmp167_;
	gchar* _tmp168_;
	gchar** _tmp169_;
	gint _tmp169__length1;
	gchar* _tmp170_;
	gchar* _tmp171_;
	gchar** _tmp172_;
	gint _tmp172__length1;
	gchar* _tmp173_;
	gchar* _tmp174_;
	gchar** _tmp175_;
	gint _tmp175__length1;
	gchar* _tmp176_;
	gchar* _tmp177_;
	gchar** _tmp178_;
	gint _tmp178__length1;
	gchar* _tmp179_;
	gchar* _tmp180_;
	gchar** _tmp181_;
	gint _tmp181__length1;
	gchar* _tmp182_;
	gchar* _tmp183_;
	gchar** _tmp184_;
	gint _tmp184__length1;
	gchar* _tmp185_;
	gchar* _tmp186_;
	gchar** _tmp187_;
	gint _tmp187__length1;
	gchar* _tmp188_;
	gchar* _tmp189_;
	gchar** _tmp190_;
	gint _tmp190__length1;
	gchar* _tmp191_;
	gchar* _tmp192_;
	gchar** _tmp193_;
	gint _tmp193__length1;
	gchar* _tmp194_;
	gchar* _tmp195_;
	gchar** _tmp196_;
	gint _tmp196__length1;
	gchar* _tmp197_;
	gchar* _tmp198_;
	gchar** _tmp199_;
	gint _tmp199__length1;
	gchar* _tmp200_;
	gchar* _tmp201_;
	gchar** _tmp202_;
	gint _tmp202__length1;
	gchar* _tmp203_;
	gchar* _tmp204_;
	gchar** _tmp205_;
	gint _tmp205__length1;
	gchar* _tmp206_;
	gchar* _tmp207_;
	gchar** _tmp208_;
	gint _tmp208__length1;
	gchar* _tmp209_;
	gchar* _tmp210_;
	gchar** _tmp211_;
	gint _tmp211__length1;
	gchar* _tmp212_;
	gchar* _tmp213_;
	gchar** _tmp214_;
	gchar** _tmp215_;
	gint _tmp215__length1;
	gchar* _tmp216_;
	gchar* _tmp217_;
	gchar** _tmp218_;
	gint _tmp218__length1;
	gchar* _tmp219_;
	gchar* _tmp220_;
	gchar** _tmp221_;
	gint _tmp221__length1;
	gchar* _tmp222_;
	gchar* _tmp223_;
	gchar** _tmp224_;
	gint _tmp224__length1;
	gchar* _tmp225_;
	gchar* _tmp226_;
	gchar** _tmp227_;
	gint _tmp227__length1;
	gchar* _tmp228_;
	gchar* _tmp229_;
	gchar** _tmp230_;
	gint _tmp230__length1;
	gchar* _tmp231_;
	gchar* _tmp232_;
	gchar** _tmp233_;
	gint _tmp233__length1;
	gchar* _tmp234_;
	gchar* _tmp235_;
	gchar** _tmp236_;
	gint _tmp236__length1;
	gchar* _tmp237_;
	gchar* _tmp238_;
	gchar** _tmp239_;
	gint _tmp239__length1;
	gchar* _tmp240_;
	gchar* _tmp241_;
	gchar** _tmp242_;
	gint _tmp242__length1;
	gchar* _tmp243_;
	gchar* _tmp244_;
	gchar** _tmp245_;
	gint _tmp245__length1;
	gchar* _tmp246_;
	gchar* _tmp247_;
	gchar** _tmp248_;
	gint _tmp248__length1;
	gchar* _tmp249_;
	gchar* _tmp250_;
	gchar** _tmp251_;
	gint _tmp251__length1;
	gchar* _tmp252_;
	gchar* _tmp253_;
	gchar** _tmp254_;
	gint _tmp254__length1;
	gchar* _tmp255_;
	gchar* _tmp256_;
	gchar** _tmp257_;
	gint _tmp257__length1;
	gchar* _tmp258_;
	gchar* _tmp259_;
	gchar** _tmp260_;
	gint _tmp260__length1;
	gchar* _tmp261_;
	gchar* _tmp262_;
	gchar** _tmp263_;
	gint _tmp263__length1;
	gchar* _tmp264_;
	gchar* _tmp265_;
	gchar** _tmp266_;
	gint _tmp266__length1;
	gchar* _tmp267_;
	gchar* _tmp268_;
	gchar** _tmp269_;
	gint _tmp269__length1;
	gchar* _tmp270_;
	gchar* _tmp271_;
	gchar** _tmp272_;
	gint _tmp272__length1;
	gchar* _tmp273_;
	gchar* _tmp274_;
	gchar** _tmp275_;
	gint _tmp275__length1;
	gchar* _tmp276_;
	gchar* _tmp277_;
	gchar** _tmp278_;
	gint _tmp278__length1;
	gchar* _tmp279_;
	gchar* _tmp280_;
	gchar** _tmp281_;
	gint _tmp281__length1;
	gchar* _tmp282_;
	gchar* _tmp283_;
	gchar** _tmp284_;
	gint _tmp284__length1;
	gchar* _tmp285_;
	gchar* _tmp286_;
	gchar** _tmp287_;
	gint _tmp287__length1;
	gchar* _tmp288_;
	gchar* _tmp289_;
	gchar** _tmp290_;
	gint _tmp290__length1;
	gchar* _tmp291_;
	gchar* _tmp292_;
	gchar** _tmp293_;
	gint _tmp293__length1;
	gchar* _tmp294_;
	gchar* _tmp295_;
	gchar** _tmp296_;
	gint _tmp296__length1;
	gchar* _tmp297_;
	gchar* _tmp298_;
	gchar** _tmp299_;
	gint _tmp299__length1;
	gchar* _tmp300_;
	gchar* _tmp301_;
	gchar** _tmp302_;
	gint _tmp302__length1;
	gchar* _tmp303_;
	gchar* _tmp304_;
	gchar** _tmp305_;
	gint _tmp305__length1;
	gchar* _tmp306_;
	gchar* _tmp307_;
	gchar** _tmp308_;
	gint _tmp308__length1;
	gchar* _tmp309_;
	gchar* _tmp310_;
	gchar** _tmp311_;
	gint _tmp311__length1;
	gchar* _tmp312_;
	gchar* _tmp313_;
	gchar** _tmp314_;
	gint _tmp314__length1;
	gchar* _tmp315_;
	gchar* _tmp316_;
	gchar** _tmp317_;
	gint _tmp317__length1;
	gchar* _tmp318_;
	gchar* _tmp319_;
	gchar** _tmp320_;
	gint _tmp320__length1;
	gchar* _tmp321_;
	gchar* _tmp322_;
	gchar** _tmp323_;
	gint _tmp323__length1;
	gchar* _tmp324_;
	gchar* _tmp325_;
	gchar** _tmp326_;
	gint _tmp326__length1;
	gchar* _tmp327_;
	gchar* _tmp328_;
	gchar** _tmp329_;
	gint _tmp329__length1;
	gchar* _tmp330_;
	gchar* _tmp331_;
	gchar** _tmp332_;
	gint _tmp332__length1;
	gchar* _tmp333_;
	gchar* _tmp334_;
	gchar** _tmp335_;
	gint _tmp335__length1;
	gchar* _tmp336_;
	gchar* _tmp337_;
	gchar** _tmp338_;
	gint _tmp338__length1;
	gchar* _tmp339_;
	gchar* _tmp340_;
	gchar** _tmp341_;
	gint _tmp341__length1;
	gchar* _tmp342_;
	gchar* _tmp343_;
	gchar** _tmp344_;
	gint _tmp344__length1;
	gchar* _tmp345_;
	gchar* _tmp346_;
	gchar** _tmp347_;
	gint _tmp347__length1;
	gchar* _tmp348_;
	gchar* _tmp349_;
	gchar** _tmp350_;
	gint _tmp350__length1;
	gchar* _tmp351_;
	gchar* _tmp352_;
	gchar** _tmp353_;
	gint _tmp353__length1;
	gchar* _tmp354_;
	gchar* _tmp355_;
	gchar** _tmp356_;
	gint _tmp356__length1;
	gchar* _tmp357_;
	gchar* _tmp358_;
	gchar** _tmp359_;
	gint _tmp359__length1;
	gchar* _tmp360_;
	gchar* _tmp361_;
	gchar** _tmp362_;
	gint _tmp362__length1;
	gchar* _tmp363_;
	gchar* _tmp364_;
	gchar** _tmp365_;
	gint _tmp365__length1;
	gchar* _tmp366_;
	gchar* _tmp367_;
	gchar** _tmp368_;
	gint _tmp368__length1;
	gchar* _tmp369_;
	gchar* _tmp370_;
	gchar** _tmp371_;
	gint _tmp371__length1;
	gchar* _tmp372_;
	gchar* _tmp373_;
	gchar** _tmp374_;
	gint _tmp374__length1;
	gchar* _tmp375_;
	gchar* _tmp376_;
	gchar** _tmp377_;
	gint _tmp377__length1;
	gchar* _tmp378_;
	gchar* _tmp379_;
	gchar** _tmp380_;
	gint _tmp380__length1;
	gchar* _tmp381_;
	gchar* _tmp382_;
	gchar** _tmp383_;
	gint _tmp383__length1;
	gchar* _tmp384_;
	gchar* _tmp385_;
	gchar** _tmp386_;
	gint _tmp386__length1;
	gchar* _tmp387_;
	gchar* _tmp388_;
	gchar** _tmp389_;
	gint _tmp389__length1;
	gchar* _tmp390_;
	gchar* _tmp391_;
	gchar** _tmp392_;
	gint _tmp392__length1;
	gchar* _tmp393_;
	gchar* _tmp394_;
	gchar** _tmp395_;
	gint _tmp395__length1;
	gchar* _tmp396_;
	gchar* _tmp397_;
	gchar** _tmp398_;
	gint _tmp398__length1;
	gchar* _tmp399_;
	gchar* _tmp400_;
	gchar** _tmp401_;
	gint _tmp401__length1;
	gchar* _tmp402_;
	gchar* _tmp403_;
	gchar** _tmp404_;
	gint _tmp404__length1;
	gchar* _tmp405_;
	gchar* _tmp406_;
	gchar** _tmp407_;
	gint _tmp407__length1;
	gchar* _tmp408_;
	gchar* _tmp409_;
	gchar** _tmp410_;
	gint _tmp410__length1;
	gchar* _tmp411_;
	gchar* _tmp412_;
	gchar** _tmp413_;
	gint _tmp413__length1;
	gchar* _tmp414_;
	gchar* _tmp415_;
	gchar** _tmp416_;
	gint _tmp416__length1;
	gchar* _tmp417_;
	gchar* _tmp418_;
	gchar** _tmp419_;
	gint _tmp419__length1;
	gchar* _tmp420_;
	gchar* _tmp421_;
	gchar** _tmp422_;
	gint _tmp422__length1;
	gchar* _tmp423_;
	gchar* _tmp424_;
	gchar** _tmp425_;
	gint _tmp425__length1;
	gchar* _tmp426_;
	gchar* _tmp427_;
#line 29 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	self = (GSettingsConfigurationEngine*) g_object_new (object_type, NULL);
#line 30 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp0_ = g_new0 (gchar*, CONFIGURABLE_PROPERTY_NUM_PROPERTIES + 1);
#line 30 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	self->priv->schema_names = (_vala_array_free (self->priv->schema_names, self->priv->schema_names_length1, (GDestroyNotify) g_free), NULL);
#line 30 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	self->priv->schema_names = _tmp0_;
#line 30 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	self->priv->schema_names_length1 = CONFIGURABLE_PROPERTY_NUM_PROPERTIES;
#line 30 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	self->priv->_schema_names_size_ = self->priv->schema_names_length1;
#line 32 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp1_ = self->priv->schema_names;
#line 32 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp1__length1 = self->priv->schema_names_length1;
#line 32 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp2_ = g_strdup (GSETTINGS_CONFIGURATION_ENGINE_FILES_PREFS_SCHEMA_NAME);
#line 32 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp1_[CONFIGURABLE_PROPERTY_AUTO_IMPORT_FROM_LIBRARY]);
#line 32 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp1_[CONFIGURABLE_PROPERTY_AUTO_IMPORT_FROM_LIBRARY] = _tmp2_;
#line 32 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp3_ = _tmp1_[CONFIGURABLE_PROPERTY_AUTO_IMPORT_FROM_LIBRARY];
#line 33 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp4_ = self->priv->schema_names;
#line 33 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp4__length1 = self->priv->schema_names_length1;
#line 33 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp5_ = g_strdup (GSETTINGS_CONFIGURATION_ENGINE_UI_PREFS_SCHEMA_NAME);
#line 33 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp4_[CONFIGURABLE_PROPERTY_BG_COLOR_NAME]);
#line 33 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp4_[CONFIGURABLE_PROPERTY_BG_COLOR_NAME] = _tmp5_;
#line 33 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp6_ = _tmp4_[CONFIGURABLE_PROPERTY_BG_COLOR_NAME];
#line 34 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp7_ = self->priv->schema_names;
#line 34 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp7__length1 = self->priv->schema_names_length1;
#line 34 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp8_ = g_strdup (GSETTINGS_CONFIGURATION_ENGINE_UI_PREFS_SCHEMA_NAME);
#line 34 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp7_[CONFIGURABLE_PROPERTY_TRANSPARENT_BACKGROUND_TYPE]);
#line 34 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp7_[CONFIGURABLE_PROPERTY_TRANSPARENT_BACKGROUND_TYPE] = _tmp8_;
#line 34 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp9_ = _tmp7_[CONFIGURABLE_PROPERTY_TRANSPARENT_BACKGROUND_TYPE];
#line 35 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp10_ = self->priv->schema_names;
#line 35 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp10__length1 = self->priv->schema_names_length1;
#line 35 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp11_ = g_strdup (GSETTINGS_CONFIGURATION_ENGINE_UI_PREFS_SCHEMA_NAME);
#line 35 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp10_[CONFIGURABLE_PROPERTY_TRANSPARENT_BACKGROUND_COLOR]);
#line 35 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp10_[CONFIGURABLE_PROPERTY_TRANSPARENT_BACKGROUND_COLOR] = _tmp11_;
#line 35 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp12_ = _tmp10_[CONFIGURABLE_PROPERTY_TRANSPARENT_BACKGROUND_COLOR];
#line 36 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp13_ = self->priv->schema_names;
#line 36 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp13__length1 = self->priv->schema_names_length1;
#line 36 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp14_ = g_strdup (GSETTINGS_CONFIGURATION_ENGINE_FILES_PREFS_SCHEMA_NAME);
#line 36 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp13_[CONFIGURABLE_PROPERTY_COMMIT_METADATA_TO_MASTERS]);
#line 36 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp13_[CONFIGURABLE_PROPERTY_COMMIT_METADATA_TO_MASTERS] = _tmp14_;
#line 36 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp15_ = _tmp13_[CONFIGURABLE_PROPERTY_COMMIT_METADATA_TO_MASTERS];
#line 37 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp16_ = self->priv->schema_names;
#line 37 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp16__length1 = self->priv->schema_names_length1;
#line 37 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp17_ = g_strdup (GSETTINGS_CONFIGURATION_ENGINE_SYSTEM_DESKTOP_SCHEMA_NAME);
#line 37 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp16_[CONFIGURABLE_PROPERTY_DESKTOP_BACKGROUND_FILE]);
#line 37 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp16_[CONFIGURABLE_PROPERTY_DESKTOP_BACKGROUND_FILE] = _tmp17_;
#line 37 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp18_ = _tmp16_[CONFIGURABLE_PROPERTY_DESKTOP_BACKGROUND_FILE];
#line 38 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp19_ = self->priv->schema_names;
#line 38 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp19__length1 = self->priv->schema_names_length1;
#line 38 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp20_ = g_strdup (GSETTINGS_CONFIGURATION_ENGINE_SYSTEM_DESKTOP_SCHEMA_NAME);
#line 38 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp19_[CONFIGURABLE_PROPERTY_DESKTOP_BACKGROUND_MODE]);
#line 38 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp19_[CONFIGURABLE_PROPERTY_DESKTOP_BACKGROUND_MODE] = _tmp20_;
#line 38 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp21_ = _tmp19_[CONFIGURABLE_PROPERTY_DESKTOP_BACKGROUND_MODE];
#line 39 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp22_ = self->priv->schema_names;
#line 39 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp22__length1 = self->priv->schema_names_length1;
#line 39 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp23_ = g_strdup (GSETTINGS_CONFIGURATION_ENGINE_SYSTEM_SCREENSAVER_SCHEMA_NAME);
#line 39 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp22_[CONFIGURABLE_PROPERTY_SCREENSAVER_FILE]);
#line 39 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp22_[CONFIGURABLE_PROPERTY_SCREENSAVER_FILE] = _tmp23_;
#line 39 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp24_ = _tmp22_[CONFIGURABLE_PROPERTY_SCREENSAVER_FILE];
#line 40 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp25_ = self->priv->schema_names;
#line 40 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp25__length1 = self->priv->schema_names_length1;
#line 40 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp26_ = g_strdup (GSETTINGS_CONFIGURATION_ENGINE_SYSTEM_SCREENSAVER_SCHEMA_NAME);
#line 40 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp25_[CONFIGURABLE_PROPERTY_SCREENSAVER_MODE]);
#line 40 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp25_[CONFIGURABLE_PROPERTY_SCREENSAVER_MODE] = _tmp26_;
#line 40 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp27_ = _tmp25_[CONFIGURABLE_PROPERTY_SCREENSAVER_MODE];
#line 41 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp28_ = self->priv->schema_names;
#line 41 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp28__length1 = self->priv->schema_names_length1;
#line 41 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp29_ = g_strdup (GSETTINGS_CONFIGURATION_ENGINE_FILES_PREFS_SCHEMA_NAME);
#line 41 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp28_[CONFIGURABLE_PROPERTY_DIRECTORY_PATTERN]);
#line 41 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp28_[CONFIGURABLE_PROPERTY_DIRECTORY_PATTERN] = _tmp29_;
#line 41 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp30_ = _tmp28_[CONFIGURABLE_PROPERTY_DIRECTORY_PATTERN];
#line 42 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp31_ = self->priv->schema_names;
#line 42 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp31__length1 = self->priv->schema_names_length1;
#line 42 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp32_ = g_strdup (GSETTINGS_CONFIGURATION_ENGINE_FILES_PREFS_SCHEMA_NAME);
#line 42 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp31_[CONFIGURABLE_PROPERTY_DIRECTORY_PATTERN_CUSTOM]);
#line 42 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp31_[CONFIGURABLE_PROPERTY_DIRECTORY_PATTERN_CUSTOM] = _tmp32_;
#line 42 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp33_ = _tmp31_[CONFIGURABLE_PROPERTY_DIRECTORY_PATTERN_CUSTOM];
#line 43 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp34_ = self->priv->schema_names;
#line 43 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp34__length1 = self->priv->schema_names_length1;
#line 43 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp35_ = g_strdup (GSETTINGS_CONFIGURATION_ENGINE_WINDOW_PREFS_SCHEMA_NAME);
#line 43 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp34_[CONFIGURABLE_PROPERTY_DIRECT_WINDOW_HEIGHT]);
#line 43 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp34_[CONFIGURABLE_PROPERTY_DIRECT_WINDOW_HEIGHT] = _tmp35_;
#line 43 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp36_ = _tmp34_[CONFIGURABLE_PROPERTY_DIRECT_WINDOW_HEIGHT];
#line 44 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp37_ = self->priv->schema_names;
#line 44 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp37__length1 = self->priv->schema_names_length1;
#line 44 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp38_ = g_strdup (GSETTINGS_CONFIGURATION_ENGINE_WINDOW_PREFS_SCHEMA_NAME);
#line 44 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp37_[CONFIGURABLE_PROPERTY_DIRECT_WINDOW_MAXIMIZE]);
#line 44 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp37_[CONFIGURABLE_PROPERTY_DIRECT_WINDOW_MAXIMIZE] = _tmp38_;
#line 44 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp39_ = _tmp37_[CONFIGURABLE_PROPERTY_DIRECT_WINDOW_MAXIMIZE];
#line 45 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp40_ = self->priv->schema_names;
#line 45 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp40__length1 = self->priv->schema_names_length1;
#line 45 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp41_ = g_strdup (GSETTINGS_CONFIGURATION_ENGINE_WINDOW_PREFS_SCHEMA_NAME);
#line 45 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp40_[CONFIGURABLE_PROPERTY_DIRECT_WINDOW_WIDTH]);
#line 45 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp40_[CONFIGURABLE_PROPERTY_DIRECT_WINDOW_WIDTH] = _tmp41_;
#line 45 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp42_ = _tmp40_[CONFIGURABLE_PROPERTY_DIRECT_WINDOW_WIDTH];
#line 46 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp43_ = self->priv->schema_names;
#line 46 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp43__length1 = self->priv->schema_names_length1;
#line 46 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp44_ = g_strdup (GSETTINGS_CONFIGURATION_ENGINE_UI_PREFS_SCHEMA_NAME);
#line 46 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp43_[CONFIGURABLE_PROPERTY_DISPLAY_BASIC_PROPERTIES]);
#line 46 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp43_[CONFIGURABLE_PROPERTY_DISPLAY_BASIC_PROPERTIES] = _tmp44_;
#line 46 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp45_ = _tmp43_[CONFIGURABLE_PROPERTY_DISPLAY_BASIC_PROPERTIES];
#line 47 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp46_ = self->priv->schema_names;
#line 47 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp46__length1 = self->priv->schema_names_length1;
#line 47 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp47_ = g_strdup (GSETTINGS_CONFIGURATION_ENGINE_UI_PREFS_SCHEMA_NAME);
#line 47 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp46_[CONFIGURABLE_PROPERTY_DISPLAY_EXTENDED_PROPERTIES]);
#line 47 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp46_[CONFIGURABLE_PROPERTY_DISPLAY_EXTENDED_PROPERTIES] = _tmp47_;
#line 47 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp48_ = _tmp46_[CONFIGURABLE_PROPERTY_DISPLAY_EXTENDED_PROPERTIES];
#line 48 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp49_ = self->priv->schema_names;
#line 48 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp49__length1 = self->priv->schema_names_length1;
#line 48 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp50_ = g_strdup (GSETTINGS_CONFIGURATION_ENGINE_UI_PREFS_SCHEMA_NAME);
#line 48 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp49_[CONFIGURABLE_PROPERTY_DISPLAY_SIDEBAR]);
#line 48 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp49_[CONFIGURABLE_PROPERTY_DISPLAY_SIDEBAR] = _tmp50_;
#line 48 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp51_ = _tmp49_[CONFIGURABLE_PROPERTY_DISPLAY_SIDEBAR];
#line 49 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp52_ = self->priv->schema_names;
#line 49 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp52__length1 = self->priv->schema_names_length1;
#line 49 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp53_ = g_strdup (GSETTINGS_CONFIGURATION_ENGINE_UI_PREFS_SCHEMA_NAME);
#line 49 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp52_[CONFIGURABLE_PROPERTY_DISPLAY_TOOLBAR]);
#line 49 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp52_[CONFIGURABLE_PROPERTY_DISPLAY_TOOLBAR] = _tmp53_;
#line 49 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp54_ = _tmp52_[CONFIGURABLE_PROPERTY_DISPLAY_TOOLBAR];
#line 50 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp55_ = self->priv->schema_names;
#line 50 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp55__length1 = self->priv->schema_names_length1;
#line 50 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp56_ = g_strdup (GSETTINGS_CONFIGURATION_ENGINE_UI_PREFS_SCHEMA_NAME);
#line 50 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp55_[CONFIGURABLE_PROPERTY_DISPLAY_SEARCH_BAR]);
#line 50 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp55_[CONFIGURABLE_PROPERTY_DISPLAY_SEARCH_BAR] = _tmp56_;
#line 50 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp57_ = _tmp55_[CONFIGURABLE_PROPERTY_DISPLAY_SEARCH_BAR];
#line 51 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp58_ = self->priv->schema_names;
#line 51 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp58__length1 = self->priv->schema_names_length1;
#line 51 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp59_ = g_strdup (GSETTINGS_CONFIGURATION_ENGINE_UI_PREFS_SCHEMA_NAME);
#line 51 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp58_[CONFIGURABLE_PROPERTY_DISPLAY_PHOTO_RATINGS]);
#line 51 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp58_[CONFIGURABLE_PROPERTY_DISPLAY_PHOTO_RATINGS] = _tmp59_;
#line 51 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp60_ = _tmp58_[CONFIGURABLE_PROPERTY_DISPLAY_PHOTO_RATINGS];
#line 52 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp61_ = self->priv->schema_names;
#line 52 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp61__length1 = self->priv->schema_names_length1;
#line 52 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp62_ = g_strdup (GSETTINGS_CONFIGURATION_ENGINE_UI_PREFS_SCHEMA_NAME);
#line 52 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp61_[CONFIGURABLE_PROPERTY_DISPLAY_PHOTO_TAGS]);
#line 52 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp61_[CONFIGURABLE_PROPERTY_DISPLAY_PHOTO_TAGS] = _tmp62_;
#line 52 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp63_ = _tmp61_[CONFIGURABLE_PROPERTY_DISPLAY_PHOTO_TAGS];
#line 53 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp64_ = self->priv->schema_names;
#line 53 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp64__length1 = self->priv->schema_names_length1;
#line 53 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp65_ = g_strdup (GSETTINGS_CONFIGURATION_ENGINE_UI_PREFS_SCHEMA_NAME);
#line 53 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp64_[CONFIGURABLE_PROPERTY_DISPLAY_PHOTO_TITLES]);
#line 53 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp64_[CONFIGURABLE_PROPERTY_DISPLAY_PHOTO_TITLES] = _tmp65_;
#line 53 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp66_ = _tmp64_[CONFIGURABLE_PROPERTY_DISPLAY_PHOTO_TITLES];
#line 54 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp67_ = self->priv->schema_names;
#line 54 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp67__length1 = self->priv->schema_names_length1;
#line 54 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp68_ = g_strdup (GSETTINGS_CONFIGURATION_ENGINE_UI_PREFS_SCHEMA_NAME);
#line 54 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp67_[CONFIGURABLE_PROPERTY_DISPLAY_PHOTO_COMMENTS]);
#line 54 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp67_[CONFIGURABLE_PROPERTY_DISPLAY_PHOTO_COMMENTS] = _tmp68_;
#line 54 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp69_ = _tmp67_[CONFIGURABLE_PROPERTY_DISPLAY_PHOTO_COMMENTS];
#line 55 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp70_ = self->priv->schema_names;
#line 55 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp70__length1 = self->priv->schema_names_length1;
#line 55 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp71_ = g_strdup (GSETTINGS_CONFIGURATION_ENGINE_UI_PREFS_SCHEMA_NAME);
#line 55 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp70_[CONFIGURABLE_PROPERTY_DISPLAY_EVENT_COMMENTS]);
#line 55 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp70_[CONFIGURABLE_PROPERTY_DISPLAY_EVENT_COMMENTS] = _tmp71_;
#line 55 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp72_ = _tmp70_[CONFIGURABLE_PROPERTY_DISPLAY_EVENT_COMMENTS];
#line 56 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp73_ = self->priv->schema_names;
#line 56 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp73__length1 = self->priv->schema_names_length1;
#line 56 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp74_ = g_strdup (GSETTINGS_CONFIGURATION_ENGINE_UI_PREFS_SCHEMA_NAME);
#line 56 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp73_[CONFIGURABLE_PROPERTY_EVENT_PHOTOS_SORT_ASCENDING]);
#line 56 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp73_[CONFIGURABLE_PROPERTY_EVENT_PHOTOS_SORT_ASCENDING] = _tmp74_;
#line 56 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp75_ = _tmp73_[CONFIGURABLE_PROPERTY_EVENT_PHOTOS_SORT_ASCENDING];
#line 57 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp76_ = self->priv->schema_names;
#line 57 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp76__length1 = self->priv->schema_names_length1;
#line 57 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp77_ = g_strdup (GSETTINGS_CONFIGURATION_ENGINE_UI_PREFS_SCHEMA_NAME);
#line 57 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp76_[CONFIGURABLE_PROPERTY_EVENT_PHOTOS_SORT_BY]);
#line 57 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp76_[CONFIGURABLE_PROPERTY_EVENT_PHOTOS_SORT_BY] = _tmp77_;
#line 57 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp78_ = _tmp76_[CONFIGURABLE_PROPERTY_EVENT_PHOTOS_SORT_BY];
#line 58 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp79_ = self->priv->schema_names;
#line 58 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp79__length1 = self->priv->schema_names_length1;
#line 58 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp80_ = g_strdup (GSETTINGS_CONFIGURATION_ENGINE_UI_PREFS_SCHEMA_NAME);
#line 58 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp79_[CONFIGURABLE_PROPERTY_EVENTS_SORT_ASCENDING]);
#line 58 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp79_[CONFIGURABLE_PROPERTY_EVENTS_SORT_ASCENDING] = _tmp80_;
#line 58 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp81_ = _tmp79_[CONFIGURABLE_PROPERTY_EVENTS_SORT_ASCENDING];
#line 59 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp82_ = self->priv->schema_names;
#line 59 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp82__length1 = self->priv->schema_names_length1;
#line 59 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp83_ = g_strdup (GSETTINGS_CONFIGURATION_ENGINE_EXPORT_PREFS_SCHEMA_NAME);
#line 59 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp82_[CONFIGURABLE_PROPERTY_EXPORT_CONSTRAINT]);
#line 59 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp82_[CONFIGURABLE_PROPERTY_EXPORT_CONSTRAINT] = _tmp83_;
#line 59 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp84_ = _tmp82_[CONFIGURABLE_PROPERTY_EXPORT_CONSTRAINT];
#line 60 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp85_ = self->priv->schema_names;
#line 60 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp85__length1 = self->priv->schema_names_length1;
#line 60 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp86_ = g_strdup (GSETTINGS_CONFIGURATION_ENGINE_EXPORT_PREFS_SCHEMA_NAME);
#line 60 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp85_[CONFIGURABLE_PROPERTY_EXPORT_EXPORT_FORMAT_MODE]);
#line 60 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp85_[CONFIGURABLE_PROPERTY_EXPORT_EXPORT_FORMAT_MODE] = _tmp86_;
#line 60 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp87_ = _tmp85_[CONFIGURABLE_PROPERTY_EXPORT_EXPORT_FORMAT_MODE];
#line 61 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp88_ = self->priv->schema_names;
#line 61 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp88__length1 = self->priv->schema_names_length1;
#line 61 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp89_ = g_strdup (GSETTINGS_CONFIGURATION_ENGINE_EXPORT_PREFS_SCHEMA_NAME);
#line 61 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp88_[CONFIGURABLE_PROPERTY_EXPORT_EXPORT_METADATA]);
#line 61 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp88_[CONFIGURABLE_PROPERTY_EXPORT_EXPORT_METADATA] = _tmp89_;
#line 61 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp90_ = _tmp88_[CONFIGURABLE_PROPERTY_EXPORT_EXPORT_METADATA];
#line 62 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp91_ = self->priv->schema_names;
#line 62 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp91__length1 = self->priv->schema_names_length1;
#line 62 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp92_ = g_strdup (GSETTINGS_CONFIGURATION_ENGINE_EXPORT_PREFS_SCHEMA_NAME);
#line 62 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp91_[CONFIGURABLE_PROPERTY_EXPORT_PHOTO_FILE_FORMAT]);
#line 62 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp91_[CONFIGURABLE_PROPERTY_EXPORT_PHOTO_FILE_FORMAT] = _tmp92_;
#line 62 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp93_ = _tmp91_[CONFIGURABLE_PROPERTY_EXPORT_PHOTO_FILE_FORMAT];
#line 63 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp94_ = self->priv->schema_names;
#line 63 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp94__length1 = self->priv->schema_names_length1;
#line 63 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp95_ = g_strdup (GSETTINGS_CONFIGURATION_ENGINE_EXPORT_PREFS_SCHEMA_NAME);
#line 63 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp94_[CONFIGURABLE_PROPERTY_EXPORT_QUALITY]);
#line 63 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp94_[CONFIGURABLE_PROPERTY_EXPORT_QUALITY] = _tmp95_;
#line 63 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp96_ = _tmp94_[CONFIGURABLE_PROPERTY_EXPORT_QUALITY];
#line 64 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp97_ = self->priv->schema_names;
#line 64 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp97__length1 = self->priv->schema_names_length1;
#line 64 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp98_ = g_strdup (GSETTINGS_CONFIGURATION_ENGINE_EXPORT_PREFS_SCHEMA_NAME);
#line 64 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp97_[CONFIGURABLE_PROPERTY_EXPORT_SCALE]);
#line 64 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp97_[CONFIGURABLE_PROPERTY_EXPORT_SCALE] = _tmp98_;
#line 64 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp99_ = _tmp97_[CONFIGURABLE_PROPERTY_EXPORT_SCALE];
#line 65 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp100_ = self->priv->schema_names;
#line 65 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp100__length1 = self->priv->schema_names_length1;
#line 65 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp101_ = g_strdup (GSETTINGS_CONFIGURATION_ENGINE_EDITING_PREFS_SCHEMA_NAME);
#line 65 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp100_[CONFIGURABLE_PROPERTY_EXTERNAL_PHOTO_APP]);
#line 65 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp100_[CONFIGURABLE_PROPERTY_EXTERNAL_PHOTO_APP] = _tmp101_;
#line 65 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp102_ = _tmp100_[CONFIGURABLE_PROPERTY_EXTERNAL_PHOTO_APP];
#line 66 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp103_ = self->priv->schema_names;
#line 66 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp103__length1 = self->priv->schema_names_length1;
#line 66 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp104_ = g_strdup (GSETTINGS_CONFIGURATION_ENGINE_EDITING_PREFS_SCHEMA_NAME);
#line 66 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp103_[CONFIGURABLE_PROPERTY_EXTERNAL_RAW_APP]);
#line 66 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp103_[CONFIGURABLE_PROPERTY_EXTERNAL_RAW_APP] = _tmp104_;
#line 66 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp105_ = _tmp103_[CONFIGURABLE_PROPERTY_EXTERNAL_RAW_APP];
#line 67 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp106_ = self->priv->schema_names;
#line 67 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp106__length1 = self->priv->schema_names_length1;
#line 67 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp107_ = g_strdup (GSETTINGS_CONFIGURATION_ENGINE_UI_PREFS_SCHEMA_NAME);
#line 67 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp106_[CONFIGURABLE_PROPERTY_HIDE_PHOTOS_ALREADY_IMPORTED]);
#line 67 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp106_[CONFIGURABLE_PROPERTY_HIDE_PHOTOS_ALREADY_IMPORTED] = _tmp107_;
#line 67 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp108_ = _tmp106_[CONFIGURABLE_PROPERTY_HIDE_PHOTOS_ALREADY_IMPORTED];
#line 68 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp109_ = self->priv->schema_names;
#line 68 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp109__length1 = self->priv->schema_names_length1;
#line 68 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp110_ = g_strdup (GSETTINGS_CONFIGURATION_ENGINE_FILES_PREFS_SCHEMA_NAME);
#line 68 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp109_[CONFIGURABLE_PROPERTY_IMPORT_DIR]);
#line 68 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp109_[CONFIGURABLE_PROPERTY_IMPORT_DIR] = _tmp110_;
#line 68 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp111_ = _tmp109_[CONFIGURABLE_PROPERTY_IMPORT_DIR];
#line 69 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp112_ = self->priv->schema_names;
#line 69 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp112__length1 = self->priv->schema_names_length1;
#line 69 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp113_ = g_strdup (GSETTINGS_CONFIGURATION_ENGINE_UI_PREFS_SCHEMA_NAME);
#line 69 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp112_[CONFIGURABLE_PROPERTY_KEEP_RELATIVITY]);
#line 69 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp112_[CONFIGURABLE_PROPERTY_KEEP_RELATIVITY] = _tmp113_;
#line 69 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp114_ = _tmp112_[CONFIGURABLE_PROPERTY_KEEP_RELATIVITY];
#line 70 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp115_ = self->priv->schema_names;
#line 70 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp115__length1 = self->priv->schema_names_length1;
#line 70 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp116_ = g_strdup (GSETTINGS_CONFIGURATION_ENGINE_CROP_SCHEMA_NAME);
#line 70 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp115_[CONFIGURABLE_PROPERTY_LAST_CROP_HEIGHT]);
#line 70 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp115_[CONFIGURABLE_PROPERTY_LAST_CROP_HEIGHT] = _tmp116_;
#line 70 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp117_ = _tmp115_[CONFIGURABLE_PROPERTY_LAST_CROP_HEIGHT];
#line 71 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp118_ = self->priv->schema_names;
#line 71 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp118__length1 = self->priv->schema_names_length1;
#line 71 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp119_ = g_strdup (GSETTINGS_CONFIGURATION_ENGINE_CROP_SCHEMA_NAME);
#line 71 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp118_[CONFIGURABLE_PROPERTY_LAST_CROP_MENU_CHOICE]);
#line 71 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp118_[CONFIGURABLE_PROPERTY_LAST_CROP_MENU_CHOICE] = _tmp119_;
#line 71 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp120_ = _tmp118_[CONFIGURABLE_PROPERTY_LAST_CROP_MENU_CHOICE];
#line 72 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp121_ = self->priv->schema_names;
#line 72 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp121__length1 = self->priv->schema_names_length1;
#line 72 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp122_ = g_strdup (GSETTINGS_CONFIGURATION_ENGINE_CROP_SCHEMA_NAME);
#line 72 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp121_[CONFIGURABLE_PROPERTY_LAST_CROP_WIDTH]);
#line 72 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp121_[CONFIGURABLE_PROPERTY_LAST_CROP_WIDTH] = _tmp122_;
#line 72 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp123_ = _tmp121_[CONFIGURABLE_PROPERTY_LAST_CROP_WIDTH];
#line 73 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp124_ = self->priv->schema_names;
#line 73 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp124__length1 = self->priv->schema_names_length1;
#line 73 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp125_ = g_strdup (GSETTINGS_CONFIGURATION_ENGINE_SHARING_SCHEMA_NAME);
#line 73 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp124_[CONFIGURABLE_PROPERTY_LAST_USED_SERVICE]);
#line 73 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp124_[CONFIGURABLE_PROPERTY_LAST_USED_SERVICE] = _tmp125_;
#line 73 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp126_ = _tmp124_[CONFIGURABLE_PROPERTY_LAST_USED_SERVICE];
#line 74 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp127_ = self->priv->schema_names;
#line 74 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp127__length1 = self->priv->schema_names_length1;
#line 74 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp128_ = g_strdup (GSETTINGS_CONFIGURATION_ENGINE_IMPORTING_SCHEMA_NAME);
#line 74 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp127_[CONFIGURABLE_PROPERTY_LAST_USED_DATAIMPORTS_SERVICE]);
#line 74 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp127_[CONFIGURABLE_PROPERTY_LAST_USED_DATAIMPORTS_SERVICE] = _tmp128_;
#line 74 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp129_ = _tmp127_[CONFIGURABLE_PROPERTY_LAST_USED_DATAIMPORTS_SERVICE];
#line 75 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp130_ = self->priv->schema_names;
#line 75 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp130__length1 = self->priv->schema_names_length1;
#line 75 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp131_ = g_strdup (GSETTINGS_CONFIGURATION_ENGINE_UI_PREFS_SCHEMA_NAME);
#line 75 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp130_[CONFIGURABLE_PROPERTY_LIBRARY_PHOTOS_SORT_ASCENDING]);
#line 75 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp130_[CONFIGURABLE_PROPERTY_LIBRARY_PHOTOS_SORT_ASCENDING] = _tmp131_;
#line 75 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp132_ = _tmp130_[CONFIGURABLE_PROPERTY_LIBRARY_PHOTOS_SORT_ASCENDING];
#line 76 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp133_ = self->priv->schema_names;
#line 76 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp133__length1 = self->priv->schema_names_length1;
#line 76 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp134_ = g_strdup (GSETTINGS_CONFIGURATION_ENGINE_UI_PREFS_SCHEMA_NAME);
#line 76 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp133_[CONFIGURABLE_PROPERTY_LIBRARY_PHOTOS_SORT_BY]);
#line 76 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp133_[CONFIGURABLE_PROPERTY_LIBRARY_PHOTOS_SORT_BY] = _tmp134_;
#line 76 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp135_ = _tmp133_[CONFIGURABLE_PROPERTY_LIBRARY_PHOTOS_SORT_BY];
#line 77 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp136_ = self->priv->schema_names;
#line 77 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp136__length1 = self->priv->schema_names_length1;
#line 77 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp137_ = g_strdup (GSETTINGS_CONFIGURATION_ENGINE_WINDOW_PREFS_SCHEMA_NAME);
#line 77 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp136_[CONFIGURABLE_PROPERTY_LIBRARY_WINDOW_HEIGHT]);
#line 77 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp136_[CONFIGURABLE_PROPERTY_LIBRARY_WINDOW_HEIGHT] = _tmp137_;
#line 77 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp138_ = _tmp136_[CONFIGURABLE_PROPERTY_LIBRARY_WINDOW_HEIGHT];
#line 78 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp139_ = self->priv->schema_names;
#line 78 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp139__length1 = self->priv->schema_names_length1;
#line 78 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp140_ = g_strdup (GSETTINGS_CONFIGURATION_ENGINE_WINDOW_PREFS_SCHEMA_NAME);
#line 78 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp139_[CONFIGURABLE_PROPERTY_LIBRARY_WINDOW_MAXIMIZE]);
#line 78 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp139_[CONFIGURABLE_PROPERTY_LIBRARY_WINDOW_MAXIMIZE] = _tmp140_;
#line 78 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp141_ = _tmp139_[CONFIGURABLE_PROPERTY_LIBRARY_WINDOW_MAXIMIZE];
#line 79 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp142_ = self->priv->schema_names;
#line 79 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp142__length1 = self->priv->schema_names_length1;
#line 79 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp143_ = g_strdup (GSETTINGS_CONFIGURATION_ENGINE_WINDOW_PREFS_SCHEMA_NAME);
#line 79 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp142_[CONFIGURABLE_PROPERTY_LIBRARY_WINDOW_WIDTH]);
#line 79 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp142_[CONFIGURABLE_PROPERTY_LIBRARY_WINDOW_WIDTH] = _tmp143_;
#line 79 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp144_ = _tmp142_[CONFIGURABLE_PROPERTY_LIBRARY_WINDOW_WIDTH];
#line 80 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp145_ = self->priv->schema_names;
#line 80 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp145__length1 = self->priv->schema_names_length1;
#line 80 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp146_ = g_strdup (GSETTINGS_CONFIGURATION_ENGINE_UI_PREFS_SCHEMA_NAME);
#line 80 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp145_[CONFIGURABLE_PROPERTY_MODIFY_ORIGINALS]);
#line 80 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp145_[CONFIGURABLE_PROPERTY_MODIFY_ORIGINALS] = _tmp146_;
#line 80 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp147_ = _tmp145_[CONFIGURABLE_PROPERTY_MODIFY_ORIGINALS];
#line 81 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp148_ = self->priv->schema_names;
#line 81 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp148__length1 = self->priv->schema_names_length1;
#line 81 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp149_ = g_strdup (GSETTINGS_CONFIGURATION_ENGINE_UI_PREFS_SCHEMA_NAME);
#line 81 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp148_[CONFIGURABLE_PROPERTY_PHOTO_THUMBNAIL_SCALE]);
#line 81 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp148_[CONFIGURABLE_PROPERTY_PHOTO_THUMBNAIL_SCALE] = _tmp149_;
#line 81 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp150_ = _tmp148_[CONFIGURABLE_PROPERTY_PHOTO_THUMBNAIL_SCALE];
#line 82 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp151_ = self->priv->schema_names;
#line 82 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp151__length1 = self->priv->schema_names_length1;
#line 82 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp152_ = g_strdup (GSETTINGS_CONFIGURATION_ENGINE_UI_PREFS_SCHEMA_NAME);
#line 82 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp151_[CONFIGURABLE_PROPERTY_PIN_TOOLBAR_STATE]);
#line 82 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp151_[CONFIGURABLE_PROPERTY_PIN_TOOLBAR_STATE] = _tmp152_;
#line 82 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp153_ = _tmp151_[CONFIGURABLE_PROPERTY_PIN_TOOLBAR_STATE];
#line 83 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp154_ = self->priv->schema_names;
#line 83 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp154__length1 = self->priv->schema_names_length1;
#line 83 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp155_ = g_strdup (GSETTINGS_CONFIGURATION_ENGINE_PRINTING_SCHEMA_NAME);
#line 83 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp154_[CONFIGURABLE_PROPERTY_PRINTING_CONTENT_HEIGHT]);
#line 83 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp154_[CONFIGURABLE_PROPERTY_PRINTING_CONTENT_HEIGHT] = _tmp155_;
#line 83 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp156_ = _tmp154_[CONFIGURABLE_PROPERTY_PRINTING_CONTENT_HEIGHT];
#line 84 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp157_ = self->priv->schema_names;
#line 84 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp157__length1 = self->priv->schema_names_length1;
#line 84 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp158_ = g_strdup (GSETTINGS_CONFIGURATION_ENGINE_PRINTING_SCHEMA_NAME);
#line 84 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp157_[CONFIGURABLE_PROPERTY_PRINTING_CONTENT_LAYOUT]);
#line 84 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp157_[CONFIGURABLE_PROPERTY_PRINTING_CONTENT_LAYOUT] = _tmp158_;
#line 84 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp159_ = _tmp157_[CONFIGURABLE_PROPERTY_PRINTING_CONTENT_LAYOUT];
#line 85 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp160_ = self->priv->schema_names;
#line 85 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp160__length1 = self->priv->schema_names_length1;
#line 85 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp161_ = g_strdup (GSETTINGS_CONFIGURATION_ENGINE_PRINTING_SCHEMA_NAME);
#line 85 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp160_[CONFIGURABLE_PROPERTY_PRINTING_CONTENT_PPI]);
#line 85 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp160_[CONFIGURABLE_PROPERTY_PRINTING_CONTENT_PPI] = _tmp161_;
#line 85 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp162_ = _tmp160_[CONFIGURABLE_PROPERTY_PRINTING_CONTENT_PPI];
#line 86 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp163_ = self->priv->schema_names;
#line 86 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp163__length1 = self->priv->schema_names_length1;
#line 86 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp164_ = g_strdup (GSETTINGS_CONFIGURATION_ENGINE_PRINTING_SCHEMA_NAME);
#line 86 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp163_[CONFIGURABLE_PROPERTY_PRINTING_CONTENT_UNITS]);
#line 86 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp163_[CONFIGURABLE_PROPERTY_PRINTING_CONTENT_UNITS] = _tmp164_;
#line 86 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp165_ = _tmp163_[CONFIGURABLE_PROPERTY_PRINTING_CONTENT_UNITS];
#line 87 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp166_ = self->priv->schema_names;
#line 87 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp166__length1 = self->priv->schema_names_length1;
#line 87 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp167_ = g_strdup (GSETTINGS_CONFIGURATION_ENGINE_PRINTING_SCHEMA_NAME);
#line 87 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp166_[CONFIGURABLE_PROPERTY_PRINTING_CONTENT_WIDTH]);
#line 87 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp166_[CONFIGURABLE_PROPERTY_PRINTING_CONTENT_WIDTH] = _tmp167_;
#line 87 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp168_ = _tmp166_[CONFIGURABLE_PROPERTY_PRINTING_CONTENT_WIDTH];
#line 88 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp169_ = self->priv->schema_names;
#line 88 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp169__length1 = self->priv->schema_names_length1;
#line 88 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp170_ = g_strdup (GSETTINGS_CONFIGURATION_ENGINE_PRINTING_SCHEMA_NAME);
#line 88 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp169_[CONFIGURABLE_PROPERTY_PRINTING_IMAGES_PER_PAGE]);
#line 88 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp169_[CONFIGURABLE_PROPERTY_PRINTING_IMAGES_PER_PAGE] = _tmp170_;
#line 88 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp171_ = _tmp169_[CONFIGURABLE_PROPERTY_PRINTING_IMAGES_PER_PAGE];
#line 89 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp172_ = self->priv->schema_names;
#line 89 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp172__length1 = self->priv->schema_names_length1;
#line 89 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp173_ = g_strdup (GSETTINGS_CONFIGURATION_ENGINE_PRINTING_SCHEMA_NAME);
#line 89 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp172_[CONFIGURABLE_PROPERTY_PRINTING_MATCH_ASPECT_RATIO]);
#line 89 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp172_[CONFIGURABLE_PROPERTY_PRINTING_MATCH_ASPECT_RATIO] = _tmp173_;
#line 89 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp174_ = _tmp172_[CONFIGURABLE_PROPERTY_PRINTING_MATCH_ASPECT_RATIO];
#line 90 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp175_ = self->priv->schema_names;
#line 90 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp175__length1 = self->priv->schema_names_length1;
#line 90 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp176_ = g_strdup (GSETTINGS_CONFIGURATION_ENGINE_PRINTING_SCHEMA_NAME);
#line 90 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp175_[CONFIGURABLE_PROPERTY_PRINTING_PRINT_TITLES]);
#line 90 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp175_[CONFIGURABLE_PROPERTY_PRINTING_PRINT_TITLES] = _tmp176_;
#line 90 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp177_ = _tmp175_[CONFIGURABLE_PROPERTY_PRINTING_PRINT_TITLES];
#line 91 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp178_ = self->priv->schema_names;
#line 91 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp178__length1 = self->priv->schema_names_length1;
#line 91 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp179_ = g_strdup (GSETTINGS_CONFIGURATION_ENGINE_PRINTING_SCHEMA_NAME);
#line 91 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp178_[CONFIGURABLE_PROPERTY_PRINTING_SIZE_SELECTION]);
#line 91 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp178_[CONFIGURABLE_PROPERTY_PRINTING_SIZE_SELECTION] = _tmp179_;
#line 91 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp180_ = _tmp178_[CONFIGURABLE_PROPERTY_PRINTING_SIZE_SELECTION];
#line 92 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp181_ = self->priv->schema_names;
#line 92 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp181__length1 = self->priv->schema_names_length1;
#line 92 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp182_ = g_strdup (GSETTINGS_CONFIGURATION_ENGINE_PRINTING_SCHEMA_NAME);
#line 92 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp181_[CONFIGURABLE_PROPERTY_PRINTING_TITLES_FONT]);
#line 92 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp181_[CONFIGURABLE_PROPERTY_PRINTING_TITLES_FONT] = _tmp182_;
#line 92 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp183_ = _tmp181_[CONFIGURABLE_PROPERTY_PRINTING_TITLES_FONT];
#line 93 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp184_ = self->priv->schema_names;
#line 93 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp184__length1 = self->priv->schema_names_length1;
#line 93 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp185_ = g_strdup (GSETTINGS_CONFIGURATION_ENGINE_FILES_PREFS_SCHEMA_NAME);
#line 93 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp184_[CONFIGURABLE_PROPERTY_RAW_DEVELOPER_DEFAULT]);
#line 93 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp184_[CONFIGURABLE_PROPERTY_RAW_DEVELOPER_DEFAULT] = _tmp185_;
#line 93 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp186_ = _tmp184_[CONFIGURABLE_PROPERTY_RAW_DEVELOPER_DEFAULT];
#line 94 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp187_ = self->priv->schema_names;
#line 94 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp187__length1 = self->priv->schema_names_length1;
#line 94 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp188_ = g_strdup (GSETTINGS_CONFIGURATION_ENGINE_UI_PREFS_SCHEMA_NAME);
#line 94 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp187_[CONFIGURABLE_PROPERTY_SHOW_WELCOME_DIALOG]);
#line 94 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp187_[CONFIGURABLE_PROPERTY_SHOW_WELCOME_DIALOG] = _tmp188_;
#line 94 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp189_ = _tmp187_[CONFIGURABLE_PROPERTY_SHOW_WELCOME_DIALOG];
#line 95 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp190_ = self->priv->schema_names;
#line 95 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp190__length1 = self->priv->schema_names_length1;
#line 95 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp191_ = g_strdup (GSETTINGS_CONFIGURATION_ENGINE_UI_PREFS_SCHEMA_NAME);
#line 95 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp190_[CONFIGURABLE_PROPERTY_SIDEBAR_POSITION]);
#line 95 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp190_[CONFIGURABLE_PROPERTY_SIDEBAR_POSITION] = _tmp191_;
#line 95 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp192_ = _tmp190_[CONFIGURABLE_PROPERTY_SIDEBAR_POSITION];
#line 96 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp193_ = self->priv->schema_names;
#line 96 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp193__length1 = self->priv->schema_names_length1;
#line 96 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp194_ = g_strdup (GSETTINGS_CONFIGURATION_ENGINE_SLIDESHOW_PREFS_SCHEMA_NAME);
#line 96 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp193_[CONFIGURABLE_PROPERTY_SLIDESHOW_DELAY]);
#line 96 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp193_[CONFIGURABLE_PROPERTY_SLIDESHOW_DELAY] = _tmp194_;
#line 96 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp195_ = _tmp193_[CONFIGURABLE_PROPERTY_SLIDESHOW_DELAY];
#line 97 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp196_ = self->priv->schema_names;
#line 97 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp196__length1 = self->priv->schema_names_length1;
#line 97 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp197_ = g_strdup (GSETTINGS_CONFIGURATION_ENGINE_SLIDESHOW_PREFS_SCHEMA_NAME);
#line 97 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp196_[CONFIGURABLE_PROPERTY_SLIDESHOW_TRANSITION_DELAY]);
#line 97 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp196_[CONFIGURABLE_PROPERTY_SLIDESHOW_TRANSITION_DELAY] = _tmp197_;
#line 97 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp198_ = _tmp196_[CONFIGURABLE_PROPERTY_SLIDESHOW_TRANSITION_DELAY];
#line 98 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp199_ = self->priv->schema_names;
#line 98 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp199__length1 = self->priv->schema_names_length1;
#line 98 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp200_ = g_strdup (GSETTINGS_CONFIGURATION_ENGINE_SLIDESHOW_PREFS_SCHEMA_NAME);
#line 98 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp199_[CONFIGURABLE_PROPERTY_SLIDESHOW_TRANSITION_EFFECT_ID]);
#line 98 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp199_[CONFIGURABLE_PROPERTY_SLIDESHOW_TRANSITION_EFFECT_ID] = _tmp200_;
#line 98 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp201_ = _tmp199_[CONFIGURABLE_PROPERTY_SLIDESHOW_TRANSITION_EFFECT_ID];
#line 99 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp202_ = self->priv->schema_names;
#line 99 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp202__length1 = self->priv->schema_names_length1;
#line 99 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp203_ = g_strdup (GSETTINGS_CONFIGURATION_ENGINE_SLIDESHOW_PREFS_SCHEMA_NAME);
#line 99 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp202_[CONFIGURABLE_PROPERTY_SLIDESHOW_SHOW_TITLE]);
#line 99 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp202_[CONFIGURABLE_PROPERTY_SLIDESHOW_SHOW_TITLE] = _tmp203_;
#line 99 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp204_ = _tmp202_[CONFIGURABLE_PROPERTY_SLIDESHOW_SHOW_TITLE];
#line 100 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp205_ = self->priv->schema_names;
#line 100 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp205__length1 = self->priv->schema_names_length1;
#line 100 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp206_ = g_strdup (GSETTINGS_CONFIGURATION_ENGINE_UI_PREFS_SCHEMA_NAME);
#line 100 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp205_[CONFIGURABLE_PROPERTY_USE_24_HOUR_TIME]);
#line 100 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp205_[CONFIGURABLE_PROPERTY_USE_24_HOUR_TIME] = _tmp206_;
#line 100 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp207_ = _tmp205_[CONFIGURABLE_PROPERTY_USE_24_HOUR_TIME];
#line 101 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp208_ = self->priv->schema_names;
#line 101 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp208__length1 = self->priv->schema_names_length1;
#line 101 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp209_ = g_strdup (GSETTINGS_CONFIGURATION_ENGINE_FILES_PREFS_SCHEMA_NAME);
#line 101 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp208_[CONFIGURABLE_PROPERTY_USE_LOWERCASE_FILENAMES]);
#line 101 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp208_[CONFIGURABLE_PROPERTY_USE_LOWERCASE_FILENAMES] = _tmp209_;
#line 101 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp210_ = _tmp208_[CONFIGURABLE_PROPERTY_USE_LOWERCASE_FILENAMES];
#line 102 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp211_ = self->priv->schema_names;
#line 102 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp211__length1 = self->priv->schema_names_length1;
#line 102 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp212_ = g_strdup (GSETTINGS_CONFIGURATION_ENGINE_VIDEO_SCHEMA_NAME);
#line 102 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp211_[CONFIGURABLE_PROPERTY_VIDEO_INTERPRETER_STATE_COOKIE]);
#line 102 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp211_[CONFIGURABLE_PROPERTY_VIDEO_INTERPRETER_STATE_COOKIE] = _tmp212_;
#line 102 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp213_ = _tmp211_[CONFIGURABLE_PROPERTY_VIDEO_INTERPRETER_STATE_COOKIE];
#line 104 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp214_ = g_new0 (gchar*, CONFIGURABLE_PROPERTY_NUM_PROPERTIES + 1);
#line 104 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	self->priv->key_names = (_vala_array_free (self->priv->key_names, self->priv->key_names_length1, (GDestroyNotify) g_free), NULL);
#line 104 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	self->priv->key_names = _tmp214_;
#line 104 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	self->priv->key_names_length1 = CONFIGURABLE_PROPERTY_NUM_PROPERTIES;
#line 104 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	self->priv->_key_names_size_ = self->priv->key_names_length1;
#line 106 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp215_ = self->priv->key_names;
#line 106 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp215__length1 = self->priv->key_names_length1;
#line 106 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp216_ = g_strdup ("auto-import");
#line 106 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp215_[CONFIGURABLE_PROPERTY_AUTO_IMPORT_FROM_LIBRARY]);
#line 106 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp215_[CONFIGURABLE_PROPERTY_AUTO_IMPORT_FROM_LIBRARY] = _tmp216_;
#line 106 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp217_ = _tmp215_[CONFIGURABLE_PROPERTY_AUTO_IMPORT_FROM_LIBRARY];
#line 107 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp218_ = self->priv->key_names;
#line 107 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp218__length1 = self->priv->key_names_length1;
#line 107 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp219_ = g_strdup ("background-color");
#line 107 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp218_[CONFIGURABLE_PROPERTY_BG_COLOR_NAME]);
#line 107 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp218_[CONFIGURABLE_PROPERTY_BG_COLOR_NAME] = _tmp219_;
#line 107 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp220_ = _tmp218_[CONFIGURABLE_PROPERTY_BG_COLOR_NAME];
#line 108 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp221_ = self->priv->key_names;
#line 108 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp221__length1 = self->priv->key_names_length1;
#line 108 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp222_ = g_strdup ("transparent-background-type");
#line 108 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp221_[CONFIGURABLE_PROPERTY_TRANSPARENT_BACKGROUND_TYPE]);
#line 108 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp221_[CONFIGURABLE_PROPERTY_TRANSPARENT_BACKGROUND_TYPE] = _tmp222_;
#line 108 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp223_ = _tmp221_[CONFIGURABLE_PROPERTY_TRANSPARENT_BACKGROUND_TYPE];
#line 109 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp224_ = self->priv->key_names;
#line 109 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp224__length1 = self->priv->key_names_length1;
#line 109 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp225_ = g_strdup ("transparent-background-color");
#line 109 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp224_[CONFIGURABLE_PROPERTY_TRANSPARENT_BACKGROUND_COLOR]);
#line 109 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp224_[CONFIGURABLE_PROPERTY_TRANSPARENT_BACKGROUND_COLOR] = _tmp225_;
#line 109 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp226_ = _tmp224_[CONFIGURABLE_PROPERTY_TRANSPARENT_BACKGROUND_COLOR];
#line 110 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp227_ = self->priv->key_names;
#line 110 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp227__length1 = self->priv->key_names_length1;
#line 110 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp228_ = g_strdup ("commit-metadata");
#line 110 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp227_[CONFIGURABLE_PROPERTY_COMMIT_METADATA_TO_MASTERS]);
#line 110 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp227_[CONFIGURABLE_PROPERTY_COMMIT_METADATA_TO_MASTERS] = _tmp228_;
#line 110 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp229_ = _tmp227_[CONFIGURABLE_PROPERTY_COMMIT_METADATA_TO_MASTERS];
#line 111 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp230_ = self->priv->key_names;
#line 111 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp230__length1 = self->priv->key_names_length1;
#line 111 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp231_ = g_strdup ("picture-uri");
#line 111 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp230_[CONFIGURABLE_PROPERTY_DESKTOP_BACKGROUND_FILE]);
#line 111 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp230_[CONFIGURABLE_PROPERTY_DESKTOP_BACKGROUND_FILE] = _tmp231_;
#line 111 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp232_ = _tmp230_[CONFIGURABLE_PROPERTY_DESKTOP_BACKGROUND_FILE];
#line 112 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp233_ = self->priv->key_names;
#line 112 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp233__length1 = self->priv->key_names_length1;
#line 112 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp234_ = g_strdup ("picture-options");
#line 112 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp233_[CONFIGURABLE_PROPERTY_DESKTOP_BACKGROUND_MODE]);
#line 112 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp233_[CONFIGURABLE_PROPERTY_DESKTOP_BACKGROUND_MODE] = _tmp234_;
#line 112 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp235_ = _tmp233_[CONFIGURABLE_PROPERTY_DESKTOP_BACKGROUND_MODE];
#line 113 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp236_ = self->priv->key_names;
#line 113 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp236__length1 = self->priv->key_names_length1;
#line 113 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp237_ = g_strdup ("picture-uri");
#line 113 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp236_[CONFIGURABLE_PROPERTY_SCREENSAVER_FILE]);
#line 113 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp236_[CONFIGURABLE_PROPERTY_SCREENSAVER_FILE] = _tmp237_;
#line 113 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp238_ = _tmp236_[CONFIGURABLE_PROPERTY_SCREENSAVER_FILE];
#line 114 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp239_ = self->priv->key_names;
#line 114 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp239__length1 = self->priv->key_names_length1;
#line 114 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp240_ = g_strdup ("picture-options");
#line 114 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp239_[CONFIGURABLE_PROPERTY_SCREENSAVER_MODE]);
#line 114 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp239_[CONFIGURABLE_PROPERTY_SCREENSAVER_MODE] = _tmp240_;
#line 114 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp241_ = _tmp239_[CONFIGURABLE_PROPERTY_SCREENSAVER_MODE];
#line 115 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp242_ = self->priv->key_names;
#line 115 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp242__length1 = self->priv->key_names_length1;
#line 115 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp243_ = g_strdup ("directory-pattern");
#line 115 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp242_[CONFIGURABLE_PROPERTY_DIRECTORY_PATTERN]);
#line 115 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp242_[CONFIGURABLE_PROPERTY_DIRECTORY_PATTERN] = _tmp243_;
#line 115 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp244_ = _tmp242_[CONFIGURABLE_PROPERTY_DIRECTORY_PATTERN];
#line 116 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp245_ = self->priv->key_names;
#line 116 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp245__length1 = self->priv->key_names_length1;
#line 116 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp246_ = g_strdup ("directory-pattern-custom");
#line 116 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp245_[CONFIGURABLE_PROPERTY_DIRECTORY_PATTERN_CUSTOM]);
#line 116 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp245_[CONFIGURABLE_PROPERTY_DIRECTORY_PATTERN_CUSTOM] = _tmp246_;
#line 116 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp247_ = _tmp245_[CONFIGURABLE_PROPERTY_DIRECTORY_PATTERN_CUSTOM];
#line 117 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp248_ = self->priv->key_names;
#line 117 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp248__length1 = self->priv->key_names_length1;
#line 117 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp249_ = g_strdup ("direct-height");
#line 117 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp248_[CONFIGURABLE_PROPERTY_DIRECT_WINDOW_HEIGHT]);
#line 117 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp248_[CONFIGURABLE_PROPERTY_DIRECT_WINDOW_HEIGHT] = _tmp249_;
#line 117 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp250_ = _tmp248_[CONFIGURABLE_PROPERTY_DIRECT_WINDOW_HEIGHT];
#line 118 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp251_ = self->priv->key_names;
#line 118 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp251__length1 = self->priv->key_names_length1;
#line 118 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp252_ = g_strdup ("direct-maximize");
#line 118 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp251_[CONFIGURABLE_PROPERTY_DIRECT_WINDOW_MAXIMIZE]);
#line 118 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp251_[CONFIGURABLE_PROPERTY_DIRECT_WINDOW_MAXIMIZE] = _tmp252_;
#line 118 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp253_ = _tmp251_[CONFIGURABLE_PROPERTY_DIRECT_WINDOW_MAXIMIZE];
#line 119 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp254_ = self->priv->key_names;
#line 119 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp254__length1 = self->priv->key_names_length1;
#line 119 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp255_ = g_strdup ("direct-width");
#line 119 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp254_[CONFIGURABLE_PROPERTY_DIRECT_WINDOW_WIDTH]);
#line 119 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp254_[CONFIGURABLE_PROPERTY_DIRECT_WINDOW_WIDTH] = _tmp255_;
#line 119 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp256_ = _tmp254_[CONFIGURABLE_PROPERTY_DIRECT_WINDOW_WIDTH];
#line 120 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp257_ = self->priv->key_names;
#line 120 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp257__length1 = self->priv->key_names_length1;
#line 120 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp258_ = g_strdup ("display-basic-properties");
#line 120 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp257_[CONFIGURABLE_PROPERTY_DISPLAY_BASIC_PROPERTIES]);
#line 120 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp257_[CONFIGURABLE_PROPERTY_DISPLAY_BASIC_PROPERTIES] = _tmp258_;
#line 120 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp259_ = _tmp257_[CONFIGURABLE_PROPERTY_DISPLAY_BASIC_PROPERTIES];
#line 121 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp260_ = self->priv->key_names;
#line 121 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp260__length1 = self->priv->key_names_length1;
#line 121 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp261_ = g_strdup ("display-extended-properties");
#line 121 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp260_[CONFIGURABLE_PROPERTY_DISPLAY_EXTENDED_PROPERTIES]);
#line 121 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp260_[CONFIGURABLE_PROPERTY_DISPLAY_EXTENDED_PROPERTIES] = _tmp261_;
#line 121 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp262_ = _tmp260_[CONFIGURABLE_PROPERTY_DISPLAY_EXTENDED_PROPERTIES];
#line 122 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp263_ = self->priv->key_names;
#line 122 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp263__length1 = self->priv->key_names_length1;
#line 122 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp264_ = g_strdup ("display-sidebar");
#line 122 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp263_[CONFIGURABLE_PROPERTY_DISPLAY_SIDEBAR]);
#line 122 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp263_[CONFIGURABLE_PROPERTY_DISPLAY_SIDEBAR] = _tmp264_;
#line 122 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp265_ = _tmp263_[CONFIGURABLE_PROPERTY_DISPLAY_SIDEBAR];
#line 123 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp266_ = self->priv->key_names;
#line 123 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp266__length1 = self->priv->key_names_length1;
#line 123 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp267_ = g_strdup ("display-toolbar");
#line 123 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp266_[CONFIGURABLE_PROPERTY_DISPLAY_TOOLBAR]);
#line 123 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp266_[CONFIGURABLE_PROPERTY_DISPLAY_TOOLBAR] = _tmp267_;
#line 123 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp268_ = _tmp266_[CONFIGURABLE_PROPERTY_DISPLAY_TOOLBAR];
#line 124 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp269_ = self->priv->key_names;
#line 124 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp269__length1 = self->priv->key_names_length1;
#line 124 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp270_ = g_strdup ("display-search-bar");
#line 124 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp269_[CONFIGURABLE_PROPERTY_DISPLAY_SEARCH_BAR]);
#line 124 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp269_[CONFIGURABLE_PROPERTY_DISPLAY_SEARCH_BAR] = _tmp270_;
#line 124 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp271_ = _tmp269_[CONFIGURABLE_PROPERTY_DISPLAY_SEARCH_BAR];
#line 125 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp272_ = self->priv->key_names;
#line 125 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp272__length1 = self->priv->key_names_length1;
#line 125 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp273_ = g_strdup ("display-photo-ratings");
#line 125 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp272_[CONFIGURABLE_PROPERTY_DISPLAY_PHOTO_RATINGS]);
#line 125 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp272_[CONFIGURABLE_PROPERTY_DISPLAY_PHOTO_RATINGS] = _tmp273_;
#line 125 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp274_ = _tmp272_[CONFIGURABLE_PROPERTY_DISPLAY_PHOTO_RATINGS];
#line 126 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp275_ = self->priv->key_names;
#line 126 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp275__length1 = self->priv->key_names_length1;
#line 126 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp276_ = g_strdup ("display-photo-tags");
#line 126 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp275_[CONFIGURABLE_PROPERTY_DISPLAY_PHOTO_TAGS]);
#line 126 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp275_[CONFIGURABLE_PROPERTY_DISPLAY_PHOTO_TAGS] = _tmp276_;
#line 126 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp277_ = _tmp275_[CONFIGURABLE_PROPERTY_DISPLAY_PHOTO_TAGS];
#line 127 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp278_ = self->priv->key_names;
#line 127 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp278__length1 = self->priv->key_names_length1;
#line 127 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp279_ = g_strdup ("display-photo-titles");
#line 127 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp278_[CONFIGURABLE_PROPERTY_DISPLAY_PHOTO_TITLES]);
#line 127 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp278_[CONFIGURABLE_PROPERTY_DISPLAY_PHOTO_TITLES] = _tmp279_;
#line 127 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp280_ = _tmp278_[CONFIGURABLE_PROPERTY_DISPLAY_PHOTO_TITLES];
#line 128 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp281_ = self->priv->key_names;
#line 128 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp281__length1 = self->priv->key_names_length1;
#line 128 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp282_ = g_strdup ("display-photo-comments");
#line 128 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp281_[CONFIGURABLE_PROPERTY_DISPLAY_PHOTO_COMMENTS]);
#line 128 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp281_[CONFIGURABLE_PROPERTY_DISPLAY_PHOTO_COMMENTS] = _tmp282_;
#line 128 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp283_ = _tmp281_[CONFIGURABLE_PROPERTY_DISPLAY_PHOTO_COMMENTS];
#line 129 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp284_ = self->priv->key_names;
#line 129 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp284__length1 = self->priv->key_names_length1;
#line 129 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp285_ = g_strdup ("display-event-comments");
#line 129 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp284_[CONFIGURABLE_PROPERTY_DISPLAY_EVENT_COMMENTS]);
#line 129 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp284_[CONFIGURABLE_PROPERTY_DISPLAY_EVENT_COMMENTS] = _tmp285_;
#line 129 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp286_ = _tmp284_[CONFIGURABLE_PROPERTY_DISPLAY_EVENT_COMMENTS];
#line 130 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp287_ = self->priv->key_names;
#line 130 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp287__length1 = self->priv->key_names_length1;
#line 130 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp288_ = g_strdup ("event-photos-sort-ascending");
#line 130 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp287_[CONFIGURABLE_PROPERTY_EVENT_PHOTOS_SORT_ASCENDING]);
#line 130 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp287_[CONFIGURABLE_PROPERTY_EVENT_PHOTOS_SORT_ASCENDING] = _tmp288_;
#line 130 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp289_ = _tmp287_[CONFIGURABLE_PROPERTY_EVENT_PHOTOS_SORT_ASCENDING];
#line 131 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp290_ = self->priv->key_names;
#line 131 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp290__length1 = self->priv->key_names_length1;
#line 131 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp291_ = g_strdup ("event-photos-sort-by");
#line 131 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp290_[CONFIGURABLE_PROPERTY_EVENT_PHOTOS_SORT_BY]);
#line 131 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp290_[CONFIGURABLE_PROPERTY_EVENT_PHOTOS_SORT_BY] = _tmp291_;
#line 131 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp292_ = _tmp290_[CONFIGURABLE_PROPERTY_EVENT_PHOTOS_SORT_BY];
#line 132 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp293_ = self->priv->key_names;
#line 132 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp293__length1 = self->priv->key_names_length1;
#line 132 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp294_ = g_strdup ("events-sort-ascending");
#line 132 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp293_[CONFIGURABLE_PROPERTY_EVENTS_SORT_ASCENDING]);
#line 132 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp293_[CONFIGURABLE_PROPERTY_EVENTS_SORT_ASCENDING] = _tmp294_;
#line 132 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp295_ = _tmp293_[CONFIGURABLE_PROPERTY_EVENTS_SORT_ASCENDING];
#line 133 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp296_ = self->priv->key_names;
#line 133 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp296__length1 = self->priv->key_names_length1;
#line 133 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp297_ = g_strdup ("constraint");
#line 133 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp296_[CONFIGURABLE_PROPERTY_EXPORT_CONSTRAINT]);
#line 133 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp296_[CONFIGURABLE_PROPERTY_EXPORT_CONSTRAINT] = _tmp297_;
#line 133 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp298_ = _tmp296_[CONFIGURABLE_PROPERTY_EXPORT_CONSTRAINT];
#line 134 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp299_ = self->priv->key_names;
#line 134 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp299__length1 = self->priv->key_names_length1;
#line 134 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp300_ = g_strdup ("export-format-mode");
#line 134 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp299_[CONFIGURABLE_PROPERTY_EXPORT_EXPORT_FORMAT_MODE]);
#line 134 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp299_[CONFIGURABLE_PROPERTY_EXPORT_EXPORT_FORMAT_MODE] = _tmp300_;
#line 134 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp301_ = _tmp299_[CONFIGURABLE_PROPERTY_EXPORT_EXPORT_FORMAT_MODE];
#line 135 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp302_ = self->priv->key_names;
#line 135 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp302__length1 = self->priv->key_names_length1;
#line 135 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp303_ = g_strdup ("export-metadata");
#line 135 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp302_[CONFIGURABLE_PROPERTY_EXPORT_EXPORT_METADATA]);
#line 135 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp302_[CONFIGURABLE_PROPERTY_EXPORT_EXPORT_METADATA] = _tmp303_;
#line 135 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp304_ = _tmp302_[CONFIGURABLE_PROPERTY_EXPORT_EXPORT_METADATA];
#line 136 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp305_ = self->priv->key_names;
#line 136 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp305__length1 = self->priv->key_names_length1;
#line 136 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp306_ = g_strdup ("photo-file-format");
#line 136 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp305_[CONFIGURABLE_PROPERTY_EXPORT_PHOTO_FILE_FORMAT]);
#line 136 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp305_[CONFIGURABLE_PROPERTY_EXPORT_PHOTO_FILE_FORMAT] = _tmp306_;
#line 136 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp307_ = _tmp305_[CONFIGURABLE_PROPERTY_EXPORT_PHOTO_FILE_FORMAT];
#line 137 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp308_ = self->priv->key_names;
#line 137 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp308__length1 = self->priv->key_names_length1;
#line 137 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp309_ = g_strdup ("quality");
#line 137 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp308_[CONFIGURABLE_PROPERTY_EXPORT_QUALITY]);
#line 137 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp308_[CONFIGURABLE_PROPERTY_EXPORT_QUALITY] = _tmp309_;
#line 137 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp310_ = _tmp308_[CONFIGURABLE_PROPERTY_EXPORT_QUALITY];
#line 138 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp311_ = self->priv->key_names;
#line 138 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp311__length1 = self->priv->key_names_length1;
#line 138 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp312_ = g_strdup ("scale");
#line 138 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp311_[CONFIGURABLE_PROPERTY_EXPORT_SCALE]);
#line 138 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp311_[CONFIGURABLE_PROPERTY_EXPORT_SCALE] = _tmp312_;
#line 138 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp313_ = _tmp311_[CONFIGURABLE_PROPERTY_EXPORT_SCALE];
#line 139 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp314_ = self->priv->key_names;
#line 139 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp314__length1 = self->priv->key_names_length1;
#line 139 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp315_ = g_strdup ("external-photo-editor");
#line 139 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp314_[CONFIGURABLE_PROPERTY_EXTERNAL_PHOTO_APP]);
#line 139 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp314_[CONFIGURABLE_PROPERTY_EXTERNAL_PHOTO_APP] = _tmp315_;
#line 139 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp316_ = _tmp314_[CONFIGURABLE_PROPERTY_EXTERNAL_PHOTO_APP];
#line 140 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp317_ = self->priv->key_names;
#line 140 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp317__length1 = self->priv->key_names_length1;
#line 140 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp318_ = g_strdup ("external-raw-editor");
#line 140 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp317_[CONFIGURABLE_PROPERTY_EXTERNAL_RAW_APP]);
#line 140 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp317_[CONFIGURABLE_PROPERTY_EXTERNAL_RAW_APP] = _tmp318_;
#line 140 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp319_ = _tmp317_[CONFIGURABLE_PROPERTY_EXTERNAL_RAW_APP];
#line 141 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp320_ = self->priv->key_names;
#line 141 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp320__length1 = self->priv->key_names_length1;
#line 141 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp321_ = g_strdup ("hide-photos-already-imported");
#line 141 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp320_[CONFIGURABLE_PROPERTY_HIDE_PHOTOS_ALREADY_IMPORTED]);
#line 141 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp320_[CONFIGURABLE_PROPERTY_HIDE_PHOTOS_ALREADY_IMPORTED] = _tmp321_;
#line 141 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp322_ = _tmp320_[CONFIGURABLE_PROPERTY_HIDE_PHOTOS_ALREADY_IMPORTED];
#line 142 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp323_ = self->priv->key_names;
#line 142 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp323__length1 = self->priv->key_names_length1;
#line 142 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp324_ = g_strdup ("import-dir");
#line 142 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp323_[CONFIGURABLE_PROPERTY_IMPORT_DIR]);
#line 142 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp323_[CONFIGURABLE_PROPERTY_IMPORT_DIR] = _tmp324_;
#line 142 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp325_ = _tmp323_[CONFIGURABLE_PROPERTY_IMPORT_DIR];
#line 143 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp326_ = self->priv->key_names;
#line 143 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp326__length1 = self->priv->key_names_length1;
#line 143 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp327_ = g_strdup ("keep-relativity");
#line 143 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp326_[CONFIGURABLE_PROPERTY_KEEP_RELATIVITY]);
#line 143 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp326_[CONFIGURABLE_PROPERTY_KEEP_RELATIVITY] = _tmp327_;
#line 143 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp328_ = _tmp326_[CONFIGURABLE_PROPERTY_KEEP_RELATIVITY];
#line 144 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp329_ = self->priv->key_names;
#line 144 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp329__length1 = self->priv->key_names_length1;
#line 144 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp330_ = g_strdup ("last-crop-height");
#line 144 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp329_[CONFIGURABLE_PROPERTY_LAST_CROP_HEIGHT]);
#line 144 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp329_[CONFIGURABLE_PROPERTY_LAST_CROP_HEIGHT] = _tmp330_;
#line 144 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp331_ = _tmp329_[CONFIGURABLE_PROPERTY_LAST_CROP_HEIGHT];
#line 145 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp332_ = self->priv->key_names;
#line 145 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp332__length1 = self->priv->key_names_length1;
#line 145 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp333_ = g_strdup ("last-crop-menu-choice");
#line 145 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp332_[CONFIGURABLE_PROPERTY_LAST_CROP_MENU_CHOICE]);
#line 145 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp332_[CONFIGURABLE_PROPERTY_LAST_CROP_MENU_CHOICE] = _tmp333_;
#line 145 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp334_ = _tmp332_[CONFIGURABLE_PROPERTY_LAST_CROP_MENU_CHOICE];
#line 146 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp335_ = self->priv->key_names;
#line 146 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp335__length1 = self->priv->key_names_length1;
#line 146 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp336_ = g_strdup ("last-crop-width");
#line 146 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp335_[CONFIGURABLE_PROPERTY_LAST_CROP_WIDTH]);
#line 146 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp335_[CONFIGURABLE_PROPERTY_LAST_CROP_WIDTH] = _tmp336_;
#line 146 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp337_ = _tmp335_[CONFIGURABLE_PROPERTY_LAST_CROP_WIDTH];
#line 147 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp338_ = self->priv->key_names;
#line 147 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp338__length1 = self->priv->key_names_length1;
#line 147 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp339_ = g_strdup ("last-used-service");
#line 147 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp338_[CONFIGURABLE_PROPERTY_LAST_USED_SERVICE]);
#line 147 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp338_[CONFIGURABLE_PROPERTY_LAST_USED_SERVICE] = _tmp339_;
#line 147 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp340_ = _tmp338_[CONFIGURABLE_PROPERTY_LAST_USED_SERVICE];
#line 148 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp341_ = self->priv->key_names;
#line 148 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp341__length1 = self->priv->key_names_length1;
#line 148 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp342_ = g_strdup ("last-used-dataimports-service");
#line 148 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp341_[CONFIGURABLE_PROPERTY_LAST_USED_DATAIMPORTS_SERVICE]);
#line 148 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp341_[CONFIGURABLE_PROPERTY_LAST_USED_DATAIMPORTS_SERVICE] = _tmp342_;
#line 148 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp343_ = _tmp341_[CONFIGURABLE_PROPERTY_LAST_USED_DATAIMPORTS_SERVICE];
#line 149 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp344_ = self->priv->key_names;
#line 149 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp344__length1 = self->priv->key_names_length1;
#line 149 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp345_ = g_strdup ("library-photos-sort-ascending");
#line 149 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp344_[CONFIGURABLE_PROPERTY_LIBRARY_PHOTOS_SORT_ASCENDING]);
#line 149 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp344_[CONFIGURABLE_PROPERTY_LIBRARY_PHOTOS_SORT_ASCENDING] = _tmp345_;
#line 149 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp346_ = _tmp344_[CONFIGURABLE_PROPERTY_LIBRARY_PHOTOS_SORT_ASCENDING];
#line 150 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp347_ = self->priv->key_names;
#line 150 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp347__length1 = self->priv->key_names_length1;
#line 150 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp348_ = g_strdup ("library-photos-sort-by");
#line 150 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp347_[CONFIGURABLE_PROPERTY_LIBRARY_PHOTOS_SORT_BY]);
#line 150 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp347_[CONFIGURABLE_PROPERTY_LIBRARY_PHOTOS_SORT_BY] = _tmp348_;
#line 150 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp349_ = _tmp347_[CONFIGURABLE_PROPERTY_LIBRARY_PHOTOS_SORT_BY];
#line 151 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp350_ = self->priv->key_names;
#line 151 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp350__length1 = self->priv->key_names_length1;
#line 151 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp351_ = g_strdup ("library-height");
#line 151 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp350_[CONFIGURABLE_PROPERTY_LIBRARY_WINDOW_HEIGHT]);
#line 151 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp350_[CONFIGURABLE_PROPERTY_LIBRARY_WINDOW_HEIGHT] = _tmp351_;
#line 151 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp352_ = _tmp350_[CONFIGURABLE_PROPERTY_LIBRARY_WINDOW_HEIGHT];
#line 152 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp353_ = self->priv->key_names;
#line 152 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp353__length1 = self->priv->key_names_length1;
#line 152 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp354_ = g_strdup ("library-maximize");
#line 152 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp353_[CONFIGURABLE_PROPERTY_LIBRARY_WINDOW_MAXIMIZE]);
#line 152 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp353_[CONFIGURABLE_PROPERTY_LIBRARY_WINDOW_MAXIMIZE] = _tmp354_;
#line 152 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp355_ = _tmp353_[CONFIGURABLE_PROPERTY_LIBRARY_WINDOW_MAXIMIZE];
#line 153 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp356_ = self->priv->key_names;
#line 153 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp356__length1 = self->priv->key_names_length1;
#line 153 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp357_ = g_strdup ("library-width");
#line 153 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp356_[CONFIGURABLE_PROPERTY_LIBRARY_WINDOW_WIDTH]);
#line 153 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp356_[CONFIGURABLE_PROPERTY_LIBRARY_WINDOW_WIDTH] = _tmp357_;
#line 153 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp358_ = _tmp356_[CONFIGURABLE_PROPERTY_LIBRARY_WINDOW_WIDTH];
#line 154 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp359_ = self->priv->key_names;
#line 154 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp359__length1 = self->priv->key_names_length1;
#line 154 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp360_ = g_strdup ("modify-originals");
#line 154 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp359_[CONFIGURABLE_PROPERTY_MODIFY_ORIGINALS]);
#line 154 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp359_[CONFIGURABLE_PROPERTY_MODIFY_ORIGINALS] = _tmp360_;
#line 154 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp361_ = _tmp359_[CONFIGURABLE_PROPERTY_MODIFY_ORIGINALS];
#line 155 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp362_ = self->priv->key_names;
#line 155 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp362__length1 = self->priv->key_names_length1;
#line 155 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp363_ = g_strdup ("photo-thumbnail-scale");
#line 155 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp362_[CONFIGURABLE_PROPERTY_PHOTO_THUMBNAIL_SCALE]);
#line 155 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp362_[CONFIGURABLE_PROPERTY_PHOTO_THUMBNAIL_SCALE] = _tmp363_;
#line 155 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp364_ = _tmp362_[CONFIGURABLE_PROPERTY_PHOTO_THUMBNAIL_SCALE];
#line 156 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp365_ = self->priv->key_names;
#line 156 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp365__length1 = self->priv->key_names_length1;
#line 156 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp366_ = g_strdup ("pin-toolbar-state");
#line 156 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp365_[CONFIGURABLE_PROPERTY_PIN_TOOLBAR_STATE]);
#line 156 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp365_[CONFIGURABLE_PROPERTY_PIN_TOOLBAR_STATE] = _tmp366_;
#line 156 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp367_ = _tmp365_[CONFIGURABLE_PROPERTY_PIN_TOOLBAR_STATE];
#line 157 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp368_ = self->priv->key_names;
#line 157 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp368__length1 = self->priv->key_names_length1;
#line 157 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp369_ = g_strdup ("content-height");
#line 157 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp368_[CONFIGURABLE_PROPERTY_PRINTING_CONTENT_HEIGHT]);
#line 157 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp368_[CONFIGURABLE_PROPERTY_PRINTING_CONTENT_HEIGHT] = _tmp369_;
#line 157 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp370_ = _tmp368_[CONFIGURABLE_PROPERTY_PRINTING_CONTENT_HEIGHT];
#line 158 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp371_ = self->priv->key_names;
#line 158 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp371__length1 = self->priv->key_names_length1;
#line 158 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp372_ = g_strdup ("content-layout");
#line 158 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp371_[CONFIGURABLE_PROPERTY_PRINTING_CONTENT_LAYOUT]);
#line 158 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp371_[CONFIGURABLE_PROPERTY_PRINTING_CONTENT_LAYOUT] = _tmp372_;
#line 158 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp373_ = _tmp371_[CONFIGURABLE_PROPERTY_PRINTING_CONTENT_LAYOUT];
#line 159 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp374_ = self->priv->key_names;
#line 159 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp374__length1 = self->priv->key_names_length1;
#line 159 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp375_ = g_strdup ("content-ppi");
#line 159 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp374_[CONFIGURABLE_PROPERTY_PRINTING_CONTENT_PPI]);
#line 159 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp374_[CONFIGURABLE_PROPERTY_PRINTING_CONTENT_PPI] = _tmp375_;
#line 159 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp376_ = _tmp374_[CONFIGURABLE_PROPERTY_PRINTING_CONTENT_PPI];
#line 160 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp377_ = self->priv->key_names;
#line 160 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp377__length1 = self->priv->key_names_length1;
#line 160 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp378_ = g_strdup ("content-units");
#line 160 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp377_[CONFIGURABLE_PROPERTY_PRINTING_CONTENT_UNITS]);
#line 160 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp377_[CONFIGURABLE_PROPERTY_PRINTING_CONTENT_UNITS] = _tmp378_;
#line 160 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp379_ = _tmp377_[CONFIGURABLE_PROPERTY_PRINTING_CONTENT_UNITS];
#line 161 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp380_ = self->priv->key_names;
#line 161 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp380__length1 = self->priv->key_names_length1;
#line 161 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp381_ = g_strdup ("content-width");
#line 161 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp380_[CONFIGURABLE_PROPERTY_PRINTING_CONTENT_WIDTH]);
#line 161 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp380_[CONFIGURABLE_PROPERTY_PRINTING_CONTENT_WIDTH] = _tmp381_;
#line 161 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp382_ = _tmp380_[CONFIGURABLE_PROPERTY_PRINTING_CONTENT_WIDTH];
#line 162 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp383_ = self->priv->key_names;
#line 162 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp383__length1 = self->priv->key_names_length1;
#line 162 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp384_ = g_strdup ("images-per-page");
#line 162 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp383_[CONFIGURABLE_PROPERTY_PRINTING_IMAGES_PER_PAGE]);
#line 162 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp383_[CONFIGURABLE_PROPERTY_PRINTING_IMAGES_PER_PAGE] = _tmp384_;
#line 162 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp385_ = _tmp383_[CONFIGURABLE_PROPERTY_PRINTING_IMAGES_PER_PAGE];
#line 163 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp386_ = self->priv->key_names;
#line 163 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp386__length1 = self->priv->key_names_length1;
#line 163 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp387_ = g_strdup ("match-aspect-ratio");
#line 163 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp386_[CONFIGURABLE_PROPERTY_PRINTING_MATCH_ASPECT_RATIO]);
#line 163 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp386_[CONFIGURABLE_PROPERTY_PRINTING_MATCH_ASPECT_RATIO] = _tmp387_;
#line 163 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp388_ = _tmp386_[CONFIGURABLE_PROPERTY_PRINTING_MATCH_ASPECT_RATIO];
#line 164 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp389_ = self->priv->key_names;
#line 164 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp389__length1 = self->priv->key_names_length1;
#line 164 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp390_ = g_strdup ("print-titles");
#line 164 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp389_[CONFIGURABLE_PROPERTY_PRINTING_PRINT_TITLES]);
#line 164 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp389_[CONFIGURABLE_PROPERTY_PRINTING_PRINT_TITLES] = _tmp390_;
#line 164 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp391_ = _tmp389_[CONFIGURABLE_PROPERTY_PRINTING_PRINT_TITLES];
#line 165 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp392_ = self->priv->key_names;
#line 165 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp392__length1 = self->priv->key_names_length1;
#line 165 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp393_ = g_strdup ("size-selection");
#line 165 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp392_[CONFIGURABLE_PROPERTY_PRINTING_SIZE_SELECTION]);
#line 165 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp392_[CONFIGURABLE_PROPERTY_PRINTING_SIZE_SELECTION] = _tmp393_;
#line 165 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp394_ = _tmp392_[CONFIGURABLE_PROPERTY_PRINTING_SIZE_SELECTION];
#line 166 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp395_ = self->priv->key_names;
#line 166 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp395__length1 = self->priv->key_names_length1;
#line 166 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp396_ = g_strdup ("titles-font");
#line 166 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp395_[CONFIGURABLE_PROPERTY_PRINTING_TITLES_FONT]);
#line 166 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp395_[CONFIGURABLE_PROPERTY_PRINTING_TITLES_FONT] = _tmp396_;
#line 166 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp397_ = _tmp395_[CONFIGURABLE_PROPERTY_PRINTING_TITLES_FONT];
#line 167 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp398_ = self->priv->key_names;
#line 167 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp398__length1 = self->priv->key_names_length1;
#line 167 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp399_ = g_strdup ("raw-developer-default");
#line 167 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp398_[CONFIGURABLE_PROPERTY_RAW_DEVELOPER_DEFAULT]);
#line 167 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp398_[CONFIGURABLE_PROPERTY_RAW_DEVELOPER_DEFAULT] = _tmp399_;
#line 167 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp400_ = _tmp398_[CONFIGURABLE_PROPERTY_RAW_DEVELOPER_DEFAULT];
#line 168 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp401_ = self->priv->key_names;
#line 168 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp401__length1 = self->priv->key_names_length1;
#line 168 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp402_ = g_strdup ("show-welcome-dialog");
#line 168 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp401_[CONFIGURABLE_PROPERTY_SHOW_WELCOME_DIALOG]);
#line 168 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp401_[CONFIGURABLE_PROPERTY_SHOW_WELCOME_DIALOG] = _tmp402_;
#line 168 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp403_ = _tmp401_[CONFIGURABLE_PROPERTY_SHOW_WELCOME_DIALOG];
#line 169 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp404_ = self->priv->key_names;
#line 169 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp404__length1 = self->priv->key_names_length1;
#line 169 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp405_ = g_strdup ("sidebar-position");
#line 169 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp404_[CONFIGURABLE_PROPERTY_SIDEBAR_POSITION]);
#line 169 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp404_[CONFIGURABLE_PROPERTY_SIDEBAR_POSITION] = _tmp405_;
#line 169 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp406_ = _tmp404_[CONFIGURABLE_PROPERTY_SIDEBAR_POSITION];
#line 170 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp407_ = self->priv->key_names;
#line 170 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp407__length1 = self->priv->key_names_length1;
#line 170 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp408_ = g_strdup ("delay");
#line 170 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp407_[CONFIGURABLE_PROPERTY_SLIDESHOW_DELAY]);
#line 170 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp407_[CONFIGURABLE_PROPERTY_SLIDESHOW_DELAY] = _tmp408_;
#line 170 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp409_ = _tmp407_[CONFIGURABLE_PROPERTY_SLIDESHOW_DELAY];
#line 171 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp410_ = self->priv->key_names;
#line 171 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp410__length1 = self->priv->key_names_length1;
#line 171 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp411_ = g_strdup ("transition-delay");
#line 171 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp410_[CONFIGURABLE_PROPERTY_SLIDESHOW_TRANSITION_DELAY]);
#line 171 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp410_[CONFIGURABLE_PROPERTY_SLIDESHOW_TRANSITION_DELAY] = _tmp411_;
#line 171 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp412_ = _tmp410_[CONFIGURABLE_PROPERTY_SLIDESHOW_TRANSITION_DELAY];
#line 172 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp413_ = self->priv->key_names;
#line 172 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp413__length1 = self->priv->key_names_length1;
#line 172 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp414_ = g_strdup ("transition-effect-id");
#line 172 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp413_[CONFIGURABLE_PROPERTY_SLIDESHOW_TRANSITION_EFFECT_ID]);
#line 172 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp413_[CONFIGURABLE_PROPERTY_SLIDESHOW_TRANSITION_EFFECT_ID] = _tmp414_;
#line 172 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp415_ = _tmp413_[CONFIGURABLE_PROPERTY_SLIDESHOW_TRANSITION_EFFECT_ID];
#line 173 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp416_ = self->priv->key_names;
#line 173 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp416__length1 = self->priv->key_names_length1;
#line 173 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp417_ = g_strdup ("show-title");
#line 173 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp416_[CONFIGURABLE_PROPERTY_SLIDESHOW_SHOW_TITLE]);
#line 173 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp416_[CONFIGURABLE_PROPERTY_SLIDESHOW_SHOW_TITLE] = _tmp417_;
#line 173 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp418_ = _tmp416_[CONFIGURABLE_PROPERTY_SLIDESHOW_SHOW_TITLE];
#line 174 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp419_ = self->priv->key_names;
#line 174 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp419__length1 = self->priv->key_names_length1;
#line 174 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp420_ = g_strdup ("use-24-hour-time");
#line 174 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp419_[CONFIGURABLE_PROPERTY_USE_24_HOUR_TIME]);
#line 174 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp419_[CONFIGURABLE_PROPERTY_USE_24_HOUR_TIME] = _tmp420_;
#line 174 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp421_ = _tmp419_[CONFIGURABLE_PROPERTY_USE_24_HOUR_TIME];
#line 175 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp422_ = self->priv->key_names;
#line 175 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp422__length1 = self->priv->key_names_length1;
#line 175 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp423_ = g_strdup ("use-lowercase-filenames");
#line 175 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp422_[CONFIGURABLE_PROPERTY_USE_LOWERCASE_FILENAMES]);
#line 175 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp422_[CONFIGURABLE_PROPERTY_USE_LOWERCASE_FILENAMES] = _tmp423_;
#line 175 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp424_ = _tmp422_[CONFIGURABLE_PROPERTY_USE_LOWERCASE_FILENAMES];
#line 176 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp425_ = self->priv->key_names;
#line 176 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp425__length1 = self->priv->key_names_length1;
#line 176 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp426_ = g_strdup ("interpreter-state-cookie");
#line 176 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp425_[CONFIGURABLE_PROPERTY_VIDEO_INTERPRETER_STATE_COOKIE]);
#line 176 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp425_[CONFIGURABLE_PROPERTY_VIDEO_INTERPRETER_STATE_COOKIE] = _tmp426_;
#line 176 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp427_ = _tmp425_[CONFIGURABLE_PROPERTY_VIDEO_INTERPRETER_STATE_COOKIE];
#line 29 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	return self;
#line 2670 "GSettingsEngine.c"
}


GSettingsConfigurationEngine*
gsettings_configuration_engine_new (void)
{
#line 29 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	return gsettings_configuration_engine_construct (TYPE_GSETTINGS_CONFIGURATION_ENGINE);
#line 2679 "GSettingsEngine.c"
}


static gpointer
_g_settings_schema_source_ref0 (gpointer self)
{
#line 180 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	return self ? g_settings_schema_source_ref (self) : NULL;
#line 2688 "GSettingsEngine.c"
}


static void
gsettings_configuration_engine_check_key_valid (GSettingsConfigurationEngine* self,
                                                const gchar* schema,
                                                const gchar* key,
                                                GError** error)
{
	GSettingsSchemaSource* schema_source = NULL;
	GSettingsSchemaSource* _tmp0_;
	GSettingsSchemaSource* _tmp1_;
	GSettingsSchema* settings_scheme = NULL;
	GSettingsSchemaSource* _tmp2_;
	GSettingsSchema* _tmp3_;
	GSettingsSchema* _tmp4_;
	GSettingsSchema* _tmp9_;
	GError * _inner_error_ = NULL;
#line 179 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	g_return_if_fail (IS_GSETTINGS_CONFIGURATION_ENGINE (self));
#line 179 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	g_return_if_fail (schema != NULL);
#line 179 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	g_return_if_fail (key != NULL);
#line 180 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp0_ = g_settings_schema_source_get_default ();
#line 180 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp1_ = _g_settings_schema_source_ref0 (_tmp0_);
#line 180 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	schema_source = _tmp1_;
#line 181 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp2_ = schema_source;
#line 181 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp3_ = g_settings_schema_source_lookup (_tmp2_, schema, TRUE);
#line 181 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	settings_scheme = _tmp3_;
#line 182 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp4_ = settings_scheme;
#line 182 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	if (_tmp4_ == NULL) {
#line 2729 "GSettingsEngine.c"
		gchar* _tmp5_;
		gchar* _tmp6_;
		GError* _tmp7_;
		GError* _tmp8_;
#line 183 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_tmp5_ = g_strdup_printf ("schema '%s' is not installed", schema);
#line 183 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_tmp6_ = _tmp5_;
#line 183 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_tmp7_ = g_error_new_literal (CONFIGURATION_ERROR, CONFIGURATION_ERROR_ENGINE_ERROR, _tmp6_);
#line 183 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_tmp8_ = _tmp7_;
#line 183 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_g_free0 (_tmp6_);
#line 183 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_inner_error_ = _tmp8_;
#line 183 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		if (_inner_error_->domain == CONFIGURATION_ERROR) {
#line 183 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			g_propagate_error (error, _inner_error_);
#line 183 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			_g_settings_schema_unref0 (settings_scheme);
#line 183 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			_g_settings_schema_source_unref0 (schema_source);
#line 183 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			return;
#line 2756 "GSettingsEngine.c"
		} else {
#line 183 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			_g_settings_schema_unref0 (settings_scheme);
#line 183 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			_g_settings_schema_source_unref0 (schema_source);
#line 183 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 183 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			g_clear_error (&_inner_error_);
#line 183 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			return;
#line 2768 "GSettingsEngine.c"
		}
	}
#line 186 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp9_ = settings_scheme;
#line 186 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	if (!g_settings_schema_has_key (_tmp9_, key)) {
#line 2775 "GSettingsEngine.c"
		gchar* _tmp10_;
		gchar* _tmp11_;
		GError* _tmp12_;
		GError* _tmp13_;
#line 187 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_tmp10_ = g_strdup_printf ("schema '%s' does not define key '%s'", schema, key);
#line 187 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_tmp11_ = _tmp10_;
#line 187 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_tmp12_ = g_error_new_literal (CONFIGURATION_ERROR, CONFIGURATION_ERROR_ENGINE_ERROR, _tmp11_);
#line 187 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_tmp13_ = _tmp12_;
#line 187 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_g_free0 (_tmp11_);
#line 187 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_inner_error_ = _tmp13_;
#line 187 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		if (_inner_error_->domain == CONFIGURATION_ERROR) {
#line 187 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			g_propagate_error (error, _inner_error_);
#line 187 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			_g_settings_schema_unref0 (settings_scheme);
#line 187 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			_g_settings_schema_source_unref0 (schema_source);
#line 187 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			return;
#line 2802 "GSettingsEngine.c"
		} else {
#line 187 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			_g_settings_schema_unref0 (settings_scheme);
#line 187 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			_g_settings_schema_source_unref0 (schema_source);
#line 187 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 187 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			g_clear_error (&_inner_error_);
#line 187 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			return;
#line 2814 "GSettingsEngine.c"
		}
	}
#line 179 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_settings_schema_unref0 (settings_scheme);
#line 179 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_settings_schema_source_unref0 (schema_source);
#line 2821 "GSettingsEngine.c"
}


static gboolean
gsettings_configuration_engine_get_gs_bool (GSettingsConfigurationEngine* self,
                                            const gchar* schema,
                                            const gchar* key,
                                            GError** error)
{
	gboolean result = FALSE;
	GSettings* schema_object = NULL;
	GSettings* _tmp2_;
	GSettings* _tmp3_;
	GError * _inner_error_ = NULL;
#line 191 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	g_return_val_if_fail (IS_GSETTINGS_CONFIGURATION_ENGINE (self), FALSE);
#line 191 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	g_return_val_if_fail (schema != NULL, FALSE);
#line 191 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	g_return_val_if_fail (key != NULL, FALSE);
#line 192 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	gsettings_configuration_engine_check_key_valid (self, schema, key, &_inner_error_);
#line 192 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 192 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		if (_inner_error_->domain == CONFIGURATION_ERROR) {
#line 2848 "GSettingsEngine.c"
			gboolean _tmp0_ = FALSE;
#line 192 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			g_propagate_error (error, _inner_error_);
#line 192 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			return _tmp0_;
#line 2854 "GSettingsEngine.c"
		} else {
			gboolean _tmp1_ = FALSE;
#line 192 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 192 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			g_clear_error (&_inner_error_);
#line 192 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			return _tmp1_;
#line 2863 "GSettingsEngine.c"
		}
	}
#line 194 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp2_ = g_settings_new (schema);
#line 194 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	schema_object = _tmp2_;
#line 196 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp3_ = schema_object;
#line 196 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	result = g_settings_get_boolean (_tmp3_, key);
#line 196 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_object_unref0 (schema_object);
#line 196 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	return result;
#line 2878 "GSettingsEngine.c"
}


static void
gsettings_configuration_engine_set_gs_bool (GSettingsConfigurationEngine* self,
                                            const gchar* schema,
                                            const gchar* key,
                                            gboolean value,
                                            GError** error)
{
	GSettings* schema_object = NULL;
	GSettings* _tmp0_;
	GSettings* _tmp1_;
	GError * _inner_error_ = NULL;
#line 199 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	g_return_if_fail (IS_GSETTINGS_CONFIGURATION_ENGINE (self));
#line 199 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	g_return_if_fail (schema != NULL);
#line 199 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	g_return_if_fail (key != NULL);
#line 200 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	gsettings_configuration_engine_check_key_valid (self, schema, key, &_inner_error_);
#line 200 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 200 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		if (_inner_error_->domain == CONFIGURATION_ERROR) {
#line 200 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			g_propagate_error (error, _inner_error_);
#line 200 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			return;
#line 2909 "GSettingsEngine.c"
		} else {
#line 200 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 200 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			g_clear_error (&_inner_error_);
#line 200 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			return;
#line 2917 "GSettingsEngine.c"
		}
	}
#line 202 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp0_ = g_settings_new (schema);
#line 202 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	schema_object = _tmp0_;
#line 204 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp1_ = schema_object;
#line 204 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	g_settings_set_boolean (_tmp1_, key, value);
#line 199 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_object_unref0 (schema_object);
#line 2930 "GSettingsEngine.c"
}


static void
gsettings_configuration_engine_set_gs_enum (GSettingsConfigurationEngine* self,
                                            const gchar* schema,
                                            const gchar* key,
                                            gint value,
                                            GError** error)
{
	GSettings* schema_object = NULL;
	GSettings* _tmp0_;
	GSettings* _tmp1_;
	GError * _inner_error_ = NULL;
#line 207 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	g_return_if_fail (IS_GSETTINGS_CONFIGURATION_ENGINE (self));
#line 207 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	g_return_if_fail (schema != NULL);
#line 207 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	g_return_if_fail (key != NULL);
#line 208 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	gsettings_configuration_engine_check_key_valid (self, schema, key, &_inner_error_);
#line 208 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 208 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		if (_inner_error_->domain == CONFIGURATION_ERROR) {
#line 208 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			g_propagate_error (error, _inner_error_);
#line 208 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			return;
#line 2961 "GSettingsEngine.c"
		} else {
#line 208 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 208 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			g_clear_error (&_inner_error_);
#line 208 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			return;
#line 2969 "GSettingsEngine.c"
		}
	}
#line 210 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp0_ = g_settings_new (schema);
#line 210 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	schema_object = _tmp0_;
#line 211 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp1_ = schema_object;
#line 211 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	g_settings_set_enum (_tmp1_, key, value);
#line 207 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_object_unref0 (schema_object);
#line 2982 "GSettingsEngine.c"
}


static gint
gsettings_configuration_engine_get_gs_enum (GSettingsConfigurationEngine* self,
                                            const gchar* schema,
                                            const gchar* key,
                                            GError** error)
{
	gint result = 0;
	GSettings* schema_object = NULL;
	GSettings* _tmp2_;
	GSettings* _tmp3_;
	GError * _inner_error_ = NULL;
#line 214 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	g_return_val_if_fail (IS_GSETTINGS_CONFIGURATION_ENGINE (self), 0);
#line 214 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	g_return_val_if_fail (schema != NULL, 0);
#line 214 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	g_return_val_if_fail (key != NULL, 0);
#line 215 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	gsettings_configuration_engine_check_key_valid (self, schema, key, &_inner_error_);
#line 215 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 215 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		if (_inner_error_->domain == CONFIGURATION_ERROR) {
#line 3009 "GSettingsEngine.c"
			gint _tmp0_ = 0;
#line 215 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			g_propagate_error (error, _inner_error_);
#line 215 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			return _tmp0_;
#line 3015 "GSettingsEngine.c"
		} else {
			gint _tmp1_ = 0;
#line 215 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 215 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			g_clear_error (&_inner_error_);
#line 215 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			return _tmp1_;
#line 3024 "GSettingsEngine.c"
		}
	}
#line 217 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp2_ = g_settings_new (schema);
#line 217 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	schema_object = _tmp2_;
#line 218 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp3_ = schema_object;
#line 218 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	result = g_settings_get_enum (_tmp3_, key);
#line 218 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_object_unref0 (schema_object);
#line 218 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	return result;
#line 3039 "GSettingsEngine.c"
}


static gint
gsettings_configuration_engine_get_gs_int (GSettingsConfigurationEngine* self,
                                           const gchar* schema,
                                           const gchar* key,
                                           GError** error)
{
	gint result = 0;
	GSettings* schema_object = NULL;
	GSettings* _tmp2_;
	GSettings* _tmp3_;
	GError * _inner_error_ = NULL;
#line 221 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	g_return_val_if_fail (IS_GSETTINGS_CONFIGURATION_ENGINE (self), 0);
#line 221 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	g_return_val_if_fail (schema != NULL, 0);
#line 221 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	g_return_val_if_fail (key != NULL, 0);
#line 222 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	gsettings_configuration_engine_check_key_valid (self, schema, key, &_inner_error_);
#line 222 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 222 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		if (_inner_error_->domain == CONFIGURATION_ERROR) {
#line 3066 "GSettingsEngine.c"
			gint _tmp0_ = 0;
#line 222 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			g_propagate_error (error, _inner_error_);
#line 222 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			return _tmp0_;
#line 3072 "GSettingsEngine.c"
		} else {
			gint _tmp1_ = 0;
#line 222 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 222 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			g_clear_error (&_inner_error_);
#line 222 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			return _tmp1_;
#line 3081 "GSettingsEngine.c"
		}
	}
#line 224 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp2_ = g_settings_new (schema);
#line 224 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	schema_object = _tmp2_;
#line 226 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp3_ = schema_object;
#line 226 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	result = g_settings_get_int (_tmp3_, key);
#line 226 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_object_unref0 (schema_object);
#line 226 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	return result;
#line 3096 "GSettingsEngine.c"
}


static void
gsettings_configuration_engine_set_gs_int (GSettingsConfigurationEngine* self,
                                           const gchar* schema,
                                           const gchar* key,
                                           gint value,
                                           GError** error)
{
	GSettings* schema_object = NULL;
	GSettings* _tmp0_;
	GSettings* _tmp1_;
	GError * _inner_error_ = NULL;
#line 229 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	g_return_if_fail (IS_GSETTINGS_CONFIGURATION_ENGINE (self));
#line 229 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	g_return_if_fail (schema != NULL);
#line 229 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	g_return_if_fail (key != NULL);
#line 230 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	gsettings_configuration_engine_check_key_valid (self, schema, key, &_inner_error_);
#line 230 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 230 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		if (_inner_error_->domain == CONFIGURATION_ERROR) {
#line 230 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			g_propagate_error (error, _inner_error_);
#line 230 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			return;
#line 3127 "GSettingsEngine.c"
		} else {
#line 230 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 230 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			g_clear_error (&_inner_error_);
#line 230 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			return;
#line 3135 "GSettingsEngine.c"
		}
	}
#line 232 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp0_ = g_settings_new (schema);
#line 232 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	schema_object = _tmp0_;
#line 234 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp1_ = schema_object;
#line 234 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	g_settings_set_int (_tmp1_, key, value);
#line 229 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_object_unref0 (schema_object);
#line 3148 "GSettingsEngine.c"
}


static gdouble
gsettings_configuration_engine_get_gs_double (GSettingsConfigurationEngine* self,
                                              const gchar* schema,
                                              const gchar* key,
                                              GError** error)
{
	gdouble result = 0.0;
	GSettings* schema_object = NULL;
	GSettings* _tmp2_;
	GSettings* _tmp3_;
	GError * _inner_error_ = NULL;
#line 237 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	g_return_val_if_fail (IS_GSETTINGS_CONFIGURATION_ENGINE (self), 0.0);
#line 237 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	g_return_val_if_fail (schema != NULL, 0.0);
#line 237 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	g_return_val_if_fail (key != NULL, 0.0);
#line 238 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	gsettings_configuration_engine_check_key_valid (self, schema, key, &_inner_error_);
#line 238 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 238 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		if (_inner_error_->domain == CONFIGURATION_ERROR) {
#line 3175 "GSettingsEngine.c"
			gdouble _tmp0_ = 0.0;
#line 238 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			g_propagate_error (error, _inner_error_);
#line 238 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			return _tmp0_;
#line 3181 "GSettingsEngine.c"
		} else {
			gdouble _tmp1_ = 0.0;
#line 238 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 238 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			g_clear_error (&_inner_error_);
#line 238 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			return _tmp1_;
#line 3190 "GSettingsEngine.c"
		}
	}
#line 240 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp2_ = g_settings_new (schema);
#line 240 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	schema_object = _tmp2_;
#line 242 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp3_ = schema_object;
#line 242 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	result = g_settings_get_double (_tmp3_, key);
#line 242 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_object_unref0 (schema_object);
#line 242 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	return result;
#line 3205 "GSettingsEngine.c"
}


static void
gsettings_configuration_engine_set_gs_double (GSettingsConfigurationEngine* self,
                                              const gchar* schema,
                                              const gchar* key,
                                              gdouble value,
                                              GError** error)
{
	GSettings* schema_object = NULL;
	GSettings* _tmp0_;
	GSettings* _tmp1_;
	GError * _inner_error_ = NULL;
#line 245 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	g_return_if_fail (IS_GSETTINGS_CONFIGURATION_ENGINE (self));
#line 245 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	g_return_if_fail (schema != NULL);
#line 245 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	g_return_if_fail (key != NULL);
#line 246 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	gsettings_configuration_engine_check_key_valid (self, schema, key, &_inner_error_);
#line 246 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 246 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		if (_inner_error_->domain == CONFIGURATION_ERROR) {
#line 246 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			g_propagate_error (error, _inner_error_);
#line 246 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			return;
#line 3236 "GSettingsEngine.c"
		} else {
#line 246 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 246 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			g_clear_error (&_inner_error_);
#line 246 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			return;
#line 3244 "GSettingsEngine.c"
		}
	}
#line 248 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp0_ = g_settings_new (schema);
#line 248 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	schema_object = _tmp0_;
#line 250 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp1_ = schema_object;
#line 250 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	g_settings_set_double (_tmp1_, key, value);
#line 245 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_object_unref0 (schema_object);
#line 3257 "GSettingsEngine.c"
}


static gchar*
gsettings_configuration_engine_get_gs_string (GSettingsConfigurationEngine* self,
                                              const gchar* schema,
                                              const gchar* key,
                                              GError** error)
{
	gchar* result = NULL;
	GSettings* schema_object = NULL;
	GSettings* _tmp0_;
	GSettings* _tmp1_;
	gchar* _tmp2_;
	GError * _inner_error_ = NULL;
#line 253 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	g_return_val_if_fail (IS_GSETTINGS_CONFIGURATION_ENGINE (self), NULL);
#line 253 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	g_return_val_if_fail (schema != NULL, NULL);
#line 253 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	g_return_val_if_fail (key != NULL, NULL);
#line 254 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	gsettings_configuration_engine_check_key_valid (self, schema, key, &_inner_error_);
#line 254 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 254 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		if (_inner_error_->domain == CONFIGURATION_ERROR) {
#line 254 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			g_propagate_error (error, _inner_error_);
#line 254 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			return NULL;
#line 3289 "GSettingsEngine.c"
		} else {
#line 254 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 254 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			g_clear_error (&_inner_error_);
#line 254 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			return NULL;
#line 3297 "GSettingsEngine.c"
		}
	}
#line 256 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp0_ = g_settings_new (schema);
#line 256 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	schema_object = _tmp0_;
#line 258 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp1_ = schema_object;
#line 258 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp2_ = g_settings_get_string (_tmp1_, key);
#line 258 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	result = _tmp2_;
#line 258 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_object_unref0 (schema_object);
#line 258 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	return result;
#line 3314 "GSettingsEngine.c"
}


static void
gsettings_configuration_engine_set_gs_string (GSettingsConfigurationEngine* self,
                                              const gchar* schema,
                                              const gchar* key,
                                              const gchar* value,
                                              GError** error)
{
	GSettings* schema_object = NULL;
	GSettings* _tmp0_;
	GSettings* _tmp1_;
	GError * _inner_error_ = NULL;
#line 261 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	g_return_if_fail (IS_GSETTINGS_CONFIGURATION_ENGINE (self));
#line 261 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	g_return_if_fail (schema != NULL);
#line 261 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	g_return_if_fail (key != NULL);
#line 261 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	g_return_if_fail (value != NULL);
#line 262 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	gsettings_configuration_engine_check_key_valid (self, schema, key, &_inner_error_);
#line 262 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 262 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		if (_inner_error_->domain == CONFIGURATION_ERROR) {
#line 262 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			g_propagate_error (error, _inner_error_);
#line 262 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			return;
#line 3347 "GSettingsEngine.c"
		} else {
#line 262 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 262 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			g_clear_error (&_inner_error_);
#line 262 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			return;
#line 3355 "GSettingsEngine.c"
		}
	}
#line 264 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp0_ = g_settings_new (schema);
#line 264 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	schema_object = _tmp0_;
#line 266 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp1_ = schema_object;
#line 266 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	g_settings_set_string (_tmp1_, key, value);
#line 261 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_object_unref0 (schema_object);
#line 3368 "GSettingsEngine.c"
}


static void
gsettings_configuration_engine_reset_gs_to_default (GSettingsConfigurationEngine* self,
                                                    const gchar* schema,
                                                    const gchar* key,
                                                    GError** error)
{
	GSettings* schema_object = NULL;
	GSettings* _tmp0_;
	GSettings* _tmp1_;
	GError * _inner_error_ = NULL;
#line 269 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	g_return_if_fail (IS_GSETTINGS_CONFIGURATION_ENGINE (self));
#line 269 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	g_return_if_fail (schema != NULL);
#line 269 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	g_return_if_fail (key != NULL);
#line 270 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	gsettings_configuration_engine_check_key_valid (self, schema, key, &_inner_error_);
#line 270 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 270 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		if (_inner_error_->domain == CONFIGURATION_ERROR) {
#line 270 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			g_propagate_error (error, _inner_error_);
#line 270 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			return;
#line 3398 "GSettingsEngine.c"
		} else {
#line 270 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 270 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			g_clear_error (&_inner_error_);
#line 270 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			return;
#line 3406 "GSettingsEngine.c"
		}
	}
#line 272 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp0_ = g_settings_new (schema);
#line 272 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	schema_object = _tmp0_;
#line 274 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp1_ = schema_object;
#line 274 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	g_settings_reset (_tmp1_, key);
#line 269 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_object_unref0 (schema_object);
#line 3419 "GSettingsEngine.c"
}


static gchar*
string_replace (const gchar* self,
                const gchar* old,
                const gchar* replacement)
{
	gchar* result = NULL;
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_ = FALSE;
	GError * _inner_error_ = NULL;
#line 1421 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, NULL);
#line 1421 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	g_return_val_if_fail (old != NULL, NULL);
#line 1421 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	g_return_val_if_fail (replacement != NULL, NULL);
#line 1422 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	if ((*((gchar*) self)) == '\0') {
#line 1422 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		_tmp1_ = TRUE;
#line 3442 "GSettingsEngine.c"
	} else {
#line 1422 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		_tmp1_ = (*((gchar*) old)) == '\0';
#line 3446 "GSettingsEngine.c"
	}
#line 1422 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	if (_tmp1_) {
#line 1422 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		_tmp0_ = TRUE;
#line 3452 "GSettingsEngine.c"
	} else {
#line 1422 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		_tmp0_ = g_strcmp0 (old, replacement) == 0;
#line 3456 "GSettingsEngine.c"
	}
#line 1422 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	if (_tmp0_) {
#line 3460 "GSettingsEngine.c"
		gchar* _tmp2_;
#line 1423 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		_tmp2_ = g_strdup (self);
#line 1423 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		result = _tmp2_;
#line 1423 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		return result;
#line 3468 "GSettingsEngine.c"
	}
	{
		GRegex* regex = NULL;
		gchar* _tmp3_;
		gchar* _tmp4_;
		GRegex* _tmp5_;
		GRegex* _tmp6_;
		gchar* _tmp7_ = NULL;
		GRegex* _tmp8_;
		gchar* _tmp9_;
		gchar* _tmp10_;
#line 1426 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		_tmp3_ = g_regex_escape_string (old, -1);
#line 1426 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		_tmp4_ = _tmp3_;
#line 1426 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		_tmp5_ = g_regex_new (_tmp4_, 0, 0, &_inner_error_);
#line 1426 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		_tmp6_ = _tmp5_;
#line 1426 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		_g_free0 (_tmp4_);
#line 1426 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		regex = _tmp6_;
#line 1426 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1426 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
			if (_inner_error_->domain == G_REGEX_ERROR) {
#line 3496 "GSettingsEngine.c"
				goto __catch217_g_regex_error;
			}
#line 1426 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1426 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
			g_clear_error (&_inner_error_);
#line 1426 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
			return NULL;
#line 3505 "GSettingsEngine.c"
		}
#line 1427 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		_tmp8_ = regex;
#line 1427 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		_tmp9_ = g_regex_replace_literal (_tmp8_, self, (gssize) -1, 0, replacement, 0, &_inner_error_);
#line 1427 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		_tmp7_ = _tmp9_;
#line 1427 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1427 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
			_g_regex_unref0 (regex);
#line 1427 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
			if (_inner_error_->domain == G_REGEX_ERROR) {
#line 3519 "GSettingsEngine.c"
				goto __catch217_g_regex_error;
			}
#line 1427 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
			_g_regex_unref0 (regex);
#line 1427 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1427 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
			g_clear_error (&_inner_error_);
#line 1427 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
			return NULL;
#line 3530 "GSettingsEngine.c"
		}
#line 1427 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		_tmp10_ = _tmp7_;
#line 1427 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		_tmp7_ = NULL;
#line 1427 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		result = _tmp10_;
#line 1427 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		_g_free0 (_tmp7_);
#line 1427 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		_g_regex_unref0 (regex);
#line 1427 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		return result;
#line 3544 "GSettingsEngine.c"
	}
	goto __finally217;
	__catch217_g_regex_error:
	{
		GError* e = NULL;
#line 1425 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		e = _inner_error_;
#line 1425 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		_inner_error_ = NULL;
#line 1429 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		g_assert_not_reached ();
#line 1425 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		_g_error_free0 (e);
#line 3558 "GSettingsEngine.c"
	}
	__finally217:
#line 1425 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1425 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1425 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		g_clear_error (&_inner_error_);
#line 1425 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		return NULL;
#line 3569 "GSettingsEngine.c"
	}
}


static gchar*
string_strip (const gchar* self)
{
	gchar* result = NULL;
	gchar* _result_ = NULL;
	gchar* _tmp0_;
	const gchar* _tmp1_;
#line 1248 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, NULL);
#line 1249 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	_tmp0_ = g_strdup (self);
#line 1249 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	_result_ = _tmp0_;
#line 1250 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	_tmp1_ = _result_;
#line 1250 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	g_strstrip (_tmp1_);
#line 1251 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	result = _result_;
#line 1251 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	return result;
#line 3595 "GSettingsEngine.c"
}


static gchar*
gsettings_configuration_engine_clean_plugin_id (const gchar* id)
{
	gchar* result = NULL;
	gchar* cleaned = NULL;
	gchar* _tmp0_;
	const gchar* _tmp1_;
	gchar* _tmp2_;
	const gchar* _tmp3_ = NULL;
	const gchar* _tmp4_;
	gchar* _tmp6_;
#line 277 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	g_return_val_if_fail (id != NULL, NULL);
#line 278 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp0_ = string_replace (id, "/", "-");
#line 278 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	cleaned = _tmp0_;
#line 279 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp1_ = cleaned;
#line 279 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp2_ = string_strip (_tmp1_);
#line 279 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (cleaned);
#line 279 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	cleaned = _tmp2_;
#line 281 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp4_ = cleaned;
#line 281 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	if (!is_string_empty (_tmp4_)) {
#line 3628 "GSettingsEngine.c"
		const gchar* _tmp5_;
#line 281 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_tmp5_ = cleaned;
#line 281 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_tmp3_ = _tmp5_;
#line 3634 "GSettingsEngine.c"
	} else {
#line 281 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_tmp3_ = NULL;
#line 3638 "GSettingsEngine.c"
	}
#line 281 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp6_ = g_strdup (_tmp3_);
#line 281 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	result = _tmp6_;
#line 281 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (cleaned);
#line 281 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	return result;
#line 3648 "GSettingsEngine.c"
}


static gchar*
gsettings_configuration_engine_get_plugin_enable_disable_name (const gchar* id)
{
	gchar* result = NULL;
	gchar* cleaned_id = NULL;
	gchar* _tmp0_;
	const gchar* _tmp1_;
	const gchar* _tmp3_;
	gchar* _tmp4_;
	const gchar* _tmp5_;
	gchar* _tmp6_;
#line 284 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	g_return_val_if_fail (id != NULL, NULL);
#line 285 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp0_ = gsettings_configuration_engine_clean_plugin_id (id);
#line 285 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	cleaned_id = _tmp0_;
#line 286 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp1_ = cleaned_id;
#line 286 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	if (_tmp1_ == NULL) {
#line 3673 "GSettingsEngine.c"
		gchar* _tmp2_;
#line 287 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_tmp2_ = g_strdup ("default");
#line 287 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_g_free0 (cleaned_id);
#line 287 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		cleaned_id = _tmp2_;
#line 3681 "GSettingsEngine.c"
	}
#line 289 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp3_ = cleaned_id;
#line 289 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp4_ = string_replace (_tmp3_, "org.yorba.shotwell.", "");
#line 289 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (cleaned_id);
#line 289 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	cleaned_id = _tmp4_;
#line 290 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp5_ = cleaned_id;
#line 290 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp6_ = string_replace (_tmp5_, ".", "-");
#line 290 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (cleaned_id);
#line 290 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	cleaned_id = _tmp6_;
#line 292 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	result = cleaned_id;
#line 292 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	return result;
#line 3703 "GSettingsEngine.c"
}


static gchar*
gsettings_configuration_engine_make_plugin_schema_name (const gchar* domain,
                                                        const gchar* id)
{
	gchar* result = NULL;
	gchar* cleaned_id = NULL;
	gchar* _tmp0_;
	const gchar* _tmp1_;
	const gchar* _tmp3_;
	gchar* _tmp4_;
	const gchar* _tmp5_;
	gchar* _tmp6_;
#line 295 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	g_return_val_if_fail (domain != NULL, NULL);
#line 295 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	g_return_val_if_fail (id != NULL, NULL);
#line 296 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp0_ = gsettings_configuration_engine_clean_plugin_id (id);
#line 296 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	cleaned_id = _tmp0_;
#line 297 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp1_ = cleaned_id;
#line 297 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	if (_tmp1_ == NULL) {
#line 3731 "GSettingsEngine.c"
		gchar* _tmp2_;
#line 298 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_tmp2_ = g_strdup ("default");
#line 298 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_g_free0 (cleaned_id);
#line 298 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		cleaned_id = _tmp2_;
#line 3739 "GSettingsEngine.c"
	}
#line 299 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp3_ = cleaned_id;
#line 299 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp4_ = string_replace (_tmp3_, ".", "-");
#line 299 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (cleaned_id);
#line 299 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	cleaned_id = _tmp4_;
#line 301 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp5_ = cleaned_id;
#line 301 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp6_ = g_strdup_printf ("org.yorba.shotwell.%s.%s", domain, _tmp5_);
#line 301 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	result = _tmp6_;
#line 301 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (cleaned_id);
#line 301 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	return result;
#line 3759 "GSettingsEngine.c"
}


static gchar*
gsettings_configuration_engine_make_gsettings_key (const gchar* gconf_key)
{
	gchar* result = NULL;
	gchar* _tmp0_;
#line 304 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	g_return_val_if_fail (gconf_key != NULL, NULL);
#line 305 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp0_ = string_replace (gconf_key, "_", "-");
#line 305 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	result = _tmp0_;
#line 305 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	return result;
#line 3776 "GSettingsEngine.c"
}


static gchar*
gsettings_configuration_engine_real_get_name (ConfigurationEngine* base)
{
	GSettingsConfigurationEngine * self;
	gchar* result = NULL;
	gchar* _tmp0_;
#line 308 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_GSETTINGS_CONFIGURATION_ENGINE, GSettingsConfigurationEngine);
#line 309 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp0_ = g_strdup ("GSettings");
#line 309 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	result = _tmp0_;
#line 309 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	return result;
#line 3794 "GSettingsEngine.c"
}


static gint
gsettings_configuration_engine_real_get_enum_property (ConfigurationEngine* base,
                                                       ConfigurableProperty p,
                                                       GError** error)
{
	GSettingsConfigurationEngine * self;
	gint result = 0;
	gint _tmp0_ = 0;
	gchar** _tmp1_;
	gint _tmp1__length1;
	const gchar* _tmp2_;
	gchar** _tmp3_;
	gint _tmp3__length1;
	const gchar* _tmp4_;
	GError * _inner_error_ = NULL;
#line 312 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_GSETTINGS_CONFIGURATION_ENGINE, GSettingsConfigurationEngine);
#line 313 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp1_ = self->priv->schema_names;
#line 313 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp1__length1 = self->priv->schema_names_length1;
#line 313 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp2_ = _tmp1_[p];
#line 313 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp3_ = self->priv->key_names;
#line 313 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp3__length1 = self->priv->key_names_length1;
#line 313 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp4_ = _tmp3_[p];
#line 313 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp0_ = gsettings_configuration_engine_get_gs_enum (self, _tmp2_, _tmp4_, &_inner_error_);
#line 313 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 313 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		if (_inner_error_->domain == CONFIGURATION_ERROR) {
#line 3833 "GSettingsEngine.c"
			gint _tmp5_ = 0;
#line 313 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			g_propagate_error (error, _inner_error_);
#line 313 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			return _tmp5_;
#line 3839 "GSettingsEngine.c"
		} else {
			gint _tmp6_ = 0;
#line 313 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 313 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			g_clear_error (&_inner_error_);
#line 313 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			return _tmp6_;
#line 3848 "GSettingsEngine.c"
		}
	}
#line 313 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	result = _tmp0_;
#line 313 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	return result;
#line 3855 "GSettingsEngine.c"
}


static void
gsettings_configuration_engine_real_set_enum_property (ConfigurationEngine* base,
                                                       ConfigurableProperty p,
                                                       gint val,
                                                       GError** error)
{
	GSettingsConfigurationEngine * self;
	gchar** _tmp0_;
	gint _tmp0__length1;
	const gchar* _tmp1_;
	gchar** _tmp2_;
	gint _tmp2__length1;
	const gchar* _tmp3_;
	GError * _inner_error_ = NULL;
#line 316 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_GSETTINGS_CONFIGURATION_ENGINE, GSettingsConfigurationEngine);
#line 317 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp0_ = self->priv->schema_names;
#line 317 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp0__length1 = self->priv->schema_names_length1;
#line 317 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp1_ = _tmp0_[p];
#line 317 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp2_ = self->priv->key_names;
#line 317 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp2__length1 = self->priv->key_names_length1;
#line 317 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp3_ = _tmp2_[p];
#line 317 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	gsettings_configuration_engine_set_gs_enum (self, _tmp1_, _tmp3_, val, &_inner_error_);
#line 317 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 317 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		if (_inner_error_->domain == CONFIGURATION_ERROR) {
#line 317 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			g_propagate_error (error, _inner_error_);
#line 317 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			return;
#line 3897 "GSettingsEngine.c"
		} else {
#line 317 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 317 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			g_clear_error (&_inner_error_);
#line 317 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			return;
#line 3905 "GSettingsEngine.c"
		}
	}
#line 318 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	g_signal_emit_by_name (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_CONFIGURATION_ENGINE, ConfigurationEngine), "property-changed", p);
#line 3910 "GSettingsEngine.c"
}


static gint
gsettings_configuration_engine_real_get_int_property (ConfigurationEngine* base,
                                                      ConfigurableProperty p,
                                                      GError** error)
{
	GSettingsConfigurationEngine * self;
	gint result = 0;
	gint _tmp0_ = 0;
	gchar** _tmp1_;
	gint _tmp1__length1;
	const gchar* _tmp2_;
	gchar** _tmp3_;
	gint _tmp3__length1;
	const gchar* _tmp4_;
	GError * _inner_error_ = NULL;
#line 321 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_GSETTINGS_CONFIGURATION_ENGINE, GSettingsConfigurationEngine);
#line 322 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp1_ = self->priv->schema_names;
#line 322 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp1__length1 = self->priv->schema_names_length1;
#line 322 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp2_ = _tmp1_[p];
#line 322 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp3_ = self->priv->key_names;
#line 322 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp3__length1 = self->priv->key_names_length1;
#line 322 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp4_ = _tmp3_[p];
#line 322 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp0_ = gsettings_configuration_engine_get_gs_int (self, _tmp2_, _tmp4_, &_inner_error_);
#line 322 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 322 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		if (_inner_error_->domain == CONFIGURATION_ERROR) {
#line 3949 "GSettingsEngine.c"
			gint _tmp5_ = 0;
#line 322 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			g_propagate_error (error, _inner_error_);
#line 322 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			return _tmp5_;
#line 3955 "GSettingsEngine.c"
		} else {
			gint _tmp6_ = 0;
#line 322 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 322 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			g_clear_error (&_inner_error_);
#line 322 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			return _tmp6_;
#line 3964 "GSettingsEngine.c"
		}
	}
#line 322 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	result = _tmp0_;
#line 322 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	return result;
#line 3971 "GSettingsEngine.c"
}


static void
gsettings_configuration_engine_real_set_int_property (ConfigurationEngine* base,
                                                      ConfigurableProperty p,
                                                      gint val,
                                                      GError** error)
{
	GSettingsConfigurationEngine * self;
	gchar** _tmp0_;
	gint _tmp0__length1;
	const gchar* _tmp1_;
	gchar** _tmp2_;
	gint _tmp2__length1;
	const gchar* _tmp3_;
	GError * _inner_error_ = NULL;
#line 325 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_GSETTINGS_CONFIGURATION_ENGINE, GSettingsConfigurationEngine);
#line 326 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp0_ = self->priv->schema_names;
#line 326 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp0__length1 = self->priv->schema_names_length1;
#line 326 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp1_ = _tmp0_[p];
#line 326 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp2_ = self->priv->key_names;
#line 326 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp2__length1 = self->priv->key_names_length1;
#line 326 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp3_ = _tmp2_[p];
#line 326 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	gsettings_configuration_engine_set_gs_int (self, _tmp1_, _tmp3_, val, &_inner_error_);
#line 326 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 326 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		if (_inner_error_->domain == CONFIGURATION_ERROR) {
#line 326 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			g_propagate_error (error, _inner_error_);
#line 326 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			return;
#line 4013 "GSettingsEngine.c"
		} else {
#line 326 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 326 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			g_clear_error (&_inner_error_);
#line 326 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			return;
#line 4021 "GSettingsEngine.c"
		}
	}
#line 327 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	g_signal_emit_by_name (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_CONFIGURATION_ENGINE, ConfigurationEngine), "property-changed", p);
#line 4026 "GSettingsEngine.c"
}


static glong
string_strnlen (gchar* str,
                glong maxlen)
{
	glong result = 0L;
	gchar* end = NULL;
	gchar* _tmp0_;
	gchar* _tmp1_;
#line 1336 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	_tmp0_ = memchr (str, 0, (gsize) maxlen);
#line 1336 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	end = _tmp0_;
#line 1337 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	_tmp1_ = end;
#line 1337 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	if (_tmp1_ == NULL) {
#line 1338 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		result = maxlen;
#line 1338 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		return result;
#line 4050 "GSettingsEngine.c"
	} else {
		gchar* _tmp2_;
#line 1340 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		_tmp2_ = end;
#line 1340 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		result = (glong) (_tmp2_ - str);
#line 1340 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		return result;
#line 4059 "GSettingsEngine.c"
	}
}


static gchar*
string_substring (const gchar* self,
                  glong offset,
                  glong len)
{
	gchar* result = NULL;
	glong string_length = 0L;
	gboolean _tmp0_ = FALSE;
	glong _tmp6_;
	gchar* _tmp7_;
#line 1347 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, NULL);
#line 1349 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	if (offset >= ((glong) 0)) {
#line 1349 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		_tmp0_ = len >= ((glong) 0);
#line 4080 "GSettingsEngine.c"
	} else {
#line 1349 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		_tmp0_ = FALSE;
#line 4084 "GSettingsEngine.c"
	}
#line 1349 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	if (_tmp0_) {
#line 1351 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		string_length = string_strnlen ((gchar*) self, offset + len);
#line 4090 "GSettingsEngine.c"
	} else {
		gint _tmp1_;
		gint _tmp2_;
#line 1353 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		_tmp1_ = strlen (self);
#line 1353 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		_tmp2_ = _tmp1_;
#line 1353 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		string_length = (glong) _tmp2_;
#line 4100 "GSettingsEngine.c"
	}
#line 1356 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	if (offset < ((glong) 0)) {
#line 4104 "GSettingsEngine.c"
		glong _tmp3_;
#line 1357 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		_tmp3_ = string_length;
#line 1357 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		offset = _tmp3_ + offset;
#line 1358 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		g_return_val_if_fail (offset >= ((glong) 0), NULL);
#line 4112 "GSettingsEngine.c"
	} else {
		glong _tmp4_;
#line 1360 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		_tmp4_ = string_length;
#line 1360 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		g_return_val_if_fail (offset <= _tmp4_, NULL);
#line 4119 "GSettingsEngine.c"
	}
#line 1362 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	if (len < ((glong) 0)) {
#line 4123 "GSettingsEngine.c"
		glong _tmp5_;
#line 1363 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		_tmp5_ = string_length;
#line 1363 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		len = _tmp5_ - offset;
#line 4129 "GSettingsEngine.c"
	}
#line 1365 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	_tmp6_ = string_length;
#line 1365 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	g_return_val_if_fail ((offset + len) <= _tmp6_, NULL);
#line 1366 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	_tmp7_ = g_strndup (((gchar*) self) + offset, (gsize) len);
#line 1366 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	result = _tmp7_;
#line 1366 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	return result;
#line 4141 "GSettingsEngine.c"
}


static gchar*
gsettings_configuration_engine_real_get_string_property (ConfigurationEngine* base,
                                                         ConfigurableProperty p,
                                                         GError** error)
{
	GSettingsConfigurationEngine * self;
	gchar* result = NULL;
	gchar* gs_result = NULL;
	gchar** _tmp0_;
	gint _tmp0__length1;
	const gchar* _tmp1_;
	gchar** _tmp2_;
	gint _tmp2__length1;
	const gchar* _tmp3_;
	gchar* _tmp4_;
	gchar* _result_ = NULL;
	gchar* _tmp5_;
	GError * _inner_error_ = NULL;
#line 330 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_GSETTINGS_CONFIGURATION_ENGINE, GSettingsConfigurationEngine);
#line 331 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp0_ = self->priv->schema_names;
#line 331 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp0__length1 = self->priv->schema_names_length1;
#line 331 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp1_ = _tmp0_[p];
#line 331 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp2_ = self->priv->key_names;
#line 331 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp2__length1 = self->priv->key_names_length1;
#line 331 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp3_ = _tmp2_[p];
#line 331 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp4_ = gsettings_configuration_engine_get_gs_string (self, _tmp1_, _tmp3_, &_inner_error_);
#line 331 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	gs_result = _tmp4_;
#line 331 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 331 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		if (_inner_error_->domain == CONFIGURATION_ERROR) {
#line 331 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			g_propagate_error (error, _inner_error_);
#line 331 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			return NULL;
#line 4189 "GSettingsEngine.c"
		} else {
#line 331 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 331 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			g_clear_error (&_inner_error_);
#line 331 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			return NULL;
#line 4197 "GSettingsEngine.c"
		}
	}
#line 335 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp5_ = g_strdup (gs_result);
#line 335 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_result_ = _tmp5_;
#line 336 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	if (p == CONFIGURABLE_PROPERTY_DESKTOP_BACKGROUND_FILE) {
#line 4206 "GSettingsEngine.c"
		gchar* _tmp6_;
#line 337 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_tmp6_ = string_substring (gs_result, (glong) 7, (glong) -1);
#line 337 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_g_free0 (_result_);
#line 337 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_result_ = _tmp6_;
#line 4214 "GSettingsEngine.c"
	}
#line 340 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	result = _result_;
#line 340 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (gs_result);
#line 340 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	return result;
#line 4222 "GSettingsEngine.c"
}


static void
gsettings_configuration_engine_real_set_string_property (ConfigurationEngine* base,
                                                         ConfigurableProperty p,
                                                         const gchar* val,
                                                         GError** error)
{
	GSettingsConfigurationEngine * self;
	gchar* converted_val = NULL;
	gchar* _tmp0_;
	gboolean _tmp1_ = FALSE;
	gchar** _tmp3_;
	gint _tmp3__length1;
	const gchar* _tmp4_;
	gchar** _tmp5_;
	gint _tmp5__length1;
	const gchar* _tmp6_;
	const gchar* _tmp7_;
	GError * _inner_error_ = NULL;
#line 343 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_GSETTINGS_CONFIGURATION_ENGINE, GSettingsConfigurationEngine);
#line 343 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	g_return_if_fail (val != NULL);
#line 345 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp0_ = g_strdup (val);
#line 345 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	converted_val = _tmp0_;
#line 346 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	if (p == CONFIGURABLE_PROPERTY_DESKTOP_BACKGROUND_FILE) {
#line 346 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_tmp1_ = TRUE;
#line 4256 "GSettingsEngine.c"
	} else {
#line 347 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_tmp1_ = p == CONFIGURABLE_PROPERTY_SCREENSAVER_FILE;
#line 4260 "GSettingsEngine.c"
	}
#line 346 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	if (_tmp1_) {
#line 4264 "GSettingsEngine.c"
		gchar* _tmp2_;
#line 348 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_tmp2_ = g_strconcat ("file://", val, NULL);
#line 348 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_g_free0 (converted_val);
#line 348 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		converted_val = _tmp2_;
#line 4272 "GSettingsEngine.c"
	}
#line 351 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp3_ = self->priv->schema_names;
#line 351 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp3__length1 = self->priv->schema_names_length1;
#line 351 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp4_ = _tmp3_[p];
#line 351 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp5_ = self->priv->key_names;
#line 351 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp5__length1 = self->priv->key_names_length1;
#line 351 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp6_ = _tmp5_[p];
#line 351 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp7_ = converted_val;
#line 351 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	gsettings_configuration_engine_set_gs_string (self, _tmp4_, _tmp6_, _tmp7_, &_inner_error_);
#line 351 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 351 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		if (_inner_error_->domain == CONFIGURATION_ERROR) {
#line 351 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			g_propagate_error (error, _inner_error_);
#line 351 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			_g_free0 (converted_val);
#line 351 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			return;
#line 4300 "GSettingsEngine.c"
		} else {
#line 351 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			_g_free0 (converted_val);
#line 351 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 351 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			g_clear_error (&_inner_error_);
#line 351 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			return;
#line 4310 "GSettingsEngine.c"
		}
	}
#line 352 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	g_signal_emit_by_name (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_CONFIGURATION_ENGINE, ConfigurationEngine), "property-changed", p);
#line 343 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (converted_val);
#line 4317 "GSettingsEngine.c"
}


static gboolean
gsettings_configuration_engine_real_get_bool_property (ConfigurationEngine* base,
                                                       ConfigurableProperty p,
                                                       GError** error)
{
	GSettingsConfigurationEngine * self;
	gboolean result = FALSE;
	gboolean _tmp0_ = FALSE;
	gchar** _tmp1_;
	gint _tmp1__length1;
	const gchar* _tmp2_;
	gchar** _tmp3_;
	gint _tmp3__length1;
	const gchar* _tmp4_;
	GError * _inner_error_ = NULL;
#line 355 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_GSETTINGS_CONFIGURATION_ENGINE, GSettingsConfigurationEngine);
#line 356 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp1_ = self->priv->schema_names;
#line 356 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp1__length1 = self->priv->schema_names_length1;
#line 356 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp2_ = _tmp1_[p];
#line 356 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp3_ = self->priv->key_names;
#line 356 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp3__length1 = self->priv->key_names_length1;
#line 356 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp4_ = _tmp3_[p];
#line 356 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp0_ = gsettings_configuration_engine_get_gs_bool (self, _tmp2_, _tmp4_, &_inner_error_);
#line 356 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 356 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		if (_inner_error_->domain == CONFIGURATION_ERROR) {
#line 4356 "GSettingsEngine.c"
			gboolean _tmp5_ = FALSE;
#line 356 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			g_propagate_error (error, _inner_error_);
#line 356 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			return _tmp5_;
#line 4362 "GSettingsEngine.c"
		} else {
			gboolean _tmp6_ = FALSE;
#line 356 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 356 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			g_clear_error (&_inner_error_);
#line 356 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			return _tmp6_;
#line 4371 "GSettingsEngine.c"
		}
	}
#line 356 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	result = _tmp0_;
#line 356 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	return result;
#line 4378 "GSettingsEngine.c"
}


static void
gsettings_configuration_engine_real_set_bool_property (ConfigurationEngine* base,
                                                       ConfigurableProperty p,
                                                       gboolean val,
                                                       GError** error)
{
	GSettingsConfigurationEngine * self;
	gchar** _tmp0_;
	gint _tmp0__length1;
	const gchar* _tmp1_;
	gchar** _tmp2_;
	gint _tmp2__length1;
	const gchar* _tmp3_;
	GError * _inner_error_ = NULL;
#line 359 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_GSETTINGS_CONFIGURATION_ENGINE, GSettingsConfigurationEngine);
#line 360 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp0_ = self->priv->schema_names;
#line 360 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp0__length1 = self->priv->schema_names_length1;
#line 360 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp1_ = _tmp0_[p];
#line 360 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp2_ = self->priv->key_names;
#line 360 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp2__length1 = self->priv->key_names_length1;
#line 360 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp3_ = _tmp2_[p];
#line 360 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	gsettings_configuration_engine_set_gs_bool (self, _tmp1_, _tmp3_, val, &_inner_error_);
#line 360 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 360 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		if (_inner_error_->domain == CONFIGURATION_ERROR) {
#line 360 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			g_propagate_error (error, _inner_error_);
#line 360 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			return;
#line 4420 "GSettingsEngine.c"
		} else {
#line 360 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 360 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			g_clear_error (&_inner_error_);
#line 360 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			return;
#line 4428 "GSettingsEngine.c"
		}
	}
#line 361 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	g_signal_emit_by_name (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_CONFIGURATION_ENGINE, ConfigurationEngine), "property-changed", p);
#line 4433 "GSettingsEngine.c"
}


static gdouble
gsettings_configuration_engine_real_get_double_property (ConfigurationEngine* base,
                                                         ConfigurableProperty p,
                                                         GError** error)
{
	GSettingsConfigurationEngine * self;
	gdouble result = 0.0;
	gdouble _tmp0_ = 0.0;
	gchar** _tmp1_;
	gint _tmp1__length1;
	const gchar* _tmp2_;
	gchar** _tmp3_;
	gint _tmp3__length1;
	const gchar* _tmp4_;
	GError * _inner_error_ = NULL;
#line 364 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_GSETTINGS_CONFIGURATION_ENGINE, GSettingsConfigurationEngine);
#line 365 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp1_ = self->priv->schema_names;
#line 365 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp1__length1 = self->priv->schema_names_length1;
#line 365 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp2_ = _tmp1_[p];
#line 365 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp3_ = self->priv->key_names;
#line 365 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp3__length1 = self->priv->key_names_length1;
#line 365 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp4_ = _tmp3_[p];
#line 365 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp0_ = gsettings_configuration_engine_get_gs_double (self, _tmp2_, _tmp4_, &_inner_error_);
#line 365 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 365 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		if (_inner_error_->domain == CONFIGURATION_ERROR) {
#line 4472 "GSettingsEngine.c"
			gdouble _tmp5_ = 0.0;
#line 365 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			g_propagate_error (error, _inner_error_);
#line 365 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			return _tmp5_;
#line 4478 "GSettingsEngine.c"
		} else {
			gdouble _tmp6_ = 0.0;
#line 365 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 365 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			g_clear_error (&_inner_error_);
#line 365 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			return _tmp6_;
#line 4487 "GSettingsEngine.c"
		}
	}
#line 365 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	result = _tmp0_;
#line 365 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	return result;
#line 4494 "GSettingsEngine.c"
}


static void
gsettings_configuration_engine_real_set_double_property (ConfigurationEngine* base,
                                                         ConfigurableProperty p,
                                                         gdouble val,
                                                         GError** error)
{
	GSettingsConfigurationEngine * self;
	gchar** _tmp0_;
	gint _tmp0__length1;
	const gchar* _tmp1_;
	gchar** _tmp2_;
	gint _tmp2__length1;
	const gchar* _tmp3_;
	GError * _inner_error_ = NULL;
#line 368 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_GSETTINGS_CONFIGURATION_ENGINE, GSettingsConfigurationEngine);
#line 369 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp0_ = self->priv->schema_names;
#line 369 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp0__length1 = self->priv->schema_names_length1;
#line 369 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp1_ = _tmp0_[p];
#line 369 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp2_ = self->priv->key_names;
#line 369 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp2__length1 = self->priv->key_names_length1;
#line 369 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp3_ = _tmp2_[p];
#line 369 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	gsettings_configuration_engine_set_gs_double (self, _tmp1_, _tmp3_, val, &_inner_error_);
#line 369 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 369 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		if (_inner_error_->domain == CONFIGURATION_ERROR) {
#line 369 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			g_propagate_error (error, _inner_error_);
#line 369 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			return;
#line 4536 "GSettingsEngine.c"
		} else {
#line 369 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 369 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			g_clear_error (&_inner_error_);
#line 369 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			return;
#line 4544 "GSettingsEngine.c"
		}
	}
#line 370 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	g_signal_emit_by_name (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_CONFIGURATION_ENGINE, ConfigurationEngine), "property-changed", p);
#line 4549 "GSettingsEngine.c"
}


static gboolean
gsettings_configuration_engine_real_get_plugin_bool (ConfigurationEngine* base,
                                                     const gchar* domain,
                                                     const gchar* id,
                                                     const gchar* key,
                                                     gboolean def)
{
	GSettingsConfigurationEngine * self;
	gboolean result = FALSE;
	gchar* schema_name = NULL;
	gchar* _tmp0_;
	gboolean _tmp8_ = FALSE;
	GError * _inner_error_ = NULL;
#line 373 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_GSETTINGS_CONFIGURATION_ENGINE, GSettingsConfigurationEngine);
#line 373 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	g_return_val_if_fail (domain != NULL, FALSE);
#line 373 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	g_return_val_if_fail (id != NULL, FALSE);
#line 373 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	g_return_val_if_fail (key != NULL, FALSE);
#line 374 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp0_ = gsettings_configuration_engine_make_plugin_schema_name (domain, id);
#line 374 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	schema_name = _tmp0_;
#line 4578 "GSettingsEngine.c"
	{
		gboolean _tmp1_ = FALSE;
		gchar* _tmp2_;
		gchar* _tmp3_;
		gboolean _tmp4_;
#line 377 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_tmp2_ = gsettings_configuration_engine_make_gsettings_key (key);
#line 377 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_tmp3_ = _tmp2_;
#line 377 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_tmp4_ = gsettings_configuration_engine_get_gs_bool (self, schema_name, _tmp3_, &_inner_error_);
#line 377 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_g_free0 (_tmp3_);
#line 377 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_tmp1_ = _tmp4_;
#line 377 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 4596 "GSettingsEngine.c"
			gboolean _tmp5_ = FALSE;
#line 377 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			if (_inner_error_->domain == CONFIGURATION_ERROR) {
#line 4600 "GSettingsEngine.c"
				goto __catch218_configuration_error;
			}
#line 377 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			_g_free0 (schema_name);
#line 377 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 377 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			g_clear_error (&_inner_error_);
#line 377 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			return _tmp5_;
#line 4611 "GSettingsEngine.c"
		}
#line 377 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		result = _tmp1_;
#line 377 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_g_free0 (schema_name);
#line 377 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		return result;
#line 4619 "GSettingsEngine.c"
	}
	goto __finally218;
	__catch218_configuration_error:
	{
		GError* err = NULL;
		GError* _tmp6_;
		const gchar* _tmp7_;
#line 376 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		err = _inner_error_;
#line 376 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_inner_error_ = NULL;
#line 379 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_tmp6_ = err;
#line 379 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_tmp7_ = _tmp6_->message;
#line 379 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		g_critical ("GSettingsEngine.vala:379: GSettingsConfigurationEngine: error: %s", _tmp7_);
#line 380 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		result = def;
#line 380 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_g_error_free0 (err);
#line 380 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_g_free0 (schema_name);
#line 380 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		return result;
#line 4645 "GSettingsEngine.c"
	}
	__finally218:
#line 376 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (schema_name);
#line 376 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 376 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	g_clear_error (&_inner_error_);
#line 376 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	return _tmp8_;
#line 4656 "GSettingsEngine.c"
}


static void
gsettings_configuration_engine_real_set_plugin_bool (ConfigurationEngine* base,
                                                     const gchar* domain,
                                                     const gchar* id,
                                                     const gchar* key,
                                                     gboolean val)
{
	GSettingsConfigurationEngine * self;
	gchar* schema_name = NULL;
	gchar* _tmp0_;
	GError * _inner_error_ = NULL;
#line 384 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_GSETTINGS_CONFIGURATION_ENGINE, GSettingsConfigurationEngine);
#line 384 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	g_return_if_fail (domain != NULL);
#line 384 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	g_return_if_fail (id != NULL);
#line 384 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	g_return_if_fail (key != NULL);
#line 385 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp0_ = gsettings_configuration_engine_make_plugin_schema_name (domain, id);
#line 385 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	schema_name = _tmp0_;
#line 4683 "GSettingsEngine.c"
	{
		gchar* _tmp1_;
		gchar* _tmp2_;
#line 388 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_tmp1_ = gsettings_configuration_engine_make_gsettings_key (key);
#line 388 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_tmp2_ = _tmp1_;
#line 388 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		gsettings_configuration_engine_set_gs_bool (self, schema_name, _tmp2_, val, &_inner_error_);
#line 388 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_g_free0 (_tmp2_);
#line 388 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 388 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			if (_inner_error_->domain == CONFIGURATION_ERROR) {
#line 4699 "GSettingsEngine.c"
				goto __catch219_configuration_error;
			}
#line 388 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			_g_free0 (schema_name);
#line 388 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 388 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			g_clear_error (&_inner_error_);
#line 388 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			return;
#line 4710 "GSettingsEngine.c"
		}
	}
	goto __finally219;
	__catch219_configuration_error:
	{
		GError* err = NULL;
		GError* _tmp3_;
		const gchar* _tmp4_;
#line 387 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		err = _inner_error_;
#line 387 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_inner_error_ = NULL;
#line 390 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_tmp3_ = err;
#line 390 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_tmp4_ = _tmp3_->message;
#line 390 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		g_critical ("GSettingsEngine.vala:390: GSettingsConfigurationEngine: error: %s", _tmp4_);
#line 387 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_g_error_free0 (err);
#line 4731 "GSettingsEngine.c"
	}
	__finally219:
#line 387 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 387 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_g_free0 (schema_name);
#line 387 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 387 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		g_clear_error (&_inner_error_);
#line 387 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		return;
#line 4744 "GSettingsEngine.c"
	}
#line 384 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (schema_name);
#line 4748 "GSettingsEngine.c"
}


static gdouble
gsettings_configuration_engine_real_get_plugin_double (ConfigurationEngine* base,
                                                       const gchar* domain,
                                                       const gchar* id,
                                                       const gchar* key,
                                                       gdouble def)
{
	GSettingsConfigurationEngine * self;
	gdouble result = 0.0;
	gchar* schema_name = NULL;
	gchar* _tmp0_;
	gdouble _tmp8_ = 0.0;
	GError * _inner_error_ = NULL;
#line 394 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_GSETTINGS_CONFIGURATION_ENGINE, GSettingsConfigurationEngine);
#line 394 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	g_return_val_if_fail (domain != NULL, 0.0);
#line 394 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	g_return_val_if_fail (id != NULL, 0.0);
#line 394 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	g_return_val_if_fail (key != NULL, 0.0);
#line 395 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp0_ = gsettings_configuration_engine_make_plugin_schema_name (domain, id);
#line 395 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	schema_name = _tmp0_;
#line 4777 "GSettingsEngine.c"
	{
		gdouble _tmp1_ = 0.0;
		gchar* _tmp2_;
		gchar* _tmp3_;
		gdouble _tmp4_;
#line 398 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_tmp2_ = gsettings_configuration_engine_make_gsettings_key (key);
#line 398 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_tmp3_ = _tmp2_;
#line 398 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_tmp4_ = gsettings_configuration_engine_get_gs_double (self, schema_name, _tmp3_, &_inner_error_);
#line 398 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_g_free0 (_tmp3_);
#line 398 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_tmp1_ = _tmp4_;
#line 398 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 4795 "GSettingsEngine.c"
			gdouble _tmp5_ = 0.0;
#line 398 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			if (_inner_error_->domain == CONFIGURATION_ERROR) {
#line 4799 "GSettingsEngine.c"
				goto __catch220_configuration_error;
			}
#line 398 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			_g_free0 (schema_name);
#line 398 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 398 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			g_clear_error (&_inner_error_);
#line 398 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			return _tmp5_;
#line 4810 "GSettingsEngine.c"
		}
#line 398 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		result = _tmp1_;
#line 398 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_g_free0 (schema_name);
#line 398 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		return result;
#line 4818 "GSettingsEngine.c"
	}
	goto __finally220;
	__catch220_configuration_error:
	{
		GError* err = NULL;
		GError* _tmp6_;
		const gchar* _tmp7_;
#line 397 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		err = _inner_error_;
#line 397 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_inner_error_ = NULL;
#line 400 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_tmp6_ = err;
#line 400 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_tmp7_ = _tmp6_->message;
#line 400 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		g_critical ("GSettingsEngine.vala:400: GSettingsConfigurationEngine: error: %s", _tmp7_);
#line 401 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		result = def;
#line 401 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_g_error_free0 (err);
#line 401 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_g_free0 (schema_name);
#line 401 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		return result;
#line 4844 "GSettingsEngine.c"
	}
	__finally220:
#line 397 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (schema_name);
#line 397 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 397 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	g_clear_error (&_inner_error_);
#line 397 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	return _tmp8_;
#line 4855 "GSettingsEngine.c"
}


static void
gsettings_configuration_engine_real_set_plugin_double (ConfigurationEngine* base,
                                                       const gchar* domain,
                                                       const gchar* id,
                                                       const gchar* key,
                                                       gdouble val)
{
	GSettingsConfigurationEngine * self;
	gchar* schema_name = NULL;
	gchar* _tmp0_;
	GError * _inner_error_ = NULL;
#line 405 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_GSETTINGS_CONFIGURATION_ENGINE, GSettingsConfigurationEngine);
#line 405 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	g_return_if_fail (domain != NULL);
#line 405 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	g_return_if_fail (id != NULL);
#line 405 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	g_return_if_fail (key != NULL);
#line 406 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp0_ = gsettings_configuration_engine_make_plugin_schema_name (domain, id);
#line 406 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	schema_name = _tmp0_;
#line 4882 "GSettingsEngine.c"
	{
		gchar* _tmp1_;
		gchar* _tmp2_;
#line 409 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_tmp1_ = gsettings_configuration_engine_make_gsettings_key (key);
#line 409 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_tmp2_ = _tmp1_;
#line 409 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		gsettings_configuration_engine_set_gs_double (self, schema_name, _tmp2_, val, &_inner_error_);
#line 409 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_g_free0 (_tmp2_);
#line 409 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 409 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			if (_inner_error_->domain == CONFIGURATION_ERROR) {
#line 4898 "GSettingsEngine.c"
				goto __catch221_configuration_error;
			}
#line 409 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			_g_free0 (schema_name);
#line 409 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 409 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			g_clear_error (&_inner_error_);
#line 409 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			return;
#line 4909 "GSettingsEngine.c"
		}
	}
	goto __finally221;
	__catch221_configuration_error:
	{
		GError* err = NULL;
		GError* _tmp3_;
		const gchar* _tmp4_;
#line 408 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		err = _inner_error_;
#line 408 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_inner_error_ = NULL;
#line 411 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_tmp3_ = err;
#line 411 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_tmp4_ = _tmp3_->message;
#line 411 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		g_critical ("GSettingsEngine.vala:411: GSettingsConfigurationEngine: error: %s", _tmp4_);
#line 408 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_g_error_free0 (err);
#line 4930 "GSettingsEngine.c"
	}
	__finally221:
#line 408 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 408 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_g_free0 (schema_name);
#line 408 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 408 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		g_clear_error (&_inner_error_);
#line 408 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		return;
#line 4943 "GSettingsEngine.c"
	}
#line 405 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (schema_name);
#line 4947 "GSettingsEngine.c"
}


static gint
gsettings_configuration_engine_real_get_plugin_int (ConfigurationEngine* base,
                                                    const gchar* domain,
                                                    const gchar* id,
                                                    const gchar* key,
                                                    gint def)
{
	GSettingsConfigurationEngine * self;
	gint result = 0;
	gchar* schema_name = NULL;
	gchar* _tmp0_;
	gint _tmp8_ = 0;
	GError * _inner_error_ = NULL;
#line 415 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_GSETTINGS_CONFIGURATION_ENGINE, GSettingsConfigurationEngine);
#line 415 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	g_return_val_if_fail (domain != NULL, 0);
#line 415 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	g_return_val_if_fail (id != NULL, 0);
#line 415 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	g_return_val_if_fail (key != NULL, 0);
#line 416 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp0_ = gsettings_configuration_engine_make_plugin_schema_name (domain, id);
#line 416 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	schema_name = _tmp0_;
#line 4976 "GSettingsEngine.c"
	{
		gint _tmp1_ = 0;
		gchar* _tmp2_;
		gchar* _tmp3_;
		gint _tmp4_;
#line 419 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_tmp2_ = gsettings_configuration_engine_make_gsettings_key (key);
#line 419 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_tmp3_ = _tmp2_;
#line 419 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_tmp4_ = gsettings_configuration_engine_get_gs_int (self, schema_name, _tmp3_, &_inner_error_);
#line 419 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_g_free0 (_tmp3_);
#line 419 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_tmp1_ = _tmp4_;
#line 419 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 4994 "GSettingsEngine.c"
			gint _tmp5_ = 0;
#line 419 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			if (_inner_error_->domain == CONFIGURATION_ERROR) {
#line 4998 "GSettingsEngine.c"
				goto __catch222_configuration_error;
			}
#line 419 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			_g_free0 (schema_name);
#line 419 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 419 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			g_clear_error (&_inner_error_);
#line 419 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			return _tmp5_;
#line 5009 "GSettingsEngine.c"
		}
#line 419 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		result = _tmp1_;
#line 419 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_g_free0 (schema_name);
#line 419 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		return result;
#line 5017 "GSettingsEngine.c"
	}
	goto __finally222;
	__catch222_configuration_error:
	{
		GError* err = NULL;
		GError* _tmp6_;
		const gchar* _tmp7_;
#line 418 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		err = _inner_error_;
#line 418 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_inner_error_ = NULL;
#line 421 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_tmp6_ = err;
#line 421 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_tmp7_ = _tmp6_->message;
#line 421 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		g_critical ("GSettingsEngine.vala:421: GSettingsConfigurationEngine: error: %s", _tmp7_);
#line 422 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		result = def;
#line 422 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_g_error_free0 (err);
#line 422 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_g_free0 (schema_name);
#line 422 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		return result;
#line 5043 "GSettingsEngine.c"
	}
	__finally222:
#line 418 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (schema_name);
#line 418 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 418 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	g_clear_error (&_inner_error_);
#line 418 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	return _tmp8_;
#line 5054 "GSettingsEngine.c"
}


static void
gsettings_configuration_engine_real_set_plugin_int (ConfigurationEngine* base,
                                                    const gchar* domain,
                                                    const gchar* id,
                                                    const gchar* key,
                                                    gint val)
{
	GSettingsConfigurationEngine * self;
	gchar* schema_name = NULL;
	gchar* _tmp0_;
	GError * _inner_error_ = NULL;
#line 426 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_GSETTINGS_CONFIGURATION_ENGINE, GSettingsConfigurationEngine);
#line 426 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	g_return_if_fail (domain != NULL);
#line 426 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	g_return_if_fail (id != NULL);
#line 426 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	g_return_if_fail (key != NULL);
#line 427 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp0_ = gsettings_configuration_engine_make_plugin_schema_name (domain, id);
#line 427 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	schema_name = _tmp0_;
#line 5081 "GSettingsEngine.c"
	{
		gchar* _tmp1_;
		gchar* _tmp2_;
#line 430 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_tmp1_ = gsettings_configuration_engine_make_gsettings_key (key);
#line 430 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_tmp2_ = _tmp1_;
#line 430 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		gsettings_configuration_engine_set_gs_int (self, schema_name, _tmp2_, val, &_inner_error_);
#line 430 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_g_free0 (_tmp2_);
#line 430 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 430 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			if (_inner_error_->domain == CONFIGURATION_ERROR) {
#line 5097 "GSettingsEngine.c"
				goto __catch223_configuration_error;
			}
#line 430 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			_g_free0 (schema_name);
#line 430 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 430 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			g_clear_error (&_inner_error_);
#line 430 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			return;
#line 5108 "GSettingsEngine.c"
		}
	}
	goto __finally223;
	__catch223_configuration_error:
	{
		GError* err = NULL;
		GError* _tmp3_;
		const gchar* _tmp4_;
#line 429 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		err = _inner_error_;
#line 429 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_inner_error_ = NULL;
#line 432 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_tmp3_ = err;
#line 432 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_tmp4_ = _tmp3_->message;
#line 432 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		g_critical ("GSettingsEngine.vala:432: GSettingsConfigurationEngine: error: %s", _tmp4_);
#line 429 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_g_error_free0 (err);
#line 5129 "GSettingsEngine.c"
	}
	__finally223:
#line 429 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 429 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_g_free0 (schema_name);
#line 429 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 429 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		g_clear_error (&_inner_error_);
#line 429 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		return;
#line 5142 "GSettingsEngine.c"
	}
#line 426 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (schema_name);
#line 5146 "GSettingsEngine.c"
}


static gchar*
gsettings_configuration_engine_real_get_plugin_string (ConfigurationEngine* base,
                                                       const gchar* domain,
                                                       const gchar* id,
                                                       const gchar* key,
                                                       const gchar* def)
{
	GSettingsConfigurationEngine * self;
	gchar* result = NULL;
	gchar* schema_name = NULL;
	gchar* _tmp0_;
	GError * _inner_error_ = NULL;
#line 436 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_GSETTINGS_CONFIGURATION_ENGINE, GSettingsConfigurationEngine);
#line 436 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	g_return_val_if_fail (domain != NULL, NULL);
#line 436 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	g_return_val_if_fail (id != NULL, NULL);
#line 436 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	g_return_val_if_fail (key != NULL, NULL);
#line 437 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp0_ = gsettings_configuration_engine_make_plugin_schema_name (domain, id);
#line 437 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	schema_name = _tmp0_;
#line 5174 "GSettingsEngine.c"
	{
		gchar* _tmp1_ = NULL;
		gchar* _tmp2_;
		gchar* _tmp3_;
		gchar* _tmp4_;
		gchar* _tmp5_;
		gchar* _tmp6_;
#line 440 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_tmp2_ = gsettings_configuration_engine_make_gsettings_key (key);
#line 440 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_tmp3_ = _tmp2_;
#line 440 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_tmp4_ = gsettings_configuration_engine_get_gs_string (self, schema_name, _tmp3_, &_inner_error_);
#line 440 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_tmp5_ = _tmp4_;
#line 440 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_g_free0 (_tmp3_);
#line 440 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_tmp1_ = _tmp5_;
#line 440 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 440 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			if (_inner_error_->domain == CONFIGURATION_ERROR) {
#line 5198 "GSettingsEngine.c"
				goto __catch224_configuration_error;
			}
#line 440 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			_g_free0 (schema_name);
#line 440 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 440 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			g_clear_error (&_inner_error_);
#line 440 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			return NULL;
#line 5209 "GSettingsEngine.c"
		}
#line 440 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_tmp6_ = _tmp1_;
#line 440 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_tmp1_ = NULL;
#line 440 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		result = _tmp6_;
#line 440 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_g_free0 (_tmp1_);
#line 440 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_g_free0 (schema_name);
#line 440 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		return result;
#line 5223 "GSettingsEngine.c"
	}
	goto __finally224;
	__catch224_configuration_error:
	{
		GError* err = NULL;
		GError* _tmp7_;
		const gchar* _tmp8_;
		gchar* _tmp9_;
#line 439 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		err = _inner_error_;
#line 439 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_inner_error_ = NULL;
#line 442 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_tmp7_ = err;
#line 442 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_tmp8_ = _tmp7_->message;
#line 442 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		g_critical ("GSettingsEngine.vala:442: GSettingsConfigurationEngine: error: %s", _tmp8_);
#line 443 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_tmp9_ = g_strdup (def);
#line 443 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		result = _tmp9_;
#line 443 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_g_error_free0 (err);
#line 443 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_g_free0 (schema_name);
#line 443 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		return result;
#line 5252 "GSettingsEngine.c"
	}
	__finally224:
#line 439 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (schema_name);
#line 439 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 439 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	g_clear_error (&_inner_error_);
#line 439 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	return NULL;
#line 5263 "GSettingsEngine.c"
}


static void
gsettings_configuration_engine_real_set_plugin_string (ConfigurationEngine* base,
                                                       const gchar* domain,
                                                       const gchar* id,
                                                       const gchar* key,
                                                       const gchar* val)
{
	GSettingsConfigurationEngine * self;
	gchar* schema_name = NULL;
	gchar* _tmp0_;
	GError * _inner_error_ = NULL;
#line 447 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_GSETTINGS_CONFIGURATION_ENGINE, GSettingsConfigurationEngine);
#line 447 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	g_return_if_fail (domain != NULL);
#line 447 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	g_return_if_fail (id != NULL);
#line 447 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	g_return_if_fail (key != NULL);
#line 448 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp0_ = gsettings_configuration_engine_make_plugin_schema_name (domain, id);
#line 448 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	schema_name = _tmp0_;
#line 5290 "GSettingsEngine.c"
	{
		gchar* _tmp1_;
		gchar* _tmp2_;
#line 451 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_tmp1_ = gsettings_configuration_engine_make_gsettings_key (key);
#line 451 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_tmp2_ = _tmp1_;
#line 451 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		gsettings_configuration_engine_set_gs_string (self, schema_name, _tmp2_, val, &_inner_error_);
#line 451 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_g_free0 (_tmp2_);
#line 451 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 451 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			if (_inner_error_->domain == CONFIGURATION_ERROR) {
#line 5306 "GSettingsEngine.c"
				goto __catch225_configuration_error;
			}
#line 451 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			_g_free0 (schema_name);
#line 451 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 451 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			g_clear_error (&_inner_error_);
#line 451 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			return;
#line 5317 "GSettingsEngine.c"
		}
	}
	goto __finally225;
	__catch225_configuration_error:
	{
		GError* err = NULL;
		GError* _tmp3_;
		const gchar* _tmp4_;
#line 450 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		err = _inner_error_;
#line 450 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_inner_error_ = NULL;
#line 453 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_tmp3_ = err;
#line 453 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_tmp4_ = _tmp3_->message;
#line 453 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		g_critical ("GSettingsEngine.vala:453: GSettingsConfigurationEngine: error: %s", _tmp4_);
#line 450 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_g_error_free0 (err);
#line 5338 "GSettingsEngine.c"
	}
	__finally225:
#line 450 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 450 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_g_free0 (schema_name);
#line 450 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 450 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		g_clear_error (&_inner_error_);
#line 450 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		return;
#line 5351 "GSettingsEngine.c"
	}
#line 447 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (schema_name);
#line 5355 "GSettingsEngine.c"
}


static void
gsettings_configuration_engine_real_unset_plugin_key (ConfigurationEngine* base,
                                                      const gchar* domain,
                                                      const gchar* id,
                                                      const gchar* key)
{
	GSettingsConfigurationEngine * self;
	gchar* schema_name = NULL;
	gchar* _tmp0_;
	GError * _inner_error_ = NULL;
#line 457 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_GSETTINGS_CONFIGURATION_ENGINE, GSettingsConfigurationEngine);
#line 457 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	g_return_if_fail (domain != NULL);
#line 457 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	g_return_if_fail (id != NULL);
#line 457 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	g_return_if_fail (key != NULL);
#line 458 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp0_ = gsettings_configuration_engine_make_plugin_schema_name (domain, id);
#line 458 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	schema_name = _tmp0_;
#line 5381 "GSettingsEngine.c"
	{
		gchar* _tmp1_;
		gchar* _tmp2_;
#line 461 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_tmp1_ = gsettings_configuration_engine_make_gsettings_key (key);
#line 461 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_tmp2_ = _tmp1_;
#line 461 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		gsettings_configuration_engine_reset_gs_to_default (self, schema_name, _tmp2_, &_inner_error_);
#line 461 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_g_free0 (_tmp2_);
#line 461 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 461 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			if (_inner_error_->domain == CONFIGURATION_ERROR) {
#line 5397 "GSettingsEngine.c"
				goto __catch226_configuration_error;
			}
#line 461 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			_g_free0 (schema_name);
#line 461 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 461 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			g_clear_error (&_inner_error_);
#line 461 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			return;
#line 5408 "GSettingsEngine.c"
		}
	}
	goto __finally226;
	__catch226_configuration_error:
	{
		GError* err = NULL;
		GError* _tmp3_;
		const gchar* _tmp4_;
#line 460 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		err = _inner_error_;
#line 460 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_inner_error_ = NULL;
#line 463 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_tmp3_ = err;
#line 463 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_tmp4_ = _tmp3_->message;
#line 463 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		g_critical ("GSettingsEngine.vala:463: GSettingsConfigurationEngine: error: %s", _tmp4_);
#line 460 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_g_error_free0 (err);
#line 5429 "GSettingsEngine.c"
	}
	__finally226:
#line 460 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 460 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_g_free0 (schema_name);
#line 460 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 460 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		g_clear_error (&_inner_error_);
#line 460 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		return;
#line 5442 "GSettingsEngine.c"
	}
#line 457 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (schema_name);
#line 5446 "GSettingsEngine.c"
}


static FuzzyPropertyState
gsettings_configuration_engine_real_is_plugin_enabled (ConfigurationEngine* base,
                                                       const gchar* id)
{
	GSettingsConfigurationEngine * self;
	FuzzyPropertyState result = 0;
	gchar* enable_disable_name = NULL;
	gchar* _tmp0_;
	GError * _inner_error_ = NULL;
#line 467 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_GSETTINGS_CONFIGURATION_ENGINE, GSettingsConfigurationEngine);
#line 467 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	g_return_val_if_fail (id != NULL, 0);
#line 468 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp0_ = gsettings_configuration_engine_get_plugin_enable_disable_name (id);
#line 468 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	enable_disable_name = _tmp0_;
#line 5467 "GSettingsEngine.c"
	{
		FuzzyPropertyState _tmp1_ = 0;
		gboolean _tmp2_ = FALSE;
#line 471 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_tmp2_ = gsettings_configuration_engine_get_gs_bool (self, GSETTINGS_CONFIGURATION_ENGINE_PLUGINS_ENABLE_DISABLE_SCHEMA_NAME, enable_disable_name, &_inner_error_);
#line 471 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 471 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			if (_inner_error_->domain == CONFIGURATION_ERROR) {
#line 5477 "GSettingsEngine.c"
				goto __catch227_configuration_error;
			}
#line 471 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			_g_free0 (enable_disable_name);
#line 471 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 471 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			g_clear_error (&_inner_error_);
#line 471 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			return 0;
#line 5488 "GSettingsEngine.c"
		}
#line 471 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		if (_tmp2_) {
#line 472 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			_tmp1_ = FUZZY_PROPERTY_STATE_ENABLED;
#line 5494 "GSettingsEngine.c"
		} else {
#line 472 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			_tmp1_ = FUZZY_PROPERTY_STATE_DISABLED;
#line 5498 "GSettingsEngine.c"
		}
#line 471 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		result = _tmp1_;
#line 471 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_g_free0 (enable_disable_name);
#line 471 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		return result;
#line 5506 "GSettingsEngine.c"
	}
	goto __finally227;
	__catch227_configuration_error:
	{
		GError* err = NULL;
		GError* _tmp3_;
		const gchar* _tmp4_;
#line 470 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		err = _inner_error_;
#line 470 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_inner_error_ = NULL;
#line 474 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_tmp3_ = err;
#line 474 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_tmp4_ = _tmp3_->message;
#line 474 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		g_critical ("GSettingsEngine.vala:474: GSettingsConfigurationEngine: error: %s", _tmp4_);
#line 475 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		result = FUZZY_PROPERTY_STATE_UNKNOWN;
#line 475 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_g_error_free0 (err);
#line 475 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_g_free0 (enable_disable_name);
#line 475 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		return result;
#line 5532 "GSettingsEngine.c"
	}
	__finally227:
#line 470 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (enable_disable_name);
#line 470 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 470 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	g_clear_error (&_inner_error_);
#line 470 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	return 0;
#line 5543 "GSettingsEngine.c"
}


static void
gsettings_configuration_engine_real_set_plugin_enabled (ConfigurationEngine* base,
                                                        const gchar* id,
                                                        gboolean enabled)
{
	GSettingsConfigurationEngine * self;
	gchar* enable_disable_name = NULL;
	gchar* _tmp0_;
	GError * _inner_error_ = NULL;
#line 479 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_GSETTINGS_CONFIGURATION_ENGINE, GSettingsConfigurationEngine);
#line 479 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	g_return_if_fail (id != NULL);
#line 480 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp0_ = gsettings_configuration_engine_get_plugin_enable_disable_name (id);
#line 480 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	enable_disable_name = _tmp0_;
#line 5564 "GSettingsEngine.c"
	{
#line 483 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		gsettings_configuration_engine_set_gs_bool (self, GSETTINGS_CONFIGURATION_ENGINE_PLUGINS_ENABLE_DISABLE_SCHEMA_NAME, enable_disable_name, enabled, &_inner_error_);
#line 483 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 483 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			if (_inner_error_->domain == CONFIGURATION_ERROR) {
#line 5572 "GSettingsEngine.c"
				goto __catch228_configuration_error;
			}
#line 483 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			_g_free0 (enable_disable_name);
#line 483 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 483 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			g_clear_error (&_inner_error_);
#line 483 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
			return;
#line 5583 "GSettingsEngine.c"
		}
	}
	goto __finally228;
	__catch228_configuration_error:
	{
		GError* err = NULL;
		GError* _tmp1_;
		const gchar* _tmp2_;
#line 482 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		err = _inner_error_;
#line 482 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_inner_error_ = NULL;
#line 485 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_tmp1_ = err;
#line 485 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_tmp2_ = _tmp1_->message;
#line 485 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		g_critical ("GSettingsEngine.vala:485: GSettingsConfigurationEngine: error: %s", _tmp2_);
#line 482 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_g_error_free0 (err);
#line 5604 "GSettingsEngine.c"
	}
	__finally228:
#line 482 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 482 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_g_free0 (enable_disable_name);
#line 482 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 482 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		g_clear_error (&_inner_error_);
#line 482 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		return;
#line 5617 "GSettingsEngine.c"
	}
#line 479 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (enable_disable_name);
#line 5621 "GSettingsEngine.c"
}


void
gsettings_configuration_engine_run_gsettings_migrator (void)
{
	gchar* cmd_line = NULL;
	GFile* _tmp0_;
	GFile* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	gchar* _tmp4_;
	gchar* _tmp5_;
	GError * _inner_error_ = NULL;
#line 494 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp0_ = app_dirs_get_settings_migrator_bin ();
#line 494 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp1_ = _tmp0_;
#line 494 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp2_ = g_file_get_path (_tmp1_);
#line 494 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp3_ = _tmp2_;
#line 494 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp4_ = g_strconcat ("sh ", _tmp3_, NULL);
#line 494 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_tmp5_ = _tmp4_;
#line 494 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (_tmp3_);
#line 494 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_object_unref0 (_tmp1_);
#line 494 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	cmd_line = _tmp5_;
#line 5654 "GSettingsEngine.c"
	{
#line 497 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		g_spawn_command_line_sync (cmd_line, NULL, NULL, NULL, &_inner_error_);
#line 497 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 5660 "GSettingsEngine.c"
			goto __catch229_g_error;
		}
	}
	goto __finally229;
	__catch229_g_error:
	{
		GError* err = NULL;
		GError* _tmp6_;
		const gchar* _tmp7_;
#line 496 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		err = _inner_error_;
#line 496 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_inner_error_ = NULL;
#line 499 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_tmp6_ = err;
#line 499 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_tmp7_ = _tmp6_->message;
#line 499 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		g_message ("GSettingsEngine.vala:499: Error running shotwell-settings-migrator: %s", _tmp7_);
#line 496 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_g_error_free0 (err);
#line 5682 "GSettingsEngine.c"
	}
	__finally229:
#line 496 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 496 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		_g_free0 (cmd_line);
#line 496 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 496 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		g_clear_error (&_inner_error_);
#line 496 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
		return;
#line 5695 "GSettingsEngine.c"
	}
#line 493 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	_g_free0 (cmd_line);
#line 5699 "GSettingsEngine.c"
}


static void
gsettings_configuration_engine_class_init (GSettingsConfigurationEngineClass * klass)
{
#line 7 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	gsettings_configuration_engine_parent_class = g_type_class_peek_parent (klass);
#line 7 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	g_type_class_add_private (klass, sizeof (GSettingsConfigurationEnginePrivate));
#line 7 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	G_OBJECT_CLASS (klass)->finalize = gsettings_configuration_engine_finalize;
#line 5712 "GSettingsEngine.c"
}


static void
gsettings_configuration_engine_configuration_engine_interface_init (ConfigurationEngineIface * iface)
{
#line 7 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	gsettings_configuration_engine_configuration_engine_parent_iface = g_type_interface_peek_parent (iface);
#line 7 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	iface->get_name = (gchar* (*) (ConfigurationEngine *)) gsettings_configuration_engine_real_get_name;
#line 7 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	iface->get_enum_property = (gint (*) (ConfigurationEngine *, ConfigurableProperty, GError**)) gsettings_configuration_engine_real_get_enum_property;
#line 7 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	iface->set_enum_property = (void (*) (ConfigurationEngine *, ConfigurableProperty, gint, GError**)) gsettings_configuration_engine_real_set_enum_property;
#line 7 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	iface->get_int_property = (gint (*) (ConfigurationEngine *, ConfigurableProperty, GError**)) gsettings_configuration_engine_real_get_int_property;
#line 7 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	iface->set_int_property = (void (*) (ConfigurationEngine *, ConfigurableProperty, gint, GError**)) gsettings_configuration_engine_real_set_int_property;
#line 7 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	iface->get_string_property = (gchar* (*) (ConfigurationEngine *, ConfigurableProperty, GError**)) gsettings_configuration_engine_real_get_string_property;
#line 7 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	iface->set_string_property = (void (*) (ConfigurationEngine *, ConfigurableProperty, const gchar*, GError**)) gsettings_configuration_engine_real_set_string_property;
#line 7 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	iface->get_bool_property = (gboolean (*) (ConfigurationEngine *, ConfigurableProperty, GError**)) gsettings_configuration_engine_real_get_bool_property;
#line 7 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	iface->set_bool_property = (void (*) (ConfigurationEngine *, ConfigurableProperty, gboolean, GError**)) gsettings_configuration_engine_real_set_bool_property;
#line 7 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	iface->get_double_property = (gdouble (*) (ConfigurationEngine *, ConfigurableProperty, GError**)) gsettings_configuration_engine_real_get_double_property;
#line 7 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	iface->set_double_property = (void (*) (ConfigurationEngine *, ConfigurableProperty, gdouble, GError**)) gsettings_configuration_engine_real_set_double_property;
#line 7 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	iface->get_plugin_bool = (gboolean (*) (ConfigurationEngine *, const gchar*, const gchar*, const gchar*, gboolean)) gsettings_configuration_engine_real_get_plugin_bool;
#line 7 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	iface->set_plugin_bool = (void (*) (ConfigurationEngine *, const gchar*, const gchar*, const gchar*, gboolean)) gsettings_configuration_engine_real_set_plugin_bool;
#line 7 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	iface->get_plugin_double = (gdouble (*) (ConfigurationEngine *, const gchar*, const gchar*, const gchar*, gdouble)) gsettings_configuration_engine_real_get_plugin_double;
#line 7 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	iface->set_plugin_double = (void (*) (ConfigurationEngine *, const gchar*, const gchar*, const gchar*, gdouble)) gsettings_configuration_engine_real_set_plugin_double;
#line 7 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	iface->get_plugin_int = (gint (*) (ConfigurationEngine *, const gchar*, const gchar*, const gchar*, gint)) gsettings_configuration_engine_real_get_plugin_int;
#line 7 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	iface->set_plugin_int = (void (*) (ConfigurationEngine *, const gchar*, const gchar*, const gchar*, gint)) gsettings_configuration_engine_real_set_plugin_int;
#line 7 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	iface->get_plugin_string = (gchar* (*) (ConfigurationEngine *, const gchar*, const gchar*, const gchar*, const gchar*)) gsettings_configuration_engine_real_get_plugin_string;
#line 7 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	iface->set_plugin_string = (void (*) (ConfigurationEngine *, const gchar*, const gchar*, const gchar*, const gchar*)) gsettings_configuration_engine_real_set_plugin_string;
#line 7 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	iface->unset_plugin_key = (void (*) (ConfigurationEngine *, const gchar*, const gchar*, const gchar*)) gsettings_configuration_engine_real_unset_plugin_key;
#line 7 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	iface->is_plugin_enabled = (FuzzyPropertyState (*) (ConfigurationEngine *, const gchar*)) gsettings_configuration_engine_real_is_plugin_enabled;
#line 7 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	iface->set_plugin_enabled = (void (*) (ConfigurationEngine *, const gchar*, gboolean)) gsettings_configuration_engine_real_set_plugin_enabled;
#line 5765 "GSettingsEngine.c"
}


static void
gsettings_configuration_engine_instance_init (GSettingsConfigurationEngine * self)
{
#line 7 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	self->priv = GSETTINGS_CONFIGURATION_ENGINE_GET_PRIVATE (self);
#line 5774 "GSettingsEngine.c"
}


static void
gsettings_configuration_engine_finalize (GObject * obj)
{
	GSettingsConfigurationEngine * self;
#line 7 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_GSETTINGS_CONFIGURATION_ENGINE, GSettingsConfigurationEngine);
#line 26 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	self->priv->schema_names = (_vala_array_free (self->priv->schema_names, self->priv->schema_names_length1, (GDestroyNotify) g_free), NULL);
#line 27 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	self->priv->key_names = (_vala_array_free (self->priv->key_names, self->priv->key_names_length1, (GDestroyNotify) g_free), NULL);
#line 7 "/home/jens/Source/shotwell/src/config/GSettingsEngine.vala"
	G_OBJECT_CLASS (gsettings_configuration_engine_parent_class)->finalize (obj);
#line 5790 "GSettingsEngine.c"
}


GType
gsettings_configuration_engine_get_type (void)
{
	static volatile gsize gsettings_configuration_engine_type_id__volatile = 0;
	if (g_once_init_enter (&gsettings_configuration_engine_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GSettingsConfigurationEngineClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gsettings_configuration_engine_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GSettingsConfigurationEngine), 0, (GInstanceInitFunc) gsettings_configuration_engine_instance_init, NULL };
		static const GInterfaceInfo configuration_engine_info = { (GInterfaceInitFunc) gsettings_configuration_engine_configuration_engine_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType gsettings_configuration_engine_type_id;
		gsettings_configuration_engine_type_id = g_type_register_static (G_TYPE_OBJECT, "GSettingsConfigurationEngine", &g_define_type_info, 0);
		g_type_add_interface_static (gsettings_configuration_engine_type_id, TYPE_CONFIGURATION_ENGINE, &configuration_engine_info);
		g_once_init_leave (&gsettings_configuration_engine_type_id__volatile, gsettings_configuration_engine_type_id);
	}
	return gsettings_configuration_engine_type_id__volatile;
}


static void
_vala_array_destroy (gpointer array,
                     gint array_length,
                     GDestroyNotify destroy_func)
{
	if ((array != NULL) && (destroy_func != NULL)) {
		int i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}


static void
_vala_array_free (gpointer array,
                  gint array_length,
                  GDestroyNotify destroy_func)
{
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}



