/* Dialogs.c generated by valac 0.40.4, the Vala compiler
 * generated from Dialogs.vala, do not modify */

/* Copyright 2016 Software Freedom Conservancy Inc.
 *
 * This software is licensed under the GNU LGPL (version 2.1 or later).
 * See the COPYING file in this distribution.
 */
/* namespace for future migration of AppWindow alert and other question dialogs into single*/
/* place: http://trac.yorba.org/ticket/3452*/


#include <glib.h>
#include <glib-object.h>
#include <stdlib.h>
#include <string.h>
#include <glib/gi18n-lib.h>
#include <gtk/gtk.h>
#include <gio/gio.h>
#include <gee.h>
#include <gobject/gvaluecollector.h>


#define TYPE_DATA_OBJECT (data_object_get_type ())
#define DATA_OBJECT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DATA_OBJECT, DataObject))
#define DATA_OBJECT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DATA_OBJECT, DataObjectClass))
#define IS_DATA_OBJECT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DATA_OBJECT))
#define IS_DATA_OBJECT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DATA_OBJECT))
#define DATA_OBJECT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DATA_OBJECT, DataObjectClass))

typedef struct _DataObject DataObject;
typedef struct _DataObjectClass DataObjectClass;

#define TYPE_DATA_SOURCE (data_source_get_type ())
#define DATA_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DATA_SOURCE, DataSource))
#define DATA_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DATA_SOURCE, DataSourceClass))
#define IS_DATA_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DATA_SOURCE))
#define IS_DATA_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DATA_SOURCE))
#define DATA_SOURCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DATA_SOURCE, DataSourceClass))

typedef struct _DataSource DataSource;
typedef struct _DataSourceClass DataSourceClass;

#define TYPE_TAG (tag_get_type ())
#define TAG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_TAG, Tag))
#define TAG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_TAG, TagClass))
#define IS_TAG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_TAG))
#define IS_TAG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_TAG))
#define TAG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_TAG, TagClass))

typedef struct _Tag Tag;
typedef struct _TagClass TagClass;
#define _g_free0(var) (var = (g_free (var), NULL))

#define TYPE_SAVED_SEARCH (saved_search_get_type ())
#define SAVED_SEARCH(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SAVED_SEARCH, SavedSearch))
#define SAVED_SEARCH_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SAVED_SEARCH, SavedSearchClass))
#define IS_SAVED_SEARCH(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SAVED_SEARCH))
#define IS_SAVED_SEARCH_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SAVED_SEARCH))
#define SAVED_SEARCH_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SAVED_SEARCH, SavedSearchClass))

typedef struct _SavedSearch SavedSearch;
typedef struct _SavedSearchClass SavedSearchClass;

#define TYPE_PAGE_WINDOW (page_window_get_type ())
#define PAGE_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PAGE_WINDOW, PageWindow))
#define PAGE_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PAGE_WINDOW, PageWindowClass))
#define IS_PAGE_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PAGE_WINDOW))
#define IS_PAGE_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PAGE_WINDOW))
#define PAGE_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PAGE_WINDOW, PageWindowClass))

typedef struct _PageWindow PageWindow;
typedef struct _PageWindowClass PageWindowClass;

#define TYPE_APP_WINDOW (app_window_get_type ())
#define APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_APP_WINDOW, AppWindow))
#define APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_APP_WINDOW, AppWindowClass))
#define IS_APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_APP_WINDOW))
#define IS_APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_APP_WINDOW))
#define APP_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_APP_WINDOW, AppWindowClass))

typedef struct _AppWindow AppWindow;
typedef struct _AppWindowClass AppWindowClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define TYPE_THUMBNAIL_SOURCE (thumbnail_source_get_type ())
#define THUMBNAIL_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_THUMBNAIL_SOURCE, ThumbnailSource))
#define THUMBNAIL_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_THUMBNAIL_SOURCE, ThumbnailSourceClass))
#define IS_THUMBNAIL_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_THUMBNAIL_SOURCE))
#define IS_THUMBNAIL_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_THUMBNAIL_SOURCE))
#define THUMBNAIL_SOURCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_THUMBNAIL_SOURCE, ThumbnailSourceClass))

typedef struct _ThumbnailSource ThumbnailSource;
typedef struct _ThumbnailSourceClass ThumbnailSourceClass;

#define TYPE_MEDIA_SOURCE (media_source_get_type ())
#define MEDIA_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_MEDIA_SOURCE, MediaSource))
#define MEDIA_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_MEDIA_SOURCE, MediaSourceClass))
#define IS_MEDIA_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_MEDIA_SOURCE))
#define IS_MEDIA_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_MEDIA_SOURCE))
#define MEDIA_SOURCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_MEDIA_SOURCE, MediaSourceClass))

typedef struct _MediaSource MediaSource;
typedef struct _MediaSourceClass MediaSourceClass;

#define TYPE_PHOTO_SOURCE (photo_source_get_type ())
#define PHOTO_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PHOTO_SOURCE, PhotoSource))
#define PHOTO_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PHOTO_SOURCE, PhotoSourceClass))
#define IS_PHOTO_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PHOTO_SOURCE))
#define IS_PHOTO_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PHOTO_SOURCE))
#define PHOTO_SOURCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PHOTO_SOURCE, PhotoSourceClass))

typedef struct _PhotoSource PhotoSource;
typedef struct _PhotoSourceClass PhotoSourceClass;

#define TYPE_PHOTO (photo_get_type ())
#define PHOTO(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PHOTO, Photo))
#define PHOTO_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PHOTO, PhotoClass))
#define IS_PHOTO(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PHOTO))
#define IS_PHOTO_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PHOTO))
#define PHOTO_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PHOTO, PhotoClass))

typedef struct _Photo Photo;
typedef struct _PhotoClass PhotoClass;

#define TYPE_BATCH_IMPORT_RESULT (batch_import_result_get_type ())
#define BATCH_IMPORT_RESULT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_BATCH_IMPORT_RESULT, BatchImportResult))
#define BATCH_IMPORT_RESULT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_BATCH_IMPORT_RESULT, BatchImportResultClass))
#define IS_BATCH_IMPORT_RESULT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_BATCH_IMPORT_RESULT))
#define IS_BATCH_IMPORT_RESULT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_BATCH_IMPORT_RESULT))
#define BATCH_IMPORT_RESULT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_BATCH_IMPORT_RESULT, BatchImportResultClass))

typedef struct _BatchImportResult BatchImportResult;
typedef struct _BatchImportResultClass BatchImportResultClass;
typedef struct _BatchImportResultPrivate BatchImportResultPrivate;

#define TYPE_BATCH_IMPORT_JOB (batch_import_job_get_type ())
#define BATCH_IMPORT_JOB(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_BATCH_IMPORT_JOB, BatchImportJob))
#define BATCH_IMPORT_JOB_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_BATCH_IMPORT_JOB, BatchImportJobClass))
#define IS_BATCH_IMPORT_JOB(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_BATCH_IMPORT_JOB))
#define IS_BATCH_IMPORT_JOB_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_BATCH_IMPORT_JOB))
#define BATCH_IMPORT_JOB_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_BATCH_IMPORT_JOB, BatchImportJobClass))

typedef struct _BatchImportJob BatchImportJob;
typedef struct _BatchImportJobClass BatchImportJobClass;

#define TYPE_IMPORT_RESULT (import_result_get_type ())

#define TYPE_DUPLICATED_FILE (duplicated_file_get_type ())
#define DUPLICATED_FILE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DUPLICATED_FILE, DuplicatedFile))
#define DUPLICATED_FILE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DUPLICATED_FILE, DuplicatedFileClass))
#define IS_DUPLICATED_FILE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DUPLICATED_FILE))
#define IS_DUPLICATED_FILE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DUPLICATED_FILE))
#define DUPLICATED_FILE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DUPLICATED_FILE, DuplicatedFileClass))

typedef struct _DuplicatedFile DuplicatedFile;
typedef struct _DuplicatedFileClass DuplicatedFileClass;
#define _batch_import_result_unref0(var) ((var == NULL) ? NULL : (var = (batch_import_result_unref (var), NULL)))

#define IMPORT_UI_TYPE_QUESTION_PARAMS (import_ui_question_params_get_type ())
#define IMPORT_UI_QUESTION_PARAMS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), IMPORT_UI_TYPE_QUESTION_PARAMS, ImportUIQuestionParams))
#define IMPORT_UI_QUESTION_PARAMS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), IMPORT_UI_TYPE_QUESTION_PARAMS, ImportUIQuestionParamsClass))
#define IMPORT_UI_IS_QUESTION_PARAMS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), IMPORT_UI_TYPE_QUESTION_PARAMS))
#define IMPORT_UI_IS_QUESTION_PARAMS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), IMPORT_UI_TYPE_QUESTION_PARAMS))
#define IMPORT_UI_QUESTION_PARAMS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), IMPORT_UI_TYPE_QUESTION_PARAMS, ImportUIQuestionParamsClass))

typedef struct _ImportUIQuestionParams ImportUIQuestionParams;
typedef struct _ImportUIQuestionParamsClass ImportUIQuestionParamsClass;
typedef struct _ImportUIQuestionParamsPrivate ImportUIQuestionParamsPrivate;
typedef struct _ImportUIParamSpecQuestionParams ImportUIParamSpecQuestionParams;

#define TYPE_PHOTO_FILE_FORMAT (photo_file_format_get_type ())

#define TYPE_IMPORT_MANIFEST (import_manifest_get_type ())
#define IMPORT_MANIFEST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_IMPORT_MANIFEST, ImportManifest))
#define IMPORT_MANIFEST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_IMPORT_MANIFEST, ImportManifestClass))
#define IS_IMPORT_MANIFEST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_IMPORT_MANIFEST))
#define IS_IMPORT_MANIFEST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_IMPORT_MANIFEST))
#define IMPORT_MANIFEST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_IMPORT_MANIFEST, ImportManifestClass))

typedef struct _ImportManifest ImportManifest;
typedef struct _ImportManifestClass ImportManifestClass;
typedef struct _ImportManifestPrivate ImportManifestPrivate;
#define _g_string_free0(var) ((var == NULL) ? NULL : (var = (g_string_free (var, TRUE), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))

#define TYPE_TEXT_ENTRY_DIALOG_MEDIATOR (text_entry_dialog_mediator_get_type ())
#define TEXT_ENTRY_DIALOG_MEDIATOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_TEXT_ENTRY_DIALOG_MEDIATOR, TextEntryDialogMediator))
#define TEXT_ENTRY_DIALOG_MEDIATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_TEXT_ENTRY_DIALOG_MEDIATOR, TextEntryDialogMediatorClass))
#define IS_TEXT_ENTRY_DIALOG_MEDIATOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_TEXT_ENTRY_DIALOG_MEDIATOR))
#define IS_TEXT_ENTRY_DIALOG_MEDIATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_TEXT_ENTRY_DIALOG_MEDIATOR))
#define TEXT_ENTRY_DIALOG_MEDIATOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_TEXT_ENTRY_DIALOG_MEDIATOR, TextEntryDialogMediatorClass))

typedef struct _TextEntryDialogMediator TextEntryDialogMediator;
typedef struct _TextEntryDialogMediatorClass TextEntryDialogMediatorClass;
typedef struct _TextEntryDialogMediatorPrivate TextEntryDialogMediatorPrivate;

#define TYPE_TEXT_ENTRY_DIALOG (text_entry_dialog_get_type ())
#define TEXT_ENTRY_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_TEXT_ENTRY_DIALOG, TextEntryDialog))
#define TEXT_ENTRY_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_TEXT_ENTRY_DIALOG, TextEntryDialogClass))
#define IS_TEXT_ENTRY_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_TEXT_ENTRY_DIALOG))
#define IS_TEXT_ENTRY_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_TEXT_ENTRY_DIALOG))
#define TEXT_ENTRY_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_TEXT_ENTRY_DIALOG, TextEntryDialogClass))

typedef struct _TextEntryDialog TextEntryDialog;
typedef struct _TextEntryDialogClass TextEntryDialogClass;
typedef struct _ParamSpecTextEntryDialogMediator ParamSpecTextEntryDialogMediator;

#define TYPE_MULTI_TEXT_ENTRY_DIALOG_MEDIATOR (multi_text_entry_dialog_mediator_get_type ())
#define MULTI_TEXT_ENTRY_DIALOG_MEDIATOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_MULTI_TEXT_ENTRY_DIALOG_MEDIATOR, MultiTextEntryDialogMediator))
#define MULTI_TEXT_ENTRY_DIALOG_MEDIATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_MULTI_TEXT_ENTRY_DIALOG_MEDIATOR, MultiTextEntryDialogMediatorClass))
#define IS_MULTI_TEXT_ENTRY_DIALOG_MEDIATOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_MULTI_TEXT_ENTRY_DIALOG_MEDIATOR))
#define IS_MULTI_TEXT_ENTRY_DIALOG_MEDIATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_MULTI_TEXT_ENTRY_DIALOG_MEDIATOR))
#define MULTI_TEXT_ENTRY_DIALOG_MEDIATOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_MULTI_TEXT_ENTRY_DIALOG_MEDIATOR, MultiTextEntryDialogMediatorClass))

typedef struct _MultiTextEntryDialogMediator MultiTextEntryDialogMediator;
typedef struct _MultiTextEntryDialogMediatorClass MultiTextEntryDialogMediatorClass;
typedef struct _MultiTextEntryDialogMediatorPrivate MultiTextEntryDialogMediatorPrivate;

#define TYPE_MULTI_TEXT_ENTRY_DIALOG (multi_text_entry_dialog_get_type ())
#define MULTI_TEXT_ENTRY_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_MULTI_TEXT_ENTRY_DIALOG, MultiTextEntryDialog))
#define MULTI_TEXT_ENTRY_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_MULTI_TEXT_ENTRY_DIALOG, MultiTextEntryDialogClass))
#define IS_MULTI_TEXT_ENTRY_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_MULTI_TEXT_ENTRY_DIALOG))
#define IS_MULTI_TEXT_ENTRY_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_MULTI_TEXT_ENTRY_DIALOG))
#define MULTI_TEXT_ENTRY_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_MULTI_TEXT_ENTRY_DIALOG, MultiTextEntryDialogClass))

typedef struct _MultiTextEntryDialog MultiTextEntryDialog;
typedef struct _MultiTextEntryDialogClass MultiTextEntryDialogClass;
typedef struct _ParamSpecMultiTextEntryDialogMediator ParamSpecMultiTextEntryDialogMediator;

#define TYPE_EVENT_RENAME_DIALOG (event_rename_dialog_get_type ())
#define EVENT_RENAME_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_EVENT_RENAME_DIALOG, EventRenameDialog))
#define EVENT_RENAME_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_EVENT_RENAME_DIALOG, EventRenameDialogClass))
#define IS_EVENT_RENAME_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_EVENT_RENAME_DIALOG))
#define IS_EVENT_RENAME_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_EVENT_RENAME_DIALOG))
#define EVENT_RENAME_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_EVENT_RENAME_DIALOG, EventRenameDialogClass))

typedef struct _EventRenameDialog EventRenameDialog;
typedef struct _EventRenameDialogClass EventRenameDialogClass;
typedef struct _EventRenameDialogPrivate EventRenameDialogPrivate;

#define TYPE_EDIT_TITLE_DIALOG (edit_title_dialog_get_type ())
#define EDIT_TITLE_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_EDIT_TITLE_DIALOG, EditTitleDialog))
#define EDIT_TITLE_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_EDIT_TITLE_DIALOG, EditTitleDialogClass))
#define IS_EDIT_TITLE_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_EDIT_TITLE_DIALOG))
#define IS_EDIT_TITLE_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_EDIT_TITLE_DIALOG))
#define EDIT_TITLE_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_EDIT_TITLE_DIALOG, EditTitleDialogClass))

typedef struct _EditTitleDialog EditTitleDialog;
typedef struct _EditTitleDialogClass EditTitleDialogClass;
typedef struct _EditTitleDialogPrivate EditTitleDialogPrivate;

#define TYPE_EDIT_COMMENT_DIALOG (edit_comment_dialog_get_type ())
#define EDIT_COMMENT_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_EDIT_COMMENT_DIALOG, EditCommentDialog))
#define EDIT_COMMENT_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_EDIT_COMMENT_DIALOG, EditCommentDialogClass))
#define IS_EDIT_COMMENT_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_EDIT_COMMENT_DIALOG))
#define IS_EDIT_COMMENT_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_EDIT_COMMENT_DIALOG))
#define EDIT_COMMENT_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_EDIT_COMMENT_DIALOG, EditCommentDialogClass))

typedef struct _EditCommentDialog EditCommentDialog;
typedef struct _EditCommentDialogClass EditCommentDialogClass;
typedef struct _EditCommentDialogPrivate EditCommentDialogPrivate;

#define TYPE_TAGS_DIALOG (tags_dialog_get_type ())
#define TAGS_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_TAGS_DIALOG, TagsDialog))
#define TAGS_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_TAGS_DIALOG, TagsDialogClass))
#define IS_TAGS_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_TAGS_DIALOG))
#define IS_TAGS_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_TAGS_DIALOG))
#define TAGS_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_TAGS_DIALOG, TagsDialogClass))

typedef struct _TagsDialog TagsDialog;
typedef struct _TagsDialogClass TagsDialogClass;
typedef struct _TagsDialogPrivate TagsDialogPrivate;

#define TYPE_HIERARCHICAL_TAG_INDEX (hierarchical_tag_index_get_type ())
#define HIERARCHICAL_TAG_INDEX(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_HIERARCHICAL_TAG_INDEX, HierarchicalTagIndex))
#define HIERARCHICAL_TAG_INDEX_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_HIERARCHICAL_TAG_INDEX, HierarchicalTagIndexClass))
#define IS_HIERARCHICAL_TAG_INDEX(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_HIERARCHICAL_TAG_INDEX))
#define IS_HIERARCHICAL_TAG_INDEX_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_HIERARCHICAL_TAG_INDEX))
#define HIERARCHICAL_TAG_INDEX_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_HIERARCHICAL_TAG_INDEX, HierarchicalTagIndexClass))

typedef struct _HierarchicalTagIndex HierarchicalTagIndex;
typedef struct _HierarchicalTagIndexClass HierarchicalTagIndexClass;
#define _hierarchical_tag_index_unref0(var) ((var == NULL) ? NULL : (var = (hierarchical_tag_index_unref (var), NULL)))

#define TYPE_ADD_TAGS_DIALOG (add_tags_dialog_get_type ())
#define ADD_TAGS_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_ADD_TAGS_DIALOG, AddTagsDialog))
#define ADD_TAGS_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_ADD_TAGS_DIALOG, AddTagsDialogClass))
#define IS_ADD_TAGS_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_ADD_TAGS_DIALOG))
#define IS_ADD_TAGS_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_ADD_TAGS_DIALOG))
#define ADD_TAGS_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_ADD_TAGS_DIALOG, AddTagsDialogClass))

typedef struct _AddTagsDialog AddTagsDialog;
typedef struct _AddTagsDialogClass AddTagsDialogClass;
typedef struct _AddTagsDialogPrivate AddTagsDialogPrivate;

#define TYPE_MODIFY_TAGS_DIALOG (modify_tags_dialog_get_type ())
#define MODIFY_TAGS_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_MODIFY_TAGS_DIALOG, ModifyTagsDialog))
#define MODIFY_TAGS_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_MODIFY_TAGS_DIALOG, ModifyTagsDialogClass))
#define IS_MODIFY_TAGS_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_MODIFY_TAGS_DIALOG))
#define IS_MODIFY_TAGS_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_MODIFY_TAGS_DIALOG))
#define MODIFY_TAGS_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_MODIFY_TAGS_DIALOG, ModifyTagsDialogClass))

typedef struct _ModifyTagsDialog ModifyTagsDialog;
typedef struct _ModifyTagsDialogClass ModifyTagsDialogClass;
typedef struct _ModifyTagsDialogPrivate ModifyTagsDialogPrivate;

#define TYPE_DATA_COLLECTION (data_collection_get_type ())
#define DATA_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DATA_COLLECTION, DataCollection))
#define DATA_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DATA_COLLECTION, DataCollectionClass))
#define IS_DATA_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DATA_COLLECTION))
#define IS_DATA_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DATA_COLLECTION))
#define DATA_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DATA_COLLECTION, DataCollectionClass))

typedef struct _DataCollection DataCollection;
typedef struct _DataCollectionClass DataCollectionClass;

#define TYPE_SOURCE_COLLECTION (source_collection_get_type ())
#define SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SOURCE_COLLECTION, SourceCollection))
#define SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SOURCE_COLLECTION, SourceCollectionClass))
#define IS_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SOURCE_COLLECTION))
#define IS_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SOURCE_COLLECTION))
#define SOURCE_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SOURCE_COLLECTION, SourceCollectionClass))

typedef struct _SourceCollection SourceCollection;
typedef struct _SourceCollectionClass SourceCollectionClass;

#define TYPE_DATABASE_SOURCE_COLLECTION (database_source_collection_get_type ())
#define DATABASE_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DATABASE_SOURCE_COLLECTION, DatabaseSourceCollection))
#define DATABASE_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DATABASE_SOURCE_COLLECTION, DatabaseSourceCollectionClass))
#define IS_DATABASE_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DATABASE_SOURCE_COLLECTION))
#define IS_DATABASE_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DATABASE_SOURCE_COLLECTION))
#define DATABASE_SOURCE_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DATABASE_SOURCE_COLLECTION, DatabaseSourceCollectionClass))

typedef struct _DatabaseSourceCollection DatabaseSourceCollection;
typedef struct _DatabaseSourceCollectionClass DatabaseSourceCollectionClass;

#define TYPE_CONTAINER_SOURCE_COLLECTION (container_source_collection_get_type ())
#define CONTAINER_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_CONTAINER_SOURCE_COLLECTION, ContainerSourceCollection))
#define CONTAINER_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_CONTAINER_SOURCE_COLLECTION, ContainerSourceCollectionClass))
#define IS_CONTAINER_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_CONTAINER_SOURCE_COLLECTION))
#define IS_CONTAINER_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_CONTAINER_SOURCE_COLLECTION))
#define CONTAINER_SOURCE_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_CONTAINER_SOURCE_COLLECTION, ContainerSourceCollectionClass))

typedef struct _ContainerSourceCollection ContainerSourceCollection;
typedef struct _ContainerSourceCollectionClass ContainerSourceCollectionClass;

#define TYPE_TAG_SOURCE_COLLECTION (tag_source_collection_get_type ())
#define TAG_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_TAG_SOURCE_COLLECTION, TagSourceCollection))
#define TAG_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_TAG_SOURCE_COLLECTION, TagSourceCollectionClass))
#define IS_TAG_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_TAG_SOURCE_COLLECTION))
#define IS_TAG_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_TAG_SOURCE_COLLECTION))
#define TAG_SOURCE_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_TAG_SOURCE_COLLECTION, TagSourceCollectionClass))

typedef struct _TagSourceCollection TagSourceCollection;
typedef struct _TagSourceCollectionClass TagSourceCollectionClass;

#define TYPE_LIBRARY_PHOTO (library_photo_get_type ())
#define LIBRARY_PHOTO(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_LIBRARY_PHOTO, LibraryPhoto))
#define LIBRARY_PHOTO_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_LIBRARY_PHOTO, LibraryPhotoClass))
#define IS_LIBRARY_PHOTO(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_LIBRARY_PHOTO))
#define IS_LIBRARY_PHOTO_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_LIBRARY_PHOTO))
#define LIBRARY_PHOTO_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_LIBRARY_PHOTO, LibraryPhotoClass))

typedef struct _LibraryPhoto LibraryPhoto;
typedef struct _LibraryPhotoClass LibraryPhotoClass;

#define TYPE_VIDEO_SOURCE (video_source_get_type ())
#define VIDEO_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_VIDEO_SOURCE, VideoSource))
#define VIDEO_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_VIDEO_SOURCE, VideoSourceClass))
#define IS_VIDEO_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_VIDEO_SOURCE))
#define IS_VIDEO_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_VIDEO_SOURCE))
#define VIDEO_SOURCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_VIDEO_SOURCE, VideoSourceClass))

typedef struct _VideoSource VideoSource;
typedef struct _VideoSourceClass VideoSourceClass;

#define TYPE_VIDEO (video_get_type ())
#define VIDEO(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_VIDEO, Video))
#define VIDEO_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_VIDEO, VideoClass))
#define IS_VIDEO(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_VIDEO))
#define IS_VIDEO_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_VIDEO))
#define VIDEO_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_VIDEO, VideoClass))

typedef struct _Video Video;
typedef struct _VideoClass VideoClass;

#define TYPE_PROGRESS_DIALOG (progress_dialog_get_type ())
#define PROGRESS_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PROGRESS_DIALOG, ProgressDialog))
#define PROGRESS_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PROGRESS_DIALOG, ProgressDialogClass))
#define IS_PROGRESS_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PROGRESS_DIALOG))
#define IS_PROGRESS_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PROGRESS_DIALOG))
#define PROGRESS_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PROGRESS_DIALOG, ProgressDialogClass))

typedef struct _ProgressDialog ProgressDialog;
typedef struct _ProgressDialogClass ProgressDialogClass;

#define TYPE_MEDIA_SOURCE_COLLECTION (media_source_collection_get_type ())
#define MEDIA_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_MEDIA_SOURCE_COLLECTION, MediaSourceCollection))
#define MEDIA_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_MEDIA_SOURCE_COLLECTION, MediaSourceCollectionClass))
#define IS_MEDIA_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_MEDIA_SOURCE_COLLECTION))
#define IS_MEDIA_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_MEDIA_SOURCE_COLLECTION))
#define MEDIA_SOURCE_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_MEDIA_SOURCE_COLLECTION, MediaSourceCollectionClass))

typedef struct _MediaSourceCollection MediaSourceCollection;
typedef struct _MediaSourceCollectionClass MediaSourceCollectionClass;

#define TYPE_LIBRARY_PHOTO_SOURCE_COLLECTION (library_photo_source_collection_get_type ())
#define LIBRARY_PHOTO_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_LIBRARY_PHOTO_SOURCE_COLLECTION, LibraryPhotoSourceCollection))
#define LIBRARY_PHOTO_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_LIBRARY_PHOTO_SOURCE_COLLECTION, LibraryPhotoSourceCollectionClass))
#define IS_LIBRARY_PHOTO_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_LIBRARY_PHOTO_SOURCE_COLLECTION))
#define IS_LIBRARY_PHOTO_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_LIBRARY_PHOTO_SOURCE_COLLECTION))
#define LIBRARY_PHOTO_SOURCE_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_LIBRARY_PHOTO_SOURCE_COLLECTION, LibraryPhotoSourceCollectionClass))

typedef struct _LibraryPhotoSourceCollection LibraryPhotoSourceCollection;
typedef struct _LibraryPhotoSourceCollectionClass LibraryPhotoSourceCollectionClass;

#define TYPE_VIDEO_SOURCE_COLLECTION (video_source_collection_get_type ())
#define VIDEO_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_VIDEO_SOURCE_COLLECTION, VideoSourceCollection))
#define VIDEO_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_VIDEO_SOURCE_COLLECTION, VideoSourceCollectionClass))
#define IS_VIDEO_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_VIDEO_SOURCE_COLLECTION))
#define IS_VIDEO_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_VIDEO_SOURCE_COLLECTION))
#define VIDEO_SOURCE_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_VIDEO_SOURCE_COLLECTION, VideoSourceCollectionClass))

typedef struct _VideoSourceCollection VideoSourceCollection;
typedef struct _VideoSourceCollectionClass VideoSourceCollectionClass;
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);
#define _vala_return_if_fail(expr, msg) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return; }
#define _vala_return_val_if_fail(expr, msg, val) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return val; }
#define _vala_warn_if_fail(expr, msg) if G_LIKELY (expr) ; else g_warn_message (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

typedef enum  {
	IMPORT_RESULT_SUCCESS,
	IMPORT_RESULT_FILE_ERROR,
	IMPORT_RESULT_DECODE_ERROR,
	IMPORT_RESULT_DATABASE_ERROR,
	IMPORT_RESULT_USER_ABORT,
	IMPORT_RESULT_NOT_A_FILE,
	IMPORT_RESULT_PHOTO_EXISTS,
	IMPORT_RESULT_UNSUPPORTED_FORMAT,
	IMPORT_RESULT_NOT_AN_IMAGE,
	IMPORT_RESULT_DISK_FAILURE,
	IMPORT_RESULT_DISK_FULL,
	IMPORT_RESULT_CAMERA_ERROR,
	IMPORT_RESULT_FILE_WRITE_ERROR,
	IMPORT_RESULT_PIXBUF_CORRUPT_IMAGE
} ImportResult;

struct _BatchImportResult {
	GTypeInstance parent_instance;
	volatile int ref_count;
	BatchImportResultPrivate * priv;
	BatchImportJob* job;
	GFile* file;
	gchar* src_identifier;
	gchar* dest_identifier;
	ImportResult result;
	gchar* errmsg;
	DuplicatedFile* duplicate_of;
};

struct _BatchImportResultClass {
	GTypeClass parent_class;
	void (*finalize) (BatchImportResult *self);
};

struct _ImportUIQuestionParams {
	GTypeInstance parent_instance;
	volatile int ref_count;
	ImportUIQuestionParamsPrivate * priv;
	gchar* question;
	gchar* yes_button;
	gchar* no_button;
};

struct _ImportUIQuestionParamsClass {
	GTypeClass parent_class;
	void (*finalize) (ImportUIQuestionParams *self);
};

struct _ImportUIParamSpecQuestionParams {
	GParamSpec parent_instance;
};

typedef enum  {
	PHOTO_FILE_FORMAT_JFIF,
	PHOTO_FILE_FORMAT_RAW,
	PHOTO_FILE_FORMAT_PNG,
	PHOTO_FILE_FORMAT_TIFF,
	PHOTO_FILE_FORMAT_BMP,
	PHOTO_FILE_FORMAT_UNKNOWN
} PhotoFileFormat;

struct _ImportManifest {
	GTypeInstance parent_instance;
	volatile int ref_count;
	ImportManifestPrivate * priv;
	GeeList* imported;
	GeeList* success;
	GeeList* camera_failed;
	GeeList* failed;
	GeeList* write_failed;
	GeeList* skipped_photos;
	GeeList* skipped_files;
	GeeList* aborted;
	GeeList* already_imported;
	GeeList* corrupt_files;
	GeeList* all;
	GTimer* timer;
};

struct _ImportManifestClass {
	GTypeClass parent_class;
	void (*finalize) (ImportManifest *self);
};

struct _TextEntryDialogMediator {
	GTypeInstance parent_instance;
	volatile int ref_count;
	TextEntryDialogMediatorPrivate * priv;
};

struct _TextEntryDialogMediatorClass {
	GTypeClass parent_class;
	void (*finalize) (TextEntryDialogMediator *self);
	gboolean (*on_modify_validate) (TextEntryDialogMediator* self, const gchar* text);
};

struct _TextEntryDialogMediatorPrivate {
	TextEntryDialog* dialog;
};

typedef gboolean (*TextEntryDialogOnModifyValidateType) (const gchar* text, void* user_data);
struct _ParamSpecTextEntryDialogMediator {
	GParamSpec parent_instance;
};

struct _MultiTextEntryDialogMediator {
	GTypeInstance parent_instance;
	volatile int ref_count;
	MultiTextEntryDialogMediatorPrivate * priv;
};

struct _MultiTextEntryDialogMediatorClass {
	GTypeClass parent_class;
	void (*finalize) (MultiTextEntryDialogMediator *self);
	gboolean (*on_modify_validate) (MultiTextEntryDialogMediator* self, const gchar* text);
};

struct _MultiTextEntryDialogMediatorPrivate {
	MultiTextEntryDialog* dialog;
};

typedef gboolean (*MultiTextEntryDialogOnModifyValidateType) (const gchar* text, void* user_data);
struct _ParamSpecMultiTextEntryDialogMediator {
	GParamSpec parent_instance;
};

struct _EventRenameDialog {
	TextEntryDialogMediator parent_instance;
	EventRenameDialogPrivate * priv;
};

struct _EventRenameDialogClass {
	TextEntryDialogMediatorClass parent_class;
	gchar* (*execute) (EventRenameDialog* self);
};

struct _EditTitleDialog {
	TextEntryDialogMediator parent_instance;
	EditTitleDialogPrivate * priv;
};

struct _EditTitleDialogClass {
	TextEntryDialogMediatorClass parent_class;
	gchar* (*execute) (EditTitleDialog* self);
};

struct _EditCommentDialog {
	MultiTextEntryDialogMediator parent_instance;
	EditCommentDialogPrivate * priv;
};

struct _EditCommentDialogClass {
	MultiTextEntryDialogMediatorClass parent_class;
	gchar* (*execute) (EditCommentDialog* self);
};

struct _TagsDialog {
	TextEntryDialogMediator parent_instance;
	TagsDialogPrivate * priv;
};

struct _TagsDialogClass {
	TextEntryDialogMediatorClass parent_class;
};

struct _AddTagsDialog {
	TagsDialog parent_instance;
	AddTagsDialogPrivate * priv;
};

struct _AddTagsDialogClass {
	TagsDialogClass parent_class;
};

struct _ModifyTagsDialog {
	TagsDialog parent_instance;
	ModifyTagsDialogPrivate * priv;
};

struct _ModifyTagsDialogClass {
	TagsDialogClass parent_class;
};

typedef gboolean (*ProgressMonitor) (guint64 current, guint64 total, gboolean do_event_loop, void* user_data);

extern GFile* export_ui_current_export_dir;
GFile* export_ui_current_export_dir = NULL;
static gpointer import_ui_question_params_parent_class = NULL;
static gpointer text_entry_dialog_mediator_parent_class = NULL;
static gpointer multi_text_entry_dialog_mediator_parent_class = NULL;
static gpointer event_rename_dialog_parent_class = NULL;
static gpointer edit_title_dialog_parent_class = NULL;
static gpointer edit_comment_dialog_parent_class = NULL;
static gpointer tags_dialog_parent_class = NULL;
static gpointer add_tags_dialog_parent_class = NULL;
static gpointer modify_tags_dialog_parent_class = NULL;
extern TagSourceCollection* tag_global;
extern LibraryPhotoSourceCollection* library_photo_global;
extern VideoSourceCollection* video_global;

GType data_object_get_type (void) G_GNUC_CONST;
GType data_source_get_type (void) G_GNUC_CONST;
GType tag_get_type (void) G_GNUC_CONST;
gboolean dialogs_confirm_delete_tag (Tag* tag);
gint tag_get_sources_count (Tag* self);
gchar* tag_get_user_visible_name (Tag* self);
gboolean app_window_negate_affirm_question (const gchar* message,
                                            const gchar* negative,
                                            const gchar* affirmative,
                                            const gchar* title,
                                            GtkWindow* parent);
#define RESOURCES_DELETE_TAG_TITLE _ ("Delete Tag")
GType saved_search_get_type (void) G_GNUC_CONST;
gboolean dialogs_confirm_delete_saved_search (SavedSearch* search);
gchar* data_object_get_name (DataObject* self);
#define RESOURCES_DELETE_SAVED_SEARCH_DIALOG_TITLE _ ("Delete Search")
gboolean dialogs_confirm_warn_developer_changed (gint number);
GType page_window_get_type (void) G_GNUC_CONST;
GType app_window_get_type (void) G_GNUC_CONST;
AppWindow* app_window_get_instance (void);
#define RESOURCES_CANCEL_LABEL _ ("_Cancel")
GFile* export_ui_choose_file (const gchar* current_file_basename);
gboolean video_reader_is_supported_video_filename (const gchar* filename);
#define RESOURCES_SAVE_LABEL _ ("_Save")
GFile* export_ui_choose_dir (const gchar* user_title);
#define RESOURCES_OK_LABEL _ ("_OK")
GType thumbnail_source_get_type (void) G_GNUC_CONST;
GType media_source_get_type (void) G_GNUC_CONST;
GType photo_source_get_type (void) G_GNUC_CONST;
GType photo_get_type (void) G_GNUC_CONST;
void open_external_editor_error_dialog (GError* err,
                                        Photo* photo);
void app_window_error_message (const gchar* message,
                               GtkWindow* parent);
GFile* media_source_get_master_file (MediaSource* self);
gchar* resources_launch_editor_failed (GError* err);
GtkResponseType export_error_dialog (GFile* dest,
                                     gboolean photos_remaining);
GtkResponseType app_window_affirm_cancel_question (const gchar* message,
                                                   const gchar* affirmative,
                                                   const gchar* title,
                                                   GtkWindow* parent);
#define IMPORT_UI_REPORT_FAILURE_COUNT 4
#define IMPORT_UI_SAVE_RESULTS_BUTTON_NAME _ ("Save Details…")
#define IMPORT_UI_SAVE_RESULTS_FILE_CHOOSER_TITLE _ ("Save Details")
#define IMPORT_UI_SAVE_RESULTS_RESPONSE_ID 1024
gpointer batch_import_result_ref (gpointer instance);
void batch_import_result_unref (gpointer instance);
GParamSpec* param_spec_batch_import_result (const gchar* name,
                                            const gchar* nick,
                                            const gchar* blurb,
                                            GType object_type,
                                            GParamFlags flags);
void value_set_batch_import_result (GValue* value,
                                    gpointer v_object);
void value_take_batch_import_result (GValue* value,
                                     gpointer v_object);
gpointer value_get_batch_import_result (const GValue* value);
GType batch_import_result_get_type (void) G_GNUC_CONST;
gchar* import_ui_generate_import_failure_list (GeeList* failed,
                                               gboolean show_dest_id);
gpointer batch_import_job_ref (gpointer instance);
void batch_import_job_unref (gpointer instance);
GParamSpec* param_spec_batch_import_job (const gchar* name,
                                         const gchar* nick,
                                         const gchar* blurb,
                                         GType object_type,
                                         GParamFlags flags);
void value_set_batch_import_job (GValue* value,
                                 gpointer v_object);
void value_take_batch_import_job (GValue* value,
                                  gpointer v_object);
gpointer value_get_batch_import_job (const GValue* value);
GType batch_import_job_get_type (void) G_GNUC_CONST;
GType import_result_get_type (void) G_GNUC_CONST;
GType duplicated_file_get_type (void) G_GNUC_CONST;
gpointer import_ui_question_params_ref (gpointer instance);
void import_ui_question_params_unref (gpointer instance);
GParamSpec* import_ui_param_spec_question_params (const gchar* name,
                                                  const gchar* nick,
                                                  const gchar* blurb,
                                                  GType object_type,
                                                  GParamFlags flags);
void import_ui_value_set_question_params (GValue* value,
                                          gpointer v_object);
void import_ui_value_take_question_params (GValue* value,
                                           gpointer v_object);
gpointer import_ui_value_get_question_params (const GValue* value);
GType import_ui_question_params_get_type (void) G_GNUC_CONST;
ImportUIQuestionParams* import_ui_question_params_new (const gchar* question,
                                                       const gchar* yes_button,
                                                       const gchar* no_button);
ImportUIQuestionParams* import_ui_question_params_construct (GType object_type,
                                                             const gchar* question,
                                                             const gchar* yes_button,
                                                             const gchar* no_button);
static void import_ui_question_params_finalize (ImportUIQuestionParams * obj);
gboolean import_ui_import_has_photos (GeeCollection* import_collection);
GType photo_file_format_get_type (void) G_GNUC_CONST;
PhotoFileFormat photo_file_format_get_by_file_extension (GFile* file);
gboolean import_ui_import_has_videos (GeeCollection* import_collection);
gboolean video_reader_is_supported_video_file (GFile* file);
gchar* import_ui_get_media_specific_string (GeeCollection* import_collection,
                                            const gchar* photos_msg,
                                            const gchar* videos_msg,
                                            const gchar* both_msg,
                                            const gchar* neither_msg);
gpointer import_manifest_ref (gpointer instance);
void import_manifest_unref (gpointer instance);
GParamSpec* param_spec_import_manifest (const gchar* name,
                                        const gchar* nick,
                                        const gchar* blurb,
                                        GType object_type,
                                        GParamFlags flags);
void value_set_import_manifest (GValue* value,
                                gpointer v_object);
void value_take_import_manifest (GValue* value,
                                 gpointer v_object);
gpointer value_get_import_manifest (const GValue* value);
GType import_manifest_get_type (void) G_GNUC_CONST;
gchar* import_ui_create_result_report_from_manifest (ImportManifest* manifest);
#define RESOURCES_APP_VERSION _VERSION
GFile* duplicated_file_get_file (DuplicatedFile* self);
gboolean import_ui_report_manifest (ImportManifest* manifest,
                                    gboolean show_dest_id,
                                    ImportUIQuestionParams* question);
void import_ui_save_import_results (GtkWindow* chooser_dialog_parent,
                                    const gchar* results_log);
#define RESOURCES_SAVE_AS_LABEL _ ("Save _As")
gpointer text_entry_dialog_mediator_ref (gpointer instance);
void text_entry_dialog_mediator_unref (gpointer instance);
GParamSpec* param_spec_text_entry_dialog_mediator (const gchar* name,
                                                   const gchar* nick,
                                                   const gchar* blurb,
                                                   GType object_type,
                                                   GParamFlags flags);
void value_set_text_entry_dialog_mediator (GValue* value,
                                           gpointer v_object);
void value_take_text_entry_dialog_mediator (GValue* value,
                                            gpointer v_object);
gpointer value_get_text_entry_dialog_mediator (const GValue* value);
GType text_entry_dialog_mediator_get_type (void) G_GNUC_CONST;
GType text_entry_dialog_get_type (void) G_GNUC_CONST;
#define TEXT_ENTRY_DIALOG_MEDIATOR_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_TEXT_ENTRY_DIALOG_MEDIATOR, TextEntryDialogMediatorPrivate))
TextEntryDialogMediator* text_entry_dialog_mediator_construct (GType object_type,
                                                               const gchar* title,
                                                               const gchar* label,
                                                               const gchar* initial_text,
                                                               GeeCollection* completion_list,
                                                               const gchar* completion_delimiter);
TextEntryDialog* text_entry_dialog_new (void);
TextEntryDialog* text_entry_dialog_construct (GType object_type);
void text_entry_dialog_setup (TextEntryDialog* self,
                              TextEntryDialogOnModifyValidateType modify_validate,
                              void* modify_validate_target,
                              const gchar* title,
                              const gchar* label,
                              const gchar* initial_text,
                              GeeCollection* completion_list,
                              const gchar* completion_delimiter);
gboolean text_entry_dialog_mediator_on_modify_validate (TextEntryDialogMediator* self,
                                                        const gchar* text);
static gboolean _text_entry_dialog_mediator_on_modify_validate_text_entry_dialog_on_modify_validate_type (const gchar* text,
                                                                                                   gpointer self);
static gboolean text_entry_dialog_mediator_real_on_modify_validate (TextEntryDialogMediator* self,
                                                             const gchar* text);
gchar* _text_entry_dialog_mediator_execute (TextEntryDialogMediator* self);
gchar* text_entry_dialog_execute (TextEntryDialog* self);
static void text_entry_dialog_mediator_finalize (TextEntryDialogMediator * obj);
gpointer multi_text_entry_dialog_mediator_ref (gpointer instance);
void multi_text_entry_dialog_mediator_unref (gpointer instance);
GParamSpec* param_spec_multi_text_entry_dialog_mediator (const gchar* name,
                                                         const gchar* nick,
                                                         const gchar* blurb,
                                                         GType object_type,
                                                         GParamFlags flags);
void value_set_multi_text_entry_dialog_mediator (GValue* value,
                                                 gpointer v_object);
void value_take_multi_text_entry_dialog_mediator (GValue* value,
                                                  gpointer v_object);
gpointer value_get_multi_text_entry_dialog_mediator (const GValue* value);
GType multi_text_entry_dialog_mediator_get_type (void) G_GNUC_CONST;
GType multi_text_entry_dialog_get_type (void) G_GNUC_CONST;
#define MULTI_TEXT_ENTRY_DIALOG_MEDIATOR_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_MULTI_TEXT_ENTRY_DIALOG_MEDIATOR, MultiTextEntryDialogMediatorPrivate))
MultiTextEntryDialogMediator* multi_text_entry_dialog_mediator_construct (GType object_type,
                                                                          const gchar* title,
                                                                          const gchar* label,
                                                                          const gchar* initial_text);
MultiTextEntryDialog* multi_text_entry_dialog_new (void);
MultiTextEntryDialog* multi_text_entry_dialog_construct (GType object_type);
void multi_text_entry_dialog_setup (MultiTextEntryDialog* self,
                                    MultiTextEntryDialogOnModifyValidateType modify_validate,
                                    void* modify_validate_target,
                                    const gchar* title,
                                    const gchar* label,
                                    const gchar* initial_text);
gboolean multi_text_entry_dialog_mediator_on_modify_validate (MultiTextEntryDialogMediator* self,
                                                              const gchar* text);
static gboolean _multi_text_entry_dialog_mediator_on_modify_validate_multi_text_entry_dialog_on_modify_validate_type (const gchar* text,
                                                                                                               gpointer self);
static gboolean multi_text_entry_dialog_mediator_real_on_modify_validate (MultiTextEntryDialogMediator* self,
                                                                   const gchar* text);
gchar* _multi_text_entry_dialog_mediator_execute (MultiTextEntryDialogMediator* self);
gchar* multi_text_entry_dialog_execute (MultiTextEntryDialog* self);
static void multi_text_entry_dialog_mediator_finalize (MultiTextEntryDialogMediator * obj);
gchar* build_alert_body_text (const gchar* primary_text,
                              const gchar* secondary_text,
                              gboolean should_escape);
gchar* guarded_markup_escape_text (const gchar* plain);
GType event_rename_dialog_get_type (void) G_GNUC_CONST;
EventRenameDialog* event_rename_dialog_new (const gchar* event_name);
EventRenameDialog* event_rename_dialog_construct (GType object_type,
                                                  const gchar* event_name);
gchar* event_rename_dialog_execute (EventRenameDialog* self);
static gchar* event_rename_dialog_real_execute (EventRenameDialog* self);
gchar* event_prep_event_name (const gchar* name);
GType edit_title_dialog_get_type (void) G_GNUC_CONST;
EditTitleDialog* edit_title_dialog_new (const gchar* photo_title);
EditTitleDialog* edit_title_dialog_construct (GType object_type,
                                              const gchar* photo_title);
gchar* edit_title_dialog_execute (EditTitleDialog* self);
static gchar* edit_title_dialog_real_execute (EditTitleDialog* self);
gchar* media_source_prep_title (const gchar* title);
static gboolean edit_title_dialog_real_on_modify_validate (TextEntryDialogMediator* base,
                                                    const gchar* text);
GType edit_comment_dialog_get_type (void) G_GNUC_CONST;
EditCommentDialog* edit_comment_dialog_new (const gchar* comment,
                                            gboolean is_event);
EditCommentDialog* edit_comment_dialog_construct (GType object_type,
                                                  const gchar* comment,
                                                  gboolean is_event);
gchar* edit_comment_dialog_execute (EditCommentDialog* self);
static gchar* edit_comment_dialog_real_execute (EditCommentDialog* self);
gchar* media_source_prep_comment (const gchar* comment);
static gboolean edit_comment_dialog_real_on_modify_validate (MultiTextEntryDialogMediator* base,
                                                      const gchar* text);
GtkResponseType remove_from_library_dialog (GtkWindow* owner,
                                            const gchar* title,
                                            const gchar* user_message,
                                            gint count);
GtkResponseType remove_from_filesystem_dialog (GtkWindow* owner,
                                               const gchar* title,
                                               const gchar* user_message);
gboolean revert_editable_dialog (GtkWindow* owner,
                                 GeeCollection* photos);
gboolean photo_has_editable (Photo* self);
gboolean remove_offline_dialog (GtkWindow* owner,
                                gint count);
#define MAX_OBJECTS_DISPLAYED 3
void multiple_object_error_dialog (GeeArrayList* objects,
                                   const gchar* message,
                                   const gchar* title);
gchar* data_object_to_string (DataObject* self);
GType tags_dialog_get_type (void) G_GNUC_CONST;
TagsDialog* tags_dialog_construct (GType object_type,
                                   const gchar* title,
                                   const gchar* label,
                                   const gchar* initial_text);
gpointer hierarchical_tag_index_ref (gpointer instance);
void hierarchical_tag_index_unref (gpointer instance);
GParamSpec* param_spec_hierarchical_tag_index (const gchar* name,
                                               const gchar* nick,
                                               const gchar* blurb,
                                               GType object_type,
                                               GParamFlags flags);
void value_set_hierarchical_tag_index (GValue* value,
                                       gpointer v_object);
void value_take_hierarchical_tag_index (GValue* value,
                                        gpointer v_object);
gpointer value_get_hierarchical_tag_index (const GValue* value);
GType hierarchical_tag_index_get_type (void) G_GNUC_CONST;
HierarchicalTagIndex* hierarchical_tag_index_get_global_index (void);
GeeCollection* hierarchical_tag_index_get_all_tags (HierarchicalTagIndex* self);
GType add_tags_dialog_get_type (void) G_GNUC_CONST;
AddTagsDialog* add_tags_dialog_new (void);
AddTagsDialog* add_tags_dialog_construct (GType object_type);
#define RESOURCES_ADD_TAGS_TITLE NC_ ("Dialog Title", "Add Tags")
gchar** add_tags_dialog_execute (AddTagsDialog* self,
                                 int* result_length1);
gchar** tag_prep_tag_names (gchar** names,
                            int names_length1,
                            int* result_length1);
static gboolean add_tags_dialog_real_on_modify_validate (TextEntryDialogMediator* base,
                                                  const gchar* text);
#define TAG_PATH_SEPARATOR_STRING "/"
GType modify_tags_dialog_get_type (void) G_GNUC_CONST;
ModifyTagsDialog* modify_tags_dialog_new (MediaSource* source);
ModifyTagsDialog* modify_tags_dialog_construct (GType object_type,
                                                MediaSource* source);
#define RESOURCES_MODIFY_TAGS_LABEL _ ("Modify Tags")
static gchar* modify_tags_dialog_get_initial_text (MediaSource* source);
gpointer data_collection_ref (gpointer instance);
void data_collection_unref (gpointer instance);
GParamSpec* param_spec_data_collection (const gchar* name,
                                        const gchar* nick,
                                        const gchar* blurb,
                                        GType object_type,
                                        GParamFlags flags);
void value_set_data_collection (GValue* value,
                                gpointer v_object);
void value_take_data_collection (GValue* value,
                                 gpointer v_object);
gpointer value_get_data_collection (const GValue* value);
GType data_collection_get_type (void) G_GNUC_CONST;
GType source_collection_get_type (void) G_GNUC_CONST;
GType database_source_collection_get_type (void) G_GNUC_CONST;
GType container_source_collection_get_type (void) G_GNUC_CONST;
GType tag_source_collection_get_type (void) G_GNUC_CONST;
GeeList* tag_source_collection_fetch_for_source (TagSourceCollection* self,
                                                 MediaSource* source);
GeeCollection* tag_get_terminal_tags (GeeCollection* tags);
gchar* hierarchical_tag_utilities_get_basename (const gchar* in_path);
gchar* tag_get_path (Tag* self);
GeeArrayList* modify_tags_dialog_execute (ModifyTagsDialog* self);
gboolean is_string_empty (const gchar* s);
gchar** hierarchical_tag_index_get_paths_for_names_array (HierarchicalTagIndex* self,
                                                          gchar** names,
                                                          int names_length1,
                                                          int* result_length1);
Tag* tag_for_path (const gchar* name);
static gboolean modify_tags_dialog_real_on_modify_validate (TextEntryDialogMediator* base,
                                                     const gchar* text);
GtkResponseType copy_files_dialog (void);
GType library_photo_get_type (void) G_GNUC_CONST;
void remove_photos_from_library (GeeCollection* photos);
void remove_from_app (GeeCollection* sources,
                      const gchar* dialog_title,
                      const gchar* progress_dialog_text);
GType video_source_get_type (void) G_GNUC_CONST;
GType video_get_type (void) G_GNUC_CONST;
void media_source_collection_filter_media (GeeCollection* media,
                                           GeeCollection* photos,
                                           GeeCollection* videos);
void page_window_set_busy_cursor (PageWindow* self);
GType progress_dialog_get_type (void) G_GNUC_CONST;
ProgressDialog* progress_dialog_new (GtkWindow* owner,
                                     const gchar* text,
                                     GCancellable* cancellable);
ProgressDialog* progress_dialog_construct (GType object_type,
                                           GtkWindow* owner,
                                           const gchar* text,
                                           GCancellable* cancellable);
gboolean progress_dialog_monitor (ProgressDialog* self,
                                  guint64 count,
                                  guint64 total,
                                  gboolean do_event_loop);
static gboolean _progress_dialog_monitor_progress_monitor (guint64 current,
                                                    guint64 total,
                                                    gboolean do_event_loop,
                                                    gpointer self);
GType media_source_collection_get_type (void) G_GNUC_CONST;
GType library_photo_source_collection_get_type (void) G_GNUC_CONST;
void media_source_collection_remove_from_app (MediaSourceCollection* self,
                                              GeeCollection* sources,
                                              gboolean delete_backing,
                                              ProgressMonitor monitor,
                                              void* monitor_target,
                                              GeeList* not_removed);
GType video_source_collection_get_type (void) G_GNUC_CONST;
void media_source_collection_delete_backing_files (MediaSourceCollection* self,
                                                   GeeCollection* sources,
                                                   ProgressMonitor monitor,
                                                   void* monitor_target,
                                                   GeeList* not_deleted);
void app_window_error_message_with_title (const gchar* title,
                                          const gchar* message,
                                          GtkWindow* parent,
                                          gboolean should_escape);
void progress_dialog_close (ProgressDialog* self);
void page_window_set_normal_cursor (PageWindow* self);
static void _vala_array_destroy (gpointer array,
                          gint array_length,
                          GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array,
                       gint array_length,
                       GDestroyNotify destroy_func);
static gint _vala_array_length (gpointer array);


gboolean
dialogs_confirm_delete_tag (Tag* tag)
{
	gboolean result = FALSE;
	gint count = 0;
	gint _tmp0_;
	gchar* msg = NULL;
	gint _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	gint _tmp4_;
	gchar* _tmp5_;
	gchar* _tmp6_;
	const gchar* _tmp7_;
#line 11 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (IS_TAG (tag), FALSE);
#line 12 "/home/jens/Source/shotwell/src/Dialogs.vala"
	count = tag_get_sources_count (tag);
#line 13 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = count;
#line 13 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp0_ == 0) {
#line 14 "/home/jens/Source/shotwell/src/Dialogs.vala"
		result = TRUE;
#line 14 "/home/jens/Source/shotwell/src/Dialogs.vala"
		return result;
#line 1039 "Dialogs.c"
	}
#line 15 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = count;
#line 15 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = tag_get_user_visible_name (tag);
#line 15 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = _tmp2_;
#line 15 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = count;
#line 15 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = g_strdup_printf (ngettext ("This will remove the tag “%s” from one photo. Continue?", "This will remove the tag “%s” from %d photos. Continue?", (gulong) _tmp1_), _tmp3_, _tmp4_);
#line 15 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6_ = _tmp5_;
#line 15 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp3_);
#line 15 "/home/jens/Source/shotwell/src/Dialogs.vala"
	msg = _tmp6_;
#line 20 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp7_ = msg;
#line 20 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = app_window_negate_affirm_question (_tmp7_, _ ("_Cancel"), _ ("_Delete"), RESOURCES_DELETE_TAG_TITLE, NULL);
#line 20 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (msg);
#line 20 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 1065 "Dialogs.c"
}


gboolean
dialogs_confirm_delete_saved_search (SavedSearch* search)
{
	gboolean result = FALSE;
	gchar* msg = NULL;
	gchar* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
#line 24 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (IS_SAVED_SEARCH (search), FALSE);
#line 25 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = data_object_get_name (G_TYPE_CHECK_INSTANCE_CAST (search, TYPE_DATA_OBJECT, DataObject));
#line 25 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = _tmp0_;
#line 25 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = g_strdup_printf (_ ("This will remove the saved search “%s”. Continue?"), _tmp1_);
#line 25 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = _tmp2_;
#line 25 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp1_);
#line 25 "/home/jens/Source/shotwell/src/Dialogs.vala"
	msg = _tmp3_;
#line 28 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = app_window_negate_affirm_question (msg, _ ("_Cancel"), _ ("_Delete"), RESOURCES_DELETE_SAVED_SEARCH_DIALOG_TITLE, NULL);
#line 28 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (msg);
#line 28 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 1098 "Dialogs.c"
}


gboolean
dialogs_confirm_warn_developer_changed (gint number)
{
	gboolean result = FALSE;
	GtkMessageDialog* dialog = NULL;
	AppWindow* _tmp0_;
	AppWindow* _tmp1_;
	GtkMessageDialog* _tmp2_;
	GtkMessageDialog* _tmp3_;
	gint response = 0;
#line 33 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = app_window_get_instance ();
#line 33 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = _tmp0_;
#line 33 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = (GtkMessageDialog*) gtk_message_dialog_new_with_markup (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, gtk_window_get_type (), GtkWindow), GTK_DIALOG_MODAL, GTK_MESSAGE_WARNING, GTK_BUTTONS_NONE, "<span weight=\"bold\" size=\"larger\">%s</span>", ngettext ("Switching developers will undo all changes you have made to this photo" \
" in Shotwell", "Switching developers will undo all changes you have made to these phot" \
"os in Shotwell", (gulong) number));
#line 33 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp2_);
#line 33 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = _tmp2_;
#line 33 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (_tmp1_);
#line 33 "/home/jens/Source/shotwell/src/Dialogs.vala"
	dialog = _tmp3_;
#line 39 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_dialog_add_buttons (G_TYPE_CHECK_INSTANCE_CAST (dialog, gtk_dialog_get_type (), GtkDialog), RESOURCES_CANCEL_LABEL, GTK_RESPONSE_CANCEL, NULL);
#line 40 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_dialog_add_buttons (G_TYPE_CHECK_INSTANCE_CAST (dialog, gtk_dialog_get_type (), GtkDialog), _ ("_Switch Developer"), GTK_RESPONSE_YES, NULL);
#line 42 "/home/jens/Source/shotwell/src/Dialogs.vala"
	response = gtk_dialog_run (G_TYPE_CHECK_INSTANCE_CAST (dialog, gtk_dialog_get_type (), GtkDialog));
#line 44 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_destroy (G_TYPE_CHECK_INSTANCE_CAST (dialog, gtk_widget_get_type (), GtkWidget));
#line 46 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = response == ((gint) GTK_RESPONSE_YES);
#line 46 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (dialog);
#line 46 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 1140 "Dialogs.c"
}


GFile*
export_ui_choose_file (const gchar* current_file_basename)
{
	GFile* result = NULL;
	GFile* _tmp0_;
	const gchar* _tmp3_ = NULL;
	gchar* file_chooser_title = NULL;
	gchar* _tmp4_;
	GtkFileChooserDialog* chooser = NULL;
	const gchar* _tmp5_;
	AppWindow* _tmp6_;
	AppWindow* _tmp7_;
	GtkFileChooserDialog* _tmp8_;
	GtkFileChooserDialog* _tmp9_;
	GtkFileChooserDialog* _tmp10_;
	GtkFileChooserDialog* _tmp11_;
	GFile* _tmp12_;
	gchar* _tmp13_;
	gchar* _tmp14_;
	GtkFileChooserDialog* _tmp15_;
	GtkFileChooserDialog* _tmp16_;
	GFile* file = NULL;
	GtkFileChooserDialog* _tmp17_;
	GtkFileChooserDialog* _tmp24_;
#line 54 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (current_file_basename != NULL, NULL);
#line 55 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = export_ui_current_export_dir;
#line 55 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp0_ == NULL) {
#line 1174 "Dialogs.c"
		const gchar* _tmp1_;
		GFile* _tmp2_;
#line 56 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp1_ = g_get_home_dir ();
#line 56 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp2_ = g_file_new_for_path (_tmp1_);
#line 56 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (export_ui_current_export_dir);
#line 56 "/home/jens/Source/shotwell/src/Dialogs.vala"
		export_ui_current_export_dir = _tmp2_;
#line 1185 "Dialogs.c"
	}
#line 58 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (video_reader_is_supported_video_filename (current_file_basename)) {
#line 59 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp3_ = _ ("Export Video");
#line 1191 "Dialogs.c"
	} else {
#line 59 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp3_ = _ ("Export Photo");
#line 1195 "Dialogs.c"
	}
#line 58 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = g_strdup (_tmp3_);
#line 58 "/home/jens/Source/shotwell/src/Dialogs.vala"
	file_chooser_title = _tmp4_;
#line 61 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = file_chooser_title;
#line 61 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6_ = app_window_get_instance ();
#line 61 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp7_ = _tmp6_;
#line 61 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp8_ = (GtkFileChooserDialog*) gtk_file_chooser_dialog_new (_tmp5_, G_TYPE_CHECK_INSTANCE_CAST (_tmp7_, gtk_window_get_type (), GtkWindow), GTK_FILE_CHOOSER_ACTION_SAVE, RESOURCES_CANCEL_LABEL, GTK_RESPONSE_CANCEL, RESOURCES_SAVE_LABEL, GTK_RESPONSE_ACCEPT, NULL, NULL);
#line 61 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp8_);
#line 61 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp9_ = _tmp8_;
#line 61 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (_tmp7_);
#line 61 "/home/jens/Source/shotwell/src/Dialogs.vala"
	chooser = _tmp9_;
#line 64 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp10_ = chooser;
#line 64 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_file_chooser_set_do_overwrite_confirmation (G_TYPE_CHECK_INSTANCE_CAST (_tmp10_, gtk_file_chooser_get_type (), GtkFileChooser), TRUE);
#line 65 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp11_ = chooser;
#line 65 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp12_ = export_ui_current_export_dir;
#line 65 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp13_ = g_file_get_path (_tmp12_);
#line 65 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp14_ = _tmp13_;
#line 65 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_file_chooser_set_current_folder (G_TYPE_CHECK_INSTANCE_CAST (_tmp11_, gtk_file_chooser_get_type (), GtkFileChooser), _tmp14_);
#line 65 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp14_);
#line 66 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp15_ = chooser;
#line 66 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_file_chooser_set_current_name (G_TYPE_CHECK_INSTANCE_CAST (_tmp15_, gtk_file_chooser_get_type (), GtkFileChooser), current_file_basename);
#line 67 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp16_ = chooser;
#line 67 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_file_chooser_set_local_only (G_TYPE_CHECK_INSTANCE_CAST (_tmp16_, gtk_file_chooser_get_type (), GtkFileChooser), FALSE);
#line 69 "/home/jens/Source/shotwell/src/Dialogs.vala"
	file = NULL;
#line 70 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp17_ = chooser;
#line 70 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (gtk_dialog_run (G_TYPE_CHECK_INSTANCE_CAST (_tmp17_, gtk_dialog_get_type (), GtkDialog)) == ((gint) GTK_RESPONSE_ACCEPT)) {
#line 1247 "Dialogs.c"
		GtkFileChooserDialog* _tmp18_;
		gchar* _tmp19_;
		gchar* _tmp20_;
		GFile* _tmp21_;
		GFile* _tmp22_;
		GFile* _tmp23_;
#line 71 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp18_ = chooser;
#line 71 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp19_ = gtk_file_chooser_get_filename (G_TYPE_CHECK_INSTANCE_CAST (_tmp18_, gtk_file_chooser_get_type (), GtkFileChooser));
#line 71 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp20_ = _tmp19_;
#line 71 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp21_ = g_file_new_for_path (_tmp20_);
#line 71 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (file);
#line 71 "/home/jens/Source/shotwell/src/Dialogs.vala"
		file = _tmp21_;
#line 71 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp20_);
#line 72 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp22_ = file;
#line 72 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp23_ = g_file_get_parent (_tmp22_);
#line 72 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (export_ui_current_export_dir);
#line 72 "/home/jens/Source/shotwell/src/Dialogs.vala"
		export_ui_current_export_dir = _tmp23_;
#line 1276 "Dialogs.c"
	}
#line 74 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp24_ = chooser;
#line 74 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_destroy (G_TYPE_CHECK_INSTANCE_CAST (_tmp24_, gtk_widget_get_type (), GtkWidget));
#line 76 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = file;
#line 76 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (chooser);
#line 76 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (file_chooser_title);
#line 76 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 1290 "Dialogs.c"
}


static gpointer
_g_object_ref0 (gpointer self)
{
#line 95 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return self ? g_object_ref (self) : NULL;
#line 1299 "Dialogs.c"
}


GFile*
export_ui_choose_dir (const gchar* user_title)
{
	GFile* result = NULL;
	GFile* _tmp0_;
	GtkFileChooserDialog* chooser = NULL;
	AppWindow* _tmp3_;
	AppWindow* _tmp4_;
	GtkFileChooserDialog* _tmp5_;
	GtkFileChooserDialog* _tmp6_;
	GtkFileChooserDialog* _tmp7_;
	GFile* _tmp8_;
	gchar* _tmp9_;
	gchar* _tmp10_;
	GtkFileChooserDialog* _tmp11_;
	GFile* dir = NULL;
	GtkFileChooserDialog* _tmp12_;
	GtkFileChooserDialog* _tmp19_;
#line 80 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = export_ui_current_export_dir;
#line 80 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp0_ == NULL) {
#line 1325 "Dialogs.c"
		const gchar* _tmp1_;
		GFile* _tmp2_;
#line 81 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp1_ = g_get_home_dir ();
#line 81 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp2_ = g_file_new_for_path (_tmp1_);
#line 81 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (export_ui_current_export_dir);
#line 81 "/home/jens/Source/shotwell/src/Dialogs.vala"
		export_ui_current_export_dir = _tmp2_;
#line 1336 "Dialogs.c"
	}
#line 83 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (user_title == NULL) {
#line 84 "/home/jens/Source/shotwell/src/Dialogs.vala"
		user_title = _ ("Export Photos");
#line 1342 "Dialogs.c"
	}
#line 86 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = app_window_get_instance ();
#line 86 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = _tmp3_;
#line 86 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = (GtkFileChooserDialog*) gtk_file_chooser_dialog_new (user_title, G_TYPE_CHECK_INSTANCE_CAST (_tmp4_, gtk_window_get_type (), GtkWindow), GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER, RESOURCES_CANCEL_LABEL, GTK_RESPONSE_CANCEL, RESOURCES_OK_LABEL, GTK_RESPONSE_ACCEPT, NULL, NULL);
#line 86 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp5_);
#line 86 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6_ = _tmp5_;
#line 86 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (_tmp4_);
#line 86 "/home/jens/Source/shotwell/src/Dialogs.vala"
	chooser = _tmp6_;
#line 89 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp7_ = chooser;
#line 89 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp8_ = export_ui_current_export_dir;
#line 89 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp9_ = g_file_get_path (_tmp8_);
#line 89 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp10_ = _tmp9_;
#line 89 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_file_chooser_set_current_folder (G_TYPE_CHECK_INSTANCE_CAST (_tmp7_, gtk_file_chooser_get_type (), GtkFileChooser), _tmp10_);
#line 89 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp10_);
#line 90 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp11_ = chooser;
#line 90 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_file_chooser_set_local_only (G_TYPE_CHECK_INSTANCE_CAST (_tmp11_, gtk_file_chooser_get_type (), GtkFileChooser), FALSE);
#line 92 "/home/jens/Source/shotwell/src/Dialogs.vala"
	dir = NULL;
#line 93 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp12_ = chooser;
#line 93 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (gtk_dialog_run (G_TYPE_CHECK_INSTANCE_CAST (_tmp12_, gtk_dialog_get_type (), GtkDialog)) == ((gint) GTK_RESPONSE_ACCEPT)) {
#line 1380 "Dialogs.c"
		GtkFileChooserDialog* _tmp13_;
		gchar* _tmp14_;
		gchar* _tmp15_;
		GFile* _tmp16_;
		GFile* _tmp17_;
		GFile* _tmp18_;
#line 94 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp13_ = chooser;
#line 94 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp14_ = gtk_file_chooser_get_filename (G_TYPE_CHECK_INSTANCE_CAST (_tmp13_, gtk_file_chooser_get_type (), GtkFileChooser));
#line 94 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp15_ = _tmp14_;
#line 94 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp16_ = g_file_new_for_path (_tmp15_);
#line 94 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (dir);
#line 94 "/home/jens/Source/shotwell/src/Dialogs.vala"
		dir = _tmp16_;
#line 94 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp15_);
#line 95 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp17_ = dir;
#line 95 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp18_ = _g_object_ref0 (_tmp17_);
#line 95 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (export_ui_current_export_dir);
#line 95 "/home/jens/Source/shotwell/src/Dialogs.vala"
		export_ui_current_export_dir = _tmp18_;
#line 1409 "Dialogs.c"
	}
#line 98 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp19_ = chooser;
#line 98 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_destroy (G_TYPE_CHECK_INSTANCE_CAST (_tmp19_, gtk_widget_get_type (), GtkWidget));
#line 100 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = dir;
#line 100 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (chooser);
#line 100 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 1421 "Dialogs.c"
}


void
open_external_editor_error_dialog (GError* err,
                                   Photo* photo)
{
	gboolean _tmp0_ = FALSE;
#line 107 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (IS_PHOTO (photo));
#line 109 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (g_error_matches (err, G_IO_ERROR, G_IO_ERROR_PERMISSION_DENIED)) {
#line 109 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp0_ = TRUE;
#line 1436 "Dialogs.c"
	} else {
#line 109 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp0_ = g_error_matches (err, G_FILE_ERROR, G_FILE_ERROR_PERM);
#line 1440 "Dialogs.c"
	}
#line 109 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp0_) {
#line 1444 "Dialogs.c"
		GFile* _tmp1_;
		GFile* _tmp2_;
		GFile* _tmp3_;
		GFile* _tmp4_;
		gchar* _tmp5_;
		gchar* _tmp6_;
		gchar* _tmp7_;
		gchar* _tmp8_;
#line 111 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp1_ = media_source_get_master_file (G_TYPE_CHECK_INSTANCE_CAST (photo, TYPE_MEDIA_SOURCE, MediaSource));
#line 111 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp2_ = _tmp1_;
#line 111 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp3_ = g_file_get_parent (_tmp2_);
#line 111 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp4_ = _tmp3_;
#line 111 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp5_ = g_file_get_path (_tmp4_);
#line 111 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp6_ = _tmp5_;
#line 111 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp7_ = g_strdup_printf (_ ("Shotwell couldn’t create a file for editing this photo because you do " \
"not have permission to write to %s."), _tmp6_);
#line 111 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp8_ = _tmp7_;
#line 111 "/home/jens/Source/shotwell/src/Dialogs.vala"
		app_window_error_message (_tmp8_, NULL);
#line 111 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp8_);
#line 111 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp6_);
#line 111 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (_tmp4_);
#line 111 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (_tmp2_);
#line 1479 "Dialogs.c"
	} else {
		gchar* _tmp9_;
		gchar* _tmp10_;
#line 116 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp9_ = resources_launch_editor_failed (err);
#line 116 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp10_ = _tmp9_;
#line 116 "/home/jens/Source/shotwell/src/Dialogs.vala"
		app_window_error_message (_tmp10_, NULL);
#line 116 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp10_);
#line 1491 "Dialogs.c"
	}
}


GtkResponseType
export_error_dialog (GFile* dest,
                     gboolean photos_remaining)
{
	GtkResponseType result = 0;
	gchar* message = NULL;
	gchar* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	GtkResponseType response = 0;
#line 120 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (G_IS_FILE (dest), 0);
#line 121 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = g_file_get_path (dest);
#line 121 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = _tmp0_;
#line 121 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = g_strconcat (_ ("Unable to export the following photo due to a file error.\n\n"), _tmp1_, NULL);
#line 121 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = _tmp2_;
#line 121 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp1_);
#line 121 "/home/jens/Source/shotwell/src/Dialogs.vala"
	message = _tmp3_;
#line 124 "/home/jens/Source/shotwell/src/Dialogs.vala"
	response = GTK_RESPONSE_NONE;
#line 126 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (photos_remaining) {
#line 1525 "Dialogs.c"
		const gchar* _tmp4_;
		gchar* _tmp5_;
		const gchar* _tmp6_;
#line 127 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp4_ = message;
#line 127 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp5_ = g_strconcat (_tmp4_, _ ("\n\nWould you like to continue exporting?"), NULL);
#line 127 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (message);
#line 127 "/home/jens/Source/shotwell/src/Dialogs.vala"
		message = _tmp5_;
#line 128 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp6_ = message;
#line 128 "/home/jens/Source/shotwell/src/Dialogs.vala"
		response = app_window_affirm_cancel_question (_tmp6_, _ ("Con_tinue"), NULL, NULL);
#line 1541 "Dialogs.c"
	} else {
		const gchar* _tmp7_;
#line 130 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp7_ = message;
#line 130 "/home/jens/Source/shotwell/src/Dialogs.vala"
		app_window_error_message (_tmp7_, NULL);
#line 1548 "Dialogs.c"
	}
#line 133 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = response;
#line 133 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (message);
#line 133 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 1556 "Dialogs.c"
}


gchar*
import_ui_generate_import_failure_list (GeeList* failed,
                                        gboolean show_dest_id)
{
	gchar* result = NULL;
	gint _tmp0_;
	gint _tmp1_;
	gchar* list = NULL;
	gchar* _tmp2_;
	gint remaining = 0;
	gint _tmp23_;
	gint _tmp24_;
	gint _tmp25_;
#line 143 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (GEE_IS_LIST (failed), NULL);
#line 144 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (failed, GEE_TYPE_COLLECTION, GeeCollection));
#line 144 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = _tmp0_;
#line 144 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp1_ == 0) {
#line 145 "/home/jens/Source/shotwell/src/Dialogs.vala"
		result = NULL;
#line 145 "/home/jens/Source/shotwell/src/Dialogs.vala"
		return result;
#line 1585 "Dialogs.c"
	}
#line 147 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = g_strdup ("");
#line 147 "/home/jens/Source/shotwell/src/Dialogs.vala"
	list = _tmp2_;
#line 1591 "Dialogs.c"
	{
		gint ctr = 0;
#line 148 "/home/jens/Source/shotwell/src/Dialogs.vala"
		ctr = 0;
#line 1596 "Dialogs.c"
		{
			gboolean _tmp3_ = FALSE;
#line 148 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp3_ = TRUE;
#line 148 "/home/jens/Source/shotwell/src/Dialogs.vala"
			while (TRUE) {
#line 1603 "Dialogs.c"
				gboolean _tmp5_ = FALSE;
				gint _tmp6_;
				const gchar* _tmp10_ = NULL;
				const gchar* _tmp19_;
				gchar* _tmp20_;
				gchar* _tmp21_;
				gchar* _tmp22_;
#line 148 "/home/jens/Source/shotwell/src/Dialogs.vala"
				if (!_tmp3_) {
#line 1613 "Dialogs.c"
					gint _tmp4_;
#line 148 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp4_ = ctr;
#line 148 "/home/jens/Source/shotwell/src/Dialogs.vala"
					ctr = _tmp4_ + 1;
#line 1619 "Dialogs.c"
				}
#line 148 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp3_ = FALSE;
#line 148 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp6_ = ctr;
#line 148 "/home/jens/Source/shotwell/src/Dialogs.vala"
				if (_tmp6_ < IMPORT_UI_REPORT_FAILURE_COUNT) {
#line 1627 "Dialogs.c"
					gint _tmp7_;
					gint _tmp8_;
					gint _tmp9_;
#line 148 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp7_ = ctr;
#line 148 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp8_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (failed, GEE_TYPE_COLLECTION, GeeCollection));
#line 148 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp9_ = _tmp8_;
#line 148 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp5_ = _tmp7_ < _tmp9_;
#line 1639 "Dialogs.c"
				} else {
#line 148 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp5_ = FALSE;
#line 1643 "Dialogs.c"
				}
#line 148 "/home/jens/Source/shotwell/src/Dialogs.vala"
				if (!_tmp5_) {
#line 148 "/home/jens/Source/shotwell/src/Dialogs.vala"
					break;
#line 1649 "Dialogs.c"
				}
#line 149 "/home/jens/Source/shotwell/src/Dialogs.vala"
				if (show_dest_id) {
#line 1653 "Dialogs.c"
					gint _tmp11_;
					gpointer _tmp12_;
					BatchImportResult* _tmp13_;
					const gchar* _tmp14_;
#line 149 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp11_ = ctr;
#line 149 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp12_ = gee_list_get (failed, _tmp11_);
#line 149 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp13_ = (BatchImportResult*) _tmp12_;
#line 149 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp14_ = _tmp13_->dest_identifier;
#line 149 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp10_ = _tmp14_;
#line 149 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_batch_import_result_unref0 (_tmp13_);
#line 1670 "Dialogs.c"
				} else {
					gint _tmp15_;
					gpointer _tmp16_;
					BatchImportResult* _tmp17_;
					const gchar* _tmp18_;
#line 150 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp15_ = ctr;
#line 150 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp16_ = gee_list_get (failed, _tmp15_);
#line 150 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp17_ = (BatchImportResult*) _tmp16_;
#line 150 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp18_ = _tmp17_->src_identifier;
#line 150 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp10_ = _tmp18_;
#line 150 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_batch_import_result_unref0 (_tmp17_);
#line 1688 "Dialogs.c"
				}
#line 149 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp19_ = list;
#line 149 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp20_ = g_strdup_printf ("%s\n", _tmp10_);
#line 149 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp21_ = _tmp20_;
#line 149 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp22_ = g_strconcat (_tmp19_, _tmp21_, NULL);
#line 149 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (list);
#line 149 "/home/jens/Source/shotwell/src/Dialogs.vala"
				list = _tmp22_;
#line 149 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp21_);
#line 1704 "Dialogs.c"
			}
		}
	}
#line 153 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp23_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (failed, GEE_TYPE_COLLECTION, GeeCollection));
#line 153 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp24_ = _tmp23_;
#line 153 "/home/jens/Source/shotwell/src/Dialogs.vala"
	remaining = _tmp24_ - IMPORT_UI_REPORT_FAILURE_COUNT;
#line 154 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp25_ = remaining;
#line 154 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp25_ > 0) {
#line 1718 "Dialogs.c"
		const gchar* _tmp26_;
		gint _tmp27_;
		gchar* _tmp28_;
		gchar* _tmp29_;
		gchar* _tmp30_;
#line 155 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp26_ = list;
#line 155 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp27_ = remaining;
#line 155 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp28_ = g_strdup_printf (_ ("(and %d more)\n"), _tmp27_);
#line 155 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp29_ = _tmp28_;
#line 155 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp30_ = g_strconcat (_tmp26_, _tmp29_, NULL);
#line 155 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (list);
#line 155 "/home/jens/Source/shotwell/src/Dialogs.vala"
		list = _tmp30_;
#line 155 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp29_);
#line 1740 "Dialogs.c"
	}
#line 157 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = list;
#line 157 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 1746 "Dialogs.c"
}


ImportUIQuestionParams*
import_ui_question_params_construct (GType object_type,
                                     const gchar* question,
                                     const gchar* yes_button,
                                     const gchar* no_button)
{
	ImportUIQuestionParams* self = NULL;
	gchar* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
#line 165 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (question != NULL, NULL);
#line 165 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (yes_button != NULL, NULL);
#line 165 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (no_button != NULL, NULL);
#line 165 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self = (ImportUIQuestionParams*) g_type_create_instance (object_type);
#line 166 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = g_strdup (question);
#line 166 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (self->question);
#line 166 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->question = _tmp0_;
#line 167 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = g_strdup (yes_button);
#line 167 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (self->yes_button);
#line 167 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->yes_button = _tmp1_;
#line 168 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = g_strdup (no_button);
#line 168 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (self->no_button);
#line 168 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->no_button = _tmp2_;
#line 165 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return self;
#line 1788 "Dialogs.c"
}


ImportUIQuestionParams*
import_ui_question_params_new (const gchar* question,
                               const gchar* yes_button,
                               const gchar* no_button)
{
#line 165 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return import_ui_question_params_construct (IMPORT_UI_TYPE_QUESTION_PARAMS, question, yes_button, no_button);
#line 1799 "Dialogs.c"
}


static void
import_ui_value_question_params_init (GValue* value)
{
#line 160 "/home/jens/Source/shotwell/src/Dialogs.vala"
	value->data[0].v_pointer = NULL;
#line 1808 "Dialogs.c"
}


static void
import_ui_value_question_params_free_value (GValue* value)
{
#line 160 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (value->data[0].v_pointer) {
#line 160 "/home/jens/Source/shotwell/src/Dialogs.vala"
		import_ui_question_params_unref (value->data[0].v_pointer);
#line 1819 "Dialogs.c"
	}
}


static void
import_ui_value_question_params_copy_value (const GValue* src_value,
                                            GValue* dest_value)
{
#line 160 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (src_value->data[0].v_pointer) {
#line 160 "/home/jens/Source/shotwell/src/Dialogs.vala"
		dest_value->data[0].v_pointer = import_ui_question_params_ref (src_value->data[0].v_pointer);
#line 1832 "Dialogs.c"
	} else {
#line 160 "/home/jens/Source/shotwell/src/Dialogs.vala"
		dest_value->data[0].v_pointer = NULL;
#line 1836 "Dialogs.c"
	}
}


static gpointer
import_ui_value_question_params_peek_pointer (const GValue* value)
{
#line 160 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return value->data[0].v_pointer;
#line 1846 "Dialogs.c"
}


static gchar*
import_ui_value_question_params_collect_value (GValue* value,
                                               guint n_collect_values,
                                               GTypeCValue* collect_values,
                                               guint collect_flags)
{
#line 160 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (collect_values[0].v_pointer) {
#line 1858 "Dialogs.c"
		ImportUIQuestionParams * object;
		object = collect_values[0].v_pointer;
#line 160 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (object->parent_instance.g_class == NULL) {
#line 160 "/home/jens/Source/shotwell/src/Dialogs.vala"
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 1865 "Dialogs.c"
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
#line 160 "/home/jens/Source/shotwell/src/Dialogs.vala"
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 1869 "Dialogs.c"
		}
#line 160 "/home/jens/Source/shotwell/src/Dialogs.vala"
		value->data[0].v_pointer = import_ui_question_params_ref (object);
#line 1873 "Dialogs.c"
	} else {
#line 160 "/home/jens/Source/shotwell/src/Dialogs.vala"
		value->data[0].v_pointer = NULL;
#line 1877 "Dialogs.c"
	}
#line 160 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return NULL;
#line 1881 "Dialogs.c"
}


static gchar*
import_ui_value_question_params_lcopy_value (const GValue* value,
                                             guint n_collect_values,
                                             GTypeCValue* collect_values,
                                             guint collect_flags)
{
	ImportUIQuestionParams ** object_p;
	object_p = collect_values[0].v_pointer;
#line 160 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (!object_p) {
#line 160 "/home/jens/Source/shotwell/src/Dialogs.vala"
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
#line 1897 "Dialogs.c"
	}
#line 160 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (!value->data[0].v_pointer) {
#line 160 "/home/jens/Source/shotwell/src/Dialogs.vala"
		*object_p = NULL;
#line 1903 "Dialogs.c"
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
#line 160 "/home/jens/Source/shotwell/src/Dialogs.vala"
		*object_p = value->data[0].v_pointer;
#line 1907 "Dialogs.c"
	} else {
#line 160 "/home/jens/Source/shotwell/src/Dialogs.vala"
		*object_p = import_ui_question_params_ref (value->data[0].v_pointer);
#line 1911 "Dialogs.c"
	}
#line 160 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return NULL;
#line 1915 "Dialogs.c"
}


GParamSpec*
import_ui_param_spec_question_params (const gchar* name,
                                      const gchar* nick,
                                      const gchar* blurb,
                                      GType object_type,
                                      GParamFlags flags)
{
	ImportUIParamSpecQuestionParams* spec;
#line 160 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (g_type_is_a (object_type, IMPORT_UI_TYPE_QUESTION_PARAMS), NULL);
#line 160 "/home/jens/Source/shotwell/src/Dialogs.vala"
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
#line 160 "/home/jens/Source/shotwell/src/Dialogs.vala"
	G_PARAM_SPEC (spec)->value_type = object_type;
#line 160 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return G_PARAM_SPEC (spec);
#line 1935 "Dialogs.c"
}


gpointer
import_ui_value_get_question_params (const GValue* value)
{
#line 160 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, IMPORT_UI_TYPE_QUESTION_PARAMS), NULL);
#line 160 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return value->data[0].v_pointer;
#line 1946 "Dialogs.c"
}


void
import_ui_value_set_question_params (GValue* value,
                                     gpointer v_object)
{
	ImportUIQuestionParams * old;
#line 160 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, IMPORT_UI_TYPE_QUESTION_PARAMS));
#line 160 "/home/jens/Source/shotwell/src/Dialogs.vala"
	old = value->data[0].v_pointer;
#line 160 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (v_object) {
#line 160 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, IMPORT_UI_TYPE_QUESTION_PARAMS));
#line 160 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 160 "/home/jens/Source/shotwell/src/Dialogs.vala"
		value->data[0].v_pointer = v_object;
#line 160 "/home/jens/Source/shotwell/src/Dialogs.vala"
		import_ui_question_params_ref (value->data[0].v_pointer);
#line 1969 "Dialogs.c"
	} else {
#line 160 "/home/jens/Source/shotwell/src/Dialogs.vala"
		value->data[0].v_pointer = NULL;
#line 1973 "Dialogs.c"
	}
#line 160 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (old) {
#line 160 "/home/jens/Source/shotwell/src/Dialogs.vala"
		import_ui_question_params_unref (old);
#line 1979 "Dialogs.c"
	}
}


void
import_ui_value_take_question_params (GValue* value,
                                      gpointer v_object)
{
	ImportUIQuestionParams * old;
#line 160 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, IMPORT_UI_TYPE_QUESTION_PARAMS));
#line 160 "/home/jens/Source/shotwell/src/Dialogs.vala"
	old = value->data[0].v_pointer;
#line 160 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (v_object) {
#line 160 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, IMPORT_UI_TYPE_QUESTION_PARAMS));
#line 160 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 160 "/home/jens/Source/shotwell/src/Dialogs.vala"
		value->data[0].v_pointer = v_object;
#line 2001 "Dialogs.c"
	} else {
#line 160 "/home/jens/Source/shotwell/src/Dialogs.vala"
		value->data[0].v_pointer = NULL;
#line 2005 "Dialogs.c"
	}
#line 160 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (old) {
#line 160 "/home/jens/Source/shotwell/src/Dialogs.vala"
		import_ui_question_params_unref (old);
#line 2011 "Dialogs.c"
	}
}


static void
import_ui_question_params_class_init (ImportUIQuestionParamsClass * klass)
{
#line 160 "/home/jens/Source/shotwell/src/Dialogs.vala"
	import_ui_question_params_parent_class = g_type_class_peek_parent (klass);
#line 160 "/home/jens/Source/shotwell/src/Dialogs.vala"
	((ImportUIQuestionParamsClass *) klass)->finalize = import_ui_question_params_finalize;
#line 2023 "Dialogs.c"
}


static void
import_ui_question_params_instance_init (ImportUIQuestionParams * self)
{
#line 160 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->ref_count = 1;
#line 2032 "Dialogs.c"
}


static void
import_ui_question_params_finalize (ImportUIQuestionParams * obj)
{
	ImportUIQuestionParams * self;
#line 160 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, IMPORT_UI_TYPE_QUESTION_PARAMS, ImportUIQuestionParams);
#line 160 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_signal_handlers_destroy (self);
#line 161 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (self->question);
#line 162 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (self->yes_button);
#line 163 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (self->no_button);
#line 2050 "Dialogs.c"
}


GType
import_ui_question_params_get_type (void)
{
	static volatile gsize import_ui_question_params_type_id__volatile = 0;
	if (g_once_init_enter (&import_ui_question_params_type_id__volatile)) {
		static const GTypeValueTable g_define_type_value_table = { import_ui_value_question_params_init, import_ui_value_question_params_free_value, import_ui_value_question_params_copy_value, import_ui_value_question_params_peek_pointer, "p", import_ui_value_question_params_collect_value, "p", import_ui_value_question_params_lcopy_value };
		static const GTypeInfo g_define_type_info = { sizeof (ImportUIQuestionParamsClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) import_ui_question_params_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ImportUIQuestionParams), 0, (GInstanceInitFunc) import_ui_question_params_instance_init, &g_define_type_value_table };
		static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
		GType import_ui_question_params_type_id;
		import_ui_question_params_type_id = g_type_register_fundamental (g_type_fundamental_next (), "ImportUIQuestionParams", &g_define_type_info, &g_define_type_fundamental_info, 0);
		g_once_init_leave (&import_ui_question_params_type_id__volatile, import_ui_question_params_type_id);
	}
	return import_ui_question_params_type_id__volatile;
}


gpointer
import_ui_question_params_ref (gpointer instance)
{
	ImportUIQuestionParams * self;
	self = instance;
#line 160 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_atomic_int_inc (&self->ref_count);
#line 160 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return instance;
#line 2079 "Dialogs.c"
}


void
import_ui_question_params_unref (gpointer instance)
{
	ImportUIQuestionParams * self;
	self = instance;
#line 160 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
#line 160 "/home/jens/Source/shotwell/src/Dialogs.vala"
		IMPORT_UI_QUESTION_PARAMS_GET_CLASS (self)->finalize (self);
#line 160 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_type_free_instance ((GTypeInstance *) self);
#line 2094 "Dialogs.c"
	}
}


gboolean
import_ui_import_has_photos (GeeCollection* import_collection)
{
	gboolean result = FALSE;
#line 172 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (GEE_IS_COLLECTION (import_collection), FALSE);
#line 2105 "Dialogs.c"
	{
		GeeIterator* _current_result_it = NULL;
		GeeIterator* _tmp0_;
#line 173 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp0_ = gee_iterable_iterator (G_TYPE_CHECK_INSTANCE_CAST (import_collection, GEE_TYPE_ITERABLE, GeeIterable));
#line 173 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_current_result_it = _tmp0_;
#line 173 "/home/jens/Source/shotwell/src/Dialogs.vala"
		while (TRUE) {
#line 2115 "Dialogs.c"
			GeeIterator* _tmp1_;
			BatchImportResult* current_result = NULL;
			GeeIterator* _tmp2_;
			gpointer _tmp3_;
			gboolean _tmp4_ = FALSE;
			BatchImportResult* _tmp5_;
			GFile* _tmp6_;
#line 173 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp1_ = _current_result_it;
#line 173 "/home/jens/Source/shotwell/src/Dialogs.vala"
			if (!gee_iterator_next (_tmp1_)) {
#line 173 "/home/jens/Source/shotwell/src/Dialogs.vala"
				break;
#line 2129 "Dialogs.c"
			}
#line 173 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp2_ = _current_result_it;
#line 173 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp3_ = gee_iterator_get (_tmp2_);
#line 173 "/home/jens/Source/shotwell/src/Dialogs.vala"
			current_result = (BatchImportResult*) _tmp3_;
#line 174 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp5_ = current_result;
#line 174 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp6_ = _tmp5_->file;
#line 174 "/home/jens/Source/shotwell/src/Dialogs.vala"
			if (_tmp6_ != NULL) {
#line 2143 "Dialogs.c"
				BatchImportResult* _tmp7_;
				GFile* _tmp8_;
#line 175 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp7_ = current_result;
#line 175 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp8_ = _tmp7_->file;
#line 175 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp4_ = photo_file_format_get_by_file_extension (_tmp8_) != PHOTO_FILE_FORMAT_UNKNOWN;
#line 2152 "Dialogs.c"
			} else {
#line 174 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp4_ = FALSE;
#line 2156 "Dialogs.c"
			}
#line 174 "/home/jens/Source/shotwell/src/Dialogs.vala"
			if (_tmp4_) {
#line 176 "/home/jens/Source/shotwell/src/Dialogs.vala"
				result = TRUE;
#line 176 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_batch_import_result_unref0 (current_result);
#line 176 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_object_unref0 (_current_result_it);
#line 176 "/home/jens/Source/shotwell/src/Dialogs.vala"
				return result;
#line 2168 "Dialogs.c"
			}
#line 173 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_batch_import_result_unref0 (current_result);
#line 2172 "Dialogs.c"
		}
#line 173 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (_current_result_it);
#line 2176 "Dialogs.c"
	}
#line 179 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = FALSE;
#line 179 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 2182 "Dialogs.c"
}


gboolean
import_ui_import_has_videos (GeeCollection* import_collection)
{
	gboolean result = FALSE;
#line 182 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (GEE_IS_COLLECTION (import_collection), FALSE);
#line 2192 "Dialogs.c"
	{
		GeeIterator* _current_result_it = NULL;
		GeeIterator* _tmp0_;
#line 183 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp0_ = gee_iterable_iterator (G_TYPE_CHECK_INSTANCE_CAST (import_collection, GEE_TYPE_ITERABLE, GeeIterable));
#line 183 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_current_result_it = _tmp0_;
#line 183 "/home/jens/Source/shotwell/src/Dialogs.vala"
		while (TRUE) {
#line 2202 "Dialogs.c"
			GeeIterator* _tmp1_;
			BatchImportResult* current_result = NULL;
			GeeIterator* _tmp2_;
			gpointer _tmp3_;
			gboolean _tmp4_ = FALSE;
			BatchImportResult* _tmp5_;
			GFile* _tmp6_;
#line 183 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp1_ = _current_result_it;
#line 183 "/home/jens/Source/shotwell/src/Dialogs.vala"
			if (!gee_iterator_next (_tmp1_)) {
#line 183 "/home/jens/Source/shotwell/src/Dialogs.vala"
				break;
#line 2216 "Dialogs.c"
			}
#line 183 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp2_ = _current_result_it;
#line 183 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp3_ = gee_iterator_get (_tmp2_);
#line 183 "/home/jens/Source/shotwell/src/Dialogs.vala"
			current_result = (BatchImportResult*) _tmp3_;
#line 184 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp5_ = current_result;
#line 184 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp6_ = _tmp5_->file;
#line 184 "/home/jens/Source/shotwell/src/Dialogs.vala"
			if (_tmp6_ != NULL) {
#line 2230 "Dialogs.c"
				BatchImportResult* _tmp7_;
				GFile* _tmp8_;
#line 184 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp7_ = current_result;
#line 184 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp8_ = _tmp7_->file;
#line 184 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp4_ = video_reader_is_supported_video_file (_tmp8_);
#line 2239 "Dialogs.c"
			} else {
#line 184 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp4_ = FALSE;
#line 2243 "Dialogs.c"
			}
#line 184 "/home/jens/Source/shotwell/src/Dialogs.vala"
			if (_tmp4_) {
#line 185 "/home/jens/Source/shotwell/src/Dialogs.vala"
				result = TRUE;
#line 185 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_batch_import_result_unref0 (current_result);
#line 185 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_object_unref0 (_current_result_it);
#line 185 "/home/jens/Source/shotwell/src/Dialogs.vala"
				return result;
#line 2255 "Dialogs.c"
			}
#line 183 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_batch_import_result_unref0 (current_result);
#line 2259 "Dialogs.c"
		}
#line 183 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (_current_result_it);
#line 2263 "Dialogs.c"
	}
#line 187 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = FALSE;
#line 187 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 2269 "Dialogs.c"
}


gchar*
import_ui_get_media_specific_string (GeeCollection* import_collection,
                                     const gchar* photos_msg,
                                     const gchar* videos_msg,
                                     const gchar* both_msg,
                                     const gchar* neither_msg)
{
	gchar* result = NULL;
	gboolean has_photos = FALSE;
	gboolean has_videos = FALSE;
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_;
#line 190 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (GEE_IS_COLLECTION (import_collection), NULL);
#line 190 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (photos_msg != NULL, NULL);
#line 190 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (videos_msg != NULL, NULL);
#line 190 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (both_msg != NULL, NULL);
#line 190 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (neither_msg != NULL, NULL);
#line 192 "/home/jens/Source/shotwell/src/Dialogs.vala"
	has_photos = import_ui_import_has_photos (import_collection);
#line 193 "/home/jens/Source/shotwell/src/Dialogs.vala"
	has_videos = import_ui_import_has_videos (import_collection);
#line 195 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = has_photos;
#line 195 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp1_) {
#line 2303 "Dialogs.c"
		gboolean _tmp2_;
#line 195 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp2_ = has_videos;
#line 195 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp0_ = _tmp2_;
#line 2309 "Dialogs.c"
	} else {
#line 195 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp0_ = FALSE;
#line 2313 "Dialogs.c"
	}
#line 195 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp0_) {
#line 2317 "Dialogs.c"
		gchar* _tmp3_;
#line 196 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp3_ = g_strdup (both_msg);
#line 196 "/home/jens/Source/shotwell/src/Dialogs.vala"
		result = _tmp3_;
#line 196 "/home/jens/Source/shotwell/src/Dialogs.vala"
		return result;
#line 2325 "Dialogs.c"
	} else {
		gboolean _tmp4_;
#line 197 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp4_ = has_photos;
#line 197 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (_tmp4_) {
#line 2332 "Dialogs.c"
			gchar* _tmp5_;
#line 198 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp5_ = g_strdup (photos_msg);
#line 198 "/home/jens/Source/shotwell/src/Dialogs.vala"
			result = _tmp5_;
#line 198 "/home/jens/Source/shotwell/src/Dialogs.vala"
			return result;
#line 2340 "Dialogs.c"
		} else {
			gboolean _tmp6_;
#line 199 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp6_ = has_videos;
#line 199 "/home/jens/Source/shotwell/src/Dialogs.vala"
			if (_tmp6_) {
#line 2347 "Dialogs.c"
				gchar* _tmp7_;
#line 200 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp7_ = g_strdup (videos_msg);
#line 200 "/home/jens/Source/shotwell/src/Dialogs.vala"
				result = _tmp7_;
#line 200 "/home/jens/Source/shotwell/src/Dialogs.vala"
				return result;
#line 2355 "Dialogs.c"
			} else {
				gchar* _tmp8_;
#line 202 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp8_ = g_strdup (neither_msg);
#line 202 "/home/jens/Source/shotwell/src/Dialogs.vala"
				result = _tmp8_;
#line 202 "/home/jens/Source/shotwell/src/Dialogs.vala"
				return result;
#line 2364 "Dialogs.c"
			}
		}
	}
}


gchar*
import_ui_create_result_report_from_manifest (ImportManifest* manifest)
{
	gchar* result = NULL;
	GString* builder = NULL;
	GString* _tmp0_;
	gchar* header = NULL;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	gchar* _tmp4_;
	gchar* _tmp5_;
	gchar* _tmp6_;
	GTimeVal _tmp7_ = {0};
	gchar* _tmp8_;
	gchar* _tmp9_;
	gchar* _tmp10_;
	gchar* _tmp11_;
	gchar* _tmp12_;
	gchar* _tmp13_;
	GString* _tmp14_;
	const gchar* _tmp15_;
	gchar* subhead = NULL;
	GeeList* _tmp16_;
	gint _tmp17_;
	gint _tmp18_;
	GeeList* _tmp19_;
	gint _tmp20_;
	gint _tmp21_;
	gchar* _tmp22_;
	const gchar* _tmp23_;
	gchar* _tmp24_;
	const gchar* _tmp25_;
	GeeList* _tmp26_;
	gint _tmp27_;
	gint _tmp28_;
	GeeList* _tmp29_;
	gint _tmp30_;
	gint _tmp31_;
	gchar* _tmp32_;
	gchar* _tmp33_;
	gchar* _tmp34_;
	const gchar* _tmp35_;
	gchar* _tmp36_;
	GString* _tmp37_;
	const gchar* _tmp38_;
	gchar* current_file_summary = NULL;
	gchar* _tmp39_;
	GeeList* _tmp40_;
	gint _tmp41_;
	gint _tmp42_;
	GeeList* _tmp76_;
	gint _tmp77_;
	gint _tmp78_;
	GeeList* _tmp108_;
	gint _tmp109_;
	gint _tmp110_;
	GeeList* _tmp140_;
	gint _tmp141_;
	gint _tmp142_;
	GeeList* _tmp172_;
	gint _tmp173_;
	gint _tmp174_;
	GeeList* _tmp208_;
	gint _tmp209_;
	gint _tmp210_;
	GeeList* _tmp240_;
	gint _tmp241_;
	gint _tmp242_;
	GString* _tmp272_;
	const gchar* _tmp273_;
	gchar* _tmp274_;
#line 205 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (IS_IMPORT_MANIFEST (manifest), NULL);
#line 206 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = g_string_new ("");
#line 206 "/home/jens/Source/shotwell/src/Dialogs.vala"
	builder = _tmp0_;
#line 208 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = g_strconcat (_ ("Import Results Report"), " (Shotwell ", NULL);
#line 208 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = _tmp1_;
#line 208 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = g_strconcat (_tmp2_, RESOURCES_APP_VERSION, NULL);
#line 208 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = _tmp3_;
#line 208 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = g_strconcat (_tmp4_, " @ ", NULL);
#line 208 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6_ = _tmp5_;
#line 208 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_get_current_time (&_tmp7_);
#line 208 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp8_ = g_time_val_to_iso8601 (&_tmp7_);
#line 208 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp9_ = _tmp8_;
#line 208 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp10_ = g_strconcat (_tmp6_, _tmp9_, NULL);
#line 208 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp11_ = _tmp10_;
#line 208 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp12_ = g_strconcat (_tmp11_, ")\n\n", NULL);
#line 208 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp13_ = _tmp12_;
#line 208 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp11_);
#line 208 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp9_);
#line 208 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp6_);
#line 208 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp4_);
#line 208 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp2_);
#line 208 "/home/jens/Source/shotwell/src/Dialogs.vala"
	header = _tmp13_;
#line 210 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp14_ = builder;
#line 210 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp15_ = header;
#line 210 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_string_append (_tmp14_, _tmp15_);
#line 212 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp16_ = manifest->all;
#line 212 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp17_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp16_, GEE_TYPE_COLLECTION, GeeCollection));
#line 212 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp18_ = _tmp17_;
#line 212 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp19_ = manifest->all;
#line 212 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp20_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp19_, GEE_TYPE_COLLECTION, GeeCollection));
#line 212 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp21_ = _tmp20_;
#line 212 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp22_ = g_strdup_printf (ngettext ("Attempted to import %d file.", "Attempted to import %d files.", (gulong) _tmp18_), _tmp21_);
#line 212 "/home/jens/Source/shotwell/src/Dialogs.vala"
	subhead = _tmp22_;
#line 214 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp23_ = subhead;
#line 214 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp24_ = g_strconcat (_tmp23_, " ", NULL);
#line 214 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (subhead);
#line 214 "/home/jens/Source/shotwell/src/Dialogs.vala"
	subhead = _tmp24_;
#line 215 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp25_ = subhead;
#line 215 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp26_ = manifest->success;
#line 215 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp27_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp26_, GEE_TYPE_COLLECTION, GeeCollection));
#line 215 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp28_ = _tmp27_;
#line 215 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp29_ = manifest->success;
#line 215 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp30_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp29_, GEE_TYPE_COLLECTION, GeeCollection));
#line 215 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp31_ = _tmp30_;
#line 215 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp32_ = g_strdup_printf (ngettext ("Of these, %d file was successfully imported.", "Of these, %d files were successfully imported.", (gulong) _tmp28_), _tmp31_);
#line 215 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp33_ = _tmp32_;
#line 215 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp34_ = g_strconcat (_tmp25_, _tmp33_, NULL);
#line 215 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (subhead);
#line 215 "/home/jens/Source/shotwell/src/Dialogs.vala"
	subhead = _tmp34_;
#line 215 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp33_);
#line 218 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp35_ = subhead;
#line 218 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp36_ = g_strconcat (_tmp35_, "\n\n", NULL);
#line 218 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (subhead);
#line 218 "/home/jens/Source/shotwell/src/Dialogs.vala"
	subhead = _tmp36_;
#line 219 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp37_ = builder;
#line 219 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp38_ = subhead;
#line 219 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_string_append (_tmp37_, _tmp38_);
#line 221 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp39_ = g_strdup ("");
#line 221 "/home/jens/Source/shotwell/src/Dialogs.vala"
	current_file_summary = _tmp39_;
#line 226 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp40_ = manifest->already_imported;
#line 226 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp41_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp40_, GEE_TYPE_COLLECTION, GeeCollection));
#line 226 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp42_ = _tmp41_;
#line 226 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp42_ > 0) {
#line 2569 "Dialogs.c"
		GString* _tmp43_;
		gchar* _tmp44_;
		gchar* _tmp45_;
#line 227 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp43_ = builder;
#line 227 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp44_ = g_strconcat (_ ("Duplicate Photos/Videos Not Imported:"), "\n\n", NULL);
#line 227 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp45_ = _tmp44_;
#line 227 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_string_append (_tmp43_, _tmp45_);
#line 227 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp45_);
#line 2583 "Dialogs.c"
		{
			GeeList* _result_list = NULL;
			GeeList* _tmp46_;
			GeeList* _tmp47_;
			gint _result_size = 0;
			GeeList* _tmp48_;
			gint _tmp49_;
			gint _tmp50_;
			gint _result_index = 0;
#line 229 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp46_ = manifest->already_imported;
#line 229 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp47_ = _g_object_ref0 (_tmp46_);
#line 229 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_result_list = _tmp47_;
#line 229 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp48_ = _result_list;
#line 229 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp49_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp48_, GEE_TYPE_COLLECTION, GeeCollection));
#line 229 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp50_ = _tmp49_;
#line 229 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_result_size = _tmp50_;
#line 229 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_result_index = -1;
#line 229 "/home/jens/Source/shotwell/src/Dialogs.vala"
			while (TRUE) {
#line 2611 "Dialogs.c"
				gint _tmp51_;
				gint _tmp52_;
				gint _tmp53_;
				BatchImportResult* _result_ = NULL;
				GeeList* _tmp54_;
				gint _tmp55_;
				gpointer _tmp56_;
				BatchImportResult* _tmp57_;
				const gchar* _tmp58_;
				gchar* _tmp59_;
				gchar* _tmp60_;
				gchar* _tmp61_;
				gchar* _tmp62_;
				gchar* _tmp63_;
				gchar* _tmp64_;
				BatchImportResult* _tmp65_;
				DuplicatedFile* _tmp66_;
				GFile* _tmp67_;
				GFile* _tmp68_;
				gchar* _tmp69_;
				gchar* _tmp70_;
				gchar* _tmp71_;
				gchar* _tmp72_;
				gchar* _tmp73_;
				GString* _tmp74_;
				const gchar* _tmp75_;
#line 229 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp51_ = _result_index;
#line 229 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_result_index = _tmp51_ + 1;
#line 229 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp52_ = _result_index;
#line 229 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp53_ = _result_size;
#line 229 "/home/jens/Source/shotwell/src/Dialogs.vala"
				if (!(_tmp52_ < _tmp53_)) {
#line 229 "/home/jens/Source/shotwell/src/Dialogs.vala"
					break;
#line 2650 "Dialogs.c"
				}
#line 229 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp54_ = _result_list;
#line 229 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp55_ = _result_index;
#line 229 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp56_ = gee_list_get (_tmp54_, _tmp55_);
#line 229 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_result_ = (BatchImportResult*) _tmp56_;
#line 230 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp57_ = _result_;
#line 230 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp58_ = _tmp57_->src_identifier;
#line 230 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp59_ = g_strconcat (_tmp58_, " ", NULL);
#line 230 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp60_ = _tmp59_;
#line 230 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp61_ = g_strconcat (_tmp60_, _ ("duplicates existing media item"), NULL);
#line 230 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp62_ = _tmp61_;
#line 230 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp63_ = g_strconcat (_tmp62_, "\n\t", NULL);
#line 230 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp64_ = _tmp63_;
#line 230 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp65_ = _result_;
#line 230 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp66_ = _tmp65_->duplicate_of;
#line 230 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp67_ = duplicated_file_get_file (_tmp66_);
#line 230 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp68_ = _tmp67_;
#line 230 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp69_ = g_file_get_path (_tmp68_);
#line 230 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp70_ = _tmp69_;
#line 230 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp71_ = g_strconcat (_tmp64_, _tmp70_, NULL);
#line 230 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp72_ = _tmp71_;
#line 230 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp73_ = g_strconcat (_tmp72_, "\n\n", NULL);
#line 230 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (current_file_summary);
#line 230 "/home/jens/Source/shotwell/src/Dialogs.vala"
				current_file_summary = _tmp73_;
#line 230 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp72_);
#line 230 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp70_);
#line 230 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_object_unref0 (_tmp68_);
#line 230 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp64_);
#line 230 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp62_);
#line 230 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp60_);
#line 234 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp74_ = builder;
#line 234 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp75_ = current_file_summary;
#line 234 "/home/jens/Source/shotwell/src/Dialogs.vala"
				g_string_append (_tmp74_, _tmp75_);
#line 229 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_batch_import_result_unref0 (_result_);
#line 2718 "Dialogs.c"
			}
#line 229 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_object_unref0 (_result_list);
#line 2722 "Dialogs.c"
		}
	}
#line 241 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp76_ = manifest->camera_failed;
#line 241 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp77_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp76_, GEE_TYPE_COLLECTION, GeeCollection));
#line 241 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp78_ = _tmp77_;
#line 241 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp78_ > 0) {
#line 2733 "Dialogs.c"
		GString* _tmp79_;
		gchar* _tmp80_;
		gchar* _tmp81_;
#line 242 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp79_ = builder;
#line 242 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp80_ = g_strconcat (_ ("Photos/Videos Not Imported Due to Camera Errors:"), "\n\n", NULL);
#line 242 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp81_ = _tmp80_;
#line 242 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_string_append (_tmp79_, _tmp81_);
#line 242 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp81_);
#line 2747 "Dialogs.c"
		{
			GeeList* _result_list = NULL;
			GeeList* _tmp82_;
			GeeList* _tmp83_;
			gint _result_size = 0;
			GeeList* _tmp84_;
			gint _tmp85_;
			gint _tmp86_;
			gint _result_index = 0;
#line 244 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp82_ = manifest->camera_failed;
#line 244 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp83_ = _g_object_ref0 (_tmp82_);
#line 244 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_result_list = _tmp83_;
#line 244 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp84_ = _result_list;
#line 244 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp85_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp84_, GEE_TYPE_COLLECTION, GeeCollection));
#line 244 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp86_ = _tmp85_;
#line 244 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_result_size = _tmp86_;
#line 244 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_result_index = -1;
#line 244 "/home/jens/Source/shotwell/src/Dialogs.vala"
			while (TRUE) {
#line 2775 "Dialogs.c"
				gint _tmp87_;
				gint _tmp88_;
				gint _tmp89_;
				BatchImportResult* _result_ = NULL;
				GeeList* _tmp90_;
				gint _tmp91_;
				gpointer _tmp92_;
				BatchImportResult* _tmp93_;
				const gchar* _tmp94_;
				gchar* _tmp95_;
				gchar* _tmp96_;
				gchar* _tmp97_;
				gchar* _tmp98_;
				gchar* _tmp99_;
				gchar* _tmp100_;
				BatchImportResult* _tmp101_;
				const gchar* _tmp102_;
				gchar* _tmp103_;
				gchar* _tmp104_;
				gchar* _tmp105_;
				GString* _tmp106_;
				const gchar* _tmp107_;
#line 244 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp87_ = _result_index;
#line 244 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_result_index = _tmp87_ + 1;
#line 244 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp88_ = _result_index;
#line 244 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp89_ = _result_size;
#line 244 "/home/jens/Source/shotwell/src/Dialogs.vala"
				if (!(_tmp88_ < _tmp89_)) {
#line 244 "/home/jens/Source/shotwell/src/Dialogs.vala"
					break;
#line 2810 "Dialogs.c"
				}
#line 244 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp90_ = _result_list;
#line 244 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp91_ = _result_index;
#line 244 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp92_ = gee_list_get (_tmp90_, _tmp91_);
#line 244 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_result_ = (BatchImportResult*) _tmp92_;
#line 245 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp93_ = _result_;
#line 245 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp94_ = _tmp93_->src_identifier;
#line 245 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp95_ = g_strconcat (_tmp94_, "\n\t", NULL);
#line 245 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp96_ = _tmp95_;
#line 245 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp97_ = g_strconcat (_tmp96_, _ ("error message:"), NULL);
#line 245 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp98_ = _tmp97_;
#line 245 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp99_ = g_strconcat (_tmp98_, " ", NULL);
#line 245 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp100_ = _tmp99_;
#line 245 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp101_ = _result_;
#line 245 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp102_ = _tmp101_->errmsg;
#line 245 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp103_ = g_strconcat (_tmp100_, _tmp102_, NULL);
#line 245 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp104_ = _tmp103_;
#line 245 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp105_ = g_strconcat (_tmp104_, "\n\n", NULL);
#line 245 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (current_file_summary);
#line 245 "/home/jens/Source/shotwell/src/Dialogs.vala"
				current_file_summary = _tmp105_;
#line 245 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp104_);
#line 245 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp100_);
#line 245 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp98_);
#line 245 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp96_);
#line 248 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp106_ = builder;
#line 248 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp107_ = current_file_summary;
#line 248 "/home/jens/Source/shotwell/src/Dialogs.vala"
				g_string_append (_tmp106_, _tmp107_);
#line 244 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_batch_import_result_unref0 (_result_);
#line 2866 "Dialogs.c"
			}
#line 244 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_object_unref0 (_result_list);
#line 2870 "Dialogs.c"
		}
	}
#line 255 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp108_ = manifest->skipped_files;
#line 255 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp109_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp108_, GEE_TYPE_COLLECTION, GeeCollection));
#line 255 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp110_ = _tmp109_;
#line 255 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp110_ > 0) {
#line 2881 "Dialogs.c"
		GString* _tmp111_;
		gchar* _tmp112_;
		gchar* _tmp113_;
#line 256 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp111_ = builder;
#line 256 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp112_ = g_strconcat (_ ("Files Not Imported Because They Weren’t Recognized as Photos or Videos" \
":"), "\n\n", NULL);
#line 256 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp113_ = _tmp112_;
#line 256 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_string_append (_tmp111_, _tmp113_);
#line 256 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp113_);
#line 2895 "Dialogs.c"
		{
			GeeList* _result_list = NULL;
			GeeList* _tmp114_;
			GeeList* _tmp115_;
			gint _result_size = 0;
			GeeList* _tmp116_;
			gint _tmp117_;
			gint _tmp118_;
			gint _result_index = 0;
#line 259 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp114_ = manifest->skipped_files;
#line 259 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp115_ = _g_object_ref0 (_tmp114_);
#line 259 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_result_list = _tmp115_;
#line 259 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp116_ = _result_list;
#line 259 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp117_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp116_, GEE_TYPE_COLLECTION, GeeCollection));
#line 259 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp118_ = _tmp117_;
#line 259 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_result_size = _tmp118_;
#line 259 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_result_index = -1;
#line 259 "/home/jens/Source/shotwell/src/Dialogs.vala"
			while (TRUE) {
#line 2923 "Dialogs.c"
				gint _tmp119_;
				gint _tmp120_;
				gint _tmp121_;
				BatchImportResult* _result_ = NULL;
				GeeList* _tmp122_;
				gint _tmp123_;
				gpointer _tmp124_;
				BatchImportResult* _tmp125_;
				const gchar* _tmp126_;
				gchar* _tmp127_;
				gchar* _tmp128_;
				gchar* _tmp129_;
				gchar* _tmp130_;
				gchar* _tmp131_;
				gchar* _tmp132_;
				BatchImportResult* _tmp133_;
				const gchar* _tmp134_;
				gchar* _tmp135_;
				gchar* _tmp136_;
				gchar* _tmp137_;
				GString* _tmp138_;
				const gchar* _tmp139_;
#line 259 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp119_ = _result_index;
#line 259 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_result_index = _tmp119_ + 1;
#line 259 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp120_ = _result_index;
#line 259 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp121_ = _result_size;
#line 259 "/home/jens/Source/shotwell/src/Dialogs.vala"
				if (!(_tmp120_ < _tmp121_)) {
#line 259 "/home/jens/Source/shotwell/src/Dialogs.vala"
					break;
#line 2958 "Dialogs.c"
				}
#line 259 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp122_ = _result_list;
#line 259 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp123_ = _result_index;
#line 259 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp124_ = gee_list_get (_tmp122_, _tmp123_);
#line 259 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_result_ = (BatchImportResult*) _tmp124_;
#line 260 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp125_ = _result_;
#line 260 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp126_ = _tmp125_->src_identifier;
#line 260 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp127_ = g_strconcat (_tmp126_, "\n\t", NULL);
#line 260 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp128_ = _tmp127_;
#line 260 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp129_ = g_strconcat (_tmp128_, _ ("error message:"), NULL);
#line 260 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp130_ = _tmp129_;
#line 260 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp131_ = g_strconcat (_tmp130_, " ", NULL);
#line 260 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp132_ = _tmp131_;
#line 260 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp133_ = _result_;
#line 260 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp134_ = _tmp133_->errmsg;
#line 260 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp135_ = g_strconcat (_tmp132_, _tmp134_, NULL);
#line 260 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp136_ = _tmp135_;
#line 260 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp137_ = g_strconcat (_tmp136_, "\n\n", NULL);
#line 260 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (current_file_summary);
#line 260 "/home/jens/Source/shotwell/src/Dialogs.vala"
				current_file_summary = _tmp137_;
#line 260 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp136_);
#line 260 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp132_);
#line 260 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp130_);
#line 260 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp128_);
#line 263 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp138_ = builder;
#line 263 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp139_ = current_file_summary;
#line 263 "/home/jens/Source/shotwell/src/Dialogs.vala"
				g_string_append (_tmp138_, _tmp139_);
#line 259 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_batch_import_result_unref0 (_result_);
#line 3014 "Dialogs.c"
			}
#line 259 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_object_unref0 (_result_list);
#line 3018 "Dialogs.c"
		}
	}
#line 270 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp140_ = manifest->skipped_photos;
#line 270 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp141_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp140_, GEE_TYPE_COLLECTION, GeeCollection));
#line 270 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp142_ = _tmp141_;
#line 270 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp142_ > 0) {
#line 3029 "Dialogs.c"
		GString* _tmp143_;
		gchar* _tmp144_;
		gchar* _tmp145_;
#line 271 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp143_ = builder;
#line 271 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp144_ = g_strconcat (_ ("Photos/Videos Not Imported Because They Weren’t in a Format Shotwell U" \
"nderstands:"), "\n\n", NULL);
#line 271 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp145_ = _tmp144_;
#line 271 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_string_append (_tmp143_, _tmp145_);
#line 271 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp145_);
#line 3043 "Dialogs.c"
		{
			GeeList* _result_list = NULL;
			GeeList* _tmp146_;
			GeeList* _tmp147_;
			gint _result_size = 0;
			GeeList* _tmp148_;
			gint _tmp149_;
			gint _tmp150_;
			gint _result_index = 0;
#line 274 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp146_ = manifest->skipped_photos;
#line 274 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp147_ = _g_object_ref0 (_tmp146_);
#line 274 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_result_list = _tmp147_;
#line 274 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp148_ = _result_list;
#line 274 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp149_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp148_, GEE_TYPE_COLLECTION, GeeCollection));
#line 274 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp150_ = _tmp149_;
#line 274 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_result_size = _tmp150_;
#line 274 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_result_index = -1;
#line 274 "/home/jens/Source/shotwell/src/Dialogs.vala"
			while (TRUE) {
#line 3071 "Dialogs.c"
				gint _tmp151_;
				gint _tmp152_;
				gint _tmp153_;
				BatchImportResult* _result_ = NULL;
				GeeList* _tmp154_;
				gint _tmp155_;
				gpointer _tmp156_;
				BatchImportResult* _tmp157_;
				const gchar* _tmp158_;
				gchar* _tmp159_;
				gchar* _tmp160_;
				gchar* _tmp161_;
				gchar* _tmp162_;
				gchar* _tmp163_;
				gchar* _tmp164_;
				BatchImportResult* _tmp165_;
				const gchar* _tmp166_;
				gchar* _tmp167_;
				gchar* _tmp168_;
				gchar* _tmp169_;
				GString* _tmp170_;
				const gchar* _tmp171_;
#line 274 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp151_ = _result_index;
#line 274 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_result_index = _tmp151_ + 1;
#line 274 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp152_ = _result_index;
#line 274 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp153_ = _result_size;
#line 274 "/home/jens/Source/shotwell/src/Dialogs.vala"
				if (!(_tmp152_ < _tmp153_)) {
#line 274 "/home/jens/Source/shotwell/src/Dialogs.vala"
					break;
#line 3106 "Dialogs.c"
				}
#line 274 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp154_ = _result_list;
#line 274 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp155_ = _result_index;
#line 274 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp156_ = gee_list_get (_tmp154_, _tmp155_);
#line 274 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_result_ = (BatchImportResult*) _tmp156_;
#line 275 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp157_ = _result_;
#line 275 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp158_ = _tmp157_->src_identifier;
#line 275 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp159_ = g_strconcat (_tmp158_, "\n\t", NULL);
#line 275 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp160_ = _tmp159_;
#line 275 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp161_ = g_strconcat (_tmp160_, _ ("error message:"), NULL);
#line 275 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp162_ = _tmp161_;
#line 275 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp163_ = g_strconcat (_tmp162_, " ", NULL);
#line 275 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp164_ = _tmp163_;
#line 275 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp165_ = _result_;
#line 275 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp166_ = _tmp165_->errmsg;
#line 275 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp167_ = g_strconcat (_tmp164_, _tmp166_, NULL);
#line 275 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp168_ = _tmp167_;
#line 275 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp169_ = g_strconcat (_tmp168_, "\n\n", NULL);
#line 275 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (current_file_summary);
#line 275 "/home/jens/Source/shotwell/src/Dialogs.vala"
				current_file_summary = _tmp169_;
#line 275 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp168_);
#line 275 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp164_);
#line 275 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp162_);
#line 275 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp160_);
#line 278 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp170_ = builder;
#line 278 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp171_ = current_file_summary;
#line 278 "/home/jens/Source/shotwell/src/Dialogs.vala"
				g_string_append (_tmp170_, _tmp171_);
#line 274 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_batch_import_result_unref0 (_result_);
#line 3162 "Dialogs.c"
			}
#line 274 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_object_unref0 (_result_list);
#line 3166 "Dialogs.c"
		}
	}
#line 285 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp172_ = manifest->write_failed;
#line 285 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp173_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp172_, GEE_TYPE_COLLECTION, GeeCollection));
#line 285 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp174_ = _tmp173_;
#line 285 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp174_ > 0) {
#line 3177 "Dialogs.c"
		GString* _tmp175_;
		gchar* _tmp176_;
		gchar* _tmp177_;
#line 286 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp175_ = builder;
#line 286 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp176_ = g_strconcat (_ ("Photos/Videos Not Imported Because Shotwell Couldn’t Copy Them into it" \
"s Library:"), "\n\n", NULL);
#line 286 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp177_ = _tmp176_;
#line 286 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_string_append (_tmp175_, _tmp177_);
#line 286 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp177_);
#line 3191 "Dialogs.c"
		{
			GeeList* _result_list = NULL;
			GeeList* _tmp178_;
			GeeList* _tmp179_;
			gint _result_size = 0;
			GeeList* _tmp180_;
			gint _tmp181_;
			gint _tmp182_;
			gint _result_index = 0;
#line 289 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp178_ = manifest->write_failed;
#line 289 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp179_ = _g_object_ref0 (_tmp178_);
#line 289 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_result_list = _tmp179_;
#line 289 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp180_ = _result_list;
#line 289 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp181_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp180_, GEE_TYPE_COLLECTION, GeeCollection));
#line 289 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp182_ = _tmp181_;
#line 289 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_result_size = _tmp182_;
#line 289 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_result_index = -1;
#line 289 "/home/jens/Source/shotwell/src/Dialogs.vala"
			while (TRUE) {
#line 3219 "Dialogs.c"
				gint _tmp183_;
				gint _tmp184_;
				gint _tmp185_;
				BatchImportResult* _result_ = NULL;
				GeeList* _tmp186_;
				gint _tmp187_;
				gpointer _tmp188_;
				BatchImportResult* _tmp189_;
				const gchar* _tmp190_;
				BatchImportResult* _tmp191_;
				const gchar* _tmp192_;
				gchar* _tmp193_;
				gchar* _tmp194_;
				gchar* _tmp195_;
				gchar* _tmp196_;
				gchar* _tmp197_;
				gchar* _tmp198_;
				gchar* _tmp199_;
				gchar* _tmp200_;
				BatchImportResult* _tmp201_;
				const gchar* _tmp202_;
				gchar* _tmp203_;
				gchar* _tmp204_;
				gchar* _tmp205_;
				GString* _tmp206_;
				const gchar* _tmp207_;
#line 289 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp183_ = _result_index;
#line 289 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_result_index = _tmp183_ + 1;
#line 289 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp184_ = _result_index;
#line 289 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp185_ = _result_size;
#line 289 "/home/jens/Source/shotwell/src/Dialogs.vala"
				if (!(_tmp184_ < _tmp185_)) {
#line 289 "/home/jens/Source/shotwell/src/Dialogs.vala"
					break;
#line 3258 "Dialogs.c"
				}
#line 289 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp186_ = _result_list;
#line 289 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp187_ = _result_index;
#line 289 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp188_ = gee_list_get (_tmp186_, _tmp187_);
#line 289 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_result_ = (BatchImportResult*) _tmp188_;
#line 290 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp189_ = _result_;
#line 290 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp190_ = _tmp189_->src_identifier;
#line 290 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp191_ = _result_;
#line 290 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp192_ = _tmp191_->dest_identifier;
#line 290 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp193_ = g_strdup_printf (_ ("couldn’t copy %s\n\tto %s"), _tmp190_, _tmp192_);
#line 290 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp194_ = _tmp193_;
#line 290 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp195_ = g_strconcat (_tmp194_, "\n\t", NULL);
#line 290 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp196_ = _tmp195_;
#line 290 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp197_ = g_strconcat (_tmp196_, _ ("error message:"), NULL);
#line 290 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp198_ = _tmp197_;
#line 290 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp199_ = g_strconcat (_tmp198_, " ", NULL);
#line 290 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp200_ = _tmp199_;
#line 290 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp201_ = _result_;
#line 290 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp202_ = _tmp201_->errmsg;
#line 290 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp203_ = g_strconcat (_tmp200_, _tmp202_, NULL);
#line 290 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp204_ = _tmp203_;
#line 290 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp205_ = g_strconcat (_tmp204_, "\n\n", NULL);
#line 290 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (current_file_summary);
#line 290 "/home/jens/Source/shotwell/src/Dialogs.vala"
				current_file_summary = _tmp205_;
#line 290 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp204_);
#line 290 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp200_);
#line 290 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp198_);
#line 290 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp196_);
#line 290 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp194_);
#line 294 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp206_ = builder;
#line 294 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp207_ = current_file_summary;
#line 294 "/home/jens/Source/shotwell/src/Dialogs.vala"
				g_string_append (_tmp206_, _tmp207_);
#line 289 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_batch_import_result_unref0 (_result_);
#line 3324 "Dialogs.c"
			}
#line 289 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_object_unref0 (_result_list);
#line 3328 "Dialogs.c"
		}
	}
#line 301 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp208_ = manifest->corrupt_files;
#line 301 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp209_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp208_, GEE_TYPE_COLLECTION, GeeCollection));
#line 301 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp210_ = _tmp209_;
#line 301 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp210_ > 0) {
#line 3339 "Dialogs.c"
		GString* _tmp211_;
		gchar* _tmp212_;
		gchar* _tmp213_;
#line 302 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp211_ = builder;
#line 302 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp212_ = g_strconcat (_ ("Photos/Videos Not Imported Because Files Are Corrupt:"), "\n\n", NULL);
#line 302 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp213_ = _tmp212_;
#line 302 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_string_append (_tmp211_, _tmp213_);
#line 302 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp213_);
#line 3353 "Dialogs.c"
		{
			GeeList* _result_list = NULL;
			GeeList* _tmp214_;
			GeeList* _tmp215_;
			gint _result_size = 0;
			GeeList* _tmp216_;
			gint _tmp217_;
			gint _tmp218_;
			gint _result_index = 0;
#line 305 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp214_ = manifest->corrupt_files;
#line 305 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp215_ = _g_object_ref0 (_tmp214_);
#line 305 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_result_list = _tmp215_;
#line 305 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp216_ = _result_list;
#line 305 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp217_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp216_, GEE_TYPE_COLLECTION, GeeCollection));
#line 305 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp218_ = _tmp217_;
#line 305 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_result_size = _tmp218_;
#line 305 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_result_index = -1;
#line 305 "/home/jens/Source/shotwell/src/Dialogs.vala"
			while (TRUE) {
#line 3381 "Dialogs.c"
				gint _tmp219_;
				gint _tmp220_;
				gint _tmp221_;
				BatchImportResult* _result_ = NULL;
				GeeList* _tmp222_;
				gint _tmp223_;
				gpointer _tmp224_;
				BatchImportResult* _tmp225_;
				const gchar* _tmp226_;
				gchar* _tmp227_;
				gchar* _tmp228_;
				gchar* _tmp229_;
				gchar* _tmp230_;
				gchar* _tmp231_;
				gchar* _tmp232_;
				BatchImportResult* _tmp233_;
				const gchar* _tmp234_;
				gchar* _tmp235_;
				gchar* _tmp236_;
				gchar* _tmp237_;
				GString* _tmp238_;
				const gchar* _tmp239_;
#line 305 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp219_ = _result_index;
#line 305 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_result_index = _tmp219_ + 1;
#line 305 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp220_ = _result_index;
#line 305 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp221_ = _result_size;
#line 305 "/home/jens/Source/shotwell/src/Dialogs.vala"
				if (!(_tmp220_ < _tmp221_)) {
#line 305 "/home/jens/Source/shotwell/src/Dialogs.vala"
					break;
#line 3416 "Dialogs.c"
				}
#line 305 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp222_ = _result_list;
#line 305 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp223_ = _result_index;
#line 305 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp224_ = gee_list_get (_tmp222_, _tmp223_);
#line 305 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_result_ = (BatchImportResult*) _tmp224_;
#line 306 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp225_ = _result_;
#line 306 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp226_ = _tmp225_->src_identifier;
#line 306 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp227_ = g_strconcat (_tmp226_, "\n\t", NULL);
#line 306 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp228_ = _tmp227_;
#line 306 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp229_ = g_strconcat (_tmp228_, _ ("error message:"), NULL);
#line 306 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp230_ = _tmp229_;
#line 306 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp231_ = g_strconcat (_tmp230_, " |", NULL);
#line 306 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp232_ = _tmp231_;
#line 306 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp233_ = _result_;
#line 306 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp234_ = _tmp233_->errmsg;
#line 306 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp235_ = g_strconcat (_tmp232_, _tmp234_, NULL);
#line 306 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp236_ = _tmp235_;
#line 306 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp237_ = g_strconcat (_tmp236_, "|\n\n", NULL);
#line 306 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (current_file_summary);
#line 306 "/home/jens/Source/shotwell/src/Dialogs.vala"
				current_file_summary = _tmp237_;
#line 306 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp236_);
#line 306 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp232_);
#line 306 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp230_);
#line 306 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp228_);
#line 309 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp238_ = builder;
#line 309 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp239_ = current_file_summary;
#line 309 "/home/jens/Source/shotwell/src/Dialogs.vala"
				g_string_append (_tmp238_, _tmp239_);
#line 305 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_batch_import_result_unref0 (_result_);
#line 3472 "Dialogs.c"
			}
#line 305 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_object_unref0 (_result_list);
#line 3476 "Dialogs.c"
		}
	}
#line 316 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp240_ = manifest->failed;
#line 316 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp241_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp240_, GEE_TYPE_COLLECTION, GeeCollection));
#line 316 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp242_ = _tmp241_;
#line 316 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp242_ > 0) {
#line 3487 "Dialogs.c"
		GString* _tmp243_;
		gchar* _tmp244_;
		gchar* _tmp245_;
#line 317 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp243_ = builder;
#line 317 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp244_ = g_strconcat (_ ("Photos/Videos Not Imported for Other Reasons:"), "\n\n", NULL);
#line 317 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp245_ = _tmp244_;
#line 317 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_string_append (_tmp243_, _tmp245_);
#line 317 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp245_);
#line 3501 "Dialogs.c"
		{
			GeeList* _result_list = NULL;
			GeeList* _tmp246_;
			GeeList* _tmp247_;
			gint _result_size = 0;
			GeeList* _tmp248_;
			gint _tmp249_;
			gint _tmp250_;
			gint _result_index = 0;
#line 319 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp246_ = manifest->failed;
#line 319 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp247_ = _g_object_ref0 (_tmp246_);
#line 319 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_result_list = _tmp247_;
#line 319 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp248_ = _result_list;
#line 319 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp249_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp248_, GEE_TYPE_COLLECTION, GeeCollection));
#line 319 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp250_ = _tmp249_;
#line 319 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_result_size = _tmp250_;
#line 319 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_result_index = -1;
#line 319 "/home/jens/Source/shotwell/src/Dialogs.vala"
			while (TRUE) {
#line 3529 "Dialogs.c"
				gint _tmp251_;
				gint _tmp252_;
				gint _tmp253_;
				BatchImportResult* _result_ = NULL;
				GeeList* _tmp254_;
				gint _tmp255_;
				gpointer _tmp256_;
				BatchImportResult* _tmp257_;
				const gchar* _tmp258_;
				gchar* _tmp259_;
				gchar* _tmp260_;
				gchar* _tmp261_;
				gchar* _tmp262_;
				gchar* _tmp263_;
				gchar* _tmp264_;
				BatchImportResult* _tmp265_;
				const gchar* _tmp266_;
				gchar* _tmp267_;
				gchar* _tmp268_;
				gchar* _tmp269_;
				GString* _tmp270_;
				const gchar* _tmp271_;
#line 319 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp251_ = _result_index;
#line 319 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_result_index = _tmp251_ + 1;
#line 319 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp252_ = _result_index;
#line 319 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp253_ = _result_size;
#line 319 "/home/jens/Source/shotwell/src/Dialogs.vala"
				if (!(_tmp252_ < _tmp253_)) {
#line 319 "/home/jens/Source/shotwell/src/Dialogs.vala"
					break;
#line 3564 "Dialogs.c"
				}
#line 319 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp254_ = _result_list;
#line 319 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp255_ = _result_index;
#line 319 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp256_ = gee_list_get (_tmp254_, _tmp255_);
#line 319 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_result_ = (BatchImportResult*) _tmp256_;
#line 320 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp257_ = _result_;
#line 320 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp258_ = _tmp257_->src_identifier;
#line 320 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp259_ = g_strconcat (_tmp258_, "\n\t", NULL);
#line 320 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp260_ = _tmp259_;
#line 320 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp261_ = g_strconcat (_tmp260_, _ ("error message:"), NULL);
#line 320 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp262_ = _tmp261_;
#line 320 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp263_ = g_strconcat (_tmp262_, " ", NULL);
#line 320 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp264_ = _tmp263_;
#line 320 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp265_ = _result_;
#line 320 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp266_ = _tmp265_->errmsg;
#line 320 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp267_ = g_strconcat (_tmp264_, _tmp266_, NULL);
#line 320 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp268_ = _tmp267_;
#line 320 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp269_ = g_strconcat (_tmp268_, "\n\n", NULL);
#line 320 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (current_file_summary);
#line 320 "/home/jens/Source/shotwell/src/Dialogs.vala"
				current_file_summary = _tmp269_;
#line 320 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp268_);
#line 320 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp264_);
#line 320 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp262_);
#line 320 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp260_);
#line 323 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp270_ = builder;
#line 323 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp271_ = current_file_summary;
#line 323 "/home/jens/Source/shotwell/src/Dialogs.vala"
				g_string_append (_tmp270_, _tmp271_);
#line 319 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_batch_import_result_unref0 (_result_);
#line 3620 "Dialogs.c"
			}
#line 319 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_object_unref0 (_result_list);
#line 3624 "Dialogs.c"
		}
	}
#line 327 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp272_ = builder;
#line 327 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp273_ = _tmp272_->str;
#line 327 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp274_ = g_strdup (_tmp273_);
#line 327 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = _tmp274_;
#line 327 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (current_file_summary);
#line 327 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (subhead);
#line 327 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (header);
#line 327 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_string_free0 (builder);
#line 327 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 3645 "Dialogs.c"
}


gboolean
import_ui_report_manifest (ImportManifest* manifest,
                           gboolean show_dest_id,
                           ImportUIQuestionParams* question)
{
	gboolean result = FALSE;
	gchar* message = NULL;
	gchar* _tmp0_;
	GeeList* _tmp1_;
	gint _tmp2_;
	gint _tmp3_;
	GeeList* _tmp39_;
	gint _tmp40_;
	gint _tmp41_;
	GeeList* _tmp89_;
	gint _tmp90_;
	gint _tmp91_;
	GeeList* _tmp139_;
	gint _tmp140_;
	gint _tmp141_;
	GeeList* _tmp189_;
	gint _tmp190_;
	gint _tmp191_;
	GeeList* _tmp239_;
	gint _tmp240_;
	gint _tmp241_;
	GeeList* _tmp262_;
	gint _tmp263_;
	gint _tmp264_;
	GeeList* _tmp280_;
	gint _tmp281_;
	gint _tmp282_;
	GeeList* _tmp330_;
	gint _tmp331_;
	gint _tmp332_;
	gint total = 0;
	GeeList* _tmp367_;
	gint _tmp368_;
	gint _tmp369_;
	GeeList* _tmp370_;
	gint _tmp371_;
	gint _tmp372_;
	GeeList* _tmp373_;
	gint _tmp374_;
	gint _tmp375_;
	GeeList* _tmp376_;
	gint _tmp377_;
	gint _tmp378_;
	GeeList* _tmp379_;
	gint _tmp380_;
	gint _tmp381_;
	GeeList* _tmp382_;
	gint _tmp383_;
	gint _tmp384_;
	GeeList* _tmp385_;
	gint _tmp386_;
	gint _tmp387_;
	GeeList* _tmp388_;
	gint _tmp389_;
	gint _tmp390_;
	GeeList* _tmp391_;
	gint _tmp392_;
	gint _tmp393_;
	gint _tmp394_;
	GeeList* _tmp395_;
	gint _tmp396_;
	gint _tmp397_;
	gint _tmp398_;
	GtkMessageDialog* dialog = NULL;
	gint dialog_response = 0;
	gint _tmp466_;
#line 332 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (IS_IMPORT_MANIFEST (manifest), FALSE);
#line 332 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail ((question == NULL) || IMPORT_UI_IS_QUESTION_PARAMS (question), FALSE);
#line 334 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = g_strdup ("");
#line 334 "/home/jens/Source/shotwell/src/Dialogs.vala"
	message = _tmp0_;
#line 336 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = manifest->already_imported;
#line 336 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, GEE_TYPE_COLLECTION, GeeCollection));
#line 336 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = _tmp2_;
#line 336 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp3_ > 0) {
#line 3736 "Dialogs.c"
		gchar* photos_message = NULL;
		GeeList* _tmp4_;
		gint _tmp5_;
		gint _tmp6_;
		GeeList* _tmp7_;
		gint _tmp8_;
		gint _tmp9_;
		gchar* _tmp10_;
		gchar* videos_message = NULL;
		GeeList* _tmp11_;
		gint _tmp12_;
		gint _tmp13_;
		GeeList* _tmp14_;
		gint _tmp15_;
		gint _tmp16_;
		gchar* _tmp17_;
		gchar* both_message = NULL;
		GeeList* _tmp18_;
		gint _tmp19_;
		gint _tmp20_;
		GeeList* _tmp21_;
		gint _tmp22_;
		gint _tmp23_;
		gchar* _tmp24_;
		const gchar* _tmp25_;
		GeeList* _tmp26_;
		const gchar* _tmp27_;
		const gchar* _tmp28_;
		const gchar* _tmp29_;
		const gchar* _tmp30_;
		gchar* _tmp31_;
		gchar* _tmp32_;
		gchar* _tmp33_;
		const gchar* _tmp34_;
		GeeList* _tmp35_;
		gchar* _tmp36_;
		gchar* _tmp37_;
		gchar* _tmp38_;
#line 337 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp4_ = manifest->already_imported;
#line 337 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp5_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp4_, GEE_TYPE_COLLECTION, GeeCollection));
#line 337 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp6_ = _tmp5_;
#line 337 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp7_ = manifest->already_imported;
#line 337 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp8_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp7_, GEE_TYPE_COLLECTION, GeeCollection));
#line 337 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp9_ = _tmp8_;
#line 337 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp10_ = g_strdup_printf (ngettext ("1 duplicate photo was not imported:\n", "%d duplicate photos were not imported:\n", (gulong) _tmp6_), _tmp9_);
#line 337 "/home/jens/Source/shotwell/src/Dialogs.vala"
		photos_message = _tmp10_;
#line 340 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp11_ = manifest->already_imported;
#line 340 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp12_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp11_, GEE_TYPE_COLLECTION, GeeCollection));
#line 340 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp13_ = _tmp12_;
#line 340 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp14_ = manifest->already_imported;
#line 340 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp15_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp14_, GEE_TYPE_COLLECTION, GeeCollection));
#line 340 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp16_ = _tmp15_;
#line 340 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp17_ = g_strdup_printf (ngettext ("1 duplicate video was not imported:\n", "%d duplicate videos were not imported:\n", (gulong) _tmp13_), _tmp16_);
#line 340 "/home/jens/Source/shotwell/src/Dialogs.vala"
		videos_message = _tmp17_;
#line 343 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp18_ = manifest->already_imported;
#line 343 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp19_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp18_, GEE_TYPE_COLLECTION, GeeCollection));
#line 343 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp20_ = _tmp19_;
#line 343 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp21_ = manifest->already_imported;
#line 343 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp22_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp21_, GEE_TYPE_COLLECTION, GeeCollection));
#line 343 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp23_ = _tmp22_;
#line 343 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp24_ = g_strdup_printf (ngettext ("1 duplicate photo/video was not imported:\n", "%d duplicate photos/videos were not imported:\n", (gulong) _tmp20_), _tmp23_);
#line 343 "/home/jens/Source/shotwell/src/Dialogs.vala"
		both_message = _tmp24_;
#line 347 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp25_ = message;
#line 347 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp26_ = manifest->already_imported;
#line 347 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp27_ = photos_message;
#line 347 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp28_ = videos_message;
#line 347 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp29_ = both_message;
#line 347 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp30_ = both_message;
#line 347 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp31_ = import_ui_get_media_specific_string (G_TYPE_CHECK_INSTANCE_CAST (_tmp26_, GEE_TYPE_COLLECTION, GeeCollection), _tmp27_, _tmp28_, _tmp29_, _tmp30_);
#line 347 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp32_ = _tmp31_;
#line 347 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp33_ = g_strconcat (_tmp25_, _tmp32_, NULL);
#line 347 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (message);
#line 347 "/home/jens/Source/shotwell/src/Dialogs.vala"
		message = _tmp33_;
#line 347 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp32_);
#line 350 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp34_ = message;
#line 350 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp35_ = manifest->already_imported;
#line 350 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp36_ = import_ui_generate_import_failure_list (_tmp35_, show_dest_id);
#line 350 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp37_ = _tmp36_;
#line 350 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp38_ = g_strconcat (_tmp34_, _tmp37_, NULL);
#line 350 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (message);
#line 350 "/home/jens/Source/shotwell/src/Dialogs.vala"
		message = _tmp38_;
#line 350 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp37_);
#line 336 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (both_message);
#line 336 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (videos_message);
#line 336 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (photos_message);
#line 3869 "Dialogs.c"
	}
#line 353 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp39_ = manifest->failed;
#line 353 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp40_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp39_, GEE_TYPE_COLLECTION, GeeCollection));
#line 353 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp41_ = _tmp40_;
#line 353 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp41_ > 0) {
#line 3879 "Dialogs.c"
		const gchar* _tmp42_;
		gint _tmp43_;
		gint _tmp44_;
		gchar* photos_message = NULL;
		GeeList* _tmp47_;
		gint _tmp48_;
		gint _tmp49_;
		GeeList* _tmp50_;
		gint _tmp51_;
		gint _tmp52_;
		gchar* _tmp53_;
		gchar* videos_message = NULL;
		GeeList* _tmp54_;
		gint _tmp55_;
		gint _tmp56_;
		GeeList* _tmp57_;
		gint _tmp58_;
		gint _tmp59_;
		gchar* _tmp60_;
		gchar* both_message = NULL;
		GeeList* _tmp61_;
		gint _tmp62_;
		gint _tmp63_;
		GeeList* _tmp64_;
		gint _tmp65_;
		gint _tmp66_;
		gchar* _tmp67_;
		gchar* neither_message = NULL;
		GeeList* _tmp68_;
		gint _tmp69_;
		gint _tmp70_;
		GeeList* _tmp71_;
		gint _tmp72_;
		gint _tmp73_;
		gchar* _tmp74_;
		const gchar* _tmp75_;
		GeeList* _tmp76_;
		const gchar* _tmp77_;
		const gchar* _tmp78_;
		const gchar* _tmp79_;
		const gchar* _tmp80_;
		gchar* _tmp81_;
		gchar* _tmp82_;
		gchar* _tmp83_;
		const gchar* _tmp84_;
		GeeList* _tmp85_;
		gchar* _tmp86_;
		gchar* _tmp87_;
		gchar* _tmp88_;
#line 354 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp42_ = message;
#line 354 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp43_ = strlen (_tmp42_);
#line 354 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp44_ = _tmp43_;
#line 354 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (_tmp44_ > 0) {
#line 3937 "Dialogs.c"
			const gchar* _tmp45_;
			gchar* _tmp46_;
#line 355 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp45_ = message;
#line 355 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp46_ = g_strconcat (_tmp45_, "\n", NULL);
#line 355 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_free0 (message);
#line 355 "/home/jens/Source/shotwell/src/Dialogs.vala"
			message = _tmp46_;
#line 3948 "Dialogs.c"
		}
#line 357 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp47_ = manifest->failed;
#line 357 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp48_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp47_, GEE_TYPE_COLLECTION, GeeCollection));
#line 357 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp49_ = _tmp48_;
#line 357 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp50_ = manifest->failed;
#line 357 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp51_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp50_, GEE_TYPE_COLLECTION, GeeCollection));
#line 357 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp52_ = _tmp51_;
#line 357 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp53_ = g_strdup_printf (ngettext ("1 photo failed to import due to a file or hardware error:\n", "%d photos failed to import due to a file or hardware error:\n", (gulong) _tmp49_), _tmp52_);
#line 357 "/home/jens/Source/shotwell/src/Dialogs.vala"
		photos_message = _tmp53_;
#line 360 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp54_ = manifest->failed;
#line 360 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp55_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp54_, GEE_TYPE_COLLECTION, GeeCollection));
#line 360 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp56_ = _tmp55_;
#line 360 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp57_ = manifest->failed;
#line 360 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp58_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp57_, GEE_TYPE_COLLECTION, GeeCollection));
#line 360 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp59_ = _tmp58_;
#line 360 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp60_ = g_strdup_printf (ngettext ("1 video failed to import due to a file or hardware error:\n", "%d videos failed to import due to a file or hardware error:\n", (gulong) _tmp56_), _tmp59_);
#line 360 "/home/jens/Source/shotwell/src/Dialogs.vala"
		videos_message = _tmp60_;
#line 363 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp61_ = manifest->failed;
#line 363 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp62_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp61_, GEE_TYPE_COLLECTION, GeeCollection));
#line 363 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp63_ = _tmp62_;
#line 363 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp64_ = manifest->failed;
#line 363 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp65_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp64_, GEE_TYPE_COLLECTION, GeeCollection));
#line 363 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp66_ = _tmp65_;
#line 363 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp67_ = g_strdup_printf (ngettext ("1 photo/video failed to import due to a file or hardware error:\n", "%d photos/videos failed to import due to a file or hardware error:\n", (gulong) _tmp63_), _tmp66_);
#line 363 "/home/jens/Source/shotwell/src/Dialogs.vala"
		both_message = _tmp67_;
#line 366 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp68_ = manifest->failed;
#line 366 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp69_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp68_, GEE_TYPE_COLLECTION, GeeCollection));
#line 366 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp70_ = _tmp69_;
#line 366 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp71_ = manifest->failed;
#line 366 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp72_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp71_, GEE_TYPE_COLLECTION, GeeCollection));
#line 366 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp73_ = _tmp72_;
#line 366 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp74_ = g_strdup_printf (ngettext ("1 file failed to import due to a file or hardware error:\n", "%d files failed to import due to a file or hardware error:\n", (gulong) _tmp70_), _tmp73_);
#line 366 "/home/jens/Source/shotwell/src/Dialogs.vala"
		neither_message = _tmp74_;
#line 370 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp75_ = message;
#line 370 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp76_ = manifest->failed;
#line 370 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp77_ = photos_message;
#line 370 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp78_ = videos_message;
#line 370 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp79_ = both_message;
#line 370 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp80_ = neither_message;
#line 370 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp81_ = import_ui_get_media_specific_string (G_TYPE_CHECK_INSTANCE_CAST (_tmp76_, GEE_TYPE_COLLECTION, GeeCollection), _tmp77_, _tmp78_, _tmp79_, _tmp80_);
#line 370 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp82_ = _tmp81_;
#line 370 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp83_ = g_strconcat (_tmp75_, _tmp82_, NULL);
#line 370 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (message);
#line 370 "/home/jens/Source/shotwell/src/Dialogs.vala"
		message = _tmp83_;
#line 370 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp82_);
#line 373 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp84_ = message;
#line 373 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp85_ = manifest->failed;
#line 373 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp86_ = import_ui_generate_import_failure_list (_tmp85_, show_dest_id);
#line 373 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp87_ = _tmp86_;
#line 373 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp88_ = g_strconcat (_tmp84_, _tmp87_, NULL);
#line 373 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (message);
#line 373 "/home/jens/Source/shotwell/src/Dialogs.vala"
		message = _tmp88_;
#line 373 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp87_);
#line 353 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (neither_message);
#line 353 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (both_message);
#line 353 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (videos_message);
#line 353 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (photos_message);
#line 4062 "Dialogs.c"
	}
#line 376 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp89_ = manifest->write_failed;
#line 376 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp90_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp89_, GEE_TYPE_COLLECTION, GeeCollection));
#line 376 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp91_ = _tmp90_;
#line 376 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp91_ > 0) {
#line 4072 "Dialogs.c"
		const gchar* _tmp92_;
		gint _tmp93_;
		gint _tmp94_;
		gchar* photos_message = NULL;
		GeeList* _tmp97_;
		gint _tmp98_;
		gint _tmp99_;
		GeeList* _tmp100_;
		gint _tmp101_;
		gint _tmp102_;
		gchar* _tmp103_;
		gchar* videos_message = NULL;
		GeeList* _tmp104_;
		gint _tmp105_;
		gint _tmp106_;
		GeeList* _tmp107_;
		gint _tmp108_;
		gint _tmp109_;
		gchar* _tmp110_;
		gchar* both_message = NULL;
		GeeList* _tmp111_;
		gint _tmp112_;
		gint _tmp113_;
		GeeList* _tmp114_;
		gint _tmp115_;
		gint _tmp116_;
		gchar* _tmp117_;
		gchar* neither_message = NULL;
		GeeList* _tmp118_;
		gint _tmp119_;
		gint _tmp120_;
		GeeList* _tmp121_;
		gint _tmp122_;
		gint _tmp123_;
		gchar* _tmp124_;
		const gchar* _tmp125_;
		GeeList* _tmp126_;
		const gchar* _tmp127_;
		const gchar* _tmp128_;
		const gchar* _tmp129_;
		const gchar* _tmp130_;
		gchar* _tmp131_;
		gchar* _tmp132_;
		gchar* _tmp133_;
		const gchar* _tmp134_;
		GeeList* _tmp135_;
		gchar* _tmp136_;
		gchar* _tmp137_;
		gchar* _tmp138_;
#line 377 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp92_ = message;
#line 377 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp93_ = strlen (_tmp92_);
#line 377 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp94_ = _tmp93_;
#line 377 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (_tmp94_ > 0) {
#line 4130 "Dialogs.c"
			const gchar* _tmp95_;
			gchar* _tmp96_;
#line 378 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp95_ = message;
#line 378 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp96_ = g_strconcat (_tmp95_, "\n", NULL);
#line 378 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_free0 (message);
#line 378 "/home/jens/Source/shotwell/src/Dialogs.vala"
			message = _tmp96_;
#line 4141 "Dialogs.c"
		}
#line 380 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp97_ = manifest->write_failed;
#line 380 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp98_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp97_, GEE_TYPE_COLLECTION, GeeCollection));
#line 380 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp99_ = _tmp98_;
#line 380 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp100_ = manifest->write_failed;
#line 380 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp101_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp100_, GEE_TYPE_COLLECTION, GeeCollection));
#line 380 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp102_ = _tmp101_;
#line 380 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp103_ = g_strdup_printf (ngettext ("1 photo failed to import because the photo library folder was not writ" \
"able:\n", "%d photos failed to import because the photo library folder was not wr" \
"itable:\n", (gulong) _tmp99_), _tmp102_);
#line 380 "/home/jens/Source/shotwell/src/Dialogs.vala"
		photos_message = _tmp103_;
#line 383 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp104_ = manifest->write_failed;
#line 383 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp105_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp104_, GEE_TYPE_COLLECTION, GeeCollection));
#line 383 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp106_ = _tmp105_;
#line 383 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp107_ = manifest->write_failed;
#line 383 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp108_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp107_, GEE_TYPE_COLLECTION, GeeCollection));
#line 383 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp109_ = _tmp108_;
#line 383 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp110_ = g_strdup_printf (ngettext ("1 video failed to import because the photo library folder was not writ" \
"able:\n", "%d videos failed to import because the photo library folder was not wr" \
"itable:\n", (gulong) _tmp106_), _tmp109_);
#line 383 "/home/jens/Source/shotwell/src/Dialogs.vala"
		videos_message = _tmp110_;
#line 386 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp111_ = manifest->write_failed;
#line 386 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp112_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp111_, GEE_TYPE_COLLECTION, GeeCollection));
#line 386 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp113_ = _tmp112_;
#line 386 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp114_ = manifest->write_failed;
#line 386 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp115_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp114_, GEE_TYPE_COLLECTION, GeeCollection));
#line 386 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp116_ = _tmp115_;
#line 386 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp117_ = g_strdup_printf (ngettext ("1 photo/video failed to import because the photo library folder was no" \
"t writable:\n", "%d photos/videos failed to import because the photo library folder was" \
" not writable:\n", (gulong) _tmp113_), _tmp116_);
#line 386 "/home/jens/Source/shotwell/src/Dialogs.vala"
		both_message = _tmp117_;
#line 389 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp118_ = manifest->write_failed;
#line 389 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp119_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp118_, GEE_TYPE_COLLECTION, GeeCollection));
#line 389 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp120_ = _tmp119_;
#line 389 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp121_ = manifest->write_failed;
#line 389 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp122_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp121_, GEE_TYPE_COLLECTION, GeeCollection));
#line 389 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp123_ = _tmp122_;
#line 389 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp124_ = g_strdup_printf (ngettext ("1 file failed to import because the photo library folder was not writa" \
"ble:\n", "%d files failed to import because the photo library folder was not wri" \
"table:\n", (gulong) _tmp120_), _tmp123_);
#line 389 "/home/jens/Source/shotwell/src/Dialogs.vala"
		neither_message = _tmp124_;
#line 393 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp125_ = message;
#line 393 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp126_ = manifest->write_failed;
#line 393 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp127_ = photos_message;
#line 393 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp128_ = videos_message;
#line 393 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp129_ = both_message;
#line 393 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp130_ = neither_message;
#line 393 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp131_ = import_ui_get_media_specific_string (G_TYPE_CHECK_INSTANCE_CAST (_tmp126_, GEE_TYPE_COLLECTION, GeeCollection), _tmp127_, _tmp128_, _tmp129_, _tmp130_);
#line 393 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp132_ = _tmp131_;
#line 393 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp133_ = g_strconcat (_tmp125_, _tmp132_, NULL);
#line 393 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (message);
#line 393 "/home/jens/Source/shotwell/src/Dialogs.vala"
		message = _tmp133_;
#line 393 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp132_);
#line 396 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp134_ = message;
#line 396 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp135_ = manifest->write_failed;
#line 396 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp136_ = import_ui_generate_import_failure_list (_tmp135_, show_dest_id);
#line 396 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp137_ = _tmp136_;
#line 396 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp138_ = g_strconcat (_tmp134_, _tmp137_, NULL);
#line 396 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (message);
#line 396 "/home/jens/Source/shotwell/src/Dialogs.vala"
		message = _tmp138_;
#line 396 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp137_);
#line 376 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (neither_message);
#line 376 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (both_message);
#line 376 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (videos_message);
#line 376 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (photos_message);
#line 4255 "Dialogs.c"
	}
#line 399 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp139_ = manifest->camera_failed;
#line 399 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp140_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp139_, GEE_TYPE_COLLECTION, GeeCollection));
#line 399 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp141_ = _tmp140_;
#line 399 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp141_ > 0) {
#line 4265 "Dialogs.c"
		const gchar* _tmp142_;
		gint _tmp143_;
		gint _tmp144_;
		gchar* photos_message = NULL;
		GeeList* _tmp147_;
		gint _tmp148_;
		gint _tmp149_;
		GeeList* _tmp150_;
		gint _tmp151_;
		gint _tmp152_;
		gchar* _tmp153_;
		gchar* videos_message = NULL;
		GeeList* _tmp154_;
		gint _tmp155_;
		gint _tmp156_;
		GeeList* _tmp157_;
		gint _tmp158_;
		gint _tmp159_;
		gchar* _tmp160_;
		gchar* both_message = NULL;
		GeeList* _tmp161_;
		gint _tmp162_;
		gint _tmp163_;
		GeeList* _tmp164_;
		gint _tmp165_;
		gint _tmp166_;
		gchar* _tmp167_;
		gchar* neither_message = NULL;
		GeeList* _tmp168_;
		gint _tmp169_;
		gint _tmp170_;
		GeeList* _tmp171_;
		gint _tmp172_;
		gint _tmp173_;
		gchar* _tmp174_;
		const gchar* _tmp175_;
		GeeList* _tmp176_;
		const gchar* _tmp177_;
		const gchar* _tmp178_;
		const gchar* _tmp179_;
		const gchar* _tmp180_;
		gchar* _tmp181_;
		gchar* _tmp182_;
		gchar* _tmp183_;
		const gchar* _tmp184_;
		GeeList* _tmp185_;
		gchar* _tmp186_;
		gchar* _tmp187_;
		gchar* _tmp188_;
#line 400 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp142_ = message;
#line 400 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp143_ = strlen (_tmp142_);
#line 400 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp144_ = _tmp143_;
#line 400 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (_tmp144_ > 0) {
#line 4323 "Dialogs.c"
			const gchar* _tmp145_;
			gchar* _tmp146_;
#line 401 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp145_ = message;
#line 401 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp146_ = g_strconcat (_tmp145_, "\n", NULL);
#line 401 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_free0 (message);
#line 401 "/home/jens/Source/shotwell/src/Dialogs.vala"
			message = _tmp146_;
#line 4334 "Dialogs.c"
		}
#line 403 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp147_ = manifest->camera_failed;
#line 403 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp148_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp147_, GEE_TYPE_COLLECTION, GeeCollection));
#line 403 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp149_ = _tmp148_;
#line 403 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp150_ = manifest->camera_failed;
#line 403 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp151_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp150_, GEE_TYPE_COLLECTION, GeeCollection));
#line 403 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp152_ = _tmp151_;
#line 403 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp153_ = g_strdup_printf (ngettext ("1 photo failed to import due to a camera error:\n", "%d photos failed to import due to a camera error:\n", (gulong) _tmp149_), _tmp152_);
#line 403 "/home/jens/Source/shotwell/src/Dialogs.vala"
		photos_message = _tmp153_;
#line 406 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp154_ = manifest->camera_failed;
#line 406 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp155_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp154_, GEE_TYPE_COLLECTION, GeeCollection));
#line 406 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp156_ = _tmp155_;
#line 406 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp157_ = manifest->camera_failed;
#line 406 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp158_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp157_, GEE_TYPE_COLLECTION, GeeCollection));
#line 406 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp159_ = _tmp158_;
#line 406 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp160_ = g_strdup_printf (ngettext ("1 video failed to import due to a camera error:\n", "%d videos failed to import due to a camera error:\n", (gulong) _tmp156_), _tmp159_);
#line 406 "/home/jens/Source/shotwell/src/Dialogs.vala"
		videos_message = _tmp160_;
#line 409 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp161_ = manifest->camera_failed;
#line 409 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp162_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp161_, GEE_TYPE_COLLECTION, GeeCollection));
#line 409 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp163_ = _tmp162_;
#line 409 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp164_ = manifest->camera_failed;
#line 409 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp165_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp164_, GEE_TYPE_COLLECTION, GeeCollection));
#line 409 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp166_ = _tmp165_;
#line 409 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp167_ = g_strdup_printf (ngettext ("1 photo/video failed to import due to a camera error:\n", "%d photos/videos failed to import due to a camera error:\n", (gulong) _tmp163_), _tmp166_);
#line 409 "/home/jens/Source/shotwell/src/Dialogs.vala"
		both_message = _tmp167_;
#line 412 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp168_ = manifest->camera_failed;
#line 412 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp169_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp168_, GEE_TYPE_COLLECTION, GeeCollection));
#line 412 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp170_ = _tmp169_;
#line 412 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp171_ = manifest->camera_failed;
#line 412 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp172_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp171_, GEE_TYPE_COLLECTION, GeeCollection));
#line 412 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp173_ = _tmp172_;
#line 412 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp174_ = g_strdup_printf (ngettext ("1 file failed to import due to a camera error:\n", "%d files failed to import due to a camera error:\n", (gulong) _tmp170_), _tmp173_);
#line 412 "/home/jens/Source/shotwell/src/Dialogs.vala"
		neither_message = _tmp174_;
#line 416 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp175_ = message;
#line 416 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp176_ = manifest->camera_failed;
#line 416 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp177_ = photos_message;
#line 416 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp178_ = videos_message;
#line 416 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp179_ = both_message;
#line 416 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp180_ = neither_message;
#line 416 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp181_ = import_ui_get_media_specific_string (G_TYPE_CHECK_INSTANCE_CAST (_tmp176_, GEE_TYPE_COLLECTION, GeeCollection), _tmp177_, _tmp178_, _tmp179_, _tmp180_);
#line 416 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp182_ = _tmp181_;
#line 416 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp183_ = g_strconcat (_tmp175_, _tmp182_, NULL);
#line 416 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (message);
#line 416 "/home/jens/Source/shotwell/src/Dialogs.vala"
		message = _tmp183_;
#line 416 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp182_);
#line 419 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp184_ = message;
#line 419 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp185_ = manifest->camera_failed;
#line 419 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp186_ = import_ui_generate_import_failure_list (_tmp185_, show_dest_id);
#line 419 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp187_ = _tmp186_;
#line 419 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp188_ = g_strconcat (_tmp184_, _tmp187_, NULL);
#line 419 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (message);
#line 419 "/home/jens/Source/shotwell/src/Dialogs.vala"
		message = _tmp188_;
#line 419 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp187_);
#line 399 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (neither_message);
#line 399 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (both_message);
#line 399 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (videos_message);
#line 399 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (photos_message);
#line 4448 "Dialogs.c"
	}
#line 422 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp189_ = manifest->corrupt_files;
#line 422 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp190_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp189_, GEE_TYPE_COLLECTION, GeeCollection));
#line 422 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp191_ = _tmp190_;
#line 422 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp191_ > 0) {
#line 4458 "Dialogs.c"
		const gchar* _tmp192_;
		gint _tmp193_;
		gint _tmp194_;
		gchar* photos_message = NULL;
		GeeList* _tmp197_;
		gint _tmp198_;
		gint _tmp199_;
		GeeList* _tmp200_;
		gint _tmp201_;
		gint _tmp202_;
		gchar* _tmp203_;
		gchar* videos_message = NULL;
		GeeList* _tmp204_;
		gint _tmp205_;
		gint _tmp206_;
		GeeList* _tmp207_;
		gint _tmp208_;
		gint _tmp209_;
		gchar* _tmp210_;
		gchar* both_message = NULL;
		GeeList* _tmp211_;
		gint _tmp212_;
		gint _tmp213_;
		GeeList* _tmp214_;
		gint _tmp215_;
		gint _tmp216_;
		gchar* _tmp217_;
		gchar* neither_message = NULL;
		GeeList* _tmp218_;
		gint _tmp219_;
		gint _tmp220_;
		GeeList* _tmp221_;
		gint _tmp222_;
		gint _tmp223_;
		gchar* _tmp224_;
		const gchar* _tmp225_;
		GeeList* _tmp226_;
		const gchar* _tmp227_;
		const gchar* _tmp228_;
		const gchar* _tmp229_;
		const gchar* _tmp230_;
		gchar* _tmp231_;
		gchar* _tmp232_;
		gchar* _tmp233_;
		const gchar* _tmp234_;
		GeeList* _tmp235_;
		gchar* _tmp236_;
		gchar* _tmp237_;
		gchar* _tmp238_;
#line 423 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp192_ = message;
#line 423 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp193_ = strlen (_tmp192_);
#line 423 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp194_ = _tmp193_;
#line 423 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (_tmp194_ > 0) {
#line 4516 "Dialogs.c"
			const gchar* _tmp195_;
			gchar* _tmp196_;
#line 424 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp195_ = message;
#line 424 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp196_ = g_strconcat (_tmp195_, "\n", NULL);
#line 424 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_free0 (message);
#line 424 "/home/jens/Source/shotwell/src/Dialogs.vala"
			message = _tmp196_;
#line 4527 "Dialogs.c"
		}
#line 426 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp197_ = manifest->corrupt_files;
#line 426 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp198_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp197_, GEE_TYPE_COLLECTION, GeeCollection));
#line 426 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp199_ = _tmp198_;
#line 426 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp200_ = manifest->corrupt_files;
#line 426 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp201_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp200_, GEE_TYPE_COLLECTION, GeeCollection));
#line 426 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp202_ = _tmp201_;
#line 426 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp203_ = g_strdup_printf (ngettext ("1 photo failed to import because it was corrupt:\n", "%d photos failed to import because they were corrupt:\n", (gulong) _tmp199_), _tmp202_);
#line 426 "/home/jens/Source/shotwell/src/Dialogs.vala"
		photos_message = _tmp203_;
#line 429 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp204_ = manifest->corrupt_files;
#line 429 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp205_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp204_, GEE_TYPE_COLLECTION, GeeCollection));
#line 429 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp206_ = _tmp205_;
#line 429 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp207_ = manifest->corrupt_files;
#line 429 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp208_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp207_, GEE_TYPE_COLLECTION, GeeCollection));
#line 429 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp209_ = _tmp208_;
#line 429 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp210_ = g_strdup_printf (ngettext ("1 video failed to import because it was corrupt:\n", "%d videos failed to import because they were corrupt:\n", (gulong) _tmp206_), _tmp209_);
#line 429 "/home/jens/Source/shotwell/src/Dialogs.vala"
		videos_message = _tmp210_;
#line 432 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp211_ = manifest->corrupt_files;
#line 432 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp212_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp211_, GEE_TYPE_COLLECTION, GeeCollection));
#line 432 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp213_ = _tmp212_;
#line 432 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp214_ = manifest->corrupt_files;
#line 432 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp215_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp214_, GEE_TYPE_COLLECTION, GeeCollection));
#line 432 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp216_ = _tmp215_;
#line 432 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp217_ = g_strdup_printf (ngettext ("1 photo/video failed to import because it was corrupt:\n", "%d photos/videos failed to import because they were corrupt:\n", (gulong) _tmp213_), _tmp216_);
#line 432 "/home/jens/Source/shotwell/src/Dialogs.vala"
		both_message = _tmp217_;
#line 435 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp218_ = manifest->corrupt_files;
#line 435 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp219_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp218_, GEE_TYPE_COLLECTION, GeeCollection));
#line 435 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp220_ = _tmp219_;
#line 435 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp221_ = manifest->corrupt_files;
#line 435 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp222_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp221_, GEE_TYPE_COLLECTION, GeeCollection));
#line 435 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp223_ = _tmp222_;
#line 435 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp224_ = g_strdup_printf (ngettext ("1 file failed to import because it was corrupt:\n", "%d files failed to import because it was corrupt:\n", (gulong) _tmp220_), _tmp223_);
#line 435 "/home/jens/Source/shotwell/src/Dialogs.vala"
		neither_message = _tmp224_;
#line 439 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp225_ = message;
#line 439 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp226_ = manifest->corrupt_files;
#line 439 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp227_ = photos_message;
#line 439 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp228_ = videos_message;
#line 439 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp229_ = both_message;
#line 439 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp230_ = neither_message;
#line 439 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp231_ = import_ui_get_media_specific_string (G_TYPE_CHECK_INSTANCE_CAST (_tmp226_, GEE_TYPE_COLLECTION, GeeCollection), _tmp227_, _tmp228_, _tmp229_, _tmp230_);
#line 439 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp232_ = _tmp231_;
#line 439 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp233_ = g_strconcat (_tmp225_, _tmp232_, NULL);
#line 439 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (message);
#line 439 "/home/jens/Source/shotwell/src/Dialogs.vala"
		message = _tmp233_;
#line 439 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp232_);
#line 442 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp234_ = message;
#line 442 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp235_ = manifest->corrupt_files;
#line 442 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp236_ = import_ui_generate_import_failure_list (_tmp235_, show_dest_id);
#line 442 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp237_ = _tmp236_;
#line 442 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp238_ = g_strconcat (_tmp234_, _tmp237_, NULL);
#line 442 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (message);
#line 442 "/home/jens/Source/shotwell/src/Dialogs.vala"
		message = _tmp238_;
#line 442 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp237_);
#line 422 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (neither_message);
#line 422 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (both_message);
#line 422 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (videos_message);
#line 422 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (photos_message);
#line 4641 "Dialogs.c"
	}
#line 445 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp239_ = manifest->skipped_photos;
#line 445 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp240_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp239_, GEE_TYPE_COLLECTION, GeeCollection));
#line 445 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp241_ = _tmp240_;
#line 445 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp241_ > 0) {
#line 4651 "Dialogs.c"
		const gchar* _tmp242_;
		gint _tmp243_;
		gint _tmp244_;
		gchar* skipped_photos_message = NULL;
		GeeList* _tmp247_;
		gint _tmp248_;
		gint _tmp249_;
		GeeList* _tmp250_;
		gint _tmp251_;
		gint _tmp252_;
		gchar* _tmp253_;
		const gchar* _tmp254_;
		const gchar* _tmp255_;
		gchar* _tmp256_;
		const gchar* _tmp257_;
		GeeList* _tmp258_;
		gchar* _tmp259_;
		gchar* _tmp260_;
		gchar* _tmp261_;
#line 446 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp242_ = message;
#line 446 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp243_ = strlen (_tmp242_);
#line 446 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp244_ = _tmp243_;
#line 446 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (_tmp244_ > 0) {
#line 4679 "Dialogs.c"
			const gchar* _tmp245_;
			gchar* _tmp246_;
#line 447 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp245_ = message;
#line 447 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp246_ = g_strconcat (_tmp245_, "\n", NULL);
#line 447 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_free0 (message);
#line 447 "/home/jens/Source/shotwell/src/Dialogs.vala"
			message = _tmp246_;
#line 4690 "Dialogs.c"
		}
#line 452 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp247_ = manifest->skipped_photos;
#line 452 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp248_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp247_, GEE_TYPE_COLLECTION, GeeCollection));
#line 452 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp249_ = _tmp248_;
#line 452 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp250_ = manifest->skipped_photos;
#line 452 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp251_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp250_, GEE_TYPE_COLLECTION, GeeCollection));
#line 452 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp252_ = _tmp251_;
#line 452 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp253_ = g_strdup_printf (ngettext ("1 unsupported photo skipped:\n", "%d unsupported photos skipped:\n", (gulong) _tmp249_), _tmp252_);
#line 452 "/home/jens/Source/shotwell/src/Dialogs.vala"
		skipped_photos_message = _tmp253_;
#line 456 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp254_ = message;
#line 456 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp255_ = skipped_photos_message;
#line 456 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp256_ = g_strconcat (_tmp254_, _tmp255_, NULL);
#line 456 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (message);
#line 456 "/home/jens/Source/shotwell/src/Dialogs.vala"
		message = _tmp256_;
#line 458 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp257_ = message;
#line 458 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp258_ = manifest->skipped_photos;
#line 458 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp259_ = import_ui_generate_import_failure_list (_tmp258_, show_dest_id);
#line 458 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp260_ = _tmp259_;
#line 458 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp261_ = g_strconcat (_tmp257_, _tmp260_, NULL);
#line 458 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (message);
#line 458 "/home/jens/Source/shotwell/src/Dialogs.vala"
		message = _tmp261_;
#line 458 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp260_);
#line 445 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (skipped_photos_message);
#line 4736 "Dialogs.c"
	}
#line 461 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp262_ = manifest->skipped_files;
#line 461 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp263_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp262_, GEE_TYPE_COLLECTION, GeeCollection));
#line 461 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp264_ = _tmp263_;
#line 461 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp264_ > 0) {
#line 4746 "Dialogs.c"
		const gchar* _tmp265_;
		gint _tmp266_;
		gint _tmp267_;
		gchar* skipped_files_message = NULL;
		GeeList* _tmp270_;
		gint _tmp271_;
		gint _tmp272_;
		GeeList* _tmp273_;
		gint _tmp274_;
		gint _tmp275_;
		gchar* _tmp276_;
		const gchar* _tmp277_;
		const gchar* _tmp278_;
		gchar* _tmp279_;
#line 462 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp265_ = message;
#line 462 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp266_ = strlen (_tmp265_);
#line 462 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp267_ = _tmp266_;
#line 462 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (_tmp267_ > 0) {
#line 4769 "Dialogs.c"
			const gchar* _tmp268_;
			gchar* _tmp269_;
#line 463 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp268_ = message;
#line 463 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp269_ = g_strconcat (_tmp268_, "\n", NULL);
#line 463 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_free0 (message);
#line 463 "/home/jens/Source/shotwell/src/Dialogs.vala"
			message = _tmp269_;
#line 4780 "Dialogs.c"
		}
#line 467 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp270_ = manifest->skipped_files;
#line 467 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp271_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp270_, GEE_TYPE_COLLECTION, GeeCollection));
#line 467 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp272_ = _tmp271_;
#line 467 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp273_ = manifest->skipped_files;
#line 467 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp274_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp273_, GEE_TYPE_COLLECTION, GeeCollection));
#line 467 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp275_ = _tmp274_;
#line 467 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp276_ = g_strdup_printf (ngettext ("1 non-image file skipped.\n", "%d non-image files skipped.\n", (gulong) _tmp272_), _tmp275_);
#line 467 "/home/jens/Source/shotwell/src/Dialogs.vala"
		skipped_files_message = _tmp276_;
#line 471 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp277_ = message;
#line 471 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp278_ = skipped_files_message;
#line 471 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp279_ = g_strconcat (_tmp277_, _tmp278_, NULL);
#line 471 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (message);
#line 471 "/home/jens/Source/shotwell/src/Dialogs.vala"
		message = _tmp279_;
#line 461 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (skipped_files_message);
#line 4810 "Dialogs.c"
	}
#line 474 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp280_ = manifest->aborted;
#line 474 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp281_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp280_, GEE_TYPE_COLLECTION, GeeCollection));
#line 474 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp282_ = _tmp281_;
#line 474 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp282_ > 0) {
#line 4820 "Dialogs.c"
		const gchar* _tmp283_;
		gint _tmp284_;
		gint _tmp285_;
		gchar* photos_message = NULL;
		GeeList* _tmp288_;
		gint _tmp289_;
		gint _tmp290_;
		GeeList* _tmp291_;
		gint _tmp292_;
		gint _tmp293_;
		gchar* _tmp294_;
		gchar* videos_message = NULL;
		GeeList* _tmp295_;
		gint _tmp296_;
		gint _tmp297_;
		GeeList* _tmp298_;
		gint _tmp299_;
		gint _tmp300_;
		gchar* _tmp301_;
		gchar* both_message = NULL;
		GeeList* _tmp302_;
		gint _tmp303_;
		gint _tmp304_;
		GeeList* _tmp305_;
		gint _tmp306_;
		gint _tmp307_;
		gchar* _tmp308_;
		gchar* neither_message = NULL;
		GeeList* _tmp309_;
		gint _tmp310_;
		gint _tmp311_;
		GeeList* _tmp312_;
		gint _tmp313_;
		gint _tmp314_;
		gchar* _tmp315_;
		const gchar* _tmp316_;
		GeeList* _tmp317_;
		const gchar* _tmp318_;
		const gchar* _tmp319_;
		const gchar* _tmp320_;
		const gchar* _tmp321_;
		gchar* _tmp322_;
		gchar* _tmp323_;
		gchar* _tmp324_;
		const gchar* _tmp325_;
		GeeList* _tmp326_;
		gchar* _tmp327_;
		gchar* _tmp328_;
		gchar* _tmp329_;
#line 475 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp283_ = message;
#line 475 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp284_ = strlen (_tmp283_);
#line 475 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp285_ = _tmp284_;
#line 475 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (_tmp285_ > 0) {
#line 4878 "Dialogs.c"
			const gchar* _tmp286_;
			gchar* _tmp287_;
#line 476 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp286_ = message;
#line 476 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp287_ = g_strconcat (_tmp286_, "\n", NULL);
#line 476 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_free0 (message);
#line 476 "/home/jens/Source/shotwell/src/Dialogs.vala"
			message = _tmp287_;
#line 4889 "Dialogs.c"
		}
#line 478 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp288_ = manifest->aborted;
#line 478 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp289_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp288_, GEE_TYPE_COLLECTION, GeeCollection));
#line 478 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp290_ = _tmp289_;
#line 478 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp291_ = manifest->aborted;
#line 478 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp292_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp291_, GEE_TYPE_COLLECTION, GeeCollection));
#line 478 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp293_ = _tmp292_;
#line 478 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp294_ = g_strdup_printf (ngettext ("1 photo skipped due to user cancel:\n", "%d photos skipped due to user cancel:\n", (gulong) _tmp290_), _tmp293_);
#line 478 "/home/jens/Source/shotwell/src/Dialogs.vala"
		photos_message = _tmp294_;
#line 481 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp295_ = manifest->aborted;
#line 481 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp296_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp295_, GEE_TYPE_COLLECTION, GeeCollection));
#line 481 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp297_ = _tmp296_;
#line 481 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp298_ = manifest->aborted;
#line 481 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp299_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp298_, GEE_TYPE_COLLECTION, GeeCollection));
#line 481 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp300_ = _tmp299_;
#line 481 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp301_ = g_strdup_printf (ngettext ("1 video skipped due to user cancel:\n", "%d videos skipped due to user cancel:\n", (gulong) _tmp297_), _tmp300_);
#line 481 "/home/jens/Source/shotwell/src/Dialogs.vala"
		videos_message = _tmp301_;
#line 484 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp302_ = manifest->aborted;
#line 484 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp303_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp302_, GEE_TYPE_COLLECTION, GeeCollection));
#line 484 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp304_ = _tmp303_;
#line 484 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp305_ = manifest->aborted;
#line 484 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp306_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp305_, GEE_TYPE_COLLECTION, GeeCollection));
#line 484 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp307_ = _tmp306_;
#line 484 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp308_ = g_strdup_printf (ngettext ("1 photo/video skipped due to user cancel:\n", "%d photos/videos skipped due to user cancel:\n", (gulong) _tmp304_), _tmp307_);
#line 484 "/home/jens/Source/shotwell/src/Dialogs.vala"
		both_message = _tmp308_;
#line 487 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp309_ = manifest->aborted;
#line 487 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp310_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp309_, GEE_TYPE_COLLECTION, GeeCollection));
#line 487 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp311_ = _tmp310_;
#line 487 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp312_ = manifest->aborted;
#line 487 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp313_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp312_, GEE_TYPE_COLLECTION, GeeCollection));
#line 487 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp314_ = _tmp313_;
#line 487 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp315_ = g_strdup_printf (ngettext ("1 file skipped due to user cancel:\n", "%d file skipped due to user cancel:\n", (gulong) _tmp311_), _tmp314_);
#line 487 "/home/jens/Source/shotwell/src/Dialogs.vala"
		neither_message = _tmp315_;
#line 491 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp316_ = message;
#line 491 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp317_ = manifest->aborted;
#line 491 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp318_ = photos_message;
#line 491 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp319_ = videos_message;
#line 491 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp320_ = both_message;
#line 491 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp321_ = neither_message;
#line 491 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp322_ = import_ui_get_media_specific_string (G_TYPE_CHECK_INSTANCE_CAST (_tmp317_, GEE_TYPE_COLLECTION, GeeCollection), _tmp318_, _tmp319_, _tmp320_, _tmp321_);
#line 491 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp323_ = _tmp322_;
#line 491 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp324_ = g_strconcat (_tmp316_, _tmp323_, NULL);
#line 491 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (message);
#line 491 "/home/jens/Source/shotwell/src/Dialogs.vala"
		message = _tmp324_;
#line 491 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp323_);
#line 494 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp325_ = message;
#line 494 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp326_ = manifest->aborted;
#line 494 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp327_ = import_ui_generate_import_failure_list (_tmp326_, show_dest_id);
#line 494 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp328_ = _tmp327_;
#line 494 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp329_ = g_strconcat (_tmp325_, _tmp328_, NULL);
#line 494 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (message);
#line 494 "/home/jens/Source/shotwell/src/Dialogs.vala"
		message = _tmp329_;
#line 494 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp328_);
#line 474 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (neither_message);
#line 474 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (both_message);
#line 474 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (videos_message);
#line 474 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (photos_message);
#line 5003 "Dialogs.c"
	}
#line 497 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp330_ = manifest->success;
#line 497 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp331_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp330_, GEE_TYPE_COLLECTION, GeeCollection));
#line 497 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp332_ = _tmp331_;
#line 497 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp332_ > 0) {
#line 5013 "Dialogs.c"
		const gchar* _tmp333_;
		gint _tmp334_;
		gint _tmp335_;
		gchar* photos_message = NULL;
		GeeList* _tmp338_;
		gint _tmp339_;
		gint _tmp340_;
		GeeList* _tmp341_;
		gint _tmp342_;
		gint _tmp343_;
		gchar* _tmp344_;
		gchar* videos_message = NULL;
		GeeList* _tmp345_;
		gint _tmp346_;
		gint _tmp347_;
		GeeList* _tmp348_;
		gint _tmp349_;
		gint _tmp350_;
		gchar* _tmp351_;
		gchar* both_message = NULL;
		GeeList* _tmp352_;
		gint _tmp353_;
		gint _tmp354_;
		GeeList* _tmp355_;
		gint _tmp356_;
		gint _tmp357_;
		gchar* _tmp358_;
		const gchar* _tmp359_;
		GeeList* _tmp360_;
		const gchar* _tmp361_;
		const gchar* _tmp362_;
		const gchar* _tmp363_;
		gchar* _tmp364_;
		gchar* _tmp365_;
		gchar* _tmp366_;
#line 498 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp333_ = message;
#line 498 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp334_ = strlen (_tmp333_);
#line 498 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp335_ = _tmp334_;
#line 498 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (_tmp335_ > 0) {
#line 5057 "Dialogs.c"
			const gchar* _tmp336_;
			gchar* _tmp337_;
#line 499 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp336_ = message;
#line 499 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp337_ = g_strconcat (_tmp336_, "\n", NULL);
#line 499 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_free0 (message);
#line 499 "/home/jens/Source/shotwell/src/Dialogs.vala"
			message = _tmp337_;
#line 5068 "Dialogs.c"
		}
#line 501 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp338_ = manifest->success;
#line 501 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp339_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp338_, GEE_TYPE_COLLECTION, GeeCollection));
#line 501 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp340_ = _tmp339_;
#line 501 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp341_ = manifest->success;
#line 501 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp342_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp341_, GEE_TYPE_COLLECTION, GeeCollection));
#line 501 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp343_ = _tmp342_;
#line 501 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp344_ = g_strdup_printf (ngettext ("1 photo successfully imported.\n", "%d photos successfully imported.\n", (gulong) _tmp340_), _tmp343_);
#line 501 "/home/jens/Source/shotwell/src/Dialogs.vala"
		photos_message = _tmp344_;
#line 504 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp345_ = manifest->success;
#line 504 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp346_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp345_, GEE_TYPE_COLLECTION, GeeCollection));
#line 504 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp347_ = _tmp346_;
#line 504 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp348_ = manifest->success;
#line 504 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp349_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp348_, GEE_TYPE_COLLECTION, GeeCollection));
#line 504 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp350_ = _tmp349_;
#line 504 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp351_ = g_strdup_printf (ngettext ("1 video successfully imported.\n", "%d videos successfully imported.\n", (gulong) _tmp347_), _tmp350_);
#line 504 "/home/jens/Source/shotwell/src/Dialogs.vala"
		videos_message = _tmp351_;
#line 507 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp352_ = manifest->success;
#line 507 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp353_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp352_, GEE_TYPE_COLLECTION, GeeCollection));
#line 507 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp354_ = _tmp353_;
#line 507 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp355_ = manifest->success;
#line 507 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp356_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp355_, GEE_TYPE_COLLECTION, GeeCollection));
#line 507 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp357_ = _tmp356_;
#line 507 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp358_ = g_strdup_printf (ngettext ("1 photo/video successfully imported.\n", "%d photos/videos successfully imported.\n", (gulong) _tmp354_), _tmp357_);
#line 507 "/home/jens/Source/shotwell/src/Dialogs.vala"
		both_message = _tmp358_;
#line 511 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp359_ = message;
#line 511 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp360_ = manifest->success;
#line 511 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp361_ = photos_message;
#line 511 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp362_ = videos_message;
#line 511 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp363_ = both_message;
#line 511 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp364_ = import_ui_get_media_specific_string (G_TYPE_CHECK_INSTANCE_CAST (_tmp360_, GEE_TYPE_COLLECTION, GeeCollection), _tmp361_, _tmp362_, _tmp363_, "");
#line 511 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp365_ = _tmp364_;
#line 511 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp366_ = g_strconcat (_tmp359_, _tmp365_, NULL);
#line 511 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (message);
#line 511 "/home/jens/Source/shotwell/src/Dialogs.vala"
		message = _tmp366_;
#line 511 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp365_);
#line 497 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (both_message);
#line 497 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (videos_message);
#line 497 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (photos_message);
#line 5146 "Dialogs.c"
	}
#line 515 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp367_ = manifest->success;
#line 515 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp368_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp367_, GEE_TYPE_COLLECTION, GeeCollection));
#line 515 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp369_ = _tmp368_;
#line 515 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp370_ = manifest->failed;
#line 515 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp371_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp370_, GEE_TYPE_COLLECTION, GeeCollection));
#line 515 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp372_ = _tmp371_;
#line 515 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp373_ = manifest->camera_failed;
#line 515 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp374_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp373_, GEE_TYPE_COLLECTION, GeeCollection));
#line 515 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp375_ = _tmp374_;
#line 515 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp376_ = manifest->skipped_photos;
#line 515 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp377_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp376_, GEE_TYPE_COLLECTION, GeeCollection));
#line 515 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp378_ = _tmp377_;
#line 515 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp379_ = manifest->skipped_files;
#line 515 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp380_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp379_, GEE_TYPE_COLLECTION, GeeCollection));
#line 515 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp381_ = _tmp380_;
#line 515 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp382_ = manifest->corrupt_files;
#line 515 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp383_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp382_, GEE_TYPE_COLLECTION, GeeCollection));
#line 515 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp384_ = _tmp383_;
#line 515 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp385_ = manifest->already_imported;
#line 515 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp386_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp385_, GEE_TYPE_COLLECTION, GeeCollection));
#line 515 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp387_ = _tmp386_;
#line 515 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp388_ = manifest->aborted;
#line 515 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp389_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp388_, GEE_TYPE_COLLECTION, GeeCollection));
#line 515 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp390_ = _tmp389_;
#line 515 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp391_ = manifest->write_failed;
#line 515 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp392_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp391_, GEE_TYPE_COLLECTION, GeeCollection));
#line 515 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp393_ = _tmp392_;
#line 515 "/home/jens/Source/shotwell/src/Dialogs.vala"
	total = (((((((_tmp369_ + _tmp372_) + _tmp375_) + _tmp378_) + _tmp381_) + _tmp384_) + _tmp387_) + _tmp390_) + _tmp393_;
#line 518 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp394_ = total;
#line 518 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp395_ = manifest->all;
#line 518 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp396_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp395_, GEE_TYPE_COLLECTION, GeeCollection));
#line 518 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp397_ = _tmp396_;
#line 518 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_vala_assert (_tmp394_ == _tmp397_, "total == manifest.all.size");
#line 522 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp398_ = total;
#line 522 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp398_ == 0) {
#line 5218 "Dialogs.c"
		const gchar* _tmp399_;
		gchar* _tmp400_;
#line 523 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp399_ = message;
#line 523 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp400_ = g_strconcat (_tmp399_, _ ("No photos or videos imported.\n"), NULL);
#line 523 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (message);
#line 523 "/home/jens/Source/shotwell/src/Dialogs.vala"
		message = _tmp400_;
#line 5229 "Dialogs.c"
	}
#line 525 "/home/jens/Source/shotwell/src/Dialogs.vala"
	dialog = NULL;
#line 526 "/home/jens/Source/shotwell/src/Dialogs.vala"
	dialog_response = (gint) GTK_RESPONSE_NONE;
#line 527 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (question == NULL) {
#line 5237 "Dialogs.c"
		AppWindow* _tmp401_;
		AppWindow* _tmp402_;
		const gchar* _tmp403_;
		GtkMessageDialog* _tmp404_;
		GtkMessageDialog* _tmp405_;
		GtkWidget* save_results_button = NULL;
		GtkMessageDialog* _tmp406_;
		GtkWidget* _tmp407_;
		GtkWidget* _tmp408_;
		GtkWidget* _tmp409_;
		GeeList* _tmp410_;
		gint _tmp411_;
		gint _tmp412_;
		GeeList* _tmp413_;
		gint _tmp414_;
		gint _tmp415_;
		GtkWidget* ok_button = NULL;
		GtkMessageDialog* _tmp416_;
		GtkWidget* _tmp417_;
		GtkWidget* _tmp418_;
		GtkMessageDialog* _tmp419_;
		GtkWidget* _tmp420_;
		GtkWindow* dialog_parent = NULL;
		GtkMessageDialog* _tmp421_;
		GtkContainer* _tmp422_;
		GtkWindow* _tmp423_;
		GtkMessageDialog* _tmp424_;
		GtkMessageDialog* _tmp425_;
		gint _tmp426_;
#line 528 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp401_ = app_window_get_instance ();
#line 528 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp402_ = _tmp401_;
#line 528 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp403_ = message;
#line 528 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp404_ = (GtkMessageDialog*) gtk_message_dialog_new (G_TYPE_CHECK_INSTANCE_CAST (_tmp402_, gtk_window_get_type (), GtkWindow), GTK_DIALOG_MODAL, GTK_MESSAGE_INFO, GTK_BUTTONS_NONE, "%s", _tmp403_);
#line 528 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_object_ref_sink (_tmp404_);
#line 528 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (dialog);
#line 528 "/home/jens/Source/shotwell/src/Dialogs.vala"
		dialog = _tmp404_;
#line 528 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (_tmp402_);
#line 530 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp405_ = dialog;
#line 530 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_window_set_title (G_TYPE_CHECK_INSTANCE_CAST (_tmp405_, gtk_window_get_type (), GtkWindow), _ ("Import Complete"));
#line 531 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp406_ = dialog;
#line 531 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp407_ = gtk_dialog_add_button (G_TYPE_CHECK_INSTANCE_CAST (_tmp406_, gtk_dialog_get_type (), GtkDialog), IMPORT_UI_SAVE_RESULTS_BUTTON_NAME, IMPORT_UI_SAVE_RESULTS_RESPONSE_ID);
#line 531 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp408_ = _g_object_ref0 (_tmp407_);
#line 531 "/home/jens/Source/shotwell/src/Dialogs.vala"
		save_results_button = _tmp408_;
#line 533 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp409_ = save_results_button;
#line 533 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp410_ = manifest->success;
#line 533 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp411_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp410_, GEE_TYPE_COLLECTION, GeeCollection));
#line 533 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp412_ = _tmp411_;
#line 533 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp413_ = manifest->all;
#line 533 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp414_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp413_, GEE_TYPE_COLLECTION, GeeCollection));
#line 533 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp415_ = _tmp414_;
#line 533 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_widget_set_visible (_tmp409_, _tmp412_ < _tmp415_);
#line 534 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp416_ = dialog;
#line 534 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp417_ = gtk_dialog_add_button (G_TYPE_CHECK_INSTANCE_CAST (_tmp416_, gtk_dialog_get_type (), GtkDialog), RESOURCES_OK_LABEL, (gint) GTK_RESPONSE_OK);
#line 534 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp418_ = _g_object_ref0 (_tmp417_);
#line 534 "/home/jens/Source/shotwell/src/Dialogs.vala"
		ok_button = _tmp418_;
#line 535 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp419_ = dialog;
#line 535 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp420_ = ok_button;
#line 535 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_window_set_default (G_TYPE_CHECK_INSTANCE_CAST (_tmp419_, gtk_window_get_type (), GtkWindow), _tmp420_);
#line 537 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp421_ = dialog;
#line 537 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp422_ = gtk_widget_get_parent (G_TYPE_CHECK_INSTANCE_CAST (_tmp421_, gtk_widget_get_type (), GtkWidget));
#line 537 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp423_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp422_, gtk_window_get_type (), GtkWindow));
#line 537 "/home/jens/Source/shotwell/src/Dialogs.vala"
		dialog_parent = _tmp423_;
#line 538 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp424_ = dialog;
#line 538 "/home/jens/Source/shotwell/src/Dialogs.vala"
		dialog_response = gtk_dialog_run (G_TYPE_CHECK_INSTANCE_CAST (_tmp424_, gtk_dialog_get_type (), GtkDialog));
#line 539 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp425_ = dialog;
#line 539 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_widget_destroy (G_TYPE_CHECK_INSTANCE_CAST (_tmp425_, gtk_widget_get_type (), GtkWidget));
#line 541 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp426_ = dialog_response;
#line 541 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (_tmp426_ == IMPORT_UI_SAVE_RESULTS_RESPONSE_ID) {
#line 5345 "Dialogs.c"
			GtkWindow* _tmp427_;
			gchar* _tmp428_;
			gchar* _tmp429_;
#line 542 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp427_ = dialog_parent;
#line 542 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp428_ = import_ui_create_result_report_from_manifest (manifest);
#line 542 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp429_ = _tmp428_;
#line 542 "/home/jens/Source/shotwell/src/Dialogs.vala"
			import_ui_save_import_results (_tmp427_, _tmp429_);
#line 542 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_free0 (_tmp429_);
#line 5359 "Dialogs.c"
		}
#line 527 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (dialog_parent);
#line 527 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (ok_button);
#line 527 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (save_results_button);
#line 5367 "Dialogs.c"
	} else {
		const gchar* _tmp430_;
		const gchar* _tmp431_;
		gchar* _tmp432_;
		gchar* _tmp433_;
		gchar* _tmp434_;
		AppWindow* _tmp435_;
		AppWindow* _tmp436_;
		const gchar* _tmp437_;
		GtkMessageDialog* _tmp438_;
		GtkMessageDialog* _tmp439_;
		GtkWidget* save_results_button = NULL;
		GtkMessageDialog* _tmp440_;
		GtkWidget* _tmp441_;
		GtkWidget* _tmp442_;
		GtkWidget* _tmp443_;
		GeeList* _tmp444_;
		gint _tmp445_;
		gint _tmp446_;
		GeeList* _tmp447_;
		gint _tmp448_;
		gint _tmp449_;
		GtkWidget* no_button = NULL;
		GtkMessageDialog* _tmp450_;
		const gchar* _tmp451_;
		GtkWidget* _tmp452_;
		GtkWidget* _tmp453_;
		GtkMessageDialog* _tmp454_;
		const gchar* _tmp455_;
		GtkMessageDialog* _tmp456_;
		GtkWidget* _tmp457_;
		GtkMessageDialog* _tmp458_;
		GtkMessageDialog* _tmp464_;
		GtkMessageDialog* _tmp465_;
#line 545 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp430_ = message;
#line 545 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp431_ = question->question;
#line 545 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp432_ = g_strconcat ("\n", _tmp431_, NULL);
#line 545 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp433_ = _tmp432_;
#line 545 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp434_ = g_strconcat (_tmp430_, _tmp433_, NULL);
#line 545 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (message);
#line 545 "/home/jens/Source/shotwell/src/Dialogs.vala"
		message = _tmp434_;
#line 545 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp433_);
#line 547 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp435_ = app_window_get_instance ();
#line 547 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp436_ = _tmp435_;
#line 547 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp437_ = message;
#line 547 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp438_ = (GtkMessageDialog*) gtk_message_dialog_new (G_TYPE_CHECK_INSTANCE_CAST (_tmp436_, gtk_window_get_type (), GtkWindow), GTK_DIALOG_MODAL, GTK_MESSAGE_QUESTION, GTK_BUTTONS_NONE, "%s", _tmp437_);
#line 547 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_object_ref_sink (_tmp438_);
#line 547 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (dialog);
#line 547 "/home/jens/Source/shotwell/src/Dialogs.vala"
		dialog = _tmp438_;
#line 547 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (_tmp436_);
#line 549 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp439_ = dialog;
#line 549 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_window_set_title (G_TYPE_CHECK_INSTANCE_CAST (_tmp439_, gtk_window_get_type (), GtkWindow), _ ("Import Complete"));
#line 550 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp440_ = dialog;
#line 550 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp441_ = gtk_dialog_add_button (G_TYPE_CHECK_INSTANCE_CAST (_tmp440_, gtk_dialog_get_type (), GtkDialog), IMPORT_UI_SAVE_RESULTS_BUTTON_NAME, IMPORT_UI_SAVE_RESULTS_RESPONSE_ID);
#line 550 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp442_ = _g_object_ref0 (_tmp441_);
#line 550 "/home/jens/Source/shotwell/src/Dialogs.vala"
		save_results_button = _tmp442_;
#line 552 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp443_ = save_results_button;
#line 552 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp444_ = manifest->success;
#line 552 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp445_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp444_, GEE_TYPE_COLLECTION, GeeCollection));
#line 552 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp446_ = _tmp445_;
#line 552 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp447_ = manifest->all;
#line 552 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp448_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp447_, GEE_TYPE_COLLECTION, GeeCollection));
#line 552 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp449_ = _tmp448_;
#line 552 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_widget_set_visible (_tmp443_, _tmp446_ < _tmp449_);
#line 553 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp450_ = dialog;
#line 553 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp451_ = question->no_button;
#line 553 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp452_ = gtk_dialog_add_button (G_TYPE_CHECK_INSTANCE_CAST (_tmp450_, gtk_dialog_get_type (), GtkDialog), _tmp451_, (gint) GTK_RESPONSE_NO);
#line 553 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp453_ = _g_object_ref0 (_tmp452_);
#line 553 "/home/jens/Source/shotwell/src/Dialogs.vala"
		no_button = _tmp453_;
#line 554 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp454_ = dialog;
#line 554 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp455_ = question->yes_button;
#line 554 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_dialog_add_button (G_TYPE_CHECK_INSTANCE_CAST (_tmp454_, gtk_dialog_get_type (), GtkDialog), _tmp455_, (gint) GTK_RESPONSE_YES);
#line 555 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp456_ = dialog;
#line 555 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp457_ = no_button;
#line 555 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_window_set_default (G_TYPE_CHECK_INSTANCE_CAST (_tmp456_, gtk_window_get_type (), GtkWindow), _tmp457_);
#line 557 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp458_ = dialog;
#line 557 "/home/jens/Source/shotwell/src/Dialogs.vala"
		dialog_response = gtk_dialog_run (G_TYPE_CHECK_INSTANCE_CAST (_tmp458_, gtk_dialog_get_type (), GtkDialog));
#line 558 "/home/jens/Source/shotwell/src/Dialogs.vala"
		while (TRUE) {
#line 5490 "Dialogs.c"
			gint _tmp459_;
			GtkMessageDialog* _tmp460_;
			gchar* _tmp461_;
			gchar* _tmp462_;
			GtkMessageDialog* _tmp463_;
#line 558 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp459_ = dialog_response;
#line 558 "/home/jens/Source/shotwell/src/Dialogs.vala"
			if (!(_tmp459_ == IMPORT_UI_SAVE_RESULTS_RESPONSE_ID)) {
#line 558 "/home/jens/Source/shotwell/src/Dialogs.vala"
				break;
#line 5502 "Dialogs.c"
			}
#line 559 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp460_ = dialog;
#line 559 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp461_ = import_ui_create_result_report_from_manifest (manifest);
#line 559 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp462_ = _tmp461_;
#line 559 "/home/jens/Source/shotwell/src/Dialogs.vala"
			import_ui_save_import_results (G_TYPE_CHECK_INSTANCE_CAST (_tmp460_, gtk_window_get_type (), GtkWindow), _tmp462_);
#line 559 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_free0 (_tmp462_);
#line 560 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp463_ = dialog;
#line 560 "/home/jens/Source/shotwell/src/Dialogs.vala"
			dialog_response = gtk_dialog_run (G_TYPE_CHECK_INSTANCE_CAST (_tmp463_, gtk_dialog_get_type (), GtkDialog));
#line 5518 "Dialogs.c"
		}
#line 563 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp464_ = dialog;
#line 563 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_widget_hide (G_TYPE_CHECK_INSTANCE_CAST (_tmp464_, gtk_widget_get_type (), GtkWidget));
#line 564 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp465_ = dialog;
#line 564 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_widget_destroy (G_TYPE_CHECK_INSTANCE_CAST (_tmp465_, gtk_widget_get_type (), GtkWidget));
#line 527 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (no_button);
#line 527 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (save_results_button);
#line 5532 "Dialogs.c"
	}
#line 567 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp466_ = dialog_response;
#line 567 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = _tmp466_ == ((gint) GTK_RESPONSE_YES);
#line 567 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (dialog);
#line 567 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (message);
#line 567 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 5544 "Dialogs.c"
}


static guint8*
string_get_data (const gchar* self,
                 int* result_length1)
{
	guint8* result;
	guint8* res = NULL;
	gint res_length1;
	gint _res_size_;
	gint _tmp0_;
	gint _tmp1_;
	gint _tmp2_;
	guint8* _tmp3_;
	gint _tmp3__length1;
	guint8* _tmp4_;
	gint _tmp4__length1;
#line 1442 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, NULL);
#line 1443 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	res = (guint8*) self;
#line 1443 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	res_length1 = -1;
#line 1443 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	_res_size_ = res_length1;
#line 1444 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	_tmp0_ = strlen (self);
#line 1444 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	_tmp1_ = _tmp0_;
#line 1444 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	res_length1 = (gint) _tmp1_;
#line 1444 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	_tmp2_ = res_length1;
#line 1445 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	_tmp3_ = res;
#line 1445 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	_tmp3__length1 = res_length1;
#line 1445 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	_tmp4_ = _tmp3_;
#line 1445 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	_tmp4__length1 = _tmp3__length1;
#line 1445 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	if (result_length1) {
#line 1445 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
		*result_length1 = _tmp4__length1;
#line 5591 "Dialogs.c"
	}
#line 1445 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	result = _tmp4_;
#line 1445 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	return result;
#line 5597 "Dialogs.c"
}


void
import_ui_save_import_results (GtkWindow* chooser_dialog_parent,
                               const gchar* results_log)
{
	GtkFileChooserDialog* chooser_dialog = NULL;
	GtkFileChooserDialog* _tmp0_;
	GtkFileChooserDialog* _tmp1_;
	GtkFileChooserDialog* _tmp2_;
	const gchar* _tmp3_;
	GtkFileChooserDialog* _tmp4_;
	GtkFileChooserDialog* _tmp5_;
	gint dialog_result = 0;
	GtkFileChooserDialog* _tmp6_;
	GFile* chosen_file = NULL;
	GtkFileChooserDialog* _tmp7_;
	GFile* _tmp8_;
	GtkFileChooserDialog* _tmp9_;
	GtkFileChooserDialog* _tmp10_;
	gboolean _tmp11_ = FALSE;
	gint _tmp12_;
	GError * _inner_error_ = NULL;
#line 570 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail ((chooser_dialog_parent == NULL) || GTK_IS_WINDOW (chooser_dialog_parent));
#line 570 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (results_log != NULL);
#line 571 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = (GtkFileChooserDialog*) gtk_file_chooser_dialog_new (IMPORT_UI_SAVE_RESULTS_FILE_CHOOSER_TITLE, chooser_dialog_parent, GTK_FILE_CHOOSER_ACTION_SAVE, RESOURCES_CANCEL_LABEL, GTK_RESPONSE_CANCEL, RESOURCES_SAVE_AS_LABEL, GTK_RESPONSE_ACCEPT, NULL, NULL);
#line 571 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp0_);
#line 571 "/home/jens/Source/shotwell/src/Dialogs.vala"
	chooser_dialog = _tmp0_;
#line 574 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = chooser_dialog;
#line 574 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_file_chooser_set_do_overwrite_confirmation (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, gtk_file_chooser_get_type (), GtkFileChooser), TRUE);
#line 575 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = chooser_dialog;
#line 575 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = g_get_home_dir ();
#line 575 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_file_chooser_set_current_folder (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, gtk_file_chooser_get_type (), GtkFileChooser), _tmp3_);
#line 576 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = chooser_dialog;
#line 576 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_file_chooser_set_current_name (G_TYPE_CHECK_INSTANCE_CAST (_tmp4_, gtk_file_chooser_get_type (), GtkFileChooser), "Shotwell Import Log.txt");
#line 577 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = chooser_dialog;
#line 577 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_file_chooser_set_local_only (G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, gtk_file_chooser_get_type (), GtkFileChooser), FALSE);
#line 579 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6_ = chooser_dialog;
#line 579 "/home/jens/Source/shotwell/src/Dialogs.vala"
	dialog_result = gtk_dialog_run (G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, gtk_dialog_get_type (), GtkDialog));
#line 580 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp7_ = chooser_dialog;
#line 580 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp8_ = gtk_file_chooser_get_file (G_TYPE_CHECK_INSTANCE_CAST (_tmp7_, gtk_file_chooser_get_type (), GtkFileChooser));
#line 580 "/home/jens/Source/shotwell/src/Dialogs.vala"
	chosen_file = _tmp8_;
#line 581 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp9_ = chooser_dialog;
#line 581 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_hide (G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, gtk_widget_get_type (), GtkWidget));
#line 582 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp10_ = chooser_dialog;
#line 582 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_destroy (G_TYPE_CHECK_INSTANCE_CAST (_tmp10_, gtk_widget_get_type (), GtkWidget));
#line 584 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp12_ = dialog_result;
#line 584 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp12_ == ((gint) GTK_RESPONSE_ACCEPT)) {
#line 5672 "Dialogs.c"
		GFile* _tmp13_;
#line 584 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp13_ = chosen_file;
#line 584 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp11_ = _tmp13_ != NULL;
#line 5678 "Dialogs.c"
	} else {
#line 584 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp11_ = FALSE;
#line 5682 "Dialogs.c"
	}
#line 584 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp11_) {
#line 5686 "Dialogs.c"
		{
			GFileOutputStream* outstream = NULL;
			GFile* _tmp14_;
			GFileOutputStream* _tmp15_;
			GFileOutputStream* _tmp16_;
			guint8* _tmp17_;
			gint _tmp17__length1;
			guint8* _tmp18_;
			gint _tmp18__length1;
			GFileOutputStream* _tmp19_;
#line 586 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp14_ = chosen_file;
#line 586 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp15_ = g_file_replace (_tmp14_, NULL, FALSE, G_FILE_CREATE_NONE, NULL, &_inner_error_);
#line 586 "/home/jens/Source/shotwell/src/Dialogs.vala"
			outstream = _tmp15_;
#line 586 "/home/jens/Source/shotwell/src/Dialogs.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 5705 "Dialogs.c"
				goto __catch437_g_error;
			}
#line 587 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp16_ = outstream;
#line 587 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp17_ = string_get_data (results_log, &_tmp17__length1);
#line 587 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp18_ = _tmp17_;
#line 587 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp18__length1 = _tmp17__length1;
#line 587 "/home/jens/Source/shotwell/src/Dialogs.vala"
			g_output_stream_write (G_TYPE_CHECK_INSTANCE_CAST (_tmp16_, g_output_stream_get_type (), GOutputStream), _tmp18_, (gsize) _tmp18__length1, NULL, &_inner_error_);
#line 587 "/home/jens/Source/shotwell/src/Dialogs.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 587 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_object_unref0 (outstream);
#line 5722 "Dialogs.c"
				goto __catch437_g_error;
			}
#line 588 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp19_ = outstream;
#line 588 "/home/jens/Source/shotwell/src/Dialogs.vala"
			g_output_stream_close (G_TYPE_CHECK_INSTANCE_CAST (_tmp19_, g_output_stream_get_type (), GOutputStream), NULL, &_inner_error_);
#line 588 "/home/jens/Source/shotwell/src/Dialogs.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 588 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_object_unref0 (outstream);
#line 5733 "Dialogs.c"
				goto __catch437_g_error;
			}
#line 585 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_object_unref0 (outstream);
#line 5738 "Dialogs.c"
		}
		goto __finally437;
		__catch437_g_error:
		{
			GError* err = NULL;
			GFile* _tmp20_;
			gchar* _tmp21_;
			gchar* _tmp22_;
			GError* _tmp23_;
			const gchar* _tmp24_;
#line 585 "/home/jens/Source/shotwell/src/Dialogs.vala"
			err = _inner_error_;
#line 585 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_inner_error_ = NULL;
#line 590 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp20_ = chosen_file;
#line 590 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp21_ = g_file_get_path (_tmp20_);
#line 590 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp22_ = _tmp21_;
#line 590 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp23_ = err;
#line 590 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp24_ = _tmp23_->message;
#line 590 "/home/jens/Source/shotwell/src/Dialogs.vala"
			g_critical ("Dialogs.vala:590: couldn't save import results to log file %s: %s", _tmp22_, _tmp24_);
#line 590 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_free0 (_tmp22_);
#line 585 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_error_free0 (err);
#line 5769 "Dialogs.c"
		}
		__finally437:
#line 585 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 585 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_object_unref0 (chosen_file);
#line 585 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_object_unref0 (chooser_dialog);
#line 585 "/home/jens/Source/shotwell/src/Dialogs.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 585 "/home/jens/Source/shotwell/src/Dialogs.vala"
			g_clear_error (&_inner_error_);
#line 585 "/home/jens/Source/shotwell/src/Dialogs.vala"
			return;
#line 5784 "Dialogs.c"
		}
	}
#line 570 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (chosen_file);
#line 570 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (chooser_dialog);
#line 5791 "Dialogs.c"
}


static gboolean
_text_entry_dialog_mediator_on_modify_validate_text_entry_dialog_on_modify_validate_type (const gchar* text,
                                                                                          gpointer self)
{
	gboolean result;
	result = text_entry_dialog_mediator_on_modify_validate ((TextEntryDialogMediator*) self, text);
#line 604 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 5803 "Dialogs.c"
}


TextEntryDialogMediator*
text_entry_dialog_mediator_construct (GType object_type,
                                      const gchar* title,
                                      const gchar* label,
                                      const gchar* initial_text,
                                      GeeCollection* completion_list,
                                      const gchar* completion_delimiter)
{
	TextEntryDialogMediator* self = NULL;
	TextEntryDialog* _tmp0_;
	TextEntryDialog* _tmp1_;
#line 601 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (title != NULL, NULL);
#line 601 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (label != NULL, NULL);
#line 601 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail ((completion_list == NULL) || GEE_IS_COLLECTION (completion_list), NULL);
#line 601 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self = (TextEntryDialogMediator*) g_type_create_instance (object_type);
#line 603 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = text_entry_dialog_new ();
#line 603 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp0_);
#line 603 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->dialog);
#line 603 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->dialog = _tmp0_;
#line 604 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = self->priv->dialog;
#line 604 "/home/jens/Source/shotwell/src/Dialogs.vala"
	text_entry_dialog_setup (_tmp1_, _text_entry_dialog_mediator_on_modify_validate_text_entry_dialog_on_modify_validate_type, self, title, label, initial_text, completion_list, completion_delimiter);
#line 601 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return self;
#line 5840 "Dialogs.c"
}


static gboolean
text_entry_dialog_mediator_real_on_modify_validate (TextEntryDialogMediator* self,
                                                    const gchar* text)
{
	gboolean result = FALSE;
#line 607 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (text != NULL, FALSE);
#line 608 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = TRUE;
#line 608 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 5855 "Dialogs.c"
}


gboolean
text_entry_dialog_mediator_on_modify_validate (TextEntryDialogMediator* self,
                                               const gchar* text)
{
#line 607 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (IS_TEXT_ENTRY_DIALOG_MEDIATOR (self), FALSE);
#line 607 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return TEXT_ENTRY_DIALOG_MEDIATOR_GET_CLASS (self)->on_modify_validate (self, text);
#line 5867 "Dialogs.c"
}


gchar*
_text_entry_dialog_mediator_execute (TextEntryDialogMediator* self)
{
	gchar* result = NULL;
	TextEntryDialog* _tmp0_;
	gchar* _tmp1_;
#line 611 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (IS_TEXT_ENTRY_DIALOG_MEDIATOR (self), NULL);
#line 612 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = self->priv->dialog;
#line 612 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = text_entry_dialog_execute (_tmp0_);
#line 612 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = _tmp1_;
#line 612 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 5887 "Dialogs.c"
}


static void
value_text_entry_dialog_mediator_init (GValue* value)
{
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
	value->data[0].v_pointer = NULL;
#line 5896 "Dialogs.c"
}


static void
value_text_entry_dialog_mediator_free_value (GValue* value)
{
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (value->data[0].v_pointer) {
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
		text_entry_dialog_mediator_unref (value->data[0].v_pointer);
#line 5907 "Dialogs.c"
	}
}


static void
value_text_entry_dialog_mediator_copy_value (const GValue* src_value,
                                             GValue* dest_value)
{
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (src_value->data[0].v_pointer) {
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
		dest_value->data[0].v_pointer = text_entry_dialog_mediator_ref (src_value->data[0].v_pointer);
#line 5920 "Dialogs.c"
	} else {
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
		dest_value->data[0].v_pointer = NULL;
#line 5924 "Dialogs.c"
	}
}


static gpointer
value_text_entry_dialog_mediator_peek_pointer (const GValue* value)
{
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return value->data[0].v_pointer;
#line 5934 "Dialogs.c"
}


static gchar*
value_text_entry_dialog_mediator_collect_value (GValue* value,
                                                guint n_collect_values,
                                                GTypeCValue* collect_values,
                                                guint collect_flags)
{
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (collect_values[0].v_pointer) {
#line 5946 "Dialogs.c"
		TextEntryDialogMediator * object;
		object = collect_values[0].v_pointer;
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (object->parent_instance.g_class == NULL) {
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 5953 "Dialogs.c"
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 5957 "Dialogs.c"
		}
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
		value->data[0].v_pointer = text_entry_dialog_mediator_ref (object);
#line 5961 "Dialogs.c"
	} else {
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
		value->data[0].v_pointer = NULL;
#line 5965 "Dialogs.c"
	}
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return NULL;
#line 5969 "Dialogs.c"
}


static gchar*
value_text_entry_dialog_mediator_lcopy_value (const GValue* value,
                                              guint n_collect_values,
                                              GTypeCValue* collect_values,
                                              guint collect_flags)
{
	TextEntryDialogMediator ** object_p;
	object_p = collect_values[0].v_pointer;
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (!object_p) {
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
#line 5985 "Dialogs.c"
	}
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (!value->data[0].v_pointer) {
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
		*object_p = NULL;
#line 5991 "Dialogs.c"
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
		*object_p = value->data[0].v_pointer;
#line 5995 "Dialogs.c"
	} else {
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
		*object_p = text_entry_dialog_mediator_ref (value->data[0].v_pointer);
#line 5999 "Dialogs.c"
	}
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return NULL;
#line 6003 "Dialogs.c"
}


GParamSpec*
param_spec_text_entry_dialog_mediator (const gchar* name,
                                       const gchar* nick,
                                       const gchar* blurb,
                                       GType object_type,
                                       GParamFlags flags)
{
	ParamSpecTextEntryDialogMediator* spec;
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (g_type_is_a (object_type, TYPE_TEXT_ENTRY_DIALOG_MEDIATOR), NULL);
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
	G_PARAM_SPEC (spec)->value_type = object_type;
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return G_PARAM_SPEC (spec);
#line 6023 "Dialogs.c"
}


gpointer
value_get_text_entry_dialog_mediator (const GValue* value)
{
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, TYPE_TEXT_ENTRY_DIALOG_MEDIATOR), NULL);
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return value->data[0].v_pointer;
#line 6034 "Dialogs.c"
}


void
value_set_text_entry_dialog_mediator (GValue* value,
                                      gpointer v_object)
{
	TextEntryDialogMediator * old;
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, TYPE_TEXT_ENTRY_DIALOG_MEDIATOR));
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
	old = value->data[0].v_pointer;
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (v_object) {
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, TYPE_TEXT_ENTRY_DIALOG_MEDIATOR));
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
		value->data[0].v_pointer = v_object;
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
		text_entry_dialog_mediator_ref (value->data[0].v_pointer);
#line 6057 "Dialogs.c"
	} else {
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
		value->data[0].v_pointer = NULL;
#line 6061 "Dialogs.c"
	}
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (old) {
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
		text_entry_dialog_mediator_unref (old);
#line 6067 "Dialogs.c"
	}
}


void
value_take_text_entry_dialog_mediator (GValue* value,
                                       gpointer v_object)
{
	TextEntryDialogMediator * old;
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, TYPE_TEXT_ENTRY_DIALOG_MEDIATOR));
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
	old = value->data[0].v_pointer;
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (v_object) {
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, TYPE_TEXT_ENTRY_DIALOG_MEDIATOR));
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
		value->data[0].v_pointer = v_object;
#line 6089 "Dialogs.c"
	} else {
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
		value->data[0].v_pointer = NULL;
#line 6093 "Dialogs.c"
	}
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (old) {
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
		text_entry_dialog_mediator_unref (old);
#line 6099 "Dialogs.c"
	}
}


static void
text_entry_dialog_mediator_class_init (TextEntryDialogMediatorClass * klass)
{
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
	text_entry_dialog_mediator_parent_class = g_type_class_peek_parent (klass);
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
	((TextEntryDialogMediatorClass *) klass)->finalize = text_entry_dialog_mediator_finalize;
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_type_class_add_private (klass, sizeof (TextEntryDialogMediatorPrivate));
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
	((TextEntryDialogMediatorClass *) klass)->on_modify_validate = (gboolean (*) (TextEntryDialogMediator *, const gchar*)) text_entry_dialog_mediator_real_on_modify_validate;
#line 6115 "Dialogs.c"
}


static void
text_entry_dialog_mediator_instance_init (TextEntryDialogMediator * self)
{
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv = TEXT_ENTRY_DIALOG_MEDIATOR_GET_PRIVATE (self);
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->ref_count = 1;
#line 6126 "Dialogs.c"
}


static void
text_entry_dialog_mediator_finalize (TextEntryDialogMediator * obj)
{
	TextEntryDialogMediator * self;
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_TEXT_ENTRY_DIALOG_MEDIATOR, TextEntryDialogMediator);
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_signal_handlers_destroy (self);
#line 599 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->dialog);
#line 6140 "Dialogs.c"
}


GType
text_entry_dialog_mediator_get_type (void)
{
	static volatile gsize text_entry_dialog_mediator_type_id__volatile = 0;
	if (g_once_init_enter (&text_entry_dialog_mediator_type_id__volatile)) {
		static const GTypeValueTable g_define_type_value_table = { value_text_entry_dialog_mediator_init, value_text_entry_dialog_mediator_free_value, value_text_entry_dialog_mediator_copy_value, value_text_entry_dialog_mediator_peek_pointer, "p", value_text_entry_dialog_mediator_collect_value, "p", value_text_entry_dialog_mediator_lcopy_value };
		static const GTypeInfo g_define_type_info = { sizeof (TextEntryDialogMediatorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) text_entry_dialog_mediator_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TextEntryDialogMediator), 0, (GInstanceInitFunc) text_entry_dialog_mediator_instance_init, &g_define_type_value_table };
		static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
		GType text_entry_dialog_mediator_type_id;
		text_entry_dialog_mediator_type_id = g_type_register_fundamental (g_type_fundamental_next (), "TextEntryDialogMediator", &g_define_type_info, &g_define_type_fundamental_info, G_TYPE_FLAG_ABSTRACT);
		g_once_init_leave (&text_entry_dialog_mediator_type_id__volatile, text_entry_dialog_mediator_type_id);
	}
	return text_entry_dialog_mediator_type_id__volatile;
}


gpointer
text_entry_dialog_mediator_ref (gpointer instance)
{
	TextEntryDialogMediator * self;
	self = instance;
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_atomic_int_inc (&self->ref_count);
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return instance;
#line 6169 "Dialogs.c"
}


void
text_entry_dialog_mediator_unref (gpointer instance)
{
	TextEntryDialogMediator * self;
	self = instance;
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
		TEXT_ENTRY_DIALOG_MEDIATOR_GET_CLASS (self)->finalize (self);
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_type_free_instance ((GTypeInstance *) self);
#line 6184 "Dialogs.c"
	}
}


static gboolean
_multi_text_entry_dialog_mediator_on_modify_validate_multi_text_entry_dialog_on_modify_validate_type (const gchar* text,
                                                                                                      gpointer self)
{
	gboolean result;
	result = multi_text_entry_dialog_mediator_on_modify_validate ((MultiTextEntryDialogMediator*) self, text);
#line 621 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 6197 "Dialogs.c"
}


MultiTextEntryDialogMediator*
multi_text_entry_dialog_mediator_construct (GType object_type,
                                            const gchar* title,
                                            const gchar* label,
                                            const gchar* initial_text)
{
	MultiTextEntryDialogMediator* self = NULL;
	MultiTextEntryDialog* _tmp0_;
	MultiTextEntryDialog* _tmp1_;
#line 619 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (title != NULL, NULL);
#line 619 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (label != NULL, NULL);
#line 619 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self = (MultiTextEntryDialogMediator*) g_type_create_instance (object_type);
#line 620 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = multi_text_entry_dialog_new ();
#line 620 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp0_);
#line 620 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->dialog);
#line 620 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->dialog = _tmp0_;
#line 621 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = self->priv->dialog;
#line 621 "/home/jens/Source/shotwell/src/Dialogs.vala"
	multi_text_entry_dialog_setup (_tmp1_, _multi_text_entry_dialog_mediator_on_modify_validate_multi_text_entry_dialog_on_modify_validate_type, self, title, label, initial_text);
#line 619 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return self;
#line 6230 "Dialogs.c"
}


static gboolean
multi_text_entry_dialog_mediator_real_on_modify_validate (MultiTextEntryDialogMediator* self,
                                                          const gchar* text)
{
	gboolean result = FALSE;
#line 624 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (text != NULL, FALSE);
#line 625 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = TRUE;
#line 625 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 6245 "Dialogs.c"
}


gboolean
multi_text_entry_dialog_mediator_on_modify_validate (MultiTextEntryDialogMediator* self,
                                                     const gchar* text)
{
#line 624 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (IS_MULTI_TEXT_ENTRY_DIALOG_MEDIATOR (self), FALSE);
#line 624 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return MULTI_TEXT_ENTRY_DIALOG_MEDIATOR_GET_CLASS (self)->on_modify_validate (self, text);
#line 6257 "Dialogs.c"
}


gchar*
_multi_text_entry_dialog_mediator_execute (MultiTextEntryDialogMediator* self)
{
	gchar* result = NULL;
	MultiTextEntryDialog* _tmp0_;
	gchar* _tmp1_;
#line 628 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (IS_MULTI_TEXT_ENTRY_DIALOG_MEDIATOR (self), NULL);
#line 629 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = self->priv->dialog;
#line 629 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = multi_text_entry_dialog_execute (_tmp0_);
#line 629 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = _tmp1_;
#line 629 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 6277 "Dialogs.c"
}


static void
value_multi_text_entry_dialog_mediator_init (GValue* value)
{
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
	value->data[0].v_pointer = NULL;
#line 6286 "Dialogs.c"
}


static void
value_multi_text_entry_dialog_mediator_free_value (GValue* value)
{
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (value->data[0].v_pointer) {
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
		multi_text_entry_dialog_mediator_unref (value->data[0].v_pointer);
#line 6297 "Dialogs.c"
	}
}


static void
value_multi_text_entry_dialog_mediator_copy_value (const GValue* src_value,
                                                   GValue* dest_value)
{
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (src_value->data[0].v_pointer) {
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
		dest_value->data[0].v_pointer = multi_text_entry_dialog_mediator_ref (src_value->data[0].v_pointer);
#line 6310 "Dialogs.c"
	} else {
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
		dest_value->data[0].v_pointer = NULL;
#line 6314 "Dialogs.c"
	}
}


static gpointer
value_multi_text_entry_dialog_mediator_peek_pointer (const GValue* value)
{
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return value->data[0].v_pointer;
#line 6324 "Dialogs.c"
}


static gchar*
value_multi_text_entry_dialog_mediator_collect_value (GValue* value,
                                                      guint n_collect_values,
                                                      GTypeCValue* collect_values,
                                                      guint collect_flags)
{
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (collect_values[0].v_pointer) {
#line 6336 "Dialogs.c"
		MultiTextEntryDialogMediator * object;
		object = collect_values[0].v_pointer;
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (object->parent_instance.g_class == NULL) {
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 6343 "Dialogs.c"
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 6347 "Dialogs.c"
		}
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
		value->data[0].v_pointer = multi_text_entry_dialog_mediator_ref (object);
#line 6351 "Dialogs.c"
	} else {
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
		value->data[0].v_pointer = NULL;
#line 6355 "Dialogs.c"
	}
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return NULL;
#line 6359 "Dialogs.c"
}


static gchar*
value_multi_text_entry_dialog_mediator_lcopy_value (const GValue* value,
                                                    guint n_collect_values,
                                                    GTypeCValue* collect_values,
                                                    guint collect_flags)
{
	MultiTextEntryDialogMediator ** object_p;
	object_p = collect_values[0].v_pointer;
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (!object_p) {
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
#line 6375 "Dialogs.c"
	}
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (!value->data[0].v_pointer) {
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
		*object_p = NULL;
#line 6381 "Dialogs.c"
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
		*object_p = value->data[0].v_pointer;
#line 6385 "Dialogs.c"
	} else {
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
		*object_p = multi_text_entry_dialog_mediator_ref (value->data[0].v_pointer);
#line 6389 "Dialogs.c"
	}
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return NULL;
#line 6393 "Dialogs.c"
}


GParamSpec*
param_spec_multi_text_entry_dialog_mediator (const gchar* name,
                                             const gchar* nick,
                                             const gchar* blurb,
                                             GType object_type,
                                             GParamFlags flags)
{
	ParamSpecMultiTextEntryDialogMediator* spec;
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (g_type_is_a (object_type, TYPE_MULTI_TEXT_ENTRY_DIALOG_MEDIATOR), NULL);
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
	G_PARAM_SPEC (spec)->value_type = object_type;
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return G_PARAM_SPEC (spec);
#line 6413 "Dialogs.c"
}


gpointer
value_get_multi_text_entry_dialog_mediator (const GValue* value)
{
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, TYPE_MULTI_TEXT_ENTRY_DIALOG_MEDIATOR), NULL);
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return value->data[0].v_pointer;
#line 6424 "Dialogs.c"
}


void
value_set_multi_text_entry_dialog_mediator (GValue* value,
                                            gpointer v_object)
{
	MultiTextEntryDialogMediator * old;
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, TYPE_MULTI_TEXT_ENTRY_DIALOG_MEDIATOR));
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
	old = value->data[0].v_pointer;
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (v_object) {
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, TYPE_MULTI_TEXT_ENTRY_DIALOG_MEDIATOR));
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
		value->data[0].v_pointer = v_object;
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
		multi_text_entry_dialog_mediator_ref (value->data[0].v_pointer);
#line 6447 "Dialogs.c"
	} else {
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
		value->data[0].v_pointer = NULL;
#line 6451 "Dialogs.c"
	}
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (old) {
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
		multi_text_entry_dialog_mediator_unref (old);
#line 6457 "Dialogs.c"
	}
}


void
value_take_multi_text_entry_dialog_mediator (GValue* value,
                                             gpointer v_object)
{
	MultiTextEntryDialogMediator * old;
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, TYPE_MULTI_TEXT_ENTRY_DIALOG_MEDIATOR));
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
	old = value->data[0].v_pointer;
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (v_object) {
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, TYPE_MULTI_TEXT_ENTRY_DIALOG_MEDIATOR));
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
		value->data[0].v_pointer = v_object;
#line 6479 "Dialogs.c"
	} else {
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
		value->data[0].v_pointer = NULL;
#line 6483 "Dialogs.c"
	}
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (old) {
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
		multi_text_entry_dialog_mediator_unref (old);
#line 6489 "Dialogs.c"
	}
}


static void
multi_text_entry_dialog_mediator_class_init (MultiTextEntryDialogMediatorClass * klass)
{
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
	multi_text_entry_dialog_mediator_parent_class = g_type_class_peek_parent (klass);
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
	((MultiTextEntryDialogMediatorClass *) klass)->finalize = multi_text_entry_dialog_mediator_finalize;
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_type_class_add_private (klass, sizeof (MultiTextEntryDialogMediatorPrivate));
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
	((MultiTextEntryDialogMediatorClass *) klass)->on_modify_validate = (gboolean (*) (MultiTextEntryDialogMediator *, const gchar*)) multi_text_entry_dialog_mediator_real_on_modify_validate;
#line 6505 "Dialogs.c"
}


static void
multi_text_entry_dialog_mediator_instance_init (MultiTextEntryDialogMediator * self)
{
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv = MULTI_TEXT_ENTRY_DIALOG_MEDIATOR_GET_PRIVATE (self);
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->ref_count = 1;
#line 6516 "Dialogs.c"
}


static void
multi_text_entry_dialog_mediator_finalize (MultiTextEntryDialogMediator * obj)
{
	MultiTextEntryDialogMediator * self;
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_MULTI_TEXT_ENTRY_DIALOG_MEDIATOR, MultiTextEntryDialogMediator);
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_signal_handlers_destroy (self);
#line 617 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->dialog);
#line 6530 "Dialogs.c"
}


GType
multi_text_entry_dialog_mediator_get_type (void)
{
	static volatile gsize multi_text_entry_dialog_mediator_type_id__volatile = 0;
	if (g_once_init_enter (&multi_text_entry_dialog_mediator_type_id__volatile)) {
		static const GTypeValueTable g_define_type_value_table = { value_multi_text_entry_dialog_mediator_init, value_multi_text_entry_dialog_mediator_free_value, value_multi_text_entry_dialog_mediator_copy_value, value_multi_text_entry_dialog_mediator_peek_pointer, "p", value_multi_text_entry_dialog_mediator_collect_value, "p", value_multi_text_entry_dialog_mediator_lcopy_value };
		static const GTypeInfo g_define_type_info = { sizeof (MultiTextEntryDialogMediatorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) multi_text_entry_dialog_mediator_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (MultiTextEntryDialogMediator), 0, (GInstanceInitFunc) multi_text_entry_dialog_mediator_instance_init, &g_define_type_value_table };
		static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
		GType multi_text_entry_dialog_mediator_type_id;
		multi_text_entry_dialog_mediator_type_id = g_type_register_fundamental (g_type_fundamental_next (), "MultiTextEntryDialogMediator", &g_define_type_info, &g_define_type_fundamental_info, G_TYPE_FLAG_ABSTRACT);
		g_once_init_leave (&multi_text_entry_dialog_mediator_type_id__volatile, multi_text_entry_dialog_mediator_type_id);
	}
	return multi_text_entry_dialog_mediator_type_id__volatile;
}


gpointer
multi_text_entry_dialog_mediator_ref (gpointer instance)
{
	MultiTextEntryDialogMediator * self;
	self = instance;
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_atomic_int_inc (&self->ref_count);
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return instance;
#line 6559 "Dialogs.c"
}


void
multi_text_entry_dialog_mediator_unref (gpointer instance)
{
	MultiTextEntryDialogMediator * self;
	self = instance;
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
		MULTI_TEXT_ENTRY_DIALOG_MEDIATOR_GET_CLASS (self)->finalize (self);
#line 616 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_type_free_instance ((GTypeInstance *) self);
#line 6574 "Dialogs.c"
	}
}


gchar*
build_alert_body_text (const gchar* primary_text,
                       const gchar* secondary_text,
                       gboolean should_escape)
{
	gchar* result = NULL;
	gchar* _tmp6_;
	gchar* _tmp7_;
	gchar* _tmp8_;
	gchar* _tmp9_;
#line 638 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (should_escape) {
#line 6591 "Dialogs.c"
		gchar* _tmp0_;
		gchar* _tmp1_;
		gchar* _tmp2_;
		gchar* _tmp3_;
		gchar* _tmp4_;
		gchar* _tmp5_;
#line 639 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp0_ = guarded_markup_escape_text (primary_text);
#line 639 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp1_ = _tmp0_;
#line 639 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp2_ = guarded_markup_escape_text (secondary_text);
#line 639 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp3_ = _tmp2_;
#line 639 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp4_ = g_strdup_printf ("<span weight=\"Bold\" size=\"larger\">%s</span>\n%s", _tmp1_, _tmp3_);
#line 639 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp5_ = _tmp4_;
#line 639 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp3_);
#line 639 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp1_);
#line 639 "/home/jens/Source/shotwell/src/Dialogs.vala"
		result = _tmp5_;
#line 639 "/home/jens/Source/shotwell/src/Dialogs.vala"
		return result;
#line 6618 "Dialogs.c"
	}
#line 643 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6_ = guarded_markup_escape_text (primary_text);
#line 643 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp7_ = _tmp6_;
#line 643 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp8_ = g_strdup_printf ("<span weight=\"Bold\" size=\"larger\">%s</span>\n%s", _tmp7_, secondary_text);
#line 643 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp9_ = _tmp8_;
#line 643 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp7_);
#line 643 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = _tmp9_;
#line 643 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 6634 "Dialogs.c"
}


EventRenameDialog*
event_rename_dialog_construct (GType object_type,
                               const gchar* event_name)
{
	EventRenameDialog* self = NULL;
#line 650 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self = (EventRenameDialog*) text_entry_dialog_mediator_construct (object_type, _ ("Rename Event"), _ ("Name:"), event_name, NULL, NULL);
#line 649 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return self;
#line 6647 "Dialogs.c"
}


EventRenameDialog*
event_rename_dialog_new (const gchar* event_name)
{
#line 649 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return event_rename_dialog_construct (TYPE_EVENT_RENAME_DIALOG, event_name);
#line 6656 "Dialogs.c"
}


static gchar*
event_rename_dialog_real_execute (EventRenameDialog* self)
{
	gchar* result = NULL;
	gchar* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
#line 654 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = _text_entry_dialog_mediator_execute (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_TEXT_ENTRY_DIALOG_MEDIATOR, TextEntryDialogMediator));
#line 654 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = _tmp0_;
#line 654 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = event_prep_event_name (_tmp1_);
#line 654 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = _tmp2_;
#line 654 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp1_);
#line 654 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = _tmp3_;
#line 654 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 6682 "Dialogs.c"
}


gchar*
event_rename_dialog_execute (EventRenameDialog* self)
{
#line 653 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (IS_EVENT_RENAME_DIALOG (self), NULL);
#line 653 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return EVENT_RENAME_DIALOG_GET_CLASS (self)->execute (self);
#line 6693 "Dialogs.c"
}


static void
event_rename_dialog_class_init (EventRenameDialogClass * klass)
{
#line 648 "/home/jens/Source/shotwell/src/Dialogs.vala"
	event_rename_dialog_parent_class = g_type_class_peek_parent (klass);
#line 648 "/home/jens/Source/shotwell/src/Dialogs.vala"
	((EventRenameDialogClass *) klass)->execute = (gchar* (*) (EventRenameDialog *)) event_rename_dialog_real_execute;
#line 6704 "Dialogs.c"
}


static void
event_rename_dialog_instance_init (EventRenameDialog * self)
{
}


GType
event_rename_dialog_get_type (void)
{
	static volatile gsize event_rename_dialog_type_id__volatile = 0;
	if (g_once_init_enter (&event_rename_dialog_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (EventRenameDialogClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) event_rename_dialog_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (EventRenameDialog), 0, (GInstanceInitFunc) event_rename_dialog_instance_init, NULL };
		GType event_rename_dialog_type_id;
		event_rename_dialog_type_id = g_type_register_static (TYPE_TEXT_ENTRY_DIALOG_MEDIATOR, "EventRenameDialog", &g_define_type_info, 0);
		g_once_init_leave (&event_rename_dialog_type_id__volatile, event_rename_dialog_type_id);
	}
	return event_rename_dialog_type_id__volatile;
}


EditTitleDialog*
edit_title_dialog_construct (GType object_type,
                             const gchar* photo_title)
{
	EditTitleDialog* self = NULL;
#line 661 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self = (EditTitleDialog*) text_entry_dialog_mediator_construct (object_type, C_ ("Dialog Title", "Edit Title"), _ ("Title:"), photo_title, NULL, NULL);
#line 659 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return self;
#line 6737 "Dialogs.c"
}


EditTitleDialog*
edit_title_dialog_new (const gchar* photo_title)
{
#line 659 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return edit_title_dialog_construct (TYPE_EDIT_TITLE_DIALOG, photo_title);
#line 6746 "Dialogs.c"
}


static gchar*
edit_title_dialog_real_execute (EditTitleDialog* self)
{
	gchar* result = NULL;
	gchar* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
#line 666 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = _text_entry_dialog_mediator_execute (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_TEXT_ENTRY_DIALOG_MEDIATOR, TextEntryDialogMediator));
#line 666 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = _tmp0_;
#line 666 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = media_source_prep_title (_tmp1_);
#line 666 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = _tmp2_;
#line 666 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp1_);
#line 666 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = _tmp3_;
#line 666 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 6772 "Dialogs.c"
}


gchar*
edit_title_dialog_execute (EditTitleDialog* self)
{
#line 665 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (IS_EDIT_TITLE_DIALOG (self), NULL);
#line 665 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return EDIT_TITLE_DIALOG_GET_CLASS (self)->execute (self);
#line 6783 "Dialogs.c"
}


static gboolean
edit_title_dialog_real_on_modify_validate (TextEntryDialogMediator* base,
                                           const gchar* text)
{
	EditTitleDialog * self;
	gboolean result = FALSE;
#line 669 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_EDIT_TITLE_DIALOG, EditTitleDialog);
#line 669 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (text != NULL, FALSE);
#line 670 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = TRUE;
#line 670 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 6801 "Dialogs.c"
}


static void
edit_title_dialog_class_init (EditTitleDialogClass * klass)
{
#line 658 "/home/jens/Source/shotwell/src/Dialogs.vala"
	edit_title_dialog_parent_class = g_type_class_peek_parent (klass);
#line 658 "/home/jens/Source/shotwell/src/Dialogs.vala"
	((EditTitleDialogClass *) klass)->execute = (gchar* (*) (EditTitleDialog *)) edit_title_dialog_real_execute;
#line 658 "/home/jens/Source/shotwell/src/Dialogs.vala"
	((TextEntryDialogMediatorClass *) klass)->on_modify_validate = (gboolean (*) (TextEntryDialogMediator *, const gchar*)) edit_title_dialog_real_on_modify_validate;
#line 6814 "Dialogs.c"
}


static void
edit_title_dialog_instance_init (EditTitleDialog * self)
{
}


GType
edit_title_dialog_get_type (void)
{
	static volatile gsize edit_title_dialog_type_id__volatile = 0;
	if (g_once_init_enter (&edit_title_dialog_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (EditTitleDialogClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) edit_title_dialog_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (EditTitleDialog), 0, (GInstanceInitFunc) edit_title_dialog_instance_init, NULL };
		GType edit_title_dialog_type_id;
		edit_title_dialog_type_id = g_type_register_static (TYPE_TEXT_ENTRY_DIALOG_MEDIATOR, "EditTitleDialog", &g_define_type_info, 0);
		g_once_init_leave (&edit_title_dialog_type_id__volatile, edit_title_dialog_type_id);
	}
	return edit_title_dialog_type_id__volatile;
}


EditCommentDialog*
edit_comment_dialog_construct (GType object_type,
                               const gchar* comment,
                               gboolean is_event)
{
	EditCommentDialog* self = NULL;
	const gchar* _tmp0_ = NULL;
	gchar* title_tmp = NULL;
	gchar* _tmp1_;
#line 676 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (is_event) {
#line 678 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp0_ = _ ("Edit Event Comment");
#line 6851 "Dialogs.c"
	} else {
#line 679 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp0_ = _ ("Edit Photo/Video Comment");
#line 6855 "Dialogs.c"
	}
#line 676 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 676 "/home/jens/Source/shotwell/src/Dialogs.vala"
	title_tmp = _tmp1_;
#line 680 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self = (EditCommentDialog*) multi_text_entry_dialog_mediator_construct (object_type, title_tmp, _ ("Comment:"), comment);
#line 675 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (title_tmp);
#line 675 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return self;
#line 6867 "Dialogs.c"
}


EditCommentDialog*
edit_comment_dialog_new (const gchar* comment,
                         gboolean is_event)
{
#line 675 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return edit_comment_dialog_construct (TYPE_EDIT_COMMENT_DIALOG, comment, is_event);
#line 6877 "Dialogs.c"
}


static gchar*
edit_comment_dialog_real_execute (EditCommentDialog* self)
{
	gchar* result = NULL;
	gchar* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
#line 684 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = _multi_text_entry_dialog_mediator_execute (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_MULTI_TEXT_ENTRY_DIALOG_MEDIATOR, MultiTextEntryDialogMediator));
#line 684 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = _tmp0_;
#line 684 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = media_source_prep_comment (_tmp1_);
#line 684 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = _tmp2_;
#line 684 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp1_);
#line 684 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = _tmp3_;
#line 684 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 6903 "Dialogs.c"
}


gchar*
edit_comment_dialog_execute (EditCommentDialog* self)
{
#line 683 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (IS_EDIT_COMMENT_DIALOG (self), NULL);
#line 683 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return EDIT_COMMENT_DIALOG_GET_CLASS (self)->execute (self);
#line 6914 "Dialogs.c"
}


static gboolean
edit_comment_dialog_real_on_modify_validate (MultiTextEntryDialogMediator* base,
                                             const gchar* text)
{
	EditCommentDialog * self;
	gboolean result = FALSE;
#line 687 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_EDIT_COMMENT_DIALOG, EditCommentDialog);
#line 687 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (text != NULL, FALSE);
#line 688 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = TRUE;
#line 688 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 6932 "Dialogs.c"
}


static void
edit_comment_dialog_class_init (EditCommentDialogClass * klass)
{
#line 674 "/home/jens/Source/shotwell/src/Dialogs.vala"
	edit_comment_dialog_parent_class = g_type_class_peek_parent (klass);
#line 674 "/home/jens/Source/shotwell/src/Dialogs.vala"
	((EditCommentDialogClass *) klass)->execute = (gchar* (*) (EditCommentDialog *)) edit_comment_dialog_real_execute;
#line 674 "/home/jens/Source/shotwell/src/Dialogs.vala"
	((MultiTextEntryDialogMediatorClass *) klass)->on_modify_validate = (gboolean (*) (MultiTextEntryDialogMediator *, const gchar*)) edit_comment_dialog_real_on_modify_validate;
#line 6945 "Dialogs.c"
}


static void
edit_comment_dialog_instance_init (EditCommentDialog * self)
{
}


GType
edit_comment_dialog_get_type (void)
{
	static volatile gsize edit_comment_dialog_type_id__volatile = 0;
	if (g_once_init_enter (&edit_comment_dialog_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (EditCommentDialogClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) edit_comment_dialog_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (EditCommentDialog), 0, (GInstanceInitFunc) edit_comment_dialog_instance_init, NULL };
		GType edit_comment_dialog_type_id;
		edit_comment_dialog_type_id = g_type_register_static (TYPE_MULTI_TEXT_ENTRY_DIALOG_MEDIATOR, "EditCommentDialog", &g_define_type_info, 0);
		g_once_init_leave (&edit_comment_dialog_type_id__volatile, edit_comment_dialog_type_id);
	}
	return edit_comment_dialog_type_id__volatile;
}


GtkResponseType
remove_from_library_dialog (GtkWindow* owner,
                            const gchar* title,
                            const gchar* user_message,
                            gint count)
{
	GtkResponseType result = 0;
	gchar* trash_action = NULL;
	gchar* _tmp0_;
	GtkMessageDialog* dialog = NULL;
	GtkMessageDialog* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	GtkResponseType _result_ = 0;
#line 694 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (GTK_IS_WINDOW (owner), 0);
#line 694 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (title != NULL, 0);
#line 694 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (user_message != NULL, 0);
#line 696 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = g_strdup (ngettext ("Remove and _Trash File", "Remove and _Trash Files", (gulong) count));
#line 696 "/home/jens/Source/shotwell/src/Dialogs.vala"
	trash_action = _tmp0_;
#line 698 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = (GtkMessageDialog*) gtk_message_dialog_new (owner, GTK_DIALOG_MODAL, GTK_MESSAGE_WARNING, GTK_BUTTONS_CANCEL, "%s", user_message);
#line 698 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp1_);
#line 698 "/home/jens/Source/shotwell/src/Dialogs.vala"
	dialog = _tmp1_;
#line 700 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_dialog_add_button (G_TYPE_CHECK_INSTANCE_CAST (dialog, gtk_dialog_get_type (), GtkDialog), _ ("_Remove From Library"), (gint) GTK_RESPONSE_NO);
#line 701 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_dialog_add_button (G_TYPE_CHECK_INSTANCE_CAST (dialog, gtk_dialog_get_type (), GtkDialog), trash_action, (gint) GTK_RESPONSE_YES);
#line 706 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = build_alert_body_text (title, user_message, TRUE);
#line 706 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = _tmp2_;
#line 706 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_message_dialog_set_markup (dialog, _tmp3_);
#line 706 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp3_);
#line 708 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_result_ = (GtkResponseType) gtk_dialog_run (G_TYPE_CHECK_INSTANCE_CAST (dialog, gtk_dialog_get_type (), GtkDialog));
#line 710 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_destroy (G_TYPE_CHECK_INSTANCE_CAST (dialog, gtk_widget_get_type (), GtkWidget));
#line 712 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = _result_;
#line 712 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (dialog);
#line 712 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (trash_action);
#line 712 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 7023 "Dialogs.c"
}


GtkResponseType
remove_from_filesystem_dialog (GtkWindow* owner,
                               const gchar* title,
                               const gchar* user_message)
{
	GtkResponseType result = 0;
	GtkMessageDialog* dialog = NULL;
	GtkMessageDialog* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	GtkResponseType _result_ = 0;
#line 716 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (GTK_IS_WINDOW (owner), 0);
#line 716 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (title != NULL, 0);
#line 716 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (user_message != NULL, 0);
#line 718 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = (GtkMessageDialog*) gtk_message_dialog_new (owner, GTK_DIALOG_MODAL, GTK_MESSAGE_QUESTION, GTK_BUTTONS_NONE, "%s", user_message);
#line 718 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp0_);
#line 718 "/home/jens/Source/shotwell/src/Dialogs.vala"
	dialog = _tmp0_;
#line 720 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_dialog_add_button (G_TYPE_CHECK_INSTANCE_CAST (dialog, gtk_dialog_get_type (), GtkDialog), _ ("_Keep"), (gint) GTK_RESPONSE_NO);
#line 721 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_dialog_add_button (G_TYPE_CHECK_INSTANCE_CAST (dialog, gtk_dialog_get_type (), GtkDialog), _ ("_Delete"), (gint) GTK_RESPONSE_YES);
#line 722 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_dialog_set_default_response (G_TYPE_CHECK_INSTANCE_CAST (dialog, gtk_dialog_get_type (), GtkDialog), (gint) GTK_RESPONSE_NO);
#line 724 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = build_alert_body_text (title, user_message, TRUE);
#line 724 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = _tmp1_;
#line 724 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_message_dialog_set_markup (dialog, _tmp2_);
#line 724 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp2_);
#line 726 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_result_ = (GtkResponseType) gtk_dialog_run (G_TYPE_CHECK_INSTANCE_CAST (dialog, gtk_dialog_get_type (), GtkDialog));
#line 728 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_destroy (G_TYPE_CHECK_INSTANCE_CAST (dialog, gtk_widget_get_type (), GtkWidget));
#line 730 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = _result_;
#line 730 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (dialog);
#line 730 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 7074 "Dialogs.c"
}


gboolean
revert_editable_dialog (GtkWindow* owner,
                        GeeCollection* photos)
{
	gboolean result = FALSE;
	gint count = 0;
	gint _tmp6_;
	const gchar* _tmp7_ = NULL;
	gint _tmp8_;
	gchar* headline = NULL;
	gchar* _tmp9_;
	gchar* msg = NULL;
	gint _tmp10_;
	gint _tmp11_;
	gchar* _tmp12_;
	const gchar* _tmp13_ = NULL;
	gint _tmp14_;
	gchar* action = NULL;
	gchar* _tmp15_;
	GtkMessageDialog* dialog = NULL;
	const gchar* _tmp16_;
	GtkMessageDialog* _tmp17_;
	GtkMessageDialog* _tmp18_;
	GtkMessageDialog* _tmp19_;
	const gchar* _tmp20_;
	GtkMessageDialog* _tmp21_;
	const gchar* _tmp22_;
	const gchar* _tmp23_;
	gchar* _tmp24_;
	gchar* _tmp25_;
	GtkResponseType _result_ = 0;
	GtkMessageDialog* _tmp26_;
	GtkMessageDialog* _tmp27_;
	GtkResponseType _tmp28_;
#line 733 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (GTK_IS_WINDOW (owner), FALSE);
#line 733 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (GEE_IS_COLLECTION (photos), FALSE);
#line 734 "/home/jens/Source/shotwell/src/Dialogs.vala"
	count = 0;
#line 7118 "Dialogs.c"
	{
		GeeIterator* _photo_it = NULL;
		GeeIterator* _tmp0_;
#line 735 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp0_ = gee_iterable_iterator (G_TYPE_CHECK_INSTANCE_CAST (photos, GEE_TYPE_ITERABLE, GeeIterable));
#line 735 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_photo_it = _tmp0_;
#line 735 "/home/jens/Source/shotwell/src/Dialogs.vala"
		while (TRUE) {
#line 7128 "Dialogs.c"
			GeeIterator* _tmp1_;
			Photo* photo = NULL;
			GeeIterator* _tmp2_;
			gpointer _tmp3_;
			Photo* _tmp4_;
#line 735 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp1_ = _photo_it;
#line 735 "/home/jens/Source/shotwell/src/Dialogs.vala"
			if (!gee_iterator_next (_tmp1_)) {
#line 735 "/home/jens/Source/shotwell/src/Dialogs.vala"
				break;
#line 7140 "Dialogs.c"
			}
#line 735 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp2_ = _photo_it;
#line 735 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp3_ = gee_iterator_get (_tmp2_);
#line 735 "/home/jens/Source/shotwell/src/Dialogs.vala"
			photo = (Photo*) _tmp3_;
#line 736 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp4_ = photo;
#line 736 "/home/jens/Source/shotwell/src/Dialogs.vala"
			if (photo_has_editable (_tmp4_)) {
#line 7152 "Dialogs.c"
				gint _tmp5_;
#line 737 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp5_ = count;
#line 737 "/home/jens/Source/shotwell/src/Dialogs.vala"
				count = _tmp5_ + 1;
#line 7158 "Dialogs.c"
			}
#line 735 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_object_unref0 (photo);
#line 7162 "Dialogs.c"
		}
#line 735 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (_photo_it);
#line 7166 "Dialogs.c"
	}
#line 740 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6_ = count;
#line 740 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp6_ == 0) {
#line 741 "/home/jens/Source/shotwell/src/Dialogs.vala"
		result = FALSE;
#line 741 "/home/jens/Source/shotwell/src/Dialogs.vala"
		return result;
#line 7176 "Dialogs.c"
	}
#line 743 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp8_ = count;
#line 743 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp8_ == 1) {
#line 743 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp7_ = _ ("Revert External Edit?");
#line 7184 "Dialogs.c"
	} else {
#line 743 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp7_ = _ ("Revert External Edits?");
#line 7188 "Dialogs.c"
	}
#line 743 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp9_ = g_strdup (_tmp7_);
#line 743 "/home/jens/Source/shotwell/src/Dialogs.vala"
	headline = _tmp9_;
#line 744 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp10_ = count;
#line 744 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp11_ = count;
#line 744 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp12_ = g_strdup_printf (ngettext ("This will destroy all changes made to the external file. Continue?", "This will destroy all changes made to %d external files. Continue?", (gulong) _tmp10_), _tmp11_);
#line 744 "/home/jens/Source/shotwell/src/Dialogs.vala"
	msg = _tmp12_;
#line 749 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp14_ = count;
#line 749 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp14_ == 1) {
#line 749 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp13_ = _ ("Re_vert External Edit");
#line 7208 "Dialogs.c"
	} else {
#line 749 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp13_ = _ ("Re_vert External Edits");
#line 7212 "Dialogs.c"
	}
#line 749 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp15_ = g_strdup (_tmp13_);
#line 749 "/home/jens/Source/shotwell/src/Dialogs.vala"
	action = _tmp15_;
#line 751 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp16_ = msg;
#line 751 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp17_ = (GtkMessageDialog*) gtk_message_dialog_new (owner, GTK_DIALOG_MODAL, GTK_MESSAGE_WARNING, GTK_BUTTONS_NONE, "%s", _tmp16_);
#line 751 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp17_);
#line 751 "/home/jens/Source/shotwell/src/Dialogs.vala"
	dialog = _tmp17_;
#line 753 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp18_ = dialog;
#line 753 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_dialog_add_button (G_TYPE_CHECK_INSTANCE_CAST (_tmp18_, gtk_dialog_get_type (), GtkDialog), _ ("_Cancel"), (gint) GTK_RESPONSE_CANCEL);
#line 754 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp19_ = dialog;
#line 754 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp20_ = action;
#line 754 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_dialog_add_button (G_TYPE_CHECK_INSTANCE_CAST (_tmp19_, gtk_dialog_get_type (), GtkDialog), _tmp20_, (gint) GTK_RESPONSE_YES);
#line 756 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp21_ = dialog;
#line 756 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp22_ = headline;
#line 756 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp23_ = msg;
#line 756 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp24_ = build_alert_body_text (_tmp22_, _tmp23_, TRUE);
#line 756 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp25_ = _tmp24_;
#line 756 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_message_dialog_set_markup (_tmp21_, _tmp25_);
#line 756 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp25_);
#line 758 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp26_ = dialog;
#line 758 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_result_ = (GtkResponseType) gtk_dialog_run (G_TYPE_CHECK_INSTANCE_CAST (_tmp26_, gtk_dialog_get_type (), GtkDialog));
#line 760 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp27_ = dialog;
#line 760 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_destroy (G_TYPE_CHECK_INSTANCE_CAST (_tmp27_, gtk_widget_get_type (), GtkWidget));
#line 762 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp28_ = _result_;
#line 762 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = _tmp28_ == GTK_RESPONSE_YES;
#line 762 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (dialog);
#line 762 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (action);
#line 762 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (msg);
#line 762 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (headline);
#line 762 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 7272 "Dialogs.c"
}


gboolean
remove_offline_dialog (GtkWindow* owner,
                       gint count)
{
	gboolean result = FALSE;
	gchar* msg = NULL;
	gchar* _tmp0_;
	GtkMessageDialog* dialog = NULL;
	const gchar* _tmp1_;
	GtkMessageDialog* _tmp2_;
	GtkMessageDialog* _tmp3_;
	GtkMessageDialog* _tmp4_;
	const gchar* _tmp5_ = NULL;
	GtkMessageDialog* _tmp6_;
	GtkResponseType _result_ = 0;
	GtkMessageDialog* _tmp7_;
	GtkMessageDialog* _tmp8_;
	GtkResponseType _tmp9_;
#line 765 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (GTK_IS_WINDOW (owner), FALSE);
#line 766 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (count == 0) {
#line 767 "/home/jens/Source/shotwell/src/Dialogs.vala"
		result = FALSE;
#line 767 "/home/jens/Source/shotwell/src/Dialogs.vala"
		return result;
#line 7302 "Dialogs.c"
	}
#line 769 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = g_strdup_printf (ngettext ("This will remove the photo from the library. Continue?", "This will remove %d photos from the library. Continue?", (gulong) count), count);
#line 769 "/home/jens/Source/shotwell/src/Dialogs.vala"
	msg = _tmp0_;
#line 774 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = msg;
#line 774 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = (GtkMessageDialog*) gtk_message_dialog_new (owner, GTK_DIALOG_MODAL, GTK_MESSAGE_WARNING, GTK_BUTTONS_NONE, "%s", _tmp1_);
#line 774 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp2_);
#line 774 "/home/jens/Source/shotwell/src/Dialogs.vala"
	dialog = _tmp2_;
#line 776 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = dialog;
#line 776 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_dialog_add_button (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, gtk_dialog_get_type (), GtkDialog), _ ("_Cancel"), (gint) GTK_RESPONSE_CANCEL);
#line 777 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = dialog;
#line 777 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_dialog_add_button (G_TYPE_CHECK_INSTANCE_CAST (_tmp4_, gtk_dialog_get_type (), GtkDialog), _ ("_Remove"), (gint) GTK_RESPONSE_OK);
#line 778 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (count == 1) {
#line 778 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp5_ = _ ("Remove Photo From Library");
#line 7328 "Dialogs.c"
	} else {
#line 778 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp5_ = _ ("Remove Photos From Library");
#line 7332 "Dialogs.c"
	}
#line 778 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6_ = dialog;
#line 778 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_window_set_title (G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, gtk_window_get_type (), GtkWindow), _tmp5_);
#line 780 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp7_ = dialog;
#line 780 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_result_ = (GtkResponseType) gtk_dialog_run (G_TYPE_CHECK_INSTANCE_CAST (_tmp7_, gtk_dialog_get_type (), GtkDialog));
#line 782 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp8_ = dialog;
#line 782 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_destroy (G_TYPE_CHECK_INSTANCE_CAST (_tmp8_, gtk_widget_get_type (), GtkWidget));
#line 784 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp9_ = _result_;
#line 784 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = _tmp9_ == GTK_RESPONSE_OK;
#line 784 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (dialog);
#line 784 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (msg);
#line 784 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 7356 "Dialogs.c"
}


void
multiple_object_error_dialog (GeeArrayList* objects,
                              const gchar* message,
                              const gchar* title)
{
	gchar* dialog_message = NULL;
	gchar* _tmp0_;
	gint remainder = 0;
	gint _tmp17_;
	gint _tmp18_;
	gint _tmp19_;
	GtkMessageDialog* dialog = NULL;
	AppWindow* _tmp26_;
	AppWindow* _tmp27_;
	const gchar* _tmp28_;
	GtkMessageDialog* _tmp29_;
	GtkMessageDialog* _tmp30_;
#line 788 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (GEE_IS_ARRAY_LIST (objects));
#line 788 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (message != NULL);
#line 788 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (title != NULL);
#line 790 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = g_strconcat (message, "\n", NULL);
#line 790 "/home/jens/Source/shotwell/src/Dialogs.vala"
	dialog_message = _tmp0_;
#line 7387 "Dialogs.c"
	{
		gint i = 0;
#line 793 "/home/jens/Source/shotwell/src/Dialogs.vala"
		i = 0;
#line 7392 "Dialogs.c"
		{
			gboolean _tmp1_ = FALSE;
#line 793 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp1_ = TRUE;
#line 793 "/home/jens/Source/shotwell/src/Dialogs.vala"
			while (TRUE) {
#line 7399 "Dialogs.c"
				gboolean _tmp3_ = FALSE;
				gint _tmp4_;
				const gchar* _tmp8_;
				gint _tmp9_;
				gpointer _tmp10_;
				DataObject* _tmp11_;
				gchar* _tmp12_;
				gchar* _tmp13_;
				gchar* _tmp14_;
				gchar* _tmp15_;
				gchar* _tmp16_;
#line 793 "/home/jens/Source/shotwell/src/Dialogs.vala"
				if (!_tmp1_) {
#line 7413 "Dialogs.c"
					gint _tmp2_;
#line 793 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp2_ = i;
#line 793 "/home/jens/Source/shotwell/src/Dialogs.vala"
					i = _tmp2_ + 1;
#line 7419 "Dialogs.c"
				}
#line 793 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp1_ = FALSE;
#line 793 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp4_ = i;
#line 793 "/home/jens/Source/shotwell/src/Dialogs.vala"
				if (_tmp4_ < MAX_OBJECTS_DISPLAYED) {
#line 7427 "Dialogs.c"
					gint _tmp5_;
					gint _tmp6_;
					gint _tmp7_;
#line 793 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp5_ = gee_abstract_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (objects, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection));
#line 793 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp6_ = _tmp5_;
#line 793 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp7_ = i;
#line 793 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp3_ = _tmp6_ > _tmp7_;
#line 7439 "Dialogs.c"
				} else {
#line 793 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp3_ = FALSE;
#line 7443 "Dialogs.c"
				}
#line 793 "/home/jens/Source/shotwell/src/Dialogs.vala"
				if (!_tmp3_) {
#line 793 "/home/jens/Source/shotwell/src/Dialogs.vala"
					break;
#line 7449 "Dialogs.c"
				}
#line 794 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp8_ = dialog_message;
#line 794 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp9_ = i;
#line 794 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp10_ = gee_abstract_list_get (G_TYPE_CHECK_INSTANCE_CAST (objects, GEE_TYPE_ABSTRACT_LIST, GeeAbstractList), _tmp9_);
#line 794 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp11_ = (DataObject*) _tmp10_;
#line 794 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp12_ = data_object_to_string (_tmp11_);
#line 794 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp13_ = _tmp12_;
#line 794 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp14_ = g_strconcat ("\n", _tmp13_, NULL);
#line 794 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp15_ = _tmp14_;
#line 794 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp16_ = g_strconcat (_tmp8_, _tmp15_, NULL);
#line 794 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (dialog_message);
#line 794 "/home/jens/Source/shotwell/src/Dialogs.vala"
				dialog_message = _tmp16_;
#line 794 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp15_);
#line 794 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp13_);
#line 794 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_object_unref0 (_tmp11_);
#line 7479 "Dialogs.c"
			}
		}
	}
#line 796 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp17_ = gee_abstract_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (objects, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection));
#line 796 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp18_ = _tmp17_;
#line 796 "/home/jens/Source/shotwell/src/Dialogs.vala"
	remainder = _tmp18_ - MAX_OBJECTS_DISPLAYED;
#line 797 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp19_ = remainder;
#line 797 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp19_ > 0) {
#line 7493 "Dialogs.c"
		const gchar* _tmp20_;
		gint _tmp21_;
		gint _tmp22_;
		gchar* _tmp23_;
		gchar* _tmp24_;
		gchar* _tmp25_;
#line 798 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp20_ = dialog_message;
#line 798 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp21_ = remainder;
#line 798 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp22_ = remainder;
#line 798 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp23_ = g_strdup_printf (ngettext ("\n\nAnd %d other.", "\n\nAnd %d others.", (gulong) _tmp21_), _tmp22_);
#line 798 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp24_ = _tmp23_;
#line 798 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp25_ = g_strconcat (_tmp20_, _tmp24_, NULL);
#line 798 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (dialog_message);
#line 798 "/home/jens/Source/shotwell/src/Dialogs.vala"
		dialog_message = _tmp25_;
#line 798 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp24_);
#line 7518 "Dialogs.c"
	}
#line 802 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp26_ = app_window_get_instance ();
#line 802 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp27_ = _tmp26_;
#line 802 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp28_ = dialog_message;
#line 802 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp29_ = (GtkMessageDialog*) gtk_message_dialog_new (G_TYPE_CHECK_INSTANCE_CAST (_tmp27_, gtk_window_get_type (), GtkWindow), GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, "%s", _tmp28_);
#line 802 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp29_);
#line 802 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp30_ = _tmp29_;
#line 802 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (_tmp27_);
#line 802 "/home/jens/Source/shotwell/src/Dialogs.vala"
	dialog = _tmp30_;
#line 805 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_window_set_title (G_TYPE_CHECK_INSTANCE_CAST (dialog, gtk_window_get_type (), GtkWindow), title);
#line 807 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_dialog_run (G_TYPE_CHECK_INSTANCE_CAST (dialog, gtk_dialog_get_type (), GtkDialog));
#line 808 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_destroy (G_TYPE_CHECK_INSTANCE_CAST (dialog, gtk_widget_get_type (), GtkWidget));
#line 788 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (dialog);
#line 788 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (dialog_message);
#line 7546 "Dialogs.c"
}


TagsDialog*
tags_dialog_construct (GType object_type,
                       const gchar* title,
                       const gchar* label,
                       const gchar* initial_text)
{
	TagsDialog* self = NULL;
	HierarchicalTagIndex* _tmp0_;
	HierarchicalTagIndex* _tmp1_;
	GeeCollection* _tmp2_;
	GeeCollection* _tmp3_;
#line 812 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (title != NULL, NULL);
#line 812 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (label != NULL, NULL);
#line 813 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = hierarchical_tag_index_get_global_index ();
#line 813 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = _tmp0_;
#line 813 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = hierarchical_tag_index_get_all_tags (_tmp1_);
#line 813 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = _tmp2_;
#line 813 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self = (TagsDialog*) text_entry_dialog_mediator_construct (object_type, title, label, initial_text, _tmp3_, ",");
#line 813 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (_tmp3_);
#line 813 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_hierarchical_tag_index_unref0 (_tmp1_);
#line 812 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return self;
#line 7581 "Dialogs.c"
}


static void
tags_dialog_class_init (TagsDialogClass * klass)
{
#line 811 "/home/jens/Source/shotwell/src/Dialogs.vala"
	tags_dialog_parent_class = g_type_class_peek_parent (klass);
#line 7590 "Dialogs.c"
}


static void
tags_dialog_instance_init (TagsDialog * self)
{
}


GType
tags_dialog_get_type (void)
{
	static volatile gsize tags_dialog_type_id__volatile = 0;
	if (g_once_init_enter (&tags_dialog_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (TagsDialogClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) tags_dialog_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TagsDialog), 0, (GInstanceInitFunc) tags_dialog_instance_init, NULL };
		GType tags_dialog_type_id;
		tags_dialog_type_id = g_type_register_static (TYPE_TEXT_ENTRY_DIALOG_MEDIATOR, "TagsDialog", &g_define_type_info, G_TYPE_FLAG_ABSTRACT);
		g_once_init_leave (&tags_dialog_type_id__volatile, tags_dialog_type_id);
	}
	return tags_dialog_type_id__volatile;
}


AddTagsDialog*
add_tags_dialog_construct (GType object_type)
{
	AddTagsDialog* self = NULL;
	gchar* title = NULL;
	gchar* _tmp0_;
#line 820 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = g_strdup (g_dpgettext2 (NULL, "Dialog Title", RESOURCES_ADD_TAGS_TITLE));
#line 820 "/home/jens/Source/shotwell/src/Dialogs.vala"
	title = _tmp0_;
#line 822 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self = (AddTagsDialog*) tags_dialog_construct (object_type, title, _ ("Tags (separated by commas):"), NULL);
#line 819 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (title);
#line 819 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return self;
#line 7630 "Dialogs.c"
}


AddTagsDialog*
add_tags_dialog_new (void)
{
#line 819 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return add_tags_dialog_construct (TYPE_ADD_TAGS_DIALOG);
#line 7639 "Dialogs.c"
}


gchar**
add_tags_dialog_execute (AddTagsDialog* self,
                         int* result_length1)
{
	gchar** result = NULL;
	gchar* text = NULL;
	gchar* _tmp0_;
	const gchar* _tmp1_;
	const gchar* _tmp3_;
	gchar** _tmp4_;
	gchar** _tmp5_;
	gchar** _tmp6_;
	gint _tmp6__length1;
	gint _tmp7_;
	gchar** _tmp8_;
	gchar** _tmp9_;
	gint _tmp9__length1;
	gchar** _tmp10_;
	gint _tmp10__length1;
#line 825 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (IS_ADD_TAGS_DIALOG (self), NULL);
#line 826 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = _text_entry_dialog_mediator_execute (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_TEXT_ENTRY_DIALOG_MEDIATOR, TextEntryDialogMediator));
#line 826 "/home/jens/Source/shotwell/src/Dialogs.vala"
	text = _tmp0_;
#line 827 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = text;
#line 827 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp1_ == NULL) {
#line 7672 "Dialogs.c"
		gchar** _tmp2_;
		gint _tmp2__length1;
#line 828 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp2_ = NULL;
#line 828 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp2__length1 = 0;
#line 828 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (result_length1) {
#line 828 "/home/jens/Source/shotwell/src/Dialogs.vala"
			*result_length1 = _tmp2__length1;
#line 7683 "Dialogs.c"
		}
#line 828 "/home/jens/Source/shotwell/src/Dialogs.vala"
		result = _tmp2_;
#line 828 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (text);
#line 828 "/home/jens/Source/shotwell/src/Dialogs.vala"
		return result;
#line 7691 "Dialogs.c"
	}
#line 832 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = text;
#line 832 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = _tmp4_ = g_strsplit (_tmp3_, ",", 0);
#line 832 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6_ = _tmp5_;
#line 832 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6__length1 = _vala_array_length (_tmp4_);
#line 832 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp8_ = tag_prep_tag_names (_tmp6_, _vala_array_length (_tmp4_), &_tmp7_);
#line 832 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp9_ = _tmp8_;
#line 832 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp9__length1 = _tmp7_;
#line 832 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6_ = (_vala_array_free (_tmp6_, _tmp6__length1, (GDestroyNotify) g_free), NULL);
#line 832 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp10_ = _tmp9_;
#line 832 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp10__length1 = _tmp9__length1;
#line 832 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (result_length1) {
#line 832 "/home/jens/Source/shotwell/src/Dialogs.vala"
		*result_length1 = _tmp10__length1;
#line 7717 "Dialogs.c"
	}
#line 832 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = _tmp10_;
#line 832 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (text);
#line 832 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 7725 "Dialogs.c"
}


static gboolean
string_contains (const gchar* self,
                 const gchar* needle)
{
	gboolean result = FALSE;
	gchar* _tmp0_;
#line 1417 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, FALSE);
#line 1417 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	g_return_val_if_fail (needle != NULL, FALSE);
#line 1418 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	_tmp0_ = strstr ((gchar*) self, (gchar*) needle);
#line 1418 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	result = _tmp0_ != NULL;
#line 1418 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	return result;
#line 7745 "Dialogs.c"
}


static gboolean
add_tags_dialog_real_on_modify_validate (TextEntryDialogMediator* base,
                                         const gchar* text)
{
	AddTagsDialog * self;
	gboolean result = FALSE;
	gchar** names = NULL;
	gchar** _tmp0_;
	gchar** _tmp1_;
	gchar** _tmp2_;
	gint _tmp2__length1;
	gint _tmp3_;
	gchar** _tmp4_;
	gchar** _tmp5_;
	gint _tmp5__length1;
	gint names_length1;
	gint _names_size_;
	gchar** _tmp6_;
	gint _tmp6__length1;
#line 835 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_ADD_TAGS_DIALOG, AddTagsDialog);
#line 835 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (text != NULL, FALSE);
#line 836 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (string_contains (text, TAG_PATH_SEPARATOR_STRING)) {
#line 837 "/home/jens/Source/shotwell/src/Dialogs.vala"
		result = FALSE;
#line 837 "/home/jens/Source/shotwell/src/Dialogs.vala"
		return result;
#line 7778 "Dialogs.c"
	}
#line 841 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = _tmp0_ = g_strsplit (text, ",", 0);
#line 841 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = _tmp1_;
#line 841 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2__length1 = _vala_array_length (_tmp0_);
#line 841 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = tag_prep_tag_names (_tmp2_, _vala_array_length (_tmp0_), &_tmp3_);
#line 841 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = _tmp4_;
#line 841 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5__length1 = _tmp3_;
#line 841 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = (_vala_array_free (_tmp2_, _tmp2__length1, (GDestroyNotify) g_free), NULL);
#line 841 "/home/jens/Source/shotwell/src/Dialogs.vala"
	names = _tmp5_;
#line 841 "/home/jens/Source/shotwell/src/Dialogs.vala"
	names_length1 = _tmp5__length1;
#line 841 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_names_size_ = names_length1;
#line 843 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6_ = names;
#line 843 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6__length1 = names_length1;
#line 843 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = _tmp6__length1 > 0;
#line 843 "/home/jens/Source/shotwell/src/Dialogs.vala"
	names = (_vala_array_free (names, names_length1, (GDestroyNotify) g_free), NULL);
#line 843 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 7810 "Dialogs.c"
}


static void
add_tags_dialog_class_init (AddTagsDialogClass * klass)
{
#line 818 "/home/jens/Source/shotwell/src/Dialogs.vala"
	add_tags_dialog_parent_class = g_type_class_peek_parent (klass);
#line 818 "/home/jens/Source/shotwell/src/Dialogs.vala"
	((TextEntryDialogMediatorClass *) klass)->on_modify_validate = (gboolean (*) (TextEntryDialogMediator *, const gchar*)) add_tags_dialog_real_on_modify_validate;
#line 7821 "Dialogs.c"
}


static void
add_tags_dialog_instance_init (AddTagsDialog * self)
{
}


GType
add_tags_dialog_get_type (void)
{
	static volatile gsize add_tags_dialog_type_id__volatile = 0;
	if (g_once_init_enter (&add_tags_dialog_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (AddTagsDialogClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) add_tags_dialog_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (AddTagsDialog), 0, (GInstanceInitFunc) add_tags_dialog_instance_init, NULL };
		GType add_tags_dialog_type_id;
		add_tags_dialog_type_id = g_type_register_static (TYPE_TAGS_DIALOG, "AddTagsDialog", &g_define_type_info, 0);
		g_once_init_leave (&add_tags_dialog_type_id__volatile, add_tags_dialog_type_id);
	}
	return add_tags_dialog_type_id__volatile;
}


ModifyTagsDialog*
modify_tags_dialog_construct (GType object_type,
                              MediaSource* source)
{
	ModifyTagsDialog* self = NULL;
	gchar* _tmp0_;
	gchar* _tmp1_;
#line 848 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (IS_MEDIA_SOURCE (source), NULL);
#line 849 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = modify_tags_dialog_get_initial_text (source);
#line 849 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = _tmp0_;
#line 849 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self = (ModifyTagsDialog*) tags_dialog_construct (object_type, RESOURCES_MODIFY_TAGS_LABEL, _ ("Tags (separated by commas):"), _tmp1_);
#line 849 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp1_);
#line 848 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return self;
#line 7864 "Dialogs.c"
}


ModifyTagsDialog*
modify_tags_dialog_new (MediaSource* source)
{
#line 848 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return modify_tags_dialog_construct (TYPE_MODIFY_TAGS_DIALOG, source);
#line 7873 "Dialogs.c"
}


static gchar*
modify_tags_dialog_get_initial_text (MediaSource* source)
{
	gchar* result = NULL;
	GeeCollection* source_tags = NULL;
	TagSourceCollection* _tmp0_;
	GeeList* _tmp1_;
	GeeCollection* _tmp2_;
	GeeCollection* terminal_tags = NULL;
	GeeCollection* _tmp3_;
	GeeCollection* _tmp4_;
	GeeSortedSet* tag_basenames = NULL;
	GeeTreeSet* _tmp5_;
	gchar* text = NULL;
#line 853 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (IS_MEDIA_SOURCE (source), NULL);
#line 854 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = tag_global;
#line 854 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = tag_source_collection_fetch_for_source (_tmp0_, source);
#line 854 "/home/jens/Source/shotwell/src/Dialogs.vala"
	source_tags = G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, GEE_TYPE_COLLECTION, GeeCollection);
#line 855 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = source_tags;
#line 855 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp2_ == NULL) {
#line 856 "/home/jens/Source/shotwell/src/Dialogs.vala"
		result = NULL;
#line 856 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (source_tags);
#line 856 "/home/jens/Source/shotwell/src/Dialogs.vala"
		return result;
#line 7909 "Dialogs.c"
	}
#line 858 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = source_tags;
#line 858 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = tag_get_terminal_tags (_tmp3_);
#line 858 "/home/jens/Source/shotwell/src/Dialogs.vala"
	terminal_tags = _tmp4_;
#line 860 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = gee_tree_set_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, (GDestroyNotify) g_free, NULL, NULL, NULL);
#line 860 "/home/jens/Source/shotwell/src/Dialogs.vala"
	tag_basenames = G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, GEE_TYPE_SORTED_SET, GeeSortedSet);
#line 7921 "Dialogs.c"
	{
		GeeIterator* _tag_it = NULL;
		GeeCollection* _tmp6_;
		GeeIterator* _tmp7_;
#line 861 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp6_ = terminal_tags;
#line 861 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp7_ = gee_iterable_iterator (G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, GEE_TYPE_ITERABLE, GeeIterable));
#line 861 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tag_it = _tmp7_;
#line 861 "/home/jens/Source/shotwell/src/Dialogs.vala"
		while (TRUE) {
#line 7934 "Dialogs.c"
			GeeIterator* _tmp8_;
			Tag* tag = NULL;
			GeeIterator* _tmp9_;
			gpointer _tmp10_;
			GeeSortedSet* _tmp11_;
			Tag* _tmp12_;
			gchar* _tmp13_;
			gchar* _tmp14_;
			gchar* _tmp15_;
			gchar* _tmp16_;
#line 861 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp8_ = _tag_it;
#line 861 "/home/jens/Source/shotwell/src/Dialogs.vala"
			if (!gee_iterator_next (_tmp8_)) {
#line 861 "/home/jens/Source/shotwell/src/Dialogs.vala"
				break;
#line 7951 "Dialogs.c"
			}
#line 861 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp9_ = _tag_it;
#line 861 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp10_ = gee_iterator_get (_tmp9_);
#line 861 "/home/jens/Source/shotwell/src/Dialogs.vala"
			tag = (Tag*) _tmp10_;
#line 862 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp11_ = tag_basenames;
#line 862 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp12_ = tag;
#line 862 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp13_ = tag_get_path (_tmp12_);
#line 862 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp14_ = _tmp13_;
#line 862 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp15_ = hierarchical_tag_utilities_get_basename (_tmp14_);
#line 862 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp16_ = _tmp15_;
#line 862 "/home/jens/Source/shotwell/src/Dialogs.vala"
			gee_collection_add (G_TYPE_CHECK_INSTANCE_CAST (_tmp11_, GEE_TYPE_COLLECTION, GeeCollection), _tmp16_);
#line 862 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_free0 (_tmp16_);
#line 862 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_free0 (_tmp14_);
#line 861 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_object_unref0 (tag);
#line 7979 "Dialogs.c"
		}
#line 861 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (_tag_it);
#line 7983 "Dialogs.c"
	}
#line 864 "/home/jens/Source/shotwell/src/Dialogs.vala"
	text = NULL;
#line 7987 "Dialogs.c"
	{
		GeeIterator* _name_it = NULL;
		GeeSortedSet* _tmp17_;
		GeeIterator* _tmp18_;
#line 865 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp17_ = tag_basenames;
#line 865 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp18_ = gee_iterable_iterator (G_TYPE_CHECK_INSTANCE_CAST (_tmp17_, GEE_TYPE_ITERABLE, GeeIterable));
#line 865 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_name_it = _tmp18_;
#line 865 "/home/jens/Source/shotwell/src/Dialogs.vala"
		while (TRUE) {
#line 8000 "Dialogs.c"
			GeeIterator* _tmp19_;
			gchar* name = NULL;
			GeeIterator* _tmp20_;
			gpointer _tmp21_;
			const gchar* _tmp22_;
			const gchar* _tmp26_;
			const gchar* _tmp27_;
			gchar* _tmp28_;
#line 865 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp19_ = _name_it;
#line 865 "/home/jens/Source/shotwell/src/Dialogs.vala"
			if (!gee_iterator_next (_tmp19_)) {
#line 865 "/home/jens/Source/shotwell/src/Dialogs.vala"
				break;
#line 8015 "Dialogs.c"
			}
#line 865 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp20_ = _name_it;
#line 865 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp21_ = gee_iterator_get (_tmp20_);
#line 865 "/home/jens/Source/shotwell/src/Dialogs.vala"
			name = (gchar*) _tmp21_;
#line 866 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp22_ = text;
#line 866 "/home/jens/Source/shotwell/src/Dialogs.vala"
			if (_tmp22_ == NULL) {
#line 8027 "Dialogs.c"
				gchar* _tmp23_;
#line 867 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp23_ = g_strdup ("");
#line 867 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (text);
#line 867 "/home/jens/Source/shotwell/src/Dialogs.vala"
				text = _tmp23_;
#line 8035 "Dialogs.c"
			} else {
				const gchar* _tmp24_;
				gchar* _tmp25_;
#line 869 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp24_ = text;
#line 869 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp25_ = g_strconcat (_tmp24_, ", ", NULL);
#line 869 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (text);
#line 869 "/home/jens/Source/shotwell/src/Dialogs.vala"
				text = _tmp25_;
#line 8047 "Dialogs.c"
			}
#line 871 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp26_ = text;
#line 871 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp27_ = name;
#line 871 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp28_ = g_strconcat (_tmp26_, _tmp27_, NULL);
#line 871 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_free0 (text);
#line 871 "/home/jens/Source/shotwell/src/Dialogs.vala"
			text = _tmp28_;
#line 865 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_free0 (name);
#line 8061 "Dialogs.c"
		}
#line 865 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (_name_it);
#line 8065 "Dialogs.c"
	}
#line 874 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = text;
#line 874 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (tag_basenames);
#line 874 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (terminal_tags);
#line 874 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (source_tags);
#line 874 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 8077 "Dialogs.c"
}


GeeArrayList*
modify_tags_dialog_execute (ModifyTagsDialog* self)
{
	GeeArrayList* result = NULL;
	gchar* text = NULL;
	gchar* _tmp0_;
	const gchar* _tmp1_;
	GeeArrayList* new_tags = NULL;
	GeeArrayList* _tmp2_;
	const gchar* _tmp3_;
	gchar** tag_names = NULL;
	const gchar* _tmp4_;
	gchar** _tmp5_;
	gchar** _tmp6_;
	gchar** _tmp7_;
	gint _tmp7__length1;
	gint _tmp8_;
	gchar** _tmp9_;
	gchar** _tmp10_;
	gint _tmp10__length1;
	gint tag_names_length1;
	gint _tag_names_size_;
	HierarchicalTagIndex* _tmp11_;
	HierarchicalTagIndex* _tmp12_;
	gchar** _tmp13_;
	gint _tmp13__length1;
	gint _tmp14_;
	gchar** _tmp15_;
	gchar** _tmp16_;
	gint _tmp16__length1;
#line 877 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (IS_MODIFY_TAGS_DIALOG (self), NULL);
#line 878 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = _text_entry_dialog_mediator_execute (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_TEXT_ENTRY_DIALOG_MEDIATOR, TextEntryDialogMediator));
#line 878 "/home/jens/Source/shotwell/src/Dialogs.vala"
	text = _tmp0_;
#line 879 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = text;
#line 879 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp1_ == NULL) {
#line 880 "/home/jens/Source/shotwell/src/Dialogs.vala"
		result = NULL;
#line 880 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (text);
#line 880 "/home/jens/Source/shotwell/src/Dialogs.vala"
		return result;
#line 8127 "Dialogs.c"
	}
#line 882 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = gee_array_list_new (TYPE_TAG, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, NULL, NULL, NULL);
#line 882 "/home/jens/Source/shotwell/src/Dialogs.vala"
	new_tags = _tmp2_;
#line 885 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = text;
#line 885 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (is_string_empty (_tmp3_)) {
#line 886 "/home/jens/Source/shotwell/src/Dialogs.vala"
		result = new_tags;
#line 886 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (text);
#line 886 "/home/jens/Source/shotwell/src/Dialogs.vala"
		return result;
#line 8143 "Dialogs.c"
	}
#line 889 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = text;
#line 889 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6_ = _tmp5_ = g_strsplit (_tmp4_, ",", 0);
#line 889 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp7_ = _tmp6_;
#line 889 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp7__length1 = _vala_array_length (_tmp5_);
#line 889 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp9_ = tag_prep_tag_names (_tmp7_, _vala_array_length (_tmp5_), &_tmp8_);
#line 889 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp10_ = _tmp9_;
#line 889 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp10__length1 = _tmp8_;
#line 889 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp7_ = (_vala_array_free (_tmp7_, _tmp7__length1, (GDestroyNotify) g_free), NULL);
#line 889 "/home/jens/Source/shotwell/src/Dialogs.vala"
	tag_names = _tmp10_;
#line 889 "/home/jens/Source/shotwell/src/Dialogs.vala"
	tag_names_length1 = _tmp10__length1;
#line 889 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tag_names_size_ = tag_names_length1;
#line 891 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp11_ = hierarchical_tag_index_get_global_index ();
#line 891 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp12_ = _tmp11_;
#line 891 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp13_ = tag_names;
#line 891 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp13__length1 = tag_names_length1;
#line 891 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp15_ = hierarchical_tag_index_get_paths_for_names_array (_tmp12_, _tmp13_, _tmp13__length1, &_tmp14_);
#line 891 "/home/jens/Source/shotwell/src/Dialogs.vala"
	tag_names = (_vala_array_free (tag_names, tag_names_length1, (GDestroyNotify) g_free), NULL);
#line 891 "/home/jens/Source/shotwell/src/Dialogs.vala"
	tag_names = _tmp15_;
#line 891 "/home/jens/Source/shotwell/src/Dialogs.vala"
	tag_names_length1 = _tmp14_;
#line 891 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tag_names_size_ = tag_names_length1;
#line 891 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_hierarchical_tag_index_unref0 (_tmp12_);
#line 893 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp16_ = tag_names;
#line 893 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp16__length1 = tag_names_length1;
#line 8191 "Dialogs.c"
	{
		gchar** name_collection = NULL;
		gint name_collection_length1 = 0;
		gint _name_collection_size_ = 0;
		gint name_it = 0;
#line 893 "/home/jens/Source/shotwell/src/Dialogs.vala"
		name_collection = _tmp16_;
#line 893 "/home/jens/Source/shotwell/src/Dialogs.vala"
		name_collection_length1 = _tmp16__length1;
#line 893 "/home/jens/Source/shotwell/src/Dialogs.vala"
		for (name_it = 0; name_it < _tmp16__length1; name_it = name_it + 1) {
#line 8203 "Dialogs.c"
			gchar* _tmp17_;
			gchar* name = NULL;
#line 893 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp17_ = g_strdup (name_collection[name_it]);
#line 893 "/home/jens/Source/shotwell/src/Dialogs.vala"
			name = _tmp17_;
#line 8210 "Dialogs.c"
			{
				GeeArrayList* _tmp18_;
				const gchar* _tmp19_;
				Tag* _tmp20_;
				Tag* _tmp21_;
#line 894 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp18_ = new_tags;
#line 894 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp19_ = name;
#line 894 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp20_ = tag_for_path (_tmp19_);
#line 894 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp21_ = _tmp20_;
#line 894 "/home/jens/Source/shotwell/src/Dialogs.vala"
				gee_abstract_collection_add (G_TYPE_CHECK_INSTANCE_CAST (_tmp18_, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection), _tmp21_);
#line 894 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_object_unref0 (_tmp21_);
#line 893 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (name);
#line 8230 "Dialogs.c"
			}
		}
	}
#line 896 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = new_tags;
#line 896 "/home/jens/Source/shotwell/src/Dialogs.vala"
	tag_names = (_vala_array_free (tag_names, tag_names_length1, (GDestroyNotify) g_free), NULL);
#line 896 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (text);
#line 896 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 8242 "Dialogs.c"
}


static gboolean
modify_tags_dialog_real_on_modify_validate (TextEntryDialogMediator* base,
                                            const gchar* text)
{
	ModifyTagsDialog * self;
	gboolean result = FALSE;
#line 899 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_MODIFY_TAGS_DIALOG, ModifyTagsDialog);
#line 899 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (text != NULL, FALSE);
#line 900 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = !string_contains (text, TAG_PATH_SEPARATOR_STRING);
#line 900 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 8260 "Dialogs.c"
}


static void
modify_tags_dialog_class_init (ModifyTagsDialogClass * klass)
{
#line 847 "/home/jens/Source/shotwell/src/Dialogs.vala"
	modify_tags_dialog_parent_class = g_type_class_peek_parent (klass);
#line 847 "/home/jens/Source/shotwell/src/Dialogs.vala"
	((TextEntryDialogMediatorClass *) klass)->on_modify_validate = (gboolean (*) (TextEntryDialogMediator *, const gchar*)) modify_tags_dialog_real_on_modify_validate;
#line 8271 "Dialogs.c"
}


static void
modify_tags_dialog_instance_init (ModifyTagsDialog * self)
{
}


GType
modify_tags_dialog_get_type (void)
{
	static volatile gsize modify_tags_dialog_type_id__volatile = 0;
	if (g_once_init_enter (&modify_tags_dialog_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (ModifyTagsDialogClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) modify_tags_dialog_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ModifyTagsDialog), 0, (GInstanceInitFunc) modify_tags_dialog_instance_init, NULL };
		GType modify_tags_dialog_type_id;
		modify_tags_dialog_type_id = g_type_register_static (TYPE_TAGS_DIALOG, "ModifyTagsDialog", &g_define_type_info, 0);
		g_once_init_leave (&modify_tags_dialog_type_id__volatile, modify_tags_dialog_type_id);
	}
	return modify_tags_dialog_type_id__volatile;
}


GtkResponseType
copy_files_dialog (void)
{
	GtkResponseType result = 0;
	gchar* msg = NULL;
	gchar* _tmp0_;
	GtkMessageDialog* dialog = NULL;
	AppWindow* _tmp1_;
	AppWindow* _tmp2_;
	GtkMessageDialog* _tmp3_;
	GtkMessageDialog* _tmp4_;
	GtkResponseType _result_ = 0;
#line 908 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = g_strdup (_ ("Shotwell can copy the photos into your library folder or it can import" \
" them without copying."));
#line 908 "/home/jens/Source/shotwell/src/Dialogs.vala"
	msg = _tmp0_;
#line 910 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = app_window_get_instance ();
#line 910 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = _tmp1_;
#line 910 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = (GtkMessageDialog*) gtk_message_dialog_new (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, gtk_window_get_type (), GtkWindow), GTK_DIALOG_MODAL, GTK_MESSAGE_QUESTION, GTK_BUTTONS_CANCEL, "%s", msg);
#line 910 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp3_);
#line 910 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = _tmp3_;
#line 910 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (_tmp2_);
#line 910 "/home/jens/Source/shotwell/src/Dialogs.vala"
	dialog = _tmp4_;
#line 913 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_dialog_add_button (G_TYPE_CHECK_INSTANCE_CAST (dialog, gtk_dialog_get_type (), GtkDialog), _ ("Co_py Photos"), (gint) GTK_RESPONSE_ACCEPT);
#line 914 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_dialog_add_button (G_TYPE_CHECK_INSTANCE_CAST (dialog, gtk_dialog_get_type (), GtkDialog), _ ("_Import in Place"), (gint) GTK_RESPONSE_REJECT);
#line 915 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_window_set_title (G_TYPE_CHECK_INSTANCE_CAST (dialog, gtk_window_get_type (), GtkWindow), _ ("Import to Library"));
#line 917 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_result_ = (GtkResponseType) gtk_dialog_run (G_TYPE_CHECK_INSTANCE_CAST (dialog, gtk_dialog_get_type (), GtkDialog));
#line 919 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_destroy (G_TYPE_CHECK_INSTANCE_CAST (dialog, gtk_widget_get_type (), GtkWidget));
#line 921 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = _result_;
#line 921 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (dialog);
#line 921 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (msg);
#line 921 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 8343 "Dialogs.c"
}


void
remove_photos_from_library (GeeCollection* photos)
{
	const gchar* _tmp0_ = NULL;
	gint _tmp1_;
	gint _tmp2_;
#line 924 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (GEE_IS_COLLECTION (photos));
#line 926 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = gee_collection_get_size (photos);
#line 926 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = _tmp1_;
#line 926 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp2_ == 1) {
#line 926 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp0_ = _ ("Removing Photo From Library");
#line 8363 "Dialogs.c"
	} else {
#line 926 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp0_ = _ ("Removing Photos From Library");
#line 8367 "Dialogs.c"
	}
#line 925 "/home/jens/Source/shotwell/src/Dialogs.vala"
	remove_from_app (photos, _ ("Remove From Library"), _tmp0_);
#line 8371 "Dialogs.c"
}


static gboolean
_progress_dialog_monitor_progress_monitor (guint64 current,
                                           guint64 total,
                                           gboolean do_event_loop,
                                           gpointer self)
{
	gboolean result;
	result = progress_dialog_monitor ((ProgressDialog*) self, current, total, do_event_loop);
#line 966 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 8385 "Dialogs.c"
}


void
remove_from_app (GeeCollection* sources,
                 const gchar* dialog_title,
                 const gchar* progress_dialog_text)
{
	gint _tmp0_;
	gint _tmp1_;
	GeeArrayList* photos = NULL;
	GeeArrayList* _tmp2_;
	GeeArrayList* videos = NULL;
	GeeArrayList* _tmp3_;
	GeeArrayList* _tmp4_;
	GeeArrayList* _tmp5_;
	gchar* user_message = NULL;
	gboolean _tmp6_ = FALSE;
	GeeArrayList* _tmp7_;
	gboolean _tmp8_;
	gboolean _tmp9_;
	GtkResponseType _result_ = 0;
	AppWindow* _tmp31_;
	AppWindow* _tmp32_;
	const gchar* _tmp33_;
	gint _tmp34_;
	gint _tmp35_;
	GtkResponseType _tmp36_;
	gboolean _tmp37_ = FALSE;
	GtkResponseType _tmp38_;
	gboolean delete_backing = FALSE;
	GtkResponseType _tmp40_;
	AppWindow* _tmp41_;
	AppWindow* _tmp42_;
	ProgressDialog* progress = NULL;
	ProgressMonitor monitor = NULL;
	void* monitor_target;
	GDestroyNotify monitor_target_destroy_notify;
	gint _tmp43_;
	gint _tmp44_;
	GeeArrayList* not_removed_photos = NULL;
	GeeArrayList* _tmp49_;
	GeeArrayList* not_removed_videos = NULL;
	GeeArrayList* _tmp50_;
	LibraryPhotoSourceCollection* _tmp51_;
	GeeArrayList* _tmp52_;
	gboolean _tmp53_;
	ProgressMonitor _tmp54_;
	void* _tmp54__target;
	GeeArrayList* _tmp55_;
	VideoSourceCollection* _tmp56_;
	GeeArrayList* _tmp57_;
	gboolean _tmp58_;
	ProgressMonitor _tmp59_;
	void* _tmp59__target;
	GeeArrayList* _tmp60_;
	gint num_not_removed = 0;
	GeeArrayList* _tmp61_;
	gint _tmp62_;
	gint _tmp63_;
	GeeArrayList* _tmp64_;
	gint _tmp65_;
	gint _tmp66_;
	gboolean _tmp67_ = FALSE;
	gboolean _tmp68_;
	ProgressDialog* _tmp101_;
	AppWindow* _tmp103_;
	AppWindow* _tmp104_;
#line 929 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (GEE_IS_COLLECTION (sources));
#line 929 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (dialog_title != NULL);
#line 929 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (progress_dialog_text != NULL);
#line 931 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = gee_collection_get_size (sources);
#line 931 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = _tmp0_;
#line 931 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp1_ == 0) {
#line 932 "/home/jens/Source/shotwell/src/Dialogs.vala"
		return;
#line 8468 "Dialogs.c"
	}
#line 934 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = gee_array_list_new (TYPE_LIBRARY_PHOTO, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, NULL, NULL, NULL);
#line 934 "/home/jens/Source/shotwell/src/Dialogs.vala"
	photos = _tmp2_;
#line 935 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = gee_array_list_new (TYPE_VIDEO, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, NULL, NULL, NULL);
#line 935 "/home/jens/Source/shotwell/src/Dialogs.vala"
	videos = _tmp3_;
#line 936 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = photos;
#line 936 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = videos;
#line 936 "/home/jens/Source/shotwell/src/Dialogs.vala"
	media_source_collection_filter_media (sources, G_TYPE_CHECK_INSTANCE_CAST (_tmp4_, GEE_TYPE_COLLECTION, GeeCollection), G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, GEE_TYPE_COLLECTION, GeeCollection));
#line 938 "/home/jens/Source/shotwell/src/Dialogs.vala"
	user_message = NULL;
#line 939 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp7_ = photos;
#line 939 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp8_ = gee_collection_get_is_empty (G_TYPE_CHECK_INSTANCE_CAST (_tmp7_, GEE_TYPE_COLLECTION, GeeCollection));
#line 939 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp9_ = _tmp8_;
#line 939 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (!_tmp9_) {
#line 8494 "Dialogs.c"
		GeeArrayList* _tmp10_;
		gboolean _tmp11_;
		gboolean _tmp12_;
#line 939 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp10_ = videos;
#line 939 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp11_ = gee_collection_get_is_empty (G_TYPE_CHECK_INSTANCE_CAST (_tmp10_, GEE_TYPE_COLLECTION, GeeCollection));
#line 939 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp12_ = _tmp11_;
#line 939 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp6_ = !_tmp12_;
#line 8506 "Dialogs.c"
	} else {
#line 939 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp6_ = FALSE;
#line 8510 "Dialogs.c"
	}
#line 939 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp6_) {
#line 8514 "Dialogs.c"
		gint _tmp13_;
		gint _tmp14_;
		gint _tmp15_;
		gint _tmp16_;
		gchar* _tmp17_;
#line 940 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp13_ = gee_collection_get_size (sources);
#line 940 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp14_ = _tmp13_;
#line 940 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp15_ = gee_collection_get_size (sources);
#line 940 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp16_ = _tmp15_;
#line 940 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp17_ = g_strdup_printf (ngettext ("This will remove the photo/video from your Shotwell library. Would you" \
" also like to move the file to your desktop trash?\n" \
"\n" \
"This action cannot be undone.", "This will remove %d photos/videos from your Shotwell library. Would yo" \
"u also like to move the files to your desktop trash?\n" \
"\n" \
"This action cannot be undone.", (gulong) _tmp14_), _tmp16_);
#line 940 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (user_message);
#line 940 "/home/jens/Source/shotwell/src/Dialogs.vala"
		user_message = _tmp17_;
#line 8534 "Dialogs.c"
	} else {
		GeeArrayList* _tmp18_;
		gboolean _tmp19_;
		gboolean _tmp20_;
#line 943 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp18_ = videos;
#line 943 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp19_ = gee_collection_get_is_empty (G_TYPE_CHECK_INSTANCE_CAST (_tmp18_, GEE_TYPE_COLLECTION, GeeCollection));
#line 943 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp20_ = _tmp19_;
#line 943 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (!_tmp20_) {
#line 8547 "Dialogs.c"
			gint _tmp21_;
			gint _tmp22_;
			gint _tmp23_;
			gint _tmp24_;
			gchar* _tmp25_;
#line 944 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp21_ = gee_collection_get_size (sources);
#line 944 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp22_ = _tmp21_;
#line 944 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp23_ = gee_collection_get_size (sources);
#line 944 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp24_ = _tmp23_;
#line 944 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp25_ = g_strdup_printf (ngettext ("This will remove the video from your Shotwell library. Would you also " \
"like to move the file to your desktop trash?\n" \
"\n" \
"This action cannot be undone.", "This will remove %d videos from your Shotwell library. Would you also " \
"like to move the files to your desktop trash?\n" \
"\n" \
"This action cannot be undone.", (gulong) _tmp22_), _tmp24_);
#line 944 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_free0 (user_message);
#line 944 "/home/jens/Source/shotwell/src/Dialogs.vala"
			user_message = _tmp25_;
#line 8567 "Dialogs.c"
		} else {
			gint _tmp26_;
			gint _tmp27_;
			gint _tmp28_;
			gint _tmp29_;
			gchar* _tmp30_;
#line 948 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp26_ = gee_collection_get_size (sources);
#line 948 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp27_ = _tmp26_;
#line 948 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp28_ = gee_collection_get_size (sources);
#line 948 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp29_ = _tmp28_;
#line 948 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp30_ = g_strdup_printf (ngettext ("This will remove the photo from your Shotwell library. Would you also " \
"like to move the file to your desktop trash?\n" \
"\n" \
"This action cannot be undone.", "This will remove %d photos from your Shotwell library. Would you also " \
"like to move the files to your desktop trash?\n" \
"\n" \
"This action cannot be undone.", (gulong) _tmp27_), _tmp29_);
#line 948 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_free0 (user_message);
#line 948 "/home/jens/Source/shotwell/src/Dialogs.vala"
			user_message = _tmp30_;
#line 8588 "Dialogs.c"
		}
	}
#line 953 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp31_ = app_window_get_instance ();
#line 953 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp32_ = _tmp31_;
#line 953 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp33_ = user_message;
#line 953 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp34_ = gee_collection_get_size (sources);
#line 953 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp35_ = _tmp34_;
#line 953 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp36_ = remove_from_library_dialog (G_TYPE_CHECK_INSTANCE_CAST (_tmp32_, gtk_window_get_type (), GtkWindow), dialog_title, _tmp33_, _tmp35_);
#line 953 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (_tmp32_);
#line 953 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_result_ = _tmp36_;
#line 955 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp38_ = _result_;
#line 955 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp38_ != GTK_RESPONSE_YES) {
#line 8611 "Dialogs.c"
		GtkResponseType _tmp39_;
#line 955 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp39_ = _result_;
#line 955 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp37_ = _tmp39_ != GTK_RESPONSE_NO;
#line 8617 "Dialogs.c"
	} else {
#line 955 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp37_ = FALSE;
#line 8621 "Dialogs.c"
	}
#line 955 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp37_) {
#line 956 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (user_message);
#line 956 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (videos);
#line 956 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (photos);
#line 956 "/home/jens/Source/shotwell/src/Dialogs.vala"
		return;
#line 8633 "Dialogs.c"
	}
#line 958 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp40_ = _result_;
#line 958 "/home/jens/Source/shotwell/src/Dialogs.vala"
	delete_backing = _tmp40_ == GTK_RESPONSE_YES;
#line 960 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp41_ = app_window_get_instance ();
#line 960 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp42_ = _tmp41_;
#line 960 "/home/jens/Source/shotwell/src/Dialogs.vala"
	page_window_set_busy_cursor (G_TYPE_CHECK_INSTANCE_CAST (_tmp42_, TYPE_PAGE_WINDOW, PageWindow));
#line 960 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (_tmp42_);
#line 962 "/home/jens/Source/shotwell/src/Dialogs.vala"
	progress = NULL;
#line 963 "/home/jens/Source/shotwell/src/Dialogs.vala"
	monitor = NULL;
#line 963 "/home/jens/Source/shotwell/src/Dialogs.vala"
	monitor_target = NULL;
#line 963 "/home/jens/Source/shotwell/src/Dialogs.vala"
	monitor_target_destroy_notify = NULL;
#line 964 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp43_ = gee_collection_get_size (sources);
#line 964 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp44_ = _tmp43_;
#line 964 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp44_ >= 20) {
#line 8661 "Dialogs.c"
		AppWindow* _tmp45_;
		AppWindow* _tmp46_;
		ProgressDialog* _tmp47_;
		ProgressDialog* _tmp48_;
#line 965 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp45_ = app_window_get_instance ();
#line 965 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp46_ = _tmp45_;
#line 965 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp47_ = progress_dialog_new (G_TYPE_CHECK_INSTANCE_CAST (_tmp46_, gtk_window_get_type (), GtkWindow), progress_dialog_text, NULL);
#line 965 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_object_ref_sink (_tmp47_);
#line 965 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (progress);
#line 965 "/home/jens/Source/shotwell/src/Dialogs.vala"
		progress = _tmp47_;
#line 965 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (_tmp46_);
#line 966 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp48_ = progress;
#line 966 "/home/jens/Source/shotwell/src/Dialogs.vala"
		(monitor_target_destroy_notify == NULL) ? NULL : (monitor_target_destroy_notify (monitor_target), NULL);
#line 966 "/home/jens/Source/shotwell/src/Dialogs.vala"
		monitor = NULL;
#line 966 "/home/jens/Source/shotwell/src/Dialogs.vala"
		monitor_target = NULL;
#line 966 "/home/jens/Source/shotwell/src/Dialogs.vala"
		monitor_target_destroy_notify = NULL;
#line 966 "/home/jens/Source/shotwell/src/Dialogs.vala"
		monitor = _progress_dialog_monitor_progress_monitor;
#line 966 "/home/jens/Source/shotwell/src/Dialogs.vala"
		monitor_target = g_object_ref (_tmp48_);
#line 966 "/home/jens/Source/shotwell/src/Dialogs.vala"
		monitor_target_destroy_notify = g_object_unref;
#line 8696 "Dialogs.c"
	}
#line 969 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp49_ = gee_array_list_new (TYPE_LIBRARY_PHOTO, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, NULL, NULL, NULL);
#line 969 "/home/jens/Source/shotwell/src/Dialogs.vala"
	not_removed_photos = _tmp49_;
#line 970 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp50_ = gee_array_list_new (TYPE_VIDEO, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, NULL, NULL, NULL);
#line 970 "/home/jens/Source/shotwell/src/Dialogs.vala"
	not_removed_videos = _tmp50_;
#line 973 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp51_ = library_photo_global;
#line 973 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp52_ = photos;
#line 973 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp53_ = delete_backing;
#line 973 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp54_ = monitor;
#line 973 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp54__target = monitor_target;
#line 973 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp55_ = not_removed_photos;
#line 973 "/home/jens/Source/shotwell/src/Dialogs.vala"
	media_source_collection_remove_from_app (G_TYPE_CHECK_INSTANCE_CAST (_tmp51_, TYPE_MEDIA_SOURCE_COLLECTION, MediaSourceCollection), G_TYPE_CHECK_INSTANCE_CAST (_tmp52_, GEE_TYPE_COLLECTION, GeeCollection), _tmp53_, _tmp54_, _tmp54__target, G_TYPE_CHECK_INSTANCE_CAST (_tmp55_, GEE_TYPE_LIST, GeeList));
#line 974 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp56_ = video_global;
#line 974 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp57_ = videos;
#line 974 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp58_ = delete_backing;
#line 974 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp59_ = monitor;
#line 974 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp59__target = monitor_target;
#line 974 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp60_ = not_removed_videos;
#line 974 "/home/jens/Source/shotwell/src/Dialogs.vala"
	media_source_collection_remove_from_app (G_TYPE_CHECK_INSTANCE_CAST (_tmp56_, TYPE_MEDIA_SOURCE_COLLECTION, MediaSourceCollection), G_TYPE_CHECK_INSTANCE_CAST (_tmp57_, GEE_TYPE_COLLECTION, GeeCollection), _tmp58_, _tmp59_, _tmp59__target, G_TYPE_CHECK_INSTANCE_CAST (_tmp60_, GEE_TYPE_LIST, GeeList));
#line 977 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp61_ = not_removed_photos;
#line 977 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp62_ = gee_abstract_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp61_, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection));
#line 977 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp63_ = _tmp62_;
#line 977 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp64_ = not_removed_videos;
#line 977 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp65_ = gee_abstract_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp64_, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection));
#line 977 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp66_ = _tmp65_;
#line 977 "/home/jens/Source/shotwell/src/Dialogs.vala"
	num_not_removed = _tmp63_ + _tmp66_;
#line 978 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp68_ = delete_backing;
#line 978 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp68_) {
#line 8752 "Dialogs.c"
		gint _tmp69_;
#line 978 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp69_ = num_not_removed;
#line 978 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp67_ = _tmp69_ > 0;
#line 8758 "Dialogs.c"
	} else {
#line 978 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp67_ = FALSE;
#line 8762 "Dialogs.c"
	}
#line 978 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp67_) {
#line 8766 "Dialogs.c"
		gchar* not_deleted_message = NULL;
		gint _tmp70_;
		gint _tmp71_;
		gchar* _tmp72_;
		GtkResponseType result_delete = 0;
		AppWindow* _tmp73_;
		AppWindow* _tmp74_;
		const gchar* _tmp75_;
		GtkResponseType _tmp76_;
		GtkResponseType _tmp77_;
#line 979 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp70_ = num_not_removed;
#line 979 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp71_ = num_not_removed;
#line 979 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp72_ = g_strdup_printf (ngettext ("The photo or video cannot be moved to your desktop trash. Delete this " \
"file?", "%d photos/videos cannot be moved to your desktop trash. Delete these f" \
"iles?", (gulong) _tmp70_), _tmp71_);
#line 979 "/home/jens/Source/shotwell/src/Dialogs.vala"
		not_deleted_message = _tmp72_;
#line 983 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp73_ = app_window_get_instance ();
#line 983 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp74_ = _tmp73_;
#line 983 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp75_ = not_deleted_message;
#line 983 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp76_ = remove_from_filesystem_dialog (G_TYPE_CHECK_INSTANCE_CAST (_tmp74_, gtk_window_get_type (), GtkWindow), dialog_title, _tmp75_);
#line 983 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (_tmp74_);
#line 983 "/home/jens/Source/shotwell/src/Dialogs.vala"
		result_delete = _tmp76_;
#line 986 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp77_ = result_delete;
#line 986 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (GTK_RESPONSE_YES == _tmp77_) {
#line 8801 "Dialogs.c"
			GeeArrayList* not_deleted_photos = NULL;
			GeeArrayList* _tmp78_;
			GeeArrayList* not_deleted_videos = NULL;
			GeeArrayList* _tmp79_;
			LibraryPhotoSourceCollection* _tmp80_;
			GeeArrayList* _tmp81_;
			ProgressMonitor _tmp82_;
			void* _tmp82__target;
			GeeArrayList* _tmp83_;
			VideoSourceCollection* _tmp84_;
			GeeArrayList* _tmp85_;
			ProgressMonitor _tmp86_;
			void* _tmp86__target;
			GeeArrayList* _tmp87_;
			gint num_not_deleted = 0;
			GeeArrayList* _tmp88_;
			gint _tmp89_;
			gint _tmp90_;
			GeeArrayList* _tmp91_;
			gint _tmp92_;
			gint _tmp93_;
			gint _tmp94_;
#line 988 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp78_ = gee_array_list_new (TYPE_LIBRARY_PHOTO, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, NULL, NULL, NULL);
#line 988 "/home/jens/Source/shotwell/src/Dialogs.vala"
			not_deleted_photos = _tmp78_;
#line 989 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp79_ = gee_array_list_new (TYPE_VIDEO, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, NULL, NULL, NULL);
#line 989 "/home/jens/Source/shotwell/src/Dialogs.vala"
			not_deleted_videos = _tmp79_;
#line 990 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp80_ = library_photo_global;
#line 990 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp81_ = not_removed_photos;
#line 990 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp82_ = monitor;
#line 990 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp82__target = monitor_target;
#line 990 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp83_ = not_deleted_photos;
#line 990 "/home/jens/Source/shotwell/src/Dialogs.vala"
			media_source_collection_delete_backing_files (G_TYPE_CHECK_INSTANCE_CAST (_tmp80_, TYPE_MEDIA_SOURCE_COLLECTION, MediaSourceCollection), G_TYPE_CHECK_INSTANCE_CAST (_tmp81_, GEE_TYPE_COLLECTION, GeeCollection), _tmp82_, _tmp82__target, G_TYPE_CHECK_INSTANCE_CAST (_tmp83_, GEE_TYPE_LIST, GeeList));
#line 991 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp84_ = video_global;
#line 991 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp85_ = not_removed_videos;
#line 991 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp86_ = monitor;
#line 991 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp86__target = monitor_target;
#line 991 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp87_ = not_deleted_videos;
#line 991 "/home/jens/Source/shotwell/src/Dialogs.vala"
			media_source_collection_delete_backing_files (G_TYPE_CHECK_INSTANCE_CAST (_tmp84_, TYPE_MEDIA_SOURCE_COLLECTION, MediaSourceCollection), G_TYPE_CHECK_INSTANCE_CAST (_tmp85_, GEE_TYPE_COLLECTION, GeeCollection), _tmp86_, _tmp86__target, G_TYPE_CHECK_INSTANCE_CAST (_tmp87_, GEE_TYPE_LIST, GeeList));
#line 993 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp88_ = not_deleted_photos;
#line 993 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp89_ = gee_abstract_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp88_, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection));
#line 993 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp90_ = _tmp89_;
#line 993 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp91_ = not_deleted_videos;
#line 993 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp92_ = gee_abstract_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp91_, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection));
#line 993 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp93_ = _tmp92_;
#line 993 "/home/jens/Source/shotwell/src/Dialogs.vala"
			num_not_deleted = _tmp90_ + _tmp93_;
#line 994 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp94_ = num_not_deleted;
#line 994 "/home/jens/Source/shotwell/src/Dialogs.vala"
			if (_tmp94_ > 0) {
#line 8874 "Dialogs.c"
				gchar* delete_failed_message = NULL;
				gint _tmp95_;
				gint _tmp96_;
				gchar* _tmp97_;
				const gchar* _tmp98_;
				AppWindow* _tmp99_;
				AppWindow* _tmp100_;
#line 996 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp95_ = num_not_deleted;
#line 996 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp96_ = num_not_deleted;
#line 996 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp97_ = g_strdup_printf (ngettext ("The photo or video cannot be deleted.", "%d photos/videos cannot be deleted.", (gulong) _tmp95_), _tmp96_);
#line 996 "/home/jens/Source/shotwell/src/Dialogs.vala"
				delete_failed_message = _tmp97_;
#line 1000 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp98_ = delete_failed_message;
#line 1000 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp99_ = app_window_get_instance ();
#line 1000 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp100_ = _tmp99_;
#line 1000 "/home/jens/Source/shotwell/src/Dialogs.vala"
				app_window_error_message_with_title (dialog_title, _tmp98_, G_TYPE_CHECK_INSTANCE_CAST (_tmp100_, gtk_window_get_type (), GtkWindow), TRUE);
#line 1000 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_object_unref0 (_tmp100_);
#line 994 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (delete_failed_message);
#line 8902 "Dialogs.c"
			}
#line 986 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_object_unref0 (not_deleted_videos);
#line 986 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_object_unref0 (not_deleted_photos);
#line 8908 "Dialogs.c"
		}
#line 978 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (not_deleted_message);
#line 8912 "Dialogs.c"
	}
#line 1005 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp101_ = progress;
#line 1005 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp101_ != NULL) {
#line 8918 "Dialogs.c"
		ProgressDialog* _tmp102_;
#line 1006 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp102_ = progress;
#line 1006 "/home/jens/Source/shotwell/src/Dialogs.vala"
		progress_dialog_close (_tmp102_);
#line 8924 "Dialogs.c"
	}
#line 1008 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp103_ = app_window_get_instance ();
#line 1008 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp104_ = _tmp103_;
#line 1008 "/home/jens/Source/shotwell/src/Dialogs.vala"
	page_window_set_normal_cursor (G_TYPE_CHECK_INSTANCE_CAST (_tmp104_, TYPE_PAGE_WINDOW, PageWindow));
#line 1008 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (_tmp104_);
#line 929 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (not_removed_videos);
#line 929 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (not_removed_photos);
#line 929 "/home/jens/Source/shotwell/src/Dialogs.vala"
	(monitor_target_destroy_notify == NULL) ? NULL : (monitor_target_destroy_notify (monitor_target), NULL);
#line 929 "/home/jens/Source/shotwell/src/Dialogs.vala"
	monitor = NULL;
#line 929 "/home/jens/Source/shotwell/src/Dialogs.vala"
	monitor_target = NULL;
#line 929 "/home/jens/Source/shotwell/src/Dialogs.vala"
	monitor_target_destroy_notify = NULL;
#line 929 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (progress);
#line 929 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (user_message);
#line 929 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (videos);
#line 929 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (photos);
#line 8954 "Dialogs.c"
}


static void
_vala_array_destroy (gpointer array,
                     gint array_length,
                     GDestroyNotify destroy_func)
{
	if ((array != NULL) && (destroy_func != NULL)) {
		int i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}


static void
_vala_array_free (gpointer array,
                  gint array_length,
                  GDestroyNotify destroy_func)
{
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}


static gint
_vala_array_length (gpointer array)
{
	int length;
	length = 0;
	if (array) {
		while (((gpointer*) array)[length]) {
			length++;
		}
	}
	return length;
}



