/* FlickrPublishing.c generated by valac 0.40.4, the Vala compiler
 * generated from FlickrPublishing.vala, do not modify */

/* Copyright 2016 Software Freedom Conservancy Inc.
 *
 * This software is licensed under the GNU Lesser General Public License
 * (version 2.1 or later).  See the COPYING file in this distribution.
 */


#include <glib.h>
#include <glib-object.h>
#include <shotwell-plugin-dev-1.0.h>
#include <gdk-pixbuf/gdk-pixbuf.h>
#include <stdlib.h>
#include <string.h>
#include <gio/gio.h>
#include "shotwell-plugin-common.h"
#include <glib/gi18n-lib.h>
#include "shotwell-authenticator.h"
#include <float.h>
#include <math.h>
#include <libxml/tree.h>
#include <gtk/gtk.h>
#include <gee.h>
#include <libsoup/soup.h>
#include <gexiv2/gexiv2.h>
#include <gobject/gvaluecollector.h>


#define TYPE_FLICKR_SERVICE (flickr_service_get_type ())
#define FLICKR_SERVICE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_FLICKR_SERVICE, FlickrService))
#define FLICKR_SERVICE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_FLICKR_SERVICE, FlickrServiceClass))
#define IS_FLICKR_SERVICE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_FLICKR_SERVICE))
#define IS_FLICKR_SERVICE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_FLICKR_SERVICE))
#define FLICKR_SERVICE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_FLICKR_SERVICE, FlickrServiceClass))

typedef struct _FlickrService FlickrService;
typedef struct _FlickrServiceClass FlickrServiceClass;
typedef struct _FlickrServicePrivate FlickrServicePrivate;
enum  {
	FLICKR_SERVICE_0_PROPERTY,
	FLICKR_SERVICE_NUM_PROPERTIES
};
static GParamSpec* flickr_service_properties[FLICKR_SERVICE_NUM_PROPERTIES];
#define _g_free0(var) (var = (g_free (var), NULL))

#define PUBLISHING_FLICKR_TYPE_FLICKR_PUBLISHER (publishing_flickr_flickr_publisher_get_type ())
#define PUBLISHING_FLICKR_FLICKR_PUBLISHER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_FLICKR_TYPE_FLICKR_PUBLISHER, PublishingFlickrFlickrPublisher))
#define PUBLISHING_FLICKR_FLICKR_PUBLISHER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_FLICKR_TYPE_FLICKR_PUBLISHER, PublishingFlickrFlickrPublisherClass))
#define PUBLISHING_FLICKR_IS_FLICKR_PUBLISHER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_FLICKR_TYPE_FLICKR_PUBLISHER))
#define PUBLISHING_FLICKR_IS_FLICKR_PUBLISHER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_FLICKR_TYPE_FLICKR_PUBLISHER))
#define PUBLISHING_FLICKR_FLICKR_PUBLISHER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_FLICKR_TYPE_FLICKR_PUBLISHER, PublishingFlickrFlickrPublisherClass))

typedef struct _PublishingFlickrFlickrPublisher PublishingFlickrFlickrPublisher;
typedef struct _PublishingFlickrFlickrPublisherClass PublishingFlickrFlickrPublisherClass;

#define PUBLISHING_FLICKR_TYPE_USER_KIND (publishing_flickr_user_kind_get_type ())

#define PUBLISHING_FLICKR_TYPE_VISIBILITY_SPECIFICATION (publishing_flickr_visibility_specification_get_type ())
#define PUBLISHING_FLICKR_VISIBILITY_SPECIFICATION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_FLICKR_TYPE_VISIBILITY_SPECIFICATION, PublishingFlickrVisibilitySpecification))
#define PUBLISHING_FLICKR_VISIBILITY_SPECIFICATION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_FLICKR_TYPE_VISIBILITY_SPECIFICATION, PublishingFlickrVisibilitySpecificationClass))
#define PUBLISHING_FLICKR_IS_VISIBILITY_SPECIFICATION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_FLICKR_TYPE_VISIBILITY_SPECIFICATION))
#define PUBLISHING_FLICKR_IS_VISIBILITY_SPECIFICATION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_FLICKR_TYPE_VISIBILITY_SPECIFICATION))
#define PUBLISHING_FLICKR_VISIBILITY_SPECIFICATION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_FLICKR_TYPE_VISIBILITY_SPECIFICATION, PublishingFlickrVisibilitySpecificationClass))

typedef struct _PublishingFlickrVisibilitySpecification PublishingFlickrVisibilitySpecification;
typedef struct _PublishingFlickrVisibilitySpecificationClass PublishingFlickrVisibilitySpecificationClass;
typedef struct _PublishingFlickrVisibilitySpecificationPrivate PublishingFlickrVisibilitySpecificationPrivate;
typedef struct _PublishingFlickrParamSpecVisibilitySpecification PublishingFlickrParamSpecVisibilitySpecification;

#define PUBLISHING_FLICKR_TYPE_PUBLISHING_PARAMETERS (publishing_flickr_publishing_parameters_get_type ())
#define PUBLISHING_FLICKR_PUBLISHING_PARAMETERS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_FLICKR_TYPE_PUBLISHING_PARAMETERS, PublishingFlickrPublishingParameters))
#define PUBLISHING_FLICKR_PUBLISHING_PARAMETERS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_FLICKR_TYPE_PUBLISHING_PARAMETERS, PublishingFlickrPublishingParametersClass))
#define PUBLISHING_FLICKR_IS_PUBLISHING_PARAMETERS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_FLICKR_TYPE_PUBLISHING_PARAMETERS))
#define PUBLISHING_FLICKR_IS_PUBLISHING_PARAMETERS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_FLICKR_TYPE_PUBLISHING_PARAMETERS))
#define PUBLISHING_FLICKR_PUBLISHING_PARAMETERS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_FLICKR_TYPE_PUBLISHING_PARAMETERS, PublishingFlickrPublishingParametersClass))

typedef struct _PublishingFlickrPublishingParameters PublishingFlickrPublishingParameters;
typedef struct _PublishingFlickrPublishingParametersClass PublishingFlickrPublishingParametersClass;
typedef struct _PublishingFlickrPublishingParametersPrivate PublishingFlickrPublishingParametersPrivate;
#define _publishing_flickr_visibility_specification_unref0(var) ((var == NULL) ? NULL : (var = (publishing_flickr_visibility_specification_unref (var), NULL)))
typedef struct _PublishingFlickrParamSpecPublishingParameters PublishingFlickrParamSpecPublishingParameters;
typedef struct _PublishingFlickrFlickrPublisherPrivate PublishingFlickrFlickrPublisherPrivate;

#define PUBLISHING_FLICKR_TYPE_PUBLISHING_OPTIONS_PANE (publishing_flickr_publishing_options_pane_get_type ())
#define PUBLISHING_FLICKR_PUBLISHING_OPTIONS_PANE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_FLICKR_TYPE_PUBLISHING_OPTIONS_PANE, PublishingFlickrPublishingOptionsPane))
#define PUBLISHING_FLICKR_PUBLISHING_OPTIONS_PANE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_FLICKR_TYPE_PUBLISHING_OPTIONS_PANE, PublishingFlickrPublishingOptionsPaneClass))
#define PUBLISHING_FLICKR_IS_PUBLISHING_OPTIONS_PANE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_FLICKR_TYPE_PUBLISHING_OPTIONS_PANE))
#define PUBLISHING_FLICKR_IS_PUBLISHING_OPTIONS_PANE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_FLICKR_TYPE_PUBLISHING_OPTIONS_PANE))
#define PUBLISHING_FLICKR_PUBLISHING_OPTIONS_PANE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_FLICKR_TYPE_PUBLISHING_OPTIONS_PANE, PublishingFlickrPublishingOptionsPaneClass))

typedef struct _PublishingFlickrPublishingOptionsPane PublishingFlickrPublishingOptionsPane;
typedef struct _PublishingFlickrPublishingOptionsPaneClass PublishingFlickrPublishingOptionsPaneClass;
enum  {
	PUBLISHING_FLICKR_FLICKR_PUBLISHER_0_PROPERTY,
	PUBLISHING_FLICKR_FLICKR_PUBLISHER_NUM_PROPERTIES
};
static GParamSpec* publishing_flickr_flickr_publisher_properties[PUBLISHING_FLICKR_FLICKR_PUBLISHER_NUM_PROPERTIES];
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _publishing_rest_support_session_unref0(var) ((var == NULL) ? NULL : (var = (publishing_rest_support_session_unref (var), NULL)))
#define _publishing_flickr_publishing_parameters_unref0(var) ((var == NULL) ? NULL : (var = (publishing_flickr_publishing_parameters_unref (var), NULL)))
#define _g_variant_unref0(var) ((var == NULL) ? NULL : (var = (g_variant_unref (var), NULL)))
#define _g_hash_table_unref0(var) ((var == NULL) ? NULL : (var = (g_hash_table_unref (var), NULL)))

#define PUBLISHING_FLICKR_TYPE_ACCOUNT_INFO_FETCH_TRANSACTION (publishing_flickr_account_info_fetch_transaction_get_type ())
#define PUBLISHING_FLICKR_ACCOUNT_INFO_FETCH_TRANSACTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_FLICKR_TYPE_ACCOUNT_INFO_FETCH_TRANSACTION, PublishingFlickrAccountInfoFetchTransaction))
#define PUBLISHING_FLICKR_ACCOUNT_INFO_FETCH_TRANSACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_FLICKR_TYPE_ACCOUNT_INFO_FETCH_TRANSACTION, PublishingFlickrAccountInfoFetchTransactionClass))
#define PUBLISHING_FLICKR_IS_ACCOUNT_INFO_FETCH_TRANSACTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_FLICKR_TYPE_ACCOUNT_INFO_FETCH_TRANSACTION))
#define PUBLISHING_FLICKR_IS_ACCOUNT_INFO_FETCH_TRANSACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_FLICKR_TYPE_ACCOUNT_INFO_FETCH_TRANSACTION))
#define PUBLISHING_FLICKR_ACCOUNT_INFO_FETCH_TRANSACTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_FLICKR_TYPE_ACCOUNT_INFO_FETCH_TRANSACTION, PublishingFlickrAccountInfoFetchTransactionClass))

typedef struct _PublishingFlickrAccountInfoFetchTransaction PublishingFlickrAccountInfoFetchTransaction;
typedef struct _PublishingFlickrAccountInfoFetchTransactionClass PublishingFlickrAccountInfoFetchTransactionClass;
#define _publishing_rest_support_transaction_unref0(var) ((var == NULL) ? NULL : (var = (publishing_rest_support_transaction_unref (var), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
#define _publishing_rest_support_xml_document_unref0(var) ((var == NULL) ? NULL : (var = (publishing_rest_support_xml_document_unref (var), NULL)))
#define _g_date_time_unref0(var) ((var == NULL) ? NULL : (var = (g_date_time_unref (var), NULL)))

#define PUBLISHING_FLICKR_TYPE_UPLOADER (publishing_flickr_uploader_get_type ())
#define PUBLISHING_FLICKR_UPLOADER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_FLICKR_TYPE_UPLOADER, PublishingFlickrUploader))
#define PUBLISHING_FLICKR_UPLOADER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_FLICKR_TYPE_UPLOADER, PublishingFlickrUploaderClass))
#define PUBLISHING_FLICKR_IS_UPLOADER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_FLICKR_TYPE_UPLOADER))
#define PUBLISHING_FLICKR_IS_UPLOADER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_FLICKR_TYPE_UPLOADER))
#define PUBLISHING_FLICKR_UPLOADER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_FLICKR_TYPE_UPLOADER, PublishingFlickrUploaderClass))

typedef struct _PublishingFlickrUploader PublishingFlickrUploader;
typedef struct _PublishingFlickrUploaderClass PublishingFlickrUploaderClass;
#define _publishing_rest_support_batch_uploader_unref0(var) ((var == NULL) ? NULL : (var = (publishing_rest_support_batch_uploader_unref (var), NULL)))
typedef struct _PublishingFlickrAccountInfoFetchTransactionPrivate PublishingFlickrAccountInfoFetchTransactionPrivate;

#define PUBLISHING_FLICKR_TYPE_UPLOAD_TRANSACTION (publishing_flickr_upload_transaction_get_type ())
#define PUBLISHING_FLICKR_UPLOAD_TRANSACTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_FLICKR_TYPE_UPLOAD_TRANSACTION, PublishingFlickrUploadTransaction))
#define PUBLISHING_FLICKR_UPLOAD_TRANSACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_FLICKR_TYPE_UPLOAD_TRANSACTION, PublishingFlickrUploadTransactionClass))
#define PUBLISHING_FLICKR_IS_UPLOAD_TRANSACTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_FLICKR_TYPE_UPLOAD_TRANSACTION))
#define PUBLISHING_FLICKR_IS_UPLOAD_TRANSACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_FLICKR_TYPE_UPLOAD_TRANSACTION))
#define PUBLISHING_FLICKR_UPLOAD_TRANSACTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_FLICKR_TYPE_UPLOAD_TRANSACTION, PublishingFlickrUploadTransactionClass))

typedef struct _PublishingFlickrUploadTransaction PublishingFlickrUploadTransaction;
typedef struct _PublishingFlickrUploadTransactionClass PublishingFlickrUploadTransactionClass;
typedef struct _PublishingFlickrUploadTransactionPrivate PublishingFlickrUploadTransactionPrivate;
typedef struct _PublishingFlickrPublishingOptionsPanePrivate PublishingFlickrPublishingOptionsPanePrivate;

#define PUBLISHING_FLICKR_PUBLISHING_OPTIONS_PANE_TYPE_VISIBILITY_ENTRY (publishing_flickr_publishing_options_pane_visibility_entry_get_type ())
#define PUBLISHING_FLICKR_PUBLISHING_OPTIONS_PANE_VISIBILITY_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_FLICKR_PUBLISHING_OPTIONS_PANE_TYPE_VISIBILITY_ENTRY, PublishingFlickrPublishingOptionsPaneVisibilityEntry))
#define PUBLISHING_FLICKR_PUBLISHING_OPTIONS_PANE_VISIBILITY_ENTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_FLICKR_PUBLISHING_OPTIONS_PANE_TYPE_VISIBILITY_ENTRY, PublishingFlickrPublishingOptionsPaneVisibilityEntryClass))
#define PUBLISHING_FLICKR_PUBLISHING_OPTIONS_PANE_IS_VISIBILITY_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_FLICKR_PUBLISHING_OPTIONS_PANE_TYPE_VISIBILITY_ENTRY))
#define PUBLISHING_FLICKR_PUBLISHING_OPTIONS_PANE_IS_VISIBILITY_ENTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_FLICKR_PUBLISHING_OPTIONS_PANE_TYPE_VISIBILITY_ENTRY))
#define PUBLISHING_FLICKR_PUBLISHING_OPTIONS_PANE_VISIBILITY_ENTRY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_FLICKR_PUBLISHING_OPTIONS_PANE_TYPE_VISIBILITY_ENTRY, PublishingFlickrPublishingOptionsPaneVisibilityEntryClass))

typedef struct _PublishingFlickrPublishingOptionsPaneVisibilityEntry PublishingFlickrPublishingOptionsPaneVisibilityEntry;
typedef struct _PublishingFlickrPublishingOptionsPaneVisibilityEntryClass PublishingFlickrPublishingOptionsPaneVisibilityEntryClass;

#define PUBLISHING_FLICKR_PUBLISHING_OPTIONS_PANE_TYPE_SIZE_ENTRY (publishing_flickr_publishing_options_pane_size_entry_get_type ())
#define PUBLISHING_FLICKR_PUBLISHING_OPTIONS_PANE_SIZE_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_FLICKR_PUBLISHING_OPTIONS_PANE_TYPE_SIZE_ENTRY, PublishingFlickrPublishingOptionsPaneSizeEntry))
#define PUBLISHING_FLICKR_PUBLISHING_OPTIONS_PANE_SIZE_ENTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_FLICKR_PUBLISHING_OPTIONS_PANE_TYPE_SIZE_ENTRY, PublishingFlickrPublishingOptionsPaneSizeEntryClass))
#define PUBLISHING_FLICKR_PUBLISHING_OPTIONS_PANE_IS_SIZE_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_FLICKR_PUBLISHING_OPTIONS_PANE_TYPE_SIZE_ENTRY))
#define PUBLISHING_FLICKR_PUBLISHING_OPTIONS_PANE_IS_SIZE_ENTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_FLICKR_PUBLISHING_OPTIONS_PANE_TYPE_SIZE_ENTRY))
#define PUBLISHING_FLICKR_PUBLISHING_OPTIONS_PANE_SIZE_ENTRY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_FLICKR_PUBLISHING_OPTIONS_PANE_TYPE_SIZE_ENTRY, PublishingFlickrPublishingOptionsPaneSizeEntryClass))

typedef struct _PublishingFlickrPublishingOptionsPaneSizeEntry PublishingFlickrPublishingOptionsPaneSizeEntry;
typedef struct _PublishingFlickrPublishingOptionsPaneSizeEntryClass PublishingFlickrPublishingOptionsPaneSizeEntryClass;
enum  {
	PUBLISHING_FLICKR_PUBLISHING_OPTIONS_PANE_0_PROPERTY,
	PUBLISHING_FLICKR_PUBLISHING_OPTIONS_PANE_NUM_PROPERTIES
};
static GParamSpec* publishing_flickr_publishing_options_pane_properties[PUBLISHING_FLICKR_PUBLISHING_OPTIONS_PANE_NUM_PROPERTIES];
#define _g_slist_free0(var) ((var == NULL) ? NULL : (var = (g_slist_free (var), NULL)))
typedef struct _PublishingFlickrPublishingOptionsPaneVisibilityEntryPrivate PublishingFlickrPublishingOptionsPaneVisibilityEntryPrivate;
typedef struct _PublishingFlickrPublishingOptionsPaneSizeEntryPrivate PublishingFlickrPublishingOptionsPaneSizeEntryPrivate;
#define _publishing_flickr_publishing_options_pane_visibility_entry_unref0(var) ((var == NULL) ? NULL : (var = (publishing_flickr_publishing_options_pane_visibility_entry_unref (var), NULL)))
#define _publishing_flickr_publishing_options_pane_size_entry_unref0(var) ((var == NULL) ? NULL : (var = (publishing_flickr_publishing_options_pane_size_entry_unref (var), NULL)))
typedef struct _PublishingFlickrPublishingOptionsPaneParamSpecSizeEntry PublishingFlickrPublishingOptionsPaneParamSpecSizeEntry;
typedef struct _PublishingFlickrPublishingOptionsPaneParamSpecVisibilityEntry PublishingFlickrPublishingOptionsPaneParamSpecVisibilityEntry;
enum  {
	PUBLISHING_FLICKR_PUBLISHING_OPTIONS_PANE_PUBLISH_SIGNAL,
	PUBLISHING_FLICKR_PUBLISHING_OPTIONS_PANE_LOGOUT_SIGNAL,
	PUBLISHING_FLICKR_PUBLISHING_OPTIONS_PANE_NUM_SIGNALS
};
static guint publishing_flickr_publishing_options_pane_signals[PUBLISHING_FLICKR_PUBLISHING_OPTIONS_PANE_NUM_SIGNALS] = {0};
typedef struct _PublishingFlickrUploaderPrivate PublishingFlickrUploaderPrivate;
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);
#define _vala_return_if_fail(expr, msg) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return; }
#define _vala_return_val_if_fail(expr, msg, val) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return val; }
#define _vala_warn_if_fail(expr, msg) if G_LIKELY (expr) ; else g_warn_message (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _FlickrService {
	GObject parent_instance;
	FlickrServicePrivate * priv;
};

struct _FlickrServiceClass {
	GObjectClass parent_class;
};

typedef enum  {
	PUBLISHING_FLICKR_USER_KIND_PRO,
	PUBLISHING_FLICKR_USER_KIND_FREE
} PublishingFlickrUserKind;

struct _PublishingFlickrVisibilitySpecification {
	GTypeInstance parent_instance;
	volatile int ref_count;
	PublishingFlickrVisibilitySpecificationPrivate * priv;
	gint friends_level;
	gint family_level;
	gint everyone_level;
};

struct _PublishingFlickrVisibilitySpecificationClass {
	GTypeClass parent_class;
	void (*finalize) (PublishingFlickrVisibilitySpecification *self);
};

struct _PublishingFlickrParamSpecVisibilitySpecification {
	GParamSpec parent_instance;
};

struct _PublishingFlickrPublishingParameters {
	GTypeInstance parent_instance;
	volatile int ref_count;
	PublishingFlickrPublishingParametersPrivate * priv;
	PublishingFlickrUserKind user_kind;
	gint64 quota_free_bytes;
	gint photo_major_axis_size;
	gchar* username;
	PublishingFlickrVisibilitySpecification* visibility_specification;
};

struct _PublishingFlickrPublishingParametersClass {
	GTypeClass parent_class;
	void (*finalize) (PublishingFlickrPublishingParameters *self);
};

struct _PublishingFlickrParamSpecPublishingParameters {
	GParamSpec parent_instance;
};

struct _PublishingFlickrFlickrPublisher {
	GObject parent_instance;
	PublishingFlickrFlickrPublisherPrivate * priv;
};

struct _PublishingFlickrFlickrPublisherClass {
	GObjectClass parent_class;
};

struct _PublishingFlickrFlickrPublisherPrivate {
	SpitPublishingService* service;
	SpitPublishingPluginHost* host;
	SpitPublishingProgressCallback progress_reporter;
	gpointer progress_reporter_target;
	GDestroyNotify progress_reporter_target_destroy_notify;
	gboolean running;
	gboolean was_started;
	PublishingRESTSupportOAuth1Session* session;
	PublishingFlickrPublishingOptionsPane* publishing_options_pane;
	SpitPublishingAuthenticator* authenticator;
	PublishingFlickrPublishingParameters* parameters;
};

struct _PublishingFlickrAccountInfoFetchTransaction {
	PublishingRESTSupportOAuth1Transaction parent_instance;
	PublishingFlickrAccountInfoFetchTransactionPrivate * priv;
};

struct _PublishingFlickrAccountInfoFetchTransactionClass {
	PublishingRESTSupportOAuth1TransactionClass parent_class;
};

struct _PublishingFlickrUploadTransaction {
	PublishingRESTSupportOAuth1UploadTransaction parent_instance;
	PublishingFlickrUploadTransactionPrivate * priv;
};

struct _PublishingFlickrUploadTransactionClass {
	PublishingRESTSupportOAuth1UploadTransactionClass parent_class;
};

struct _PublishingFlickrUploadTransactionPrivate {
	PublishingFlickrPublishingParameters* parameters;
};

struct _PublishingFlickrPublishingOptionsPane {
	GObject parent_instance;
	PublishingFlickrPublishingOptionsPanePrivate * priv;
};

struct _PublishingFlickrPublishingOptionsPaneClass {
	GObjectClass parent_class;
};

struct _PublishingFlickrPublishingOptionsPanePrivate {
	GtkBuilder* builder;
	GtkBox* pane_widget;
	GtkLabel* visibility_label;
	GtkLabel* upload_info_label;
	GtkLabel* size_label;
	GtkButton* logout_button;
	GtkButton* publish_button;
	GtkComboBoxText* visibility_combo;
	GtkComboBoxText* size_combo;
	GtkCheckButton* strip_metadata_check;
	PublishingFlickrPublishingOptionsPaneVisibilityEntry** visibilities;
	gint visibilities_length1;
	gint _visibilities_size_;
	PublishingFlickrPublishingOptionsPaneSizeEntry** sizes;
	gint sizes_length1;
	gint _sizes_size_;
	PublishingFlickrPublishingParameters* parameters;
	PublishingFlickrFlickrPublisher* publisher;
	SpitPublishingPublisherMediaType media_type;
};

struct _PublishingFlickrPublishingOptionsPaneVisibilityEntry {
	GTypeInstance parent_instance;
	volatile int ref_count;
	PublishingFlickrPublishingOptionsPaneVisibilityEntryPrivate * priv;
	PublishingFlickrVisibilitySpecification* specification;
	gchar* title;
};

struct _PublishingFlickrPublishingOptionsPaneVisibilityEntryClass {
	GTypeClass parent_class;
	void (*finalize) (PublishingFlickrPublishingOptionsPaneVisibilityEntry *self);
};

struct _PublishingFlickrPublishingOptionsPaneSizeEntry {
	GTypeInstance parent_instance;
	volatile int ref_count;
	PublishingFlickrPublishingOptionsPaneSizeEntryPrivate * priv;
	gchar* title;
	gint size;
};

struct _PublishingFlickrPublishingOptionsPaneSizeEntryClass {
	GTypeClass parent_class;
	void (*finalize) (PublishingFlickrPublishingOptionsPaneSizeEntry *self);
};

struct _PublishingFlickrPublishingOptionsPaneParamSpecSizeEntry {
	GParamSpec parent_instance;
};

struct _PublishingFlickrPublishingOptionsPaneParamSpecVisibilityEntry {
	GParamSpec parent_instance;
};

struct _PublishingFlickrUploader {
	PublishingRESTSupportBatchUploader parent_instance;
	PublishingFlickrUploaderPrivate * priv;
};

struct _PublishingFlickrUploaderClass {
	PublishingRESTSupportBatchUploaderClass parent_class;
};

struct _PublishingFlickrUploaderPrivate {
	PublishingFlickrPublishingParameters* parameters;
	gboolean strip_metadata;
};


static gpointer flickr_service_parent_class = NULL;
static GdkPixbuf** flickr_service_icon_pixbuf_set;
static gint flickr_service_icon_pixbuf_set_length1;
static GdkPixbuf** flickr_service_icon_pixbuf_set = NULL;
static gint flickr_service_icon_pixbuf_set_length1 = 0;
static gint _flickr_service_icon_pixbuf_set_size_ = 0;
static SpitPluggableIface * flickr_service_spit_pluggable_parent_iface = NULL;
static SpitPublishingServiceIface * flickr_service_spit_publishing_service_parent_iface = NULL;
static gpointer publishing_flickr_visibility_specification_parent_class = NULL;
static gpointer publishing_flickr_publishing_parameters_parent_class = NULL;
static gpointer publishing_flickr_flickr_publisher_parent_class = NULL;
static SpitPublishingPublisherIface * publishing_flickr_flickr_publisher_spit_publishing_publisher_parent_iface = NULL;
static gpointer publishing_flickr_account_info_fetch_transaction_parent_class = NULL;
static gpointer publishing_flickr_upload_transaction_parent_class = NULL;
static gpointer publishing_flickr_publishing_options_pane_parent_class = NULL;
static gpointer publishing_flickr_publishing_options_pane_size_entry_parent_class = NULL;
static gpointer publishing_flickr_publishing_options_pane_visibility_entry_parent_class = NULL;
static SpitPublishingDialogPaneIface * publishing_flickr_publishing_options_pane_spit_publishing_dialog_pane_parent_iface = NULL;
static gpointer publishing_flickr_uploader_parent_class = NULL;

GType flickr_service_get_type (void) G_GNUC_CONST;
#define FLICKR_SERVICE_ICON_FILENAME "flickr.png"
FlickrService* flickr_service_new (GFile* resource_directory);
FlickrService* flickr_service_construct (GType object_type,
                                         GFile* resource_directory);
static gint flickr_service_real_get_pluggable_interface (SpitPluggable* base,
                                                  gint min_host_interface,
                                                  gint max_host_interface);
static const gchar* flickr_service_real_get_id (SpitPluggable* base);
static const gchar* flickr_service_real_get_pluggable_name (SpitPluggable* base);
static void flickr_service_real_get_info (SpitPluggable* base,
                                   SpitPluggableInfo* info);
static GdkPixbuf** _vala_array_dup7 (GdkPixbuf** self,
                              int length);
static void flickr_service_real_activation (SpitPluggable* base,
                                     gboolean enabled);
static SpitPublishingPublisher* flickr_service_real_create_publisher (SpitPublishingService* base,
                                                               SpitPublishingPluginHost* host);
PublishingFlickrFlickrPublisher* publishing_flickr_flickr_publisher_new (SpitPublishingService* service,
                                                                         SpitPublishingPluginHost* host);
PublishingFlickrFlickrPublisher* publishing_flickr_flickr_publisher_construct (GType object_type,
                                                                               SpitPublishingService* service,
                                                                               SpitPublishingPluginHost* host);
GType publishing_flickr_flickr_publisher_get_type (void) G_GNUC_CONST;
static SpitPublishingPublisherMediaType flickr_service_real_get_supported_media (SpitPublishingService* base);
static void flickr_service_finalize (GObject * obj);
#define PUBLISHING_FLICKR_SERVICE_NAME "Flickr"
#define PUBLISHING_FLICKR_ENDPOINT_URL "https://api.flickr.com/services/rest"
#define PUBLISHING_FLICKR_ORIGINAL_SIZE -1
#define PUBLISHING_FLICKR_EXPIRED_SESSION_ERROR_CODE "98"
GType publishing_flickr_user_kind_get_type (void) G_GNUC_CONST;
gpointer publishing_flickr_visibility_specification_ref (gpointer instance);
void publishing_flickr_visibility_specification_unref (gpointer instance);
GParamSpec* publishing_flickr_param_spec_visibility_specification (const gchar* name,
                                                                   const gchar* nick,
                                                                   const gchar* blurb,
                                                                   GType object_type,
                                                                   GParamFlags flags);
void publishing_flickr_value_set_visibility_specification (GValue* value,
                                                           gpointer v_object);
void publishing_flickr_value_take_visibility_specification (GValue* value,
                                                            gpointer v_object);
gpointer publishing_flickr_value_get_visibility_specification (const GValue* value);
GType publishing_flickr_visibility_specification_get_type (void) G_GNUC_CONST;
PublishingFlickrVisibilitySpecification* publishing_flickr_visibility_specification_new (gint friends_level,
                                                                                         gint family_level,
                                                                                         gint everyone_level);
PublishingFlickrVisibilitySpecification* publishing_flickr_visibility_specification_construct (GType object_type,
                                                                                               gint friends_level,
                                                                                               gint family_level,
                                                                                               gint everyone_level);
static void publishing_flickr_visibility_specification_finalize (PublishingFlickrVisibilitySpecification * obj);
gpointer publishing_flickr_publishing_parameters_ref (gpointer instance);
void publishing_flickr_publishing_parameters_unref (gpointer instance);
GParamSpec* publishing_flickr_param_spec_publishing_parameters (const gchar* name,
                                                                const gchar* nick,
                                                                const gchar* blurb,
                                                                GType object_type,
                                                                GParamFlags flags);
void publishing_flickr_value_set_publishing_parameters (GValue* value,
                                                        gpointer v_object);
void publishing_flickr_value_take_publishing_parameters (GValue* value,
                                                         gpointer v_object);
gpointer publishing_flickr_value_get_publishing_parameters (const GValue* value);
GType publishing_flickr_publishing_parameters_get_type (void) G_GNUC_CONST;
PublishingFlickrPublishingParameters* publishing_flickr_publishing_parameters_new (void);
PublishingFlickrPublishingParameters* publishing_flickr_publishing_parameters_construct (GType object_type);
static void publishing_flickr_publishing_parameters_finalize (PublishingFlickrPublishingParameters * obj);
GType publishing_flickr_publishing_options_pane_get_type (void) G_GNUC_CONST;
#define PUBLISHING_FLICKR_FLICKR_PUBLISHER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PUBLISHING_FLICKR_TYPE_FLICKR_PUBLISHER, PublishingFlickrFlickrPublisherPrivate))
static void publishing_flickr_flickr_publisher_on_session_authenticated (PublishingFlickrFlickrPublisher* self);
static void _publishing_flickr_flickr_publisher_on_session_authenticated_spit_publishing_authenticator_authenticated (SpitPublishingAuthenticator* _sender,
                                                                                                               gpointer self);
SpitPublishingAuthenticator* publishing_flickr_flickr_publisher_get_authenticator (PublishingFlickrFlickrPublisher* self);
static gboolean publishing_flickr_flickr_publisher_get_persistent_strip_metadata (PublishingFlickrFlickrPublisher* self);
static void publishing_flickr_flickr_publisher_set_persistent_strip_metadata (PublishingFlickrFlickrPublisher* self,
                                                                       gboolean strip_metadata);
static void publishing_flickr_flickr_publisher_do_fetch_account_info (PublishingFlickrFlickrPublisher* self);
static void publishing_flickr_flickr_publisher_on_account_fetch_txn_completed (PublishingFlickrFlickrPublisher* self,
                                                                        PublishingRESTSupportTransaction* txn);
static void _publishing_flickr_flickr_publisher_on_account_fetch_txn_completed_publishing_rest_support_transaction_completed (PublishingRESTSupportTransaction* _sender,
                                                                                                                       gpointer self);
static void publishing_flickr_flickr_publisher_on_account_fetch_txn_error (PublishingFlickrFlickrPublisher* self,
                                                                    PublishingRESTSupportTransaction* txn,
                                                                    GError* err);
static void _publishing_flickr_flickr_publisher_on_account_fetch_txn_error_publishing_rest_support_transaction_network_error (PublishingRESTSupportTransaction* _sender,
                                                                                                                       GError* err,
                                                                                                                       gpointer self);
static void publishing_flickr_flickr_publisher_do_parse_account_info_from_xml (PublishingFlickrFlickrPublisher* self,
                                                                        const gchar* xml);
static void publishing_flickr_flickr_publisher_on_account_info_available (PublishingFlickrFlickrPublisher* self);
static void publishing_flickr_flickr_publisher_do_show_publishing_options_pane (PublishingFlickrFlickrPublisher* self);
static void publishing_flickr_flickr_publisher_on_publishing_options_pane_publish (PublishingFlickrFlickrPublisher* self,
                                                                            gboolean strip_metadata);
static void _publishing_flickr_flickr_publisher_on_publishing_options_pane_publish_publishing_flickr_publishing_options_pane_publish (PublishingFlickrPublishingOptionsPane* _sender,
                                                                                                                               gboolean strip_metadata,
                                                                                                                               gpointer self);
static void publishing_flickr_flickr_publisher_on_publishing_options_pane_logout (PublishingFlickrFlickrPublisher* self);
static void _publishing_flickr_flickr_publisher_on_publishing_options_pane_logout_publishing_flickr_publishing_options_pane_logout (PublishingFlickrPublishingOptionsPane* _sender,
                                                                                                                             gpointer self);
static void publishing_flickr_flickr_publisher_do_publish (PublishingFlickrFlickrPublisher* self,
                                                    gboolean strip_metadata);
static void publishing_flickr_flickr_publisher_do_logout (PublishingFlickrFlickrPublisher* self);
static void publishing_flickr_flickr_publisher_on_upload_status_updated (PublishingFlickrFlickrPublisher* self,
                                                                  gint file_number,
                                                                  gdouble completed_fraction);
static void publishing_flickr_flickr_publisher_on_upload_complete (PublishingFlickrFlickrPublisher* self,
                                                            PublishingRESTSupportBatchUploader* uploader,
                                                            gint num_published);
static void _publishing_flickr_flickr_publisher_on_upload_complete_publishing_rest_support_batch_uploader_upload_complete (PublishingRESTSupportBatchUploader* _sender,
                                                                                                                    gint num_photos_published,
                                                                                                                    gpointer self);
static void publishing_flickr_flickr_publisher_on_upload_error (PublishingFlickrFlickrPublisher* self,
                                                         PublishingRESTSupportBatchUploader* uploader,
                                                         GError* err);
static void _publishing_flickr_flickr_publisher_on_upload_error_publishing_rest_support_batch_uploader_upload_error (PublishingRESTSupportBatchUploader* _sender,
                                                                                                              GError* err,
                                                                                                              gpointer self);
static void publishing_flickr_flickr_publisher_do_show_success_pane (PublishingFlickrFlickrPublisher* self);
GType publishing_flickr_account_info_fetch_transaction_get_type (void) G_GNUC_CONST;
PublishingFlickrAccountInfoFetchTransaction* publishing_flickr_account_info_fetch_transaction_new (PublishingRESTSupportOAuth1Session* session);
PublishingFlickrAccountInfoFetchTransaction* publishing_flickr_account_info_fetch_transaction_construct (GType object_type,
                                                                                                         PublishingRESTSupportOAuth1Session* session);
PublishingRESTSupportXmlDocument* publishing_flickr_transaction_parse_flickr_response (const gchar* xml,
                                                                                       GError** error);
static void publishing_flickr_flickr_publisher_attempt_start (PublishingFlickrFlickrPublisher* self);
PublishingFlickrPublishingOptionsPane* publishing_flickr_publishing_options_pane_new (PublishingFlickrFlickrPublisher* publisher,
                                                                                      PublishingFlickrPublishingParameters* parameters,
                                                                                      SpitPublishingPublisherMediaType media_type,
                                                                                      GtkBuilder* builder,
                                                                                      gboolean strip_metadata);
PublishingFlickrPublishingOptionsPane* publishing_flickr_publishing_options_pane_construct (GType object_type,
                                                                                            PublishingFlickrFlickrPublisher* publisher,
                                                                                            PublishingFlickrPublishingParameters* parameters,
                                                                                            SpitPublishingPublisherMediaType media_type,
                                                                                            GtkBuilder* builder,
                                                                                            gboolean strip_metadata);
gint publishing_flickr_flickr_publisher_flickr_date_time_compare_func (SpitPublishingPublishable* a,
                                                                       SpitPublishingPublishable* b);
static gint _publishing_flickr_flickr_publisher_flickr_date_time_compare_func_gcompare_data_func (gconstpointer a,
                                                                                           gconstpointer b,
                                                                                           gpointer self);
GType publishing_flickr_uploader_get_type (void) G_GNUC_CONST;
PublishingFlickrUploader* publishing_flickr_uploader_new (PublishingRESTSupportOAuth1Session* session,
                                                          SpitPublishingPublishable** publishables,
                                                          int publishables_length1,
                                                          PublishingFlickrPublishingParameters* parameters,
                                                          gboolean strip_metadata);
PublishingFlickrUploader* publishing_flickr_uploader_construct (GType object_type,
                                                                PublishingRESTSupportOAuth1Session* session,
                                                                SpitPublishingPublishable** publishables,
                                                                int publishables_length1,
                                                                PublishingFlickrPublishingParameters* parameters,
                                                                gboolean strip_metadata);
static void _publishing_flickr_flickr_publisher_on_upload_status_updated_spit_publishing_progress_callback (gint file_number,
                                                                                                     gdouble fraction_complete,
                                                                                                     gpointer self);
gint publishing_flickr_flickr_publisher_get_persistent_visibility (PublishingFlickrFlickrPublisher* self);
void publishing_flickr_flickr_publisher_set_persistent_visibility (PublishingFlickrFlickrPublisher* self,
                                                                   gint vis);
gint publishing_flickr_flickr_publisher_get_persistent_default_size (PublishingFlickrFlickrPublisher* self);
void publishing_flickr_flickr_publisher_set_persistent_default_size (PublishingFlickrFlickrPublisher* self,
                                                                     gint size);
static SpitPublishingService* publishing_flickr_flickr_publisher_real_get_service (SpitPublishingPublisher* base);
static gboolean publishing_flickr_flickr_publisher_real_is_running (SpitPublishingPublisher* base);
static void publishing_flickr_flickr_publisher_real_start (SpitPublishingPublisher* base);
static void publishing_flickr_flickr_publisher_real_stop (SpitPublishingPublisher* base);
static void publishing_flickr_flickr_publisher_finalize (GObject * obj);
gchar* publishing_flickr_transaction_validate_xml (PublishingRESTSupportXmlDocument* doc);
static gchar* _publishing_flickr_transaction_validate_xml_publishing_rest_support_xml_document_check_for_error_response (PublishingRESTSupportXmlDocument* doc,
                                                                                                                  gpointer self);
GType publishing_flickr_upload_transaction_get_type (void) G_GNUC_CONST;
#define PUBLISHING_FLICKR_UPLOAD_TRANSACTION_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PUBLISHING_FLICKR_TYPE_UPLOAD_TRANSACTION, PublishingFlickrUploadTransactionPrivate))
PublishingFlickrUploadTransaction* publishing_flickr_upload_transaction_new (PublishingRESTSupportOAuth1Session* session,
                                                                             PublishingFlickrPublishingParameters* parameters,
                                                                             SpitPublishingPublishable* publishable);
PublishingFlickrUploadTransaction* publishing_flickr_upload_transaction_construct (GType object_type,
                                                                                   PublishingRESTSupportOAuth1Session* session,
                                                                                   PublishingFlickrPublishingParameters* parameters,
                                                                                   SpitPublishingPublishable* publishable);
static void _g_free0_ (gpointer var);
static void publishing_flickr_upload_transaction_real_execute (PublishingRESTSupportTransaction* base,
                                                        GError** error);
static void publishing_flickr_upload_transaction_finalize (PublishingRESTSupportTransaction * obj);
static gpointer publishing_flickr_publishing_options_pane_visibility_entry_ref (gpointer instance);
static void publishing_flickr_publishing_options_pane_visibility_entry_unref (gpointer instance);
static GParamSpec* publishing_flickr_publishing_options_pane_param_spec_visibility_entry (const gchar* name,
                                                                                   const gchar* nick,
                                                                                   const gchar* blurb,
                                                                                   GType object_type,
                                                                                   GParamFlags flags) G_GNUC_UNUSED;
static void publishing_flickr_publishing_options_pane_value_set_visibility_entry (GValue* value,
                                                                           gpointer v_object) G_GNUC_UNUSED;
static void publishing_flickr_publishing_options_pane_value_take_visibility_entry (GValue* value,
                                                                            gpointer v_object) G_GNUC_UNUSED;
static gpointer publishing_flickr_publishing_options_pane_value_get_visibility_entry (const GValue* value) G_GNUC_UNUSED;
static GType publishing_flickr_publishing_options_pane_visibility_entry_get_type (void) G_GNUC_CONST G_GNUC_UNUSED;
static gpointer publishing_flickr_publishing_options_pane_size_entry_ref (gpointer instance);
static void publishing_flickr_publishing_options_pane_size_entry_unref (gpointer instance);
static GParamSpec* publishing_flickr_publishing_options_pane_param_spec_size_entry (const gchar* name,
                                                                             const gchar* nick,
                                                                             const gchar* blurb,
                                                                             GType object_type,
                                                                             GParamFlags flags) G_GNUC_UNUSED;
static void publishing_flickr_publishing_options_pane_value_set_size_entry (GValue* value,
                                                                     gpointer v_object) G_GNUC_UNUSED;
static void publishing_flickr_publishing_options_pane_value_take_size_entry (GValue* value,
                                                                      gpointer v_object) G_GNUC_UNUSED;
static gpointer publishing_flickr_publishing_options_pane_value_get_size_entry (const GValue* value) G_GNUC_UNUSED;
static GType publishing_flickr_publishing_options_pane_size_entry_get_type (void) G_GNUC_CONST G_GNUC_UNUSED;
#define PUBLISHING_FLICKR_PUBLISHING_OPTIONS_PANE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PUBLISHING_FLICKR_TYPE_PUBLISHING_OPTIONS_PANE, PublishingFlickrPublishingOptionsPanePrivate))
static PublishingFlickrPublishingOptionsPaneVisibilityEntry** publishing_flickr_publishing_options_pane_create_visibilities (PublishingFlickrPublishingOptionsPane* self,
                                                                                                                      int* result_length1);
static PublishingFlickrPublishingOptionsPaneSizeEntry** publishing_flickr_publishing_options_pane_create_sizes (PublishingFlickrPublishingOptionsPane* self,
                                                                                                         int* result_length1);
static void publishing_flickr_publishing_options_pane_populate_visibility_combo (PublishingFlickrPublishingOptionsPane* self);
static void publishing_flickr_publishing_options_pane_on_visibility_changed (PublishingFlickrPublishingOptionsPane* self);
static void _publishing_flickr_publishing_options_pane_on_visibility_changed_gtk_combo_box_changed (GtkComboBox* _sender,
                                                                                             gpointer self);
static void publishing_flickr_publishing_options_pane_populate_size_combo (PublishingFlickrPublishingOptionsPane* self);
static void publishing_flickr_publishing_options_pane_on_size_changed (PublishingFlickrPublishingOptionsPane* self);
static void _publishing_flickr_publishing_options_pane_on_size_changed_gtk_combo_box_changed (GtkComboBox* _sender,
                                                                                       gpointer self);
static void publishing_flickr_publishing_options_pane_on_logout_clicked (PublishingFlickrPublishingOptionsPane* self);
static void _publishing_flickr_publishing_options_pane_on_logout_clicked_gtk_button_clicked (GtkButton* _sender,
                                                                                      gpointer self);
static void publishing_flickr_publishing_options_pane_on_publish_clicked (PublishingFlickrPublishingOptionsPane* self);
static void _publishing_flickr_publishing_options_pane_on_publish_clicked_gtk_button_clicked (GtkButton* _sender,
                                                                                       gpointer self);
static PublishingFlickrPublishingOptionsPaneVisibilityEntry* publishing_flickr_publishing_options_pane_visibility_entry_new (const gchar* creator_title,
                                                                                                                      PublishingFlickrVisibilitySpecification* creator_specification);
static PublishingFlickrPublishingOptionsPaneVisibilityEntry* publishing_flickr_publishing_options_pane_visibility_entry_construct (GType object_type,
                                                                                                                            const gchar* creator_title,
                                                                                                                            PublishingFlickrVisibilitySpecification* creator_specification);
static void _vala_array_add20 (PublishingFlickrPublishingOptionsPaneVisibilityEntry** * array,
                        int* length,
                        int* size,
                        PublishingFlickrPublishingOptionsPaneVisibilityEntry* value);
static void _vala_array_add21 (PublishingFlickrPublishingOptionsPaneVisibilityEntry** * array,
                        int* length,
                        int* size,
                        PublishingFlickrPublishingOptionsPaneVisibilityEntry* value);
static void _vala_array_add22 (PublishingFlickrPublishingOptionsPaneVisibilityEntry** * array,
                        int* length,
                        int* size,
                        PublishingFlickrPublishingOptionsPaneVisibilityEntry* value);
static void _vala_array_add23 (PublishingFlickrPublishingOptionsPaneVisibilityEntry** * array,
                        int* length,
                        int* size,
                        PublishingFlickrPublishingOptionsPaneVisibilityEntry* value);
static void _vala_array_add24 (PublishingFlickrPublishingOptionsPaneVisibilityEntry** * array,
                        int* length,
                        int* size,
                        PublishingFlickrPublishingOptionsPaneVisibilityEntry* value);
static PublishingFlickrPublishingOptionsPaneSizeEntry* publishing_flickr_publishing_options_pane_size_entry_new (const gchar* creator_title,
                                                                                                          gint creator_size);
static PublishingFlickrPublishingOptionsPaneSizeEntry* publishing_flickr_publishing_options_pane_size_entry_construct (GType object_type,
                                                                                                                const gchar* creator_title,
                                                                                                                gint creator_size);
static void _vala_array_add25 (PublishingFlickrPublishingOptionsPaneSizeEntry** * array,
                        int* length,
                        int* size,
                        PublishingFlickrPublishingOptionsPaneSizeEntry* value);
static void _vala_array_add26 (PublishingFlickrPublishingOptionsPaneSizeEntry** * array,
                        int* length,
                        int* size,
                        PublishingFlickrPublishingOptionsPaneSizeEntry* value);
static void _vala_array_add27 (PublishingFlickrPublishingOptionsPaneSizeEntry** * array,
                        int* length,
                        int* size,
                        PublishingFlickrPublishingOptionsPaneSizeEntry* value);
static void _vala_array_add28 (PublishingFlickrPublishingOptionsPaneSizeEntry** * array,
                        int* length,
                        int* size,
                        PublishingFlickrPublishingOptionsPaneSizeEntry* value);
static void _vala_array_add29 (PublishingFlickrPublishingOptionsPaneSizeEntry** * array,
                        int* length,
                        int* size,
                        PublishingFlickrPublishingOptionsPaneSizeEntry* value);
void publishing_flickr_publishing_options_pane_notify_publish (PublishingFlickrPublishingOptionsPane* self);
void publishing_flickr_publishing_options_pane_notify_logout (PublishingFlickrPublishingOptionsPane* self);
static GtkWidget* publishing_flickr_publishing_options_pane_real_get_widget (SpitPublishingDialogPane* base);
static SpitPublishingDialogPaneGeometryOptions publishing_flickr_publishing_options_pane_real_get_preferred_geometry (SpitPublishingDialogPane* base);
static void publishing_flickr_publishing_options_pane_real_on_pane_installed (SpitPublishingDialogPane* base);
static void _publishing_flickr_publishing_options_pane_notify_publish_publishing_flickr_publishing_options_pane_publish (PublishingFlickrPublishingOptionsPane* _sender,
                                                                                                                  gboolean strip_metadata,
                                                                                                                  gpointer self);
static void _publishing_flickr_publishing_options_pane_notify_logout_publishing_flickr_publishing_options_pane_logout (PublishingFlickrPublishingOptionsPane* _sender,
                                                                                                                gpointer self);
static void publishing_flickr_publishing_options_pane_real_on_pane_uninstalled (SpitPublishingDialogPane* base);
static void publishing_flickr_publishing_options_pane_size_entry_finalize (PublishingFlickrPublishingOptionsPaneSizeEntry * obj);
static void publishing_flickr_publishing_options_pane_visibility_entry_finalize (PublishingFlickrPublishingOptionsPaneVisibilityEntry * obj);
static void publishing_flickr_publishing_options_pane_finalize (GObject * obj);
#define PUBLISHING_FLICKR_UPLOADER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PUBLISHING_FLICKR_TYPE_UPLOADER, PublishingFlickrUploaderPrivate))
static void publishing_flickr_uploader_preprocess_publishable (PublishingFlickrUploader* self,
                                                        SpitPublishingPublishable* publishable);
static void _vala_array_add30 (gchar** * array,
                        int* length,
                        int* size,
                        gchar* value);
static PublishingRESTSupportTransaction* publishing_flickr_uploader_real_create_transaction (PublishingRESTSupportBatchUploader* base,
                                                                                      SpitPublishingPublishable* publishable);
static void publishing_flickr_uploader_finalize (PublishingRESTSupportBatchUploader * obj);
static void _vala_array_destroy (gpointer array,
                          gint array_length,
                          GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array,
                       gint array_length,
                       GDestroyNotify destroy_func);
static gint _vala_array_length (gpointer array);


FlickrService*
flickr_service_construct (GType object_type,
                          GFile* resource_directory)
{
	FlickrService * self = NULL;
	GdkPixbuf** _tmp0_;
	gint _tmp0__length1;
#line 12 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_val_if_fail (G_IS_FILE (resource_directory), NULL);
#line 12 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self = (FlickrService*) g_object_new (object_type, NULL);
#line 13 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = flickr_service_icon_pixbuf_set;
#line 13 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0__length1 = flickr_service_icon_pixbuf_set_length1;
#line 13 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (_tmp0_ == NULL) {
#line 714 "FlickrPublishing.c"
		gint _tmp1_;
		GdkPixbuf** _tmp2_;
#line 14 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp2_ = resources_load_from_resource (PLUGIN_RESOURCE_PATH "/" FLICKR_SERVICE_ICON_FILENAME, &_tmp1_);
#line 14 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		flickr_service_icon_pixbuf_set = (_vala_array_free (flickr_service_icon_pixbuf_set, flickr_service_icon_pixbuf_set_length1, (GDestroyNotify) g_object_unref), NULL);
#line 14 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		flickr_service_icon_pixbuf_set = _tmp2_;
#line 14 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		flickr_service_icon_pixbuf_set_length1 = _tmp1_;
#line 14 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_flickr_service_icon_pixbuf_set_size_ = flickr_service_icon_pixbuf_set_length1;
#line 727 "FlickrPublishing.c"
	}
#line 12 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return self;
#line 731 "FlickrPublishing.c"
}


FlickrService*
flickr_service_new (GFile* resource_directory)
{
#line 12 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return flickr_service_construct (TYPE_FLICKR_SERVICE, resource_directory);
#line 740 "FlickrPublishing.c"
}


static gint
flickr_service_real_get_pluggable_interface (SpitPluggable* base,
                                             gint min_host_interface,
                                             gint max_host_interface)
{
	FlickrService * self;
	gint result = 0;
#line 18 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_FLICKR_SERVICE, FlickrService);
#line 19 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	result = spit_negotiate_interfaces (min_host_interface, max_host_interface, SPIT_PUBLISHING_CURRENT_INTERFACE);
#line 19 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return result;
#line 757 "FlickrPublishing.c"
}


static const gchar*
flickr_service_real_get_id (SpitPluggable* base)
{
	FlickrService * self;
	const gchar* result = NULL;
#line 23 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_FLICKR_SERVICE, FlickrService);
#line 24 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	result = "org.yorba.shotwell.publishing.flickr";
#line 24 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return result;
#line 772 "FlickrPublishing.c"
}


static const gchar*
flickr_service_real_get_pluggable_name (SpitPluggable* base)
{
	FlickrService * self;
	const gchar* result = NULL;
#line 27 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_FLICKR_SERVICE, FlickrService);
#line 28 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	result = "Flickr";
#line 28 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return result;
#line 787 "FlickrPublishing.c"
}


static gpointer
_g_object_ref0 (gpointer self)
{
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return self ? g_object_ref (self) : NULL;
#line 796 "FlickrPublishing.c"
}


static GdkPixbuf**
_vala_array_dup7 (GdkPixbuf** self,
                  int length)
{
	GdkPixbuf** result;
	int i;
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	result = g_new0 (GdkPixbuf*, length + 1);
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	for (i = 0; i < length; i++) {
#line 810 "FlickrPublishing.c"
		GdkPixbuf* _tmp0_;
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp0_ = _g_object_ref0 (self[i]);
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		result[i] = _tmp0_;
#line 816 "FlickrPublishing.c"
	}
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return result;
#line 820 "FlickrPublishing.c"
}


static void
flickr_service_real_get_info (SpitPluggable* base,
                              SpitPluggableInfo* info)
{
	FlickrService * self;
	gchar* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	gchar* _tmp4_;
	gchar* _tmp5_;
	gchar* _tmp6_;
	GdkPixbuf** _tmp7_;
	gint _tmp7__length1;
	GdkPixbuf** _tmp8_;
	gint _tmp8__length1;
#line 31 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_FLICKR_SERVICE, FlickrService);
#line 31 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (info != NULL);
#line 32 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = g_strdup ("Lucas Beeler");
#line 32 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_free0 ((*info).authors);
#line 32 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	(*info).authors = _tmp0_;
#line 33 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp1_ = g_strdup (_ ("Copyright 2016 Software Freedom Conservancy Inc."));
#line 33 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_free0 ((*info).copyright);
#line 33 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	(*info).copyright = _tmp1_;
#line 34 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp2_ = g_strdup (RESOURCES_TRANSLATORS);
#line 34 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_free0 ((*info).translators);
#line 34 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	(*info).translators = _tmp2_;
#line 35 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp3_ = g_strdup (_VERSION);
#line 35 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_free0 ((*info).version);
#line 35 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	(*info).version = _tmp3_;
#line 36 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp4_ = g_strdup (RESOURCES_WEBSITE_NAME);
#line 36 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_free0 ((*info).website_name);
#line 36 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	(*info).website_name = _tmp4_;
#line 37 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp5_ = g_strdup (RESOURCES_WEBSITE_URL);
#line 37 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_free0 ((*info).website_url);
#line 37 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	(*info).website_url = _tmp5_;
#line 38 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	(*info).is_license_wordwrapped = FALSE;
#line 39 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp6_ = g_strdup (RESOURCES_LICENSE);
#line 39 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_free0 ((*info).license);
#line 39 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	(*info).license = _tmp6_;
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp7_ = flickr_service_icon_pixbuf_set;
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp7__length1 = flickr_service_icon_pixbuf_set_length1;
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp8_ = (_tmp7_ != NULL) ? _vala_array_dup7 (_tmp7_, _tmp7__length1) : ((gpointer) _tmp7_);
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp8__length1 = _tmp7__length1;
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	(*info).icons = (_vala_array_free ((*info).icons, (*info).icons_length1, (GDestroyNotify) g_object_unref), NULL);
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	(*info).icons = _tmp8_;
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	(*info).icons_length1 = _tmp8__length1;
#line 902 "FlickrPublishing.c"
}


static void
flickr_service_real_activation (SpitPluggable* base,
                                gboolean enabled)
{
	FlickrService * self;
#line 43 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_FLICKR_SERVICE, FlickrService);
#line 913 "FlickrPublishing.c"
}


static SpitPublishingPublisher*
flickr_service_real_create_publisher (SpitPublishingService* base,
                                      SpitPublishingPluginHost* host)
{
	FlickrService * self;
	SpitPublishingPublisher* result = NULL;
	PublishingFlickrFlickrPublisher* _tmp0_;
#line 46 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_FLICKR_SERVICE, FlickrService);
#line 46 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_val_if_fail (SPIT_PUBLISHING_IS_PLUGIN_HOST (host), NULL);
#line 47 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = publishing_flickr_flickr_publisher_new (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_SERVICE, SpitPublishingService), host);
#line 47 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	result = G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_PUBLISHING_TYPE_PUBLISHER, SpitPublishingPublisher);
#line 47 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return result;
#line 934 "FlickrPublishing.c"
}


static SpitPublishingPublisherMediaType
flickr_service_real_get_supported_media (SpitPublishingService* base)
{
	FlickrService * self;
	SpitPublishingPublisherMediaType result = 0;
#line 50 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_FLICKR_SERVICE, FlickrService);
#line 51 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	result = SPIT_PUBLISHING_PUBLISHER_MEDIA_TYPE_PHOTO | SPIT_PUBLISHING_PUBLISHER_MEDIA_TYPE_VIDEO;
#line 51 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return result;
#line 949 "FlickrPublishing.c"
}


static void
flickr_service_class_init (FlickrServiceClass * klass)
{
#line 7 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	flickr_service_parent_class = g_type_class_peek_parent (klass);
#line 7 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	G_OBJECT_CLASS (klass)->finalize = flickr_service_finalize;
#line 960 "FlickrPublishing.c"
}


static void
flickr_service_spit_pluggable_interface_init (SpitPluggableIface * iface)
{
#line 7 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	flickr_service_spit_pluggable_parent_iface = g_type_interface_peek_parent (iface);
#line 7 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	iface->get_pluggable_interface = (gint (*) (SpitPluggable *, gint, gint)) flickr_service_real_get_pluggable_interface;
#line 7 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	iface->get_id = (const gchar* (*) (SpitPluggable *)) flickr_service_real_get_id;
#line 7 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	iface->get_pluggable_name = (const gchar* (*) (SpitPluggable *)) flickr_service_real_get_pluggable_name;
#line 7 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	iface->get_info = (void (*) (SpitPluggable *, SpitPluggableInfo*)) flickr_service_real_get_info;
#line 7 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	iface->activation = (void (*) (SpitPluggable *, gboolean)) flickr_service_real_activation;
#line 979 "FlickrPublishing.c"
}


static void
flickr_service_spit_publishing_service_interface_init (SpitPublishingServiceIface * iface)
{
#line 7 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	flickr_service_spit_publishing_service_parent_iface = g_type_interface_peek_parent (iface);
#line 7 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	iface->create_publisher = (SpitPublishingPublisher* (*) (SpitPublishingService *, SpitPublishingPluginHost*)) flickr_service_real_create_publisher;
#line 7 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	iface->get_supported_media = (SpitPublishingPublisherMediaType (*) (SpitPublishingService *)) flickr_service_real_get_supported_media;
#line 992 "FlickrPublishing.c"
}


static void
flickr_service_instance_init (FlickrService * self)
{
}


static void
flickr_service_finalize (GObject * obj)
{
	FlickrService * self;
#line 7 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_FLICKR_SERVICE, FlickrService);
#line 7 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	G_OBJECT_CLASS (flickr_service_parent_class)->finalize (obj);
#line 1010 "FlickrPublishing.c"
}


GType
flickr_service_get_type (void)
{
	static volatile gsize flickr_service_type_id__volatile = 0;
	if (g_once_init_enter (&flickr_service_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (FlickrServiceClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) flickr_service_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (FlickrService), 0, (GInstanceInitFunc) flickr_service_instance_init, NULL };
		static const GInterfaceInfo spit_pluggable_info = { (GInterfaceInitFunc) flickr_service_spit_pluggable_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		static const GInterfaceInfo spit_publishing_service_info = { (GInterfaceInitFunc) flickr_service_spit_publishing_service_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType flickr_service_type_id;
		flickr_service_type_id = g_type_register_static (G_TYPE_OBJECT, "FlickrService", &g_define_type_info, 0);
		g_type_add_interface_static (flickr_service_type_id, SPIT_TYPE_PLUGGABLE, &spit_pluggable_info);
		g_type_add_interface_static (flickr_service_type_id, SPIT_PUBLISHING_TYPE_SERVICE, &spit_publishing_service_info);
		g_once_init_leave (&flickr_service_type_id__volatile, flickr_service_type_id);
	}
	return flickr_service_type_id__volatile;
}


GType
publishing_flickr_user_kind_get_type (void)
{
	static volatile gsize publishing_flickr_user_kind_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_flickr_user_kind_type_id__volatile)) {
		static const GEnumValue values[] = {{PUBLISHING_FLICKR_USER_KIND_PRO, "PUBLISHING_FLICKR_USER_KIND_PRO", "pro"}, {PUBLISHING_FLICKR_USER_KIND_FREE, "PUBLISHING_FLICKR_USER_KIND_FREE", "free"}, {0, NULL, NULL}};
		GType publishing_flickr_user_kind_type_id;
		publishing_flickr_user_kind_type_id = g_enum_register_static ("PublishingFlickrUserKind", values);
		g_once_init_leave (&publishing_flickr_user_kind_type_id__volatile, publishing_flickr_user_kind_type_id);
	}
	return publishing_flickr_user_kind_type_id__volatile;
}


PublishingFlickrVisibilitySpecification*
publishing_flickr_visibility_specification_construct (GType object_type,
                                                      gint friends_level,
                                                      gint family_level,
                                                      gint everyone_level)
{
	PublishingFlickrVisibilitySpecification* self = NULL;
#line 73 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self = (PublishingFlickrVisibilitySpecification*) g_type_create_instance (object_type);
#line 74 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->friends_level = friends_level;
#line 75 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->family_level = family_level;
#line 76 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->everyone_level = everyone_level;
#line 73 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return self;
#line 1063 "FlickrPublishing.c"
}


PublishingFlickrVisibilitySpecification*
publishing_flickr_visibility_specification_new (gint friends_level,
                                                gint family_level,
                                                gint everyone_level)
{
#line 73 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return publishing_flickr_visibility_specification_construct (PUBLISHING_FLICKR_TYPE_VISIBILITY_SPECIFICATION, friends_level, family_level, everyone_level);
#line 1074 "FlickrPublishing.c"
}


static void
publishing_flickr_value_visibility_specification_init (GValue* value)
{
#line 68 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	value->data[0].v_pointer = NULL;
#line 1083 "FlickrPublishing.c"
}


static void
publishing_flickr_value_visibility_specification_free_value (GValue* value)
{
#line 68 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (value->data[0].v_pointer) {
#line 68 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		publishing_flickr_visibility_specification_unref (value->data[0].v_pointer);
#line 1094 "FlickrPublishing.c"
	}
}


static void
publishing_flickr_value_visibility_specification_copy_value (const GValue* src_value,
                                                             GValue* dest_value)
{
#line 68 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (src_value->data[0].v_pointer) {
#line 68 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		dest_value->data[0].v_pointer = publishing_flickr_visibility_specification_ref (src_value->data[0].v_pointer);
#line 1107 "FlickrPublishing.c"
	} else {
#line 68 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		dest_value->data[0].v_pointer = NULL;
#line 1111 "FlickrPublishing.c"
	}
}


static gpointer
publishing_flickr_value_visibility_specification_peek_pointer (const GValue* value)
{
#line 68 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return value->data[0].v_pointer;
#line 1121 "FlickrPublishing.c"
}


static gchar*
publishing_flickr_value_visibility_specification_collect_value (GValue* value,
                                                                guint n_collect_values,
                                                                GTypeCValue* collect_values,
                                                                guint collect_flags)
{
#line 68 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (collect_values[0].v_pointer) {
#line 1133 "FlickrPublishing.c"
		PublishingFlickrVisibilitySpecification * object;
		object = collect_values[0].v_pointer;
#line 68 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		if (object->parent_instance.g_class == NULL) {
#line 68 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 1140 "FlickrPublishing.c"
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
#line 68 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 1144 "FlickrPublishing.c"
		}
#line 68 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		value->data[0].v_pointer = publishing_flickr_visibility_specification_ref (object);
#line 1148 "FlickrPublishing.c"
	} else {
#line 68 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		value->data[0].v_pointer = NULL;
#line 1152 "FlickrPublishing.c"
	}
#line 68 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return NULL;
#line 1156 "FlickrPublishing.c"
}


static gchar*
publishing_flickr_value_visibility_specification_lcopy_value (const GValue* value,
                                                              guint n_collect_values,
                                                              GTypeCValue* collect_values,
                                                              guint collect_flags)
{
	PublishingFlickrVisibilitySpecification ** object_p;
	object_p = collect_values[0].v_pointer;
#line 68 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (!object_p) {
#line 68 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
#line 1172 "FlickrPublishing.c"
	}
#line 68 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (!value->data[0].v_pointer) {
#line 68 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		*object_p = NULL;
#line 1178 "FlickrPublishing.c"
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
#line 68 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		*object_p = value->data[0].v_pointer;
#line 1182 "FlickrPublishing.c"
	} else {
#line 68 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		*object_p = publishing_flickr_visibility_specification_ref (value->data[0].v_pointer);
#line 1186 "FlickrPublishing.c"
	}
#line 68 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return NULL;
#line 1190 "FlickrPublishing.c"
}


GParamSpec*
publishing_flickr_param_spec_visibility_specification (const gchar* name,
                                                       const gchar* nick,
                                                       const gchar* blurb,
                                                       GType object_type,
                                                       GParamFlags flags)
{
	PublishingFlickrParamSpecVisibilitySpecification* spec;
#line 68 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_val_if_fail (g_type_is_a (object_type, PUBLISHING_FLICKR_TYPE_VISIBILITY_SPECIFICATION), NULL);
#line 68 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
#line 68 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	G_PARAM_SPEC (spec)->value_type = object_type;
#line 68 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return G_PARAM_SPEC (spec);
#line 1210 "FlickrPublishing.c"
}


gpointer
publishing_flickr_value_get_visibility_specification (const GValue* value)
{
#line 68 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_FLICKR_TYPE_VISIBILITY_SPECIFICATION), NULL);
#line 68 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return value->data[0].v_pointer;
#line 1221 "FlickrPublishing.c"
}


void
publishing_flickr_value_set_visibility_specification (GValue* value,
                                                      gpointer v_object)
{
	PublishingFlickrVisibilitySpecification * old;
#line 68 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_FLICKR_TYPE_VISIBILITY_SPECIFICATION));
#line 68 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	old = value->data[0].v_pointer;
#line 68 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (v_object) {
#line 68 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, PUBLISHING_FLICKR_TYPE_VISIBILITY_SPECIFICATION));
#line 68 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 68 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		value->data[0].v_pointer = v_object;
#line 68 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		publishing_flickr_visibility_specification_ref (value->data[0].v_pointer);
#line 1244 "FlickrPublishing.c"
	} else {
#line 68 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		value->data[0].v_pointer = NULL;
#line 1248 "FlickrPublishing.c"
	}
#line 68 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (old) {
#line 68 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		publishing_flickr_visibility_specification_unref (old);
#line 1254 "FlickrPublishing.c"
	}
}


void
publishing_flickr_value_take_visibility_specification (GValue* value,
                                                       gpointer v_object)
{
	PublishingFlickrVisibilitySpecification * old;
#line 68 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_FLICKR_TYPE_VISIBILITY_SPECIFICATION));
#line 68 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	old = value->data[0].v_pointer;
#line 68 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (v_object) {
#line 68 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, PUBLISHING_FLICKR_TYPE_VISIBILITY_SPECIFICATION));
#line 68 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 68 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		value->data[0].v_pointer = v_object;
#line 1276 "FlickrPublishing.c"
	} else {
#line 68 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		value->data[0].v_pointer = NULL;
#line 1280 "FlickrPublishing.c"
	}
#line 68 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (old) {
#line 68 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		publishing_flickr_visibility_specification_unref (old);
#line 1286 "FlickrPublishing.c"
	}
}


static void
publishing_flickr_visibility_specification_class_init (PublishingFlickrVisibilitySpecificationClass * klass)
{
#line 68 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_visibility_specification_parent_class = g_type_class_peek_parent (klass);
#line 68 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	((PublishingFlickrVisibilitySpecificationClass *) klass)->finalize = publishing_flickr_visibility_specification_finalize;
#line 1298 "FlickrPublishing.c"
}


static void
publishing_flickr_visibility_specification_instance_init (PublishingFlickrVisibilitySpecification * self)
{
#line 68 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->ref_count = 1;
#line 1307 "FlickrPublishing.c"
}


static void
publishing_flickr_visibility_specification_finalize (PublishingFlickrVisibilitySpecification * obj)
{
	PublishingFlickrVisibilitySpecification * self;
#line 68 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_FLICKR_TYPE_VISIBILITY_SPECIFICATION, PublishingFlickrVisibilitySpecification);
#line 68 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_handlers_destroy (self);
#line 1319 "FlickrPublishing.c"
}


GType
publishing_flickr_visibility_specification_get_type (void)
{
	static volatile gsize publishing_flickr_visibility_specification_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_flickr_visibility_specification_type_id__volatile)) {
		static const GTypeValueTable g_define_type_value_table = { publishing_flickr_value_visibility_specification_init, publishing_flickr_value_visibility_specification_free_value, publishing_flickr_value_visibility_specification_copy_value, publishing_flickr_value_visibility_specification_peek_pointer, "p", publishing_flickr_value_visibility_specification_collect_value, "p", publishing_flickr_value_visibility_specification_lcopy_value };
		static const GTypeInfo g_define_type_info = { sizeof (PublishingFlickrVisibilitySpecificationClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_flickr_visibility_specification_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingFlickrVisibilitySpecification), 0, (GInstanceInitFunc) publishing_flickr_visibility_specification_instance_init, &g_define_type_value_table };
		static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
		GType publishing_flickr_visibility_specification_type_id;
		publishing_flickr_visibility_specification_type_id = g_type_register_fundamental (g_type_fundamental_next (), "PublishingFlickrVisibilitySpecification", &g_define_type_info, &g_define_type_fundamental_info, 0);
		g_once_init_leave (&publishing_flickr_visibility_specification_type_id__volatile, publishing_flickr_visibility_specification_type_id);
	}
	return publishing_flickr_visibility_specification_type_id__volatile;
}


gpointer
publishing_flickr_visibility_specification_ref (gpointer instance)
{
	PublishingFlickrVisibilitySpecification * self;
	self = instance;
#line 68 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_atomic_int_inc (&self->ref_count);
#line 68 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return instance;
#line 1348 "FlickrPublishing.c"
}


void
publishing_flickr_visibility_specification_unref (gpointer instance)
{
	PublishingFlickrVisibilitySpecification * self;
	self = instance;
#line 68 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
#line 68 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		PUBLISHING_FLICKR_VISIBILITY_SPECIFICATION_GET_CLASS (self)->finalize (self);
#line 68 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		g_type_free_instance ((GTypeInstance *) self);
#line 1363 "FlickrPublishing.c"
	}
}


PublishingFlickrPublishingParameters*
publishing_flickr_publishing_parameters_construct (GType object_type)
{
	PublishingFlickrPublishingParameters* self = NULL;
#line 88 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self = (PublishingFlickrPublishingParameters*) g_type_create_instance (object_type);
#line 88 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return self;
#line 1376 "FlickrPublishing.c"
}


PublishingFlickrPublishingParameters*
publishing_flickr_publishing_parameters_new (void)
{
#line 88 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return publishing_flickr_publishing_parameters_construct (PUBLISHING_FLICKR_TYPE_PUBLISHING_PARAMETERS);
#line 1385 "FlickrPublishing.c"
}


static void
publishing_flickr_value_publishing_parameters_init (GValue* value)
{
#line 81 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	value->data[0].v_pointer = NULL;
#line 1394 "FlickrPublishing.c"
}


static void
publishing_flickr_value_publishing_parameters_free_value (GValue* value)
{
#line 81 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (value->data[0].v_pointer) {
#line 81 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		publishing_flickr_publishing_parameters_unref (value->data[0].v_pointer);
#line 1405 "FlickrPublishing.c"
	}
}


static void
publishing_flickr_value_publishing_parameters_copy_value (const GValue* src_value,
                                                          GValue* dest_value)
{
#line 81 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (src_value->data[0].v_pointer) {
#line 81 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		dest_value->data[0].v_pointer = publishing_flickr_publishing_parameters_ref (src_value->data[0].v_pointer);
#line 1418 "FlickrPublishing.c"
	} else {
#line 81 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		dest_value->data[0].v_pointer = NULL;
#line 1422 "FlickrPublishing.c"
	}
}


static gpointer
publishing_flickr_value_publishing_parameters_peek_pointer (const GValue* value)
{
#line 81 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return value->data[0].v_pointer;
#line 1432 "FlickrPublishing.c"
}


static gchar*
publishing_flickr_value_publishing_parameters_collect_value (GValue* value,
                                                             guint n_collect_values,
                                                             GTypeCValue* collect_values,
                                                             guint collect_flags)
{
#line 81 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (collect_values[0].v_pointer) {
#line 1444 "FlickrPublishing.c"
		PublishingFlickrPublishingParameters * object;
		object = collect_values[0].v_pointer;
#line 81 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		if (object->parent_instance.g_class == NULL) {
#line 81 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 1451 "FlickrPublishing.c"
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
#line 81 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 1455 "FlickrPublishing.c"
		}
#line 81 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		value->data[0].v_pointer = publishing_flickr_publishing_parameters_ref (object);
#line 1459 "FlickrPublishing.c"
	} else {
#line 81 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		value->data[0].v_pointer = NULL;
#line 1463 "FlickrPublishing.c"
	}
#line 81 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return NULL;
#line 1467 "FlickrPublishing.c"
}


static gchar*
publishing_flickr_value_publishing_parameters_lcopy_value (const GValue* value,
                                                           guint n_collect_values,
                                                           GTypeCValue* collect_values,
                                                           guint collect_flags)
{
	PublishingFlickrPublishingParameters ** object_p;
	object_p = collect_values[0].v_pointer;
#line 81 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (!object_p) {
#line 81 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
#line 1483 "FlickrPublishing.c"
	}
#line 81 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (!value->data[0].v_pointer) {
#line 81 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		*object_p = NULL;
#line 1489 "FlickrPublishing.c"
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
#line 81 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		*object_p = value->data[0].v_pointer;
#line 1493 "FlickrPublishing.c"
	} else {
#line 81 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		*object_p = publishing_flickr_publishing_parameters_ref (value->data[0].v_pointer);
#line 1497 "FlickrPublishing.c"
	}
#line 81 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return NULL;
#line 1501 "FlickrPublishing.c"
}


GParamSpec*
publishing_flickr_param_spec_publishing_parameters (const gchar* name,
                                                    const gchar* nick,
                                                    const gchar* blurb,
                                                    GType object_type,
                                                    GParamFlags flags)
{
	PublishingFlickrParamSpecPublishingParameters* spec;
#line 81 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_val_if_fail (g_type_is_a (object_type, PUBLISHING_FLICKR_TYPE_PUBLISHING_PARAMETERS), NULL);
#line 81 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
#line 81 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	G_PARAM_SPEC (spec)->value_type = object_type;
#line 81 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return G_PARAM_SPEC (spec);
#line 1521 "FlickrPublishing.c"
}


gpointer
publishing_flickr_value_get_publishing_parameters (const GValue* value)
{
#line 81 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_FLICKR_TYPE_PUBLISHING_PARAMETERS), NULL);
#line 81 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return value->data[0].v_pointer;
#line 1532 "FlickrPublishing.c"
}


void
publishing_flickr_value_set_publishing_parameters (GValue* value,
                                                   gpointer v_object)
{
	PublishingFlickrPublishingParameters * old;
#line 81 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_FLICKR_TYPE_PUBLISHING_PARAMETERS));
#line 81 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	old = value->data[0].v_pointer;
#line 81 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (v_object) {
#line 81 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, PUBLISHING_FLICKR_TYPE_PUBLISHING_PARAMETERS));
#line 81 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 81 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		value->data[0].v_pointer = v_object;
#line 81 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		publishing_flickr_publishing_parameters_ref (value->data[0].v_pointer);
#line 1555 "FlickrPublishing.c"
	} else {
#line 81 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		value->data[0].v_pointer = NULL;
#line 1559 "FlickrPublishing.c"
	}
#line 81 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (old) {
#line 81 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		publishing_flickr_publishing_parameters_unref (old);
#line 1565 "FlickrPublishing.c"
	}
}


void
publishing_flickr_value_take_publishing_parameters (GValue* value,
                                                    gpointer v_object)
{
	PublishingFlickrPublishingParameters * old;
#line 81 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_FLICKR_TYPE_PUBLISHING_PARAMETERS));
#line 81 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	old = value->data[0].v_pointer;
#line 81 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (v_object) {
#line 81 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, PUBLISHING_FLICKR_TYPE_PUBLISHING_PARAMETERS));
#line 81 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 81 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		value->data[0].v_pointer = v_object;
#line 1587 "FlickrPublishing.c"
	} else {
#line 81 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		value->data[0].v_pointer = NULL;
#line 1591 "FlickrPublishing.c"
	}
#line 81 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (old) {
#line 81 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		publishing_flickr_publishing_parameters_unref (old);
#line 1597 "FlickrPublishing.c"
	}
}


static void
publishing_flickr_publishing_parameters_class_init (PublishingFlickrPublishingParametersClass * klass)
{
#line 81 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_publishing_parameters_parent_class = g_type_class_peek_parent (klass);
#line 81 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	((PublishingFlickrPublishingParametersClass *) klass)->finalize = publishing_flickr_publishing_parameters_finalize;
#line 1609 "FlickrPublishing.c"
}


static void
publishing_flickr_publishing_parameters_instance_init (PublishingFlickrPublishingParameters * self)
{
#line 81 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->ref_count = 1;
#line 1618 "FlickrPublishing.c"
}


static void
publishing_flickr_publishing_parameters_finalize (PublishingFlickrPublishingParameters * obj)
{
	PublishingFlickrPublishingParameters * self;
#line 81 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_FLICKR_TYPE_PUBLISHING_PARAMETERS, PublishingFlickrPublishingParameters);
#line 81 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_handlers_destroy (self);
#line 85 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_free0 (self->username);
#line 86 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_publishing_flickr_visibility_specification_unref0 (self->visibility_specification);
#line 1634 "FlickrPublishing.c"
}


GType
publishing_flickr_publishing_parameters_get_type (void)
{
	static volatile gsize publishing_flickr_publishing_parameters_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_flickr_publishing_parameters_type_id__volatile)) {
		static const GTypeValueTable g_define_type_value_table = { publishing_flickr_value_publishing_parameters_init, publishing_flickr_value_publishing_parameters_free_value, publishing_flickr_value_publishing_parameters_copy_value, publishing_flickr_value_publishing_parameters_peek_pointer, "p", publishing_flickr_value_publishing_parameters_collect_value, "p", publishing_flickr_value_publishing_parameters_lcopy_value };
		static const GTypeInfo g_define_type_info = { sizeof (PublishingFlickrPublishingParametersClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_flickr_publishing_parameters_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingFlickrPublishingParameters), 0, (GInstanceInitFunc) publishing_flickr_publishing_parameters_instance_init, &g_define_type_value_table };
		static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
		GType publishing_flickr_publishing_parameters_type_id;
		publishing_flickr_publishing_parameters_type_id = g_type_register_fundamental (g_type_fundamental_next (), "PublishingFlickrPublishingParameters", &g_define_type_info, &g_define_type_fundamental_info, 0);
		g_once_init_leave (&publishing_flickr_publishing_parameters_type_id__volatile, publishing_flickr_publishing_parameters_type_id);
	}
	return publishing_flickr_publishing_parameters_type_id__volatile;
}


gpointer
publishing_flickr_publishing_parameters_ref (gpointer instance)
{
	PublishingFlickrPublishingParameters * self;
	self = instance;
#line 81 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_atomic_int_inc (&self->ref_count);
#line 81 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return instance;
#line 1663 "FlickrPublishing.c"
}


void
publishing_flickr_publishing_parameters_unref (gpointer instance)
{
	PublishingFlickrPublishingParameters * self;
	self = instance;
#line 81 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
#line 81 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		PUBLISHING_FLICKR_PUBLISHING_PARAMETERS_GET_CLASS (self)->finalize (self);
#line 81 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		g_type_free_instance ((GTypeInstance *) self);
#line 1678 "FlickrPublishing.c"
	}
}


static void
_publishing_flickr_flickr_publisher_on_session_authenticated_spit_publishing_authenticator_authenticated (SpitPublishingAuthenticator* _sender,
                                                                                                          gpointer self)
{
#line 117 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_flickr_publisher_on_session_authenticated ((PublishingFlickrFlickrPublisher*) self);
#line 1689 "FlickrPublishing.c"
}


PublishingFlickrFlickrPublisher*
publishing_flickr_flickr_publisher_construct (GType object_type,
                                              SpitPublishingService* service,
                                              SpitPublishingPluginHost* host)
{
	PublishingFlickrFlickrPublisher * self = NULL;
	SpitPublishingService* _tmp0_;
	SpitPublishingPluginHost* _tmp1_;
	PublishingRESTSupportOAuth1Session* _tmp2_;
	PublishingFlickrPublishingParameters* _tmp3_;
	PublishingAuthenticatorFactory* _tmp4_;
	PublishingAuthenticatorFactory* _tmp5_;
	SpitPublishingAuthenticator* _tmp6_;
	SpitPublishingAuthenticator* _tmp7_;
#line 104 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_val_if_fail (SPIT_PUBLISHING_IS_SERVICE (service), NULL);
#line 104 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_val_if_fail (SPIT_PUBLISHING_IS_PLUGIN_HOST (host), NULL);
#line 104 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self = (PublishingFlickrFlickrPublisher*) g_object_new (object_type, NULL);
#line 106 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_debug ("FlickrPublishing.vala:106: FlickrPublisher instantiated.");
#line 107 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = _g_object_ref0 (service);
#line 107 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_object_unref0 (self->priv->service);
#line 107 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->service = _tmp0_;
#line 108 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp1_ = _g_object_ref0 (host);
#line 108 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_object_unref0 (self->priv->host);
#line 108 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->host = _tmp1_;
#line 109 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp2_ = publishing_rest_support_oauth1_session_new (PUBLISHING_FLICKR_ENDPOINT_URL);
#line 109 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_publishing_rest_support_session_unref0 (self->priv->session);
#line 109 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->session = _tmp2_;
#line 110 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp3_ = publishing_flickr_publishing_parameters_new ();
#line 110 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_publishing_flickr_publishing_parameters_unref0 (self->priv->parameters);
#line 110 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->parameters = _tmp3_;
#line 111 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp4_ = publishing_authenticator_factory_get_instance ();
#line 111 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp5_ = _tmp4_;
#line 111 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp6_ = spit_publishing_authenticator_factory_create (G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, SPIT_PUBLISHING_TYPE_AUTHENTICATOR_FACTORY, SpitPublishingAuthenticatorFactory), "flickr", host);
#line 111 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_object_unref0 (self->priv->authenticator);
#line 111 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->authenticator = _tmp6_;
#line 111 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_object_unref0 (_tmp5_);
#line 113 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp7_ = self->priv->authenticator;
#line 113 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_connect_object (_tmp7_, "authenticated", (GCallback) _publishing_flickr_flickr_publisher_on_session_authenticated_spit_publishing_authenticator_authenticated, self, 0);
#line 104 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return self;
#line 1757 "FlickrPublishing.c"
}


PublishingFlickrFlickrPublisher*
publishing_flickr_flickr_publisher_new (SpitPublishingService* service,
                                        SpitPublishingPluginHost* host)
{
#line 104 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return publishing_flickr_flickr_publisher_construct (PUBLISHING_FLICKR_TYPE_FLICKR_PUBLISHER, service, host);
#line 1767 "FlickrPublishing.c"
}


SpitPublishingAuthenticator*
publishing_flickr_flickr_publisher_get_authenticator (PublishingFlickrFlickrPublisher* self)
{
	SpitPublishingAuthenticator* result = NULL;
	SpitPublishingAuthenticator* _tmp0_;
	SpitPublishingAuthenticator* _tmp1_;
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_val_if_fail (PUBLISHING_FLICKR_IS_FLICKR_PUBLISHER (self), NULL);
#line 121 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = self->priv->authenticator;
#line 121 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 121 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	result = _tmp1_;
#line 121 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return result;
#line 1787 "FlickrPublishing.c"
}


static gboolean
publishing_flickr_flickr_publisher_get_persistent_strip_metadata (PublishingFlickrFlickrPublisher* self)
{
	gboolean result = FALSE;
	SpitPublishingPluginHost* _tmp0_;
#line 124 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_val_if_fail (PUBLISHING_FLICKR_IS_FLICKR_PUBLISHER (self), FALSE);
#line 125 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = self->priv->host;
#line 125 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	result = spit_host_interface_get_config_bool (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), "strip_metadata", FALSE);
#line 125 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return result;
#line 1804 "FlickrPublishing.c"
}


static void
publishing_flickr_flickr_publisher_set_persistent_strip_metadata (PublishingFlickrFlickrPublisher* self,
                                                                  gboolean strip_metadata)
{
	SpitPublishingPluginHost* _tmp0_;
#line 128 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (PUBLISHING_FLICKR_IS_FLICKR_PUBLISHER (self));
#line 129 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = self->priv->host;
#line 129 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	spit_host_interface_set_config_bool (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), "strip_metadata", strip_metadata);
#line 1819 "FlickrPublishing.c"
}


static gpointer
_g_variant_ref0 (gpointer self)
{
#line 145 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return self ? g_variant_ref (self) : NULL;
#line 1828 "FlickrPublishing.c"
}


static void
publishing_flickr_flickr_publisher_on_session_authenticated (PublishingFlickrFlickrPublisher* self)
{
	GHashTable* params = NULL;
	SpitPublishingAuthenticator* _tmp0_;
	GHashTable* _tmp1_;
	GVariant* consumer_key = NULL;
	GVariant* consumer_secret = NULL;
	GVariant* auth_token = NULL;
	GVariant* auth_token_secret = NULL;
	GVariant* username = NULL;
	GHashTable* _tmp2_;
	gconstpointer _tmp3_ = NULL;
	GVariant* _tmp4_;
	GHashTable* _tmp5_;
	gconstpointer _tmp6_ = NULL;
	GVariant* _tmp7_;
	PublishingRESTSupportOAuth1Session* _tmp8_;
	GVariant* _tmp9_;
	const gchar* _tmp10_;
	GVariant* _tmp11_;
	const gchar* _tmp12_;
	GHashTable* _tmp13_;
	gconstpointer _tmp14_ = NULL;
	GVariant* _tmp15_;
	GHashTable* _tmp16_;
	gconstpointer _tmp17_ = NULL;
	GVariant* _tmp18_;
	GHashTable* _tmp19_;
	gconstpointer _tmp20_ = NULL;
	GVariant* _tmp21_;
	PublishingRESTSupportOAuth1Session* _tmp22_;
	GVariant* _tmp23_;
	const gchar* _tmp24_;
	GVariant* _tmp25_;
	const gchar* _tmp26_;
	GVariant* _tmp27_;
	const gchar* _tmp28_;
	PublishingFlickrPublishingParameters* _tmp29_;
	PublishingRESTSupportOAuth1Session* _tmp30_;
	gchar* _tmp31_;
#line 132 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (PUBLISHING_FLICKR_IS_FLICKR_PUBLISHER (self));
#line 133 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (!spit_publishing_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_PUBLISHER, SpitPublishingPublisher))) {
#line 134 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		return;
#line 1879 "FlickrPublishing.c"
	}
#line 136 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_debug ("FlickrPublishing.vala:136: EVENT: a fully authenticated session has be" \
"come available");
#line 138 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = self->priv->authenticator;
#line 138 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp1_ = spit_publishing_authenticator_get_authentication_parameter (_tmp0_);
#line 138 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	params = _tmp1_;
#line 139 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	consumer_key = NULL;
#line 140 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	consumer_secret = NULL;
#line 141 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	auth_token = NULL;
#line 142 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	auth_token_secret = NULL;
#line 143 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	username = NULL;
#line 145 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp2_ = params;
#line 145 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_hash_table_lookup_extended (_tmp2_, "ConsumerKey", NULL, &_tmp3_);
#line 145 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_variant_unref0 (consumer_key);
#line 145 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp4_ = _g_variant_ref0 (_tmp3_);
#line 145 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	consumer_key = _tmp4_;
#line 146 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp5_ = params;
#line 146 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_hash_table_lookup_extended (_tmp5_, "ConsumerSecret", NULL, &_tmp6_);
#line 146 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_variant_unref0 (consumer_secret);
#line 146 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp7_ = _g_variant_ref0 (_tmp6_);
#line 146 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	consumer_secret = _tmp7_;
#line 147 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp8_ = self->priv->session;
#line 147 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp9_ = consumer_key;
#line 147 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp10_ = g_variant_get_string (_tmp9_, NULL);
#line 147 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp11_ = consumer_secret;
#line 147 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp12_ = g_variant_get_string (_tmp11_, NULL);
#line 147 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_rest_support_oauth1_session_set_api_credentials (_tmp8_, _tmp10_, _tmp12_);
#line 149 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp13_ = params;
#line 149 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_hash_table_lookup_extended (_tmp13_, "AuthToken", NULL, &_tmp14_);
#line 149 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_variant_unref0 (auth_token);
#line 149 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp15_ = _g_variant_ref0 (_tmp14_);
#line 149 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	auth_token = _tmp15_;
#line 150 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp16_ = params;
#line 150 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_hash_table_lookup_extended (_tmp16_, "AuthTokenSecret", NULL, &_tmp17_);
#line 150 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_variant_unref0 (auth_token_secret);
#line 150 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp18_ = _g_variant_ref0 (_tmp17_);
#line 150 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	auth_token_secret = _tmp18_;
#line 151 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp19_ = params;
#line 151 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_hash_table_lookup_extended (_tmp19_, "Username", NULL, &_tmp20_);
#line 151 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_variant_unref0 (username);
#line 151 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp21_ = _g_variant_ref0 (_tmp20_);
#line 151 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	username = _tmp21_;
#line 152 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp22_ = self->priv->session;
#line 152 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp23_ = auth_token;
#line 152 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp24_ = g_variant_get_string (_tmp23_, NULL);
#line 152 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp25_ = auth_token_secret;
#line 152 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp26_ = g_variant_get_string (_tmp25_, NULL);
#line 152 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp27_ = username;
#line 152 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp28_ = g_variant_get_string (_tmp27_, NULL);
#line 152 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_rest_support_oauth1_session_set_access_phase_credentials (_tmp22_, _tmp24_, _tmp26_, _tmp28_);
#line 155 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp29_ = self->priv->parameters;
#line 155 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp30_ = self->priv->session;
#line 155 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp31_ = publishing_rest_support_oauth1_session_get_username (_tmp30_);
#line 155 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_free0 (_tmp29_->username);
#line 155 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp29_->username = _tmp31_;
#line 157 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_flickr_publisher_do_fetch_account_info (self);
#line 132 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_variant_unref0 (username);
#line 132 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_variant_unref0 (auth_token_secret);
#line 132 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_variant_unref0 (auth_token);
#line 132 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_variant_unref0 (consumer_secret);
#line 132 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_variant_unref0 (consumer_key);
#line 132 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_hash_table_unref0 (params);
#line 2001 "FlickrPublishing.c"
}


static void
_publishing_flickr_flickr_publisher_on_account_fetch_txn_completed_publishing_rest_support_transaction_completed (PublishingRESTSupportTransaction* _sender,
                                                                                                                  gpointer self)
{
#line 161 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_flickr_publisher_on_account_fetch_txn_completed ((PublishingFlickrFlickrPublisher*) self, _sender);
#line 2011 "FlickrPublishing.c"
}


static void
_publishing_flickr_flickr_publisher_on_account_fetch_txn_error_publishing_rest_support_transaction_network_error (PublishingRESTSupportTransaction* _sender,
                                                                                                                  GError* err,
                                                                                                                  gpointer self)
{
#line 162 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_flickr_publisher_on_account_fetch_txn_error ((PublishingFlickrFlickrPublisher*) self, _sender, err);
#line 2022 "FlickrPublishing.c"
}


static void
publishing_flickr_flickr_publisher_on_account_fetch_txn_completed (PublishingFlickrFlickrPublisher* self,
                                                                   PublishingRESTSupportTransaction* txn)
{
	guint _tmp0_;
	guint _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
#line 160 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (PUBLISHING_FLICKR_IS_FLICKR_PUBLISHER (self));
#line 160 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (PUBLISHING_REST_SUPPORT_IS_TRANSACTION (txn));
#line 161 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_parse_name ("completed", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp0_, NULL, FALSE);
#line 161 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_handlers_disconnect_matched (txn, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp0_, 0, NULL, (GCallback) _publishing_flickr_flickr_publisher_on_account_fetch_txn_completed_publishing_rest_support_transaction_completed, self);
#line 162 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_parse_name ("network-error", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp1_, NULL, FALSE);
#line 162 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_handlers_disconnect_matched (txn, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _publishing_flickr_flickr_publisher_on_account_fetch_txn_error_publishing_rest_support_transaction_network_error, self);
#line 164 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (!spit_publishing_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_PUBLISHER, SpitPublishingPublisher))) {
#line 165 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		return;
#line 2050 "FlickrPublishing.c"
	}
#line 167 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_debug ("FlickrPublishing.vala:167: EVENT: account fetch transaction response r" \
"eceived over the network");
#line 168 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp2_ = publishing_rest_support_transaction_get_response (txn);
#line 168 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp3_ = _tmp2_;
#line 168 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_flickr_publisher_do_parse_account_info_from_xml (self, _tmp3_);
#line 168 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_free0 (_tmp3_);
#line 2062 "FlickrPublishing.c"
}


static void
publishing_flickr_flickr_publisher_on_account_fetch_txn_error (PublishingFlickrFlickrPublisher* self,
                                                               PublishingRESTSupportTransaction* txn,
                                                               GError* err)
{
	guint _tmp0_;
	guint _tmp1_;
	SpitPublishingPluginHost* _tmp2_;
#line 171 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (PUBLISHING_FLICKR_IS_FLICKR_PUBLISHER (self));
#line 171 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (PUBLISHING_REST_SUPPORT_IS_TRANSACTION (txn));
#line 173 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_parse_name ("completed", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp0_, NULL, FALSE);
#line 173 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_handlers_disconnect_matched (txn, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp0_, 0, NULL, (GCallback) _publishing_flickr_flickr_publisher_on_account_fetch_txn_completed_publishing_rest_support_transaction_completed, self);
#line 174 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_parse_name ("network-error", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp1_, NULL, FALSE);
#line 174 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_handlers_disconnect_matched (txn, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _publishing_flickr_flickr_publisher_on_account_fetch_txn_error_publishing_rest_support_transaction_network_error, self);
#line 176 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (!spit_publishing_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_PUBLISHER, SpitPublishingPublisher))) {
#line 177 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		return;
#line 2090 "FlickrPublishing.c"
	}
#line 179 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_debug ("FlickrPublishing.vala:179: EVENT: account fetch transaction caused a n" \
"etwork error");
#line 180 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp2_ = self->priv->host;
#line 180 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	spit_publishing_plugin_host_post_error (_tmp2_, err);
#line 2098 "FlickrPublishing.c"
}


static void
publishing_flickr_flickr_publisher_on_account_info_available (PublishingFlickrFlickrPublisher* self)
{
#line 183 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (PUBLISHING_FLICKR_IS_FLICKR_PUBLISHER (self));
#line 184 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (!spit_publishing_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_PUBLISHER, SpitPublishingPublisher))) {
#line 185 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		return;
#line 2111 "FlickrPublishing.c"
	}
#line 187 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_debug ("FlickrPublishing.vala:187: EVENT: account information has become avail" \
"able");
#line 188 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_flickr_publisher_do_show_publishing_options_pane (self);
#line 2117 "FlickrPublishing.c"
}


static void
_publishing_flickr_flickr_publisher_on_publishing_options_pane_publish_publishing_flickr_publishing_options_pane_publish (PublishingFlickrPublishingOptionsPane* _sender,
                                                                                                                          gboolean strip_metadata,
                                                                                                                          gpointer self)
{
#line 192 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_flickr_publisher_on_publishing_options_pane_publish ((PublishingFlickrFlickrPublisher*) self, strip_metadata);
#line 2128 "FlickrPublishing.c"
}


static void
_publishing_flickr_flickr_publisher_on_publishing_options_pane_logout_publishing_flickr_publishing_options_pane_logout (PublishingFlickrPublishingOptionsPane* _sender,
                                                                                                                        gpointer self)
{
#line 193 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_flickr_publisher_on_publishing_options_pane_logout ((PublishingFlickrFlickrPublisher*) self);
#line 2138 "FlickrPublishing.c"
}


static void
publishing_flickr_flickr_publisher_on_publishing_options_pane_publish (PublishingFlickrFlickrPublisher* self,
                                                                       gboolean strip_metadata)
{
	PublishingFlickrPublishingOptionsPane* _tmp0_;
	guint _tmp1_;
	PublishingFlickrPublishingOptionsPane* _tmp2_;
	guint _tmp3_;
#line 191 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (PUBLISHING_FLICKR_IS_FLICKR_PUBLISHER (self));
#line 192 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = self->priv->publishing_options_pane;
#line 192 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_parse_name ("publish", PUBLISHING_FLICKR_TYPE_PUBLISHING_OPTIONS_PANE, &_tmp1_, NULL, FALSE);
#line 192 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp0_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _publishing_flickr_flickr_publisher_on_publishing_options_pane_publish_publishing_flickr_publishing_options_pane_publish, self);
#line 193 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp2_ = self->priv->publishing_options_pane;
#line 193 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_parse_name ("logout", PUBLISHING_FLICKR_TYPE_PUBLISHING_OPTIONS_PANE, &_tmp3_, NULL, FALSE);
#line 193 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp2_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp3_, 0, NULL, (GCallback) _publishing_flickr_flickr_publisher_on_publishing_options_pane_logout_publishing_flickr_publishing_options_pane_logout, self);
#line 195 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (!spit_publishing_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_PUBLISHER, SpitPublishingPublisher))) {
#line 196 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		return;
#line 2168 "FlickrPublishing.c"
	}
#line 198 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_debug ("FlickrPublishing.vala:198: EVENT: user clicked the 'Publish' button in" \
" the publishing options pane");
#line 199 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_flickr_publisher_do_publish (self, strip_metadata);
#line 2174 "FlickrPublishing.c"
}


static void
publishing_flickr_flickr_publisher_on_publishing_options_pane_logout (PublishingFlickrFlickrPublisher* self)
{
	PublishingFlickrPublishingOptionsPane* _tmp0_;
	guint _tmp1_;
	PublishingFlickrPublishingOptionsPane* _tmp2_;
	guint _tmp3_;
#line 202 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (PUBLISHING_FLICKR_IS_FLICKR_PUBLISHER (self));
#line 203 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = self->priv->publishing_options_pane;
#line 203 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_parse_name ("publish", PUBLISHING_FLICKR_TYPE_PUBLISHING_OPTIONS_PANE, &_tmp1_, NULL, FALSE);
#line 203 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp0_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _publishing_flickr_flickr_publisher_on_publishing_options_pane_publish_publishing_flickr_publishing_options_pane_publish, self);
#line 204 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp2_ = self->priv->publishing_options_pane;
#line 204 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_parse_name ("logout", PUBLISHING_FLICKR_TYPE_PUBLISHING_OPTIONS_PANE, &_tmp3_, NULL, FALSE);
#line 204 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp2_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp3_, 0, NULL, (GCallback) _publishing_flickr_flickr_publisher_on_publishing_options_pane_logout_publishing_flickr_publishing_options_pane_logout, self);
#line 206 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (!spit_publishing_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_PUBLISHER, SpitPublishingPublisher))) {
#line 207 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		return;
#line 2203 "FlickrPublishing.c"
	}
#line 209 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_debug ("FlickrPublishing.vala:209: EVENT: user clicked the 'Logout' button in " \
"the publishing options pane");
#line 211 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_flickr_publisher_do_logout (self);
#line 2209 "FlickrPublishing.c"
}


static void
publishing_flickr_flickr_publisher_on_upload_status_updated (PublishingFlickrFlickrPublisher* self,
                                                             gint file_number,
                                                             gdouble completed_fraction)
{
	SpitPublishingProgressCallback _tmp0_;
	void* _tmp0__target;
	SpitPublishingProgressCallback _tmp1_;
	void* _tmp1__target;
#line 214 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (PUBLISHING_FLICKR_IS_FLICKR_PUBLISHER (self));
#line 215 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (!spit_publishing_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_PUBLISHER, SpitPublishingPublisher))) {
#line 216 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		return;
#line 2228 "FlickrPublishing.c"
	}
#line 218 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_debug ("FlickrPublishing.vala:218: EVENT: uploader reports upload %.2f percent" \
" complete.", 100.0 * completed_fraction);
#line 220 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = self->priv->progress_reporter;
#line 220 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0__target = self->priv->progress_reporter_target;
#line 220 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_vala_assert (_tmp0_ != NULL, "progress_reporter != null");
#line 222 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp1_ = self->priv->progress_reporter;
#line 222 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp1__target = self->priv->progress_reporter_target;
#line 222 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp1_ (file_number, completed_fraction, _tmp1__target);
#line 2244 "FlickrPublishing.c"
}


static void
_publishing_flickr_flickr_publisher_on_upload_complete_publishing_rest_support_batch_uploader_upload_complete (PublishingRESTSupportBatchUploader* _sender,
                                                                                                               gint num_photos_published,
                                                                                                               gpointer self)
{
#line 232 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_flickr_publisher_on_upload_complete ((PublishingFlickrFlickrPublisher*) self, _sender, num_photos_published);
#line 2255 "FlickrPublishing.c"
}


static void
_publishing_flickr_flickr_publisher_on_upload_error_publishing_rest_support_batch_uploader_upload_error (PublishingRESTSupportBatchUploader* _sender,
                                                                                                         GError* err,
                                                                                                         gpointer self)
{
#line 233 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_flickr_publisher_on_upload_error ((PublishingFlickrFlickrPublisher*) self, _sender, err);
#line 2266 "FlickrPublishing.c"
}


static void
publishing_flickr_flickr_publisher_on_upload_complete (PublishingFlickrFlickrPublisher* self,
                                                       PublishingRESTSupportBatchUploader* uploader,
                                                       gint num_published)
{
	guint _tmp0_;
	guint _tmp1_;
#line 225 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (PUBLISHING_FLICKR_IS_FLICKR_PUBLISHER (self));
#line 225 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (PUBLISHING_REST_SUPPORT_IS_BATCH_UPLOADER (uploader));
#line 227 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (!spit_publishing_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_PUBLISHER, SpitPublishingPublisher))) {
#line 228 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		return;
#line 2285 "FlickrPublishing.c"
	}
#line 230 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_debug ("FlickrPublishing.vala:230: EVENT: uploader reports upload complete; %d" \
" items published.", num_published);
#line 232 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_parse_name ("upload-complete", PUBLISHING_REST_SUPPORT_TYPE_BATCH_UPLOADER, &_tmp0_, NULL, FALSE);
#line 232 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_handlers_disconnect_matched (uploader, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp0_, 0, NULL, (GCallback) _publishing_flickr_flickr_publisher_on_upload_complete_publishing_rest_support_batch_uploader_upload_complete, self);
#line 233 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_parse_name ("upload-error", PUBLISHING_REST_SUPPORT_TYPE_BATCH_UPLOADER, &_tmp1_, NULL, FALSE);
#line 233 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_handlers_disconnect_matched (uploader, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _publishing_flickr_flickr_publisher_on_upload_error_publishing_rest_support_batch_uploader_upload_error, self);
#line 235 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_flickr_publisher_do_show_success_pane (self);
#line 2299 "FlickrPublishing.c"
}


static void
publishing_flickr_flickr_publisher_on_upload_error (PublishingFlickrFlickrPublisher* self,
                                                    PublishingRESTSupportBatchUploader* uploader,
                                                    GError* err)
{
	const gchar* _tmp0_;
	guint _tmp1_;
	guint _tmp2_;
	SpitPublishingPluginHost* _tmp3_;
#line 238 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (PUBLISHING_FLICKR_IS_FLICKR_PUBLISHER (self));
#line 238 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (PUBLISHING_REST_SUPPORT_IS_BATCH_UPLOADER (uploader));
#line 240 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (!spit_publishing_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_PUBLISHER, SpitPublishingPublisher))) {
#line 241 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		return;
#line 2320 "FlickrPublishing.c"
	}
#line 243 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = err->message;
#line 243 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_debug ("FlickrPublishing.vala:243: EVENT: uploader reports upload error = '%s'" \
".", _tmp0_);
#line 245 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_parse_name ("upload-complete", PUBLISHING_REST_SUPPORT_TYPE_BATCH_UPLOADER, &_tmp1_, NULL, FALSE);
#line 245 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_handlers_disconnect_matched (uploader, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _publishing_flickr_flickr_publisher_on_upload_complete_publishing_rest_support_batch_uploader_upload_complete, self);
#line 246 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_parse_name ("upload-error", PUBLISHING_REST_SUPPORT_TYPE_BATCH_UPLOADER, &_tmp2_, NULL, FALSE);
#line 246 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_handlers_disconnect_matched (uploader, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp2_, 0, NULL, (GCallback) _publishing_flickr_flickr_publisher_on_upload_error_publishing_rest_support_batch_uploader_upload_error, self);
#line 248 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp3_ = self->priv->host;
#line 248 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	spit_publishing_plugin_host_post_error (_tmp3_, err);
#line 2338 "FlickrPublishing.c"
}


static void
publishing_flickr_flickr_publisher_do_fetch_account_info (PublishingFlickrFlickrPublisher* self)
{
	SpitPublishingPluginHost* _tmp0_;
	SpitPublishingPluginHost* _tmp1_;
	PublishingFlickrAccountInfoFetchTransaction* txn = NULL;
	PublishingRESTSupportOAuth1Session* _tmp2_;
	PublishingFlickrAccountInfoFetchTransaction* _tmp3_;
	GError * _inner_error_ = NULL;
#line 251 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (PUBLISHING_FLICKR_IS_FLICKR_PUBLISHER (self));
#line 252 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_debug ("FlickrPublishing.vala:252: ACTION: running network transaction to fetc" \
"h account information");
#line 254 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = self->priv->host;
#line 254 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	spit_publishing_plugin_host_set_service_locked (_tmp0_, TRUE);
#line 255 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp1_ = self->priv->host;
#line 255 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	spit_publishing_plugin_host_install_account_fetch_wait_pane (_tmp1_);
#line 257 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp2_ = self->priv->session;
#line 257 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp3_ = publishing_flickr_account_info_fetch_transaction_new (_tmp2_);
#line 257 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	txn = _tmp3_;
#line 258 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (txn, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "completed", (GCallback) _publishing_flickr_flickr_publisher_on_account_fetch_txn_completed_publishing_rest_support_transaction_completed, self, 0);
#line 259 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (txn, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "network-error", (GCallback) _publishing_flickr_flickr_publisher_on_account_fetch_txn_error_publishing_rest_support_transaction_network_error, self, 0);
#line 2373 "FlickrPublishing.c"
	{
#line 262 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		publishing_rest_support_transaction_execute (G_TYPE_CHECK_INSTANCE_CAST (txn, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), &_inner_error_);
#line 262 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 262 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 2381 "FlickrPublishing.c"
				goto __catch13_spit_publishing_publishing_error;
			}
#line 262 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_publishing_rest_support_transaction_unref0 (txn);
#line 262 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 262 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			g_clear_error (&_inner_error_);
#line 262 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			return;
#line 2392 "FlickrPublishing.c"
		}
	}
	goto __finally13;
	__catch13_spit_publishing_publishing_error:
	{
		GError* err = NULL;
		SpitPublishingPluginHost* _tmp4_;
		GError* _tmp5_;
#line 261 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		err = _inner_error_;
#line 261 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_inner_error_ = NULL;
#line 264 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp4_ = self->priv->host;
#line 264 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp5_ = err;
#line 264 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		spit_publishing_plugin_host_post_error (_tmp4_, _tmp5_);
#line 261 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_g_error_free0 (err);
#line 2413 "FlickrPublishing.c"
	}
	__finally13:
#line 261 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 261 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_publishing_rest_support_transaction_unref0 (txn);
#line 261 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 261 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		g_clear_error (&_inner_error_);
#line 261 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		return;
#line 2426 "FlickrPublishing.c"
	}
#line 251 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_publishing_rest_support_transaction_unref0 (txn);
#line 2430 "FlickrPublishing.c"
}


static gint64
int64_parse (const gchar* str)
{
	gint64 result = 0LL;
	gint64 _tmp0_;
#line 687 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	g_return_val_if_fail (str != NULL, 0LL);
#line 688 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	_tmp0_ = g_ascii_strtoll (str, NULL, (guint) 0);
#line 688 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	result = _tmp0_;
#line 688 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	return result;
#line 2447 "FlickrPublishing.c"
}


static void
publishing_flickr_flickr_publisher_do_parse_account_info_from_xml (PublishingFlickrFlickrPublisher* self,
                                                                   const gchar* xml)
{
	GError * _inner_error_ = NULL;
#line 268 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (PUBLISHING_FLICKR_IS_FLICKR_PUBLISHER (self));
#line 268 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (xml != NULL);
#line 269 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_debug ("FlickrPublishing.vala:269: ACTION: parsing account information from xm" \
"l = '%s'", xml);
#line 2462 "FlickrPublishing.c"
	{
		PublishingRESTSupportXmlDocument* response_doc = NULL;
		PublishingRESTSupportXmlDocument* _tmp0_;
		xmlNode* root_node = NULL;
		PublishingRESTSupportXmlDocument* _tmp1_;
		xmlNode* _tmp2_;
		xmlNode* user_node = NULL;
		PublishingRESTSupportXmlDocument* _tmp3_;
		xmlNode* _tmp4_;
		xmlNode* _tmp5_;
		gchar* is_pro_str = NULL;
		PublishingRESTSupportXmlDocument* _tmp6_;
		xmlNode* _tmp7_;
		gchar* _tmp8_;
		xmlNode* bandwidth_node = NULL;
		PublishingRESTSupportXmlDocument* _tmp9_;
		xmlNode* _tmp10_;
		xmlNode* _tmp11_;
		gchar* remaining_kb_str = NULL;
		PublishingRESTSupportXmlDocument* _tmp12_;
		xmlNode* _tmp13_;
		gchar* _tmp14_;
		PublishingFlickrUserKind user_kind = 0;
		const gchar* _tmp15_;
		gint64 quota_bytes_left = 0LL;
		const gchar* _tmp18_;
		PublishingFlickrPublishingParameters* _tmp19_;
		gint64 _tmp20_;
		PublishingFlickrPublishingParameters* _tmp21_;
		PublishingFlickrUserKind _tmp22_;
#line 271 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp0_ = publishing_flickr_transaction_parse_flickr_response (xml, &_inner_error_);
#line 271 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		response_doc = _tmp0_;
#line 271 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 271 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 2501 "FlickrPublishing.c"
				goto __catch14_spit_publishing_publishing_error;
			}
#line 271 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 271 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			g_clear_error (&_inner_error_);
#line 271 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			return;
#line 2510 "FlickrPublishing.c"
		}
#line 272 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp1_ = response_doc;
#line 272 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp2_ = publishing_rest_support_xml_document_get_root_node (_tmp1_);
#line 272 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		root_node = _tmp2_;
#line 274 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp3_ = response_doc;
#line 274 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp4_ = root_node;
#line 274 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp5_ = publishing_rest_support_xml_document_get_named_child (_tmp3_, _tmp4_, "user", &_inner_error_);
#line 274 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		user_node = _tmp5_;
#line 274 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 274 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_publishing_rest_support_xml_document_unref0 (response_doc);
#line 274 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 2532 "FlickrPublishing.c"
				goto __catch14_spit_publishing_publishing_error;
			}
#line 274 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_publishing_rest_support_xml_document_unref0 (response_doc);
#line 274 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 274 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			g_clear_error (&_inner_error_);
#line 274 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			return;
#line 2543 "FlickrPublishing.c"
		}
#line 276 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp6_ = response_doc;
#line 276 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp7_ = user_node;
#line 276 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp8_ = publishing_rest_support_xml_document_get_property_value (_tmp6_, _tmp7_, "ispro", &_inner_error_);
#line 276 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		is_pro_str = _tmp8_;
#line 276 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 276 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_publishing_rest_support_xml_document_unref0 (response_doc);
#line 276 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 2559 "FlickrPublishing.c"
				goto __catch14_spit_publishing_publishing_error;
			}
#line 276 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_publishing_rest_support_xml_document_unref0 (response_doc);
#line 276 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 276 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			g_clear_error (&_inner_error_);
#line 276 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			return;
#line 2570 "FlickrPublishing.c"
		}
#line 278 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp9_ = response_doc;
#line 278 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp10_ = user_node;
#line 278 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp11_ = publishing_rest_support_xml_document_get_named_child (_tmp9_, _tmp10_, "bandwidth", &_inner_error_);
#line 278 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		bandwidth_node = _tmp11_;
#line 278 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 278 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_g_free0 (is_pro_str);
#line 278 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_publishing_rest_support_xml_document_unref0 (response_doc);
#line 278 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 2588 "FlickrPublishing.c"
				goto __catch14_spit_publishing_publishing_error;
			}
#line 278 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_g_free0 (is_pro_str);
#line 278 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_publishing_rest_support_xml_document_unref0 (response_doc);
#line 278 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 278 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			g_clear_error (&_inner_error_);
#line 278 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			return;
#line 2601 "FlickrPublishing.c"
		}
#line 280 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp12_ = response_doc;
#line 280 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp13_ = bandwidth_node;
#line 280 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp14_ = publishing_rest_support_xml_document_get_property_value (_tmp12_, _tmp13_, "remainingkb", &_inner_error_);
#line 280 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		remaining_kb_str = _tmp14_;
#line 280 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 280 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_g_free0 (is_pro_str);
#line 280 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_publishing_rest_support_xml_document_unref0 (response_doc);
#line 280 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 2619 "FlickrPublishing.c"
				goto __catch14_spit_publishing_publishing_error;
			}
#line 280 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_g_free0 (is_pro_str);
#line 280 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_publishing_rest_support_xml_document_unref0 (response_doc);
#line 280 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 280 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			g_clear_error (&_inner_error_);
#line 280 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			return;
#line 2632 "FlickrPublishing.c"
		}
#line 283 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp15_ = is_pro_str;
#line 283 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		if (g_strcmp0 (_tmp15_, "0") == 0) {
#line 284 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			user_kind = PUBLISHING_FLICKR_USER_KIND_FREE;
#line 2640 "FlickrPublishing.c"
		} else {
			const gchar* _tmp16_;
#line 285 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_tmp16_ = is_pro_str;
#line 285 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			if (g_strcmp0 (_tmp16_, "1") == 0) {
#line 286 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				user_kind = PUBLISHING_FLICKR_USER_KIND_PRO;
#line 2649 "FlickrPublishing.c"
			} else {
				GError* _tmp17_;
#line 288 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_tmp17_ = g_error_new_literal (SPIT_PUBLISHING_PUBLISHING_ERROR, SPIT_PUBLISHING_PUBLISHING_ERROR_MALFORMED_RESPONSE, "Unable to determine if user has free or pro account");
#line 288 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_inner_error_ = _tmp17_;
#line 288 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_g_free0 (remaining_kb_str);
#line 288 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_g_free0 (is_pro_str);
#line 288 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_publishing_rest_support_xml_document_unref0 (response_doc);
#line 288 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 2664 "FlickrPublishing.c"
					goto __catch14_spit_publishing_publishing_error;
				}
#line 288 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_g_free0 (remaining_kb_str);
#line 288 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_g_free0 (is_pro_str);
#line 288 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_publishing_rest_support_xml_document_unref0 (response_doc);
#line 288 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 288 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				g_clear_error (&_inner_error_);
#line 288 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				return;
#line 2679 "FlickrPublishing.c"
			}
		}
#line 291 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp18_ = remaining_kb_str;
#line 291 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		quota_bytes_left = int64_parse (_tmp18_) * 1024;
#line 293 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp19_ = self->priv->parameters;
#line 293 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp20_ = quota_bytes_left;
#line 293 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp19_->quota_free_bytes = _tmp20_;
#line 294 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp21_ = self->priv->parameters;
#line 294 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp22_ = user_kind;
#line 294 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp21_->user_kind = _tmp22_;
#line 270 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_g_free0 (remaining_kb_str);
#line 270 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_g_free0 (is_pro_str);
#line 270 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_publishing_rest_support_xml_document_unref0 (response_doc);
#line 2704 "FlickrPublishing.c"
	}
	goto __finally14;
	__catch14_spit_publishing_publishing_error:
	{
		GError* err = NULL;
		GError* _tmp23_;
		SpitPublishingPluginHost* _tmp24_;
		GError* _tmp25_;
#line 270 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		err = _inner_error_;
#line 270 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_inner_error_ = NULL;
#line 300 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp23_ = err;
#line 300 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		if (g_error_matches (_tmp23_, SPIT_PUBLISHING_PUBLISHING_ERROR, SPIT_PUBLISHING_PUBLISHING_ERROR_EXPIRED_SESSION)) {
#line 301 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			publishing_flickr_flickr_publisher_do_logout (self);
#line 302 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_g_error_free0 (err);
#line 302 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			return;
#line 2727 "FlickrPublishing.c"
		}
#line 305 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp24_ = self->priv->host;
#line 305 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp25_ = err;
#line 305 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		spit_publishing_plugin_host_post_error (_tmp24_, _tmp25_);
#line 306 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_g_error_free0 (err);
#line 306 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		return;
#line 2739 "FlickrPublishing.c"
	}
	__finally14:
#line 270 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 270 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 270 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		g_clear_error (&_inner_error_);
#line 270 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		return;
#line 2750 "FlickrPublishing.c"
	}
#line 309 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_flickr_publisher_on_account_info_available (self);
#line 2754 "FlickrPublishing.c"
}


static void
publishing_flickr_flickr_publisher_do_logout (PublishingFlickrFlickrPublisher* self)
{
	SpitPublishingAuthenticator* _tmp0_;
#line 312 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (PUBLISHING_FLICKR_IS_FLICKR_PUBLISHER (self));
#line 313 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_debug ("FlickrPublishing.vala:313: ACTION: logging user out, deauthenticating " \
"session, and erasing stored credentials");
#line 315 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = self->priv->authenticator;
#line 315 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (spit_publishing_authenticator_can_logout (_tmp0_)) {
#line 2770 "FlickrPublishing.c"
		SpitPublishingAuthenticator* _tmp1_;
#line 316 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp1_ = self->priv->authenticator;
#line 316 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		spit_publishing_authenticator_logout (_tmp1_);
#line 2776 "FlickrPublishing.c"
	}
#line 319 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->running = FALSE;
#line 321 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_flickr_publisher_attempt_start (self);
#line 2782 "FlickrPublishing.c"
}


static void
publishing_flickr_flickr_publisher_do_show_publishing_options_pane (PublishingFlickrFlickrPublisher* self)
{
	SpitPublishingPluginHost* _tmp0_;
	GtkBuilder* builder = NULL;
	GtkBuilder* _tmp1_;
	PublishingFlickrPublishingParameters* _tmp8_;
	SpitPublishingPluginHost* _tmp9_;
	GtkBuilder* _tmp10_;
	PublishingFlickrPublishingOptionsPane* _tmp11_;
	PublishingFlickrPublishingOptionsPane* _tmp12_;
	PublishingFlickrPublishingOptionsPane* _tmp13_;
	SpitPublishingPluginHost* _tmp14_;
	PublishingFlickrPublishingOptionsPane* _tmp15_;
	GError * _inner_error_ = NULL;
#line 324 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (PUBLISHING_FLICKR_IS_FLICKR_PUBLISHER (self));
#line 325 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_debug ("FlickrPublishing.vala:325: ACTION: displaying publishing options pane");
#line 327 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = self->priv->host;
#line 327 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	spit_publishing_plugin_host_set_service_locked (_tmp0_, FALSE);
#line 329 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp1_ = gtk_builder_new ();
#line 329 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	builder = _tmp1_;
#line 2813 "FlickrPublishing.c"
	{
		GtkBuilder* _tmp2_;
#line 334 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp2_ = builder;
#line 334 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		gtk_builder_add_from_resource (_tmp2_, PLUGIN_RESOURCE_PATH "/" "flickr_publishing_options_pane.ui", &_inner_error_);
#line 334 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 2822 "FlickrPublishing.c"
			goto __catch15_g_error;
		}
	}
	goto __finally15;
	__catch15_g_error:
	{
		GError* e = NULL;
		GError* _tmp3_;
		const gchar* _tmp4_;
		SpitPublishingPluginHost* _tmp5_;
		GError* _tmp6_;
		GError* _tmp7_;
#line 331 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		e = _inner_error_;
#line 331 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_inner_error_ = NULL;
#line 337 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp3_ = e;
#line 337 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp4_ = _tmp3_->message;
#line 337 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		g_warning ("FlickrPublishing.vala:337: Could not parse UI file! Error: %s.", _tmp4_);
#line 338 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp5_ = self->priv->host;
#line 338 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp6_ = g_error_new_literal (SPIT_PUBLISHING_PUBLISHING_ERROR, SPIT_PUBLISHING_PUBLISHING_ERROR_LOCAL_FILE_ERROR, _ ("A file required for publishing is unavailable. Publishing to Flickr ca" \
"n’t continue."));
#line 338 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp7_ = _tmp6_;
#line 338 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		spit_publishing_plugin_host_post_error (_tmp5_, _tmp7_);
#line 338 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_g_error_free0 (_tmp7_);
#line 341 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_g_error_free0 (e);
#line 341 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_g_object_unref0 (builder);
#line 341 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		return;
#line 2861 "FlickrPublishing.c"
	}
	__finally15:
#line 331 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 331 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_g_object_unref0 (builder);
#line 331 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 331 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		g_clear_error (&_inner_error_);
#line 331 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		return;
#line 2874 "FlickrPublishing.c"
	}
#line 344 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp8_ = self->priv->parameters;
#line 344 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp9_ = self->priv->host;
#line 344 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp10_ = builder;
#line 344 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp11_ = publishing_flickr_publishing_options_pane_new (self, _tmp8_, spit_publishing_plugin_host_get_publishable_media_type (_tmp9_), _tmp10_, publishing_flickr_flickr_publisher_get_persistent_strip_metadata (self));
#line 344 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_object_unref0 (self->priv->publishing_options_pane);
#line 344 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->publishing_options_pane = _tmp11_;
#line 346 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp12_ = self->priv->publishing_options_pane;
#line 346 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_connect_object (_tmp12_, "publish", (GCallback) _publishing_flickr_flickr_publisher_on_publishing_options_pane_publish_publishing_flickr_publishing_options_pane_publish, self, 0);
#line 347 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp13_ = self->priv->publishing_options_pane;
#line 347 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_connect_object (_tmp13_, "logout", (GCallback) _publishing_flickr_flickr_publisher_on_publishing_options_pane_logout_publishing_flickr_publishing_options_pane_logout, self, 0);
#line 348 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp14_ = self->priv->host;
#line 348 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp15_ = self->priv->publishing_options_pane;
#line 348 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	spit_publishing_plugin_host_install_dialog_pane (_tmp14_, G_TYPE_CHECK_INSTANCE_CAST (_tmp15_, SPIT_PUBLISHING_TYPE_DIALOG_PANE, SpitPublishingDialogPane), SPIT_PUBLISHING_PLUGIN_HOST_BUTTON_MODE_CANCEL);
#line 324 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_object_unref0 (builder);
#line 2904 "FlickrPublishing.c"
}


gint
publishing_flickr_flickr_publisher_flickr_date_time_compare_func (SpitPublishingPublishable* a,
                                                                  SpitPublishingPublishable* b)
{
	gint result = 0;
	GDateTime* _tmp0_;
	GDateTime* _tmp1_;
	GDateTime* _tmp2_;
	GDateTime* _tmp3_;
	gint _tmp4_;
#line 351 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_val_if_fail (SPIT_PUBLISHING_IS_PUBLISHABLE (a), 0);
#line 351 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_val_if_fail (SPIT_PUBLISHING_IS_PUBLISHABLE (b), 0);
#line 353 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = spit_publishing_publishable_get_exposure_date_time (a);
#line 353 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp1_ = _tmp0_;
#line 353 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp2_ = spit_publishing_publishable_get_exposure_date_time (b);
#line 353 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp3_ = _tmp2_;
#line 353 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp4_ = g_date_time_compare (_tmp1_, _tmp3_);
#line 353 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_date_time_unref0 (_tmp3_);
#line 353 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_date_time_unref0 (_tmp1_);
#line 353 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	result = _tmp4_;
#line 353 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return result;
#line 2940 "FlickrPublishing.c"
}


static gint
_publishing_flickr_flickr_publisher_flickr_date_time_compare_func_gcompare_data_func (gconstpointer a,
                                                                                      gconstpointer b,
                                                                                      gpointer self)
{
	gint result;
	result = publishing_flickr_flickr_publisher_flickr_date_time_compare_func ((SpitPublishingPublishable*) a, (SpitPublishingPublishable*) b);
#line 377 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return result;
#line 2953 "FlickrPublishing.c"
}


static void
_publishing_flickr_flickr_publisher_on_upload_status_updated_spit_publishing_progress_callback (gint file_number,
                                                                                                gdouble fraction_complete,
                                                                                                gpointer self)
{
#line 382 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_flickr_publisher_on_upload_status_updated ((PublishingFlickrFlickrPublisher*) self, file_number, fraction_complete);
#line 2964 "FlickrPublishing.c"
}


static void
publishing_flickr_flickr_publisher_do_publish (PublishingFlickrFlickrPublisher* self,
                                               gboolean strip_metadata)
{
	SpitPublishingPluginHost* _tmp0_;
	SpitPublishingPluginHost* _tmp1_;
	PublishingFlickrPublishingParameters* _tmp2_;
	gint _tmp3_;
	void* _tmp4_;
	GDestroyNotify _tmp5_;
	SpitPublishingProgressCallback _tmp6_;
	SpitPublishingPublishable** publishables = NULL;
	SpitPublishingPluginHost* _tmp7_;
	gint _tmp8_;
	SpitPublishingPublishable** _tmp9_;
	gint publishables_length1;
	gint _publishables_size_;
	GeeArrayList* sorted_list = NULL;
	GeeArrayList* _tmp10_;
	SpitPublishingPublishable** _tmp11_;
	gint _tmp11__length1;
	GeeArrayList* _tmp15_;
	PublishingFlickrUploader* uploader = NULL;
	PublishingRESTSupportOAuth1Session* _tmp16_;
	GeeArrayList* _tmp17_;
	gint _tmp18_;
	gpointer* _tmp19_;
	SpitPublishingPublishable** _tmp20_;
	gint _tmp20__length1;
	PublishingFlickrPublishingParameters* _tmp21_;
	PublishingFlickrUploader* _tmp22_;
	PublishingFlickrUploader* _tmp23_;
	PublishingFlickrUploader* _tmp24_;
	PublishingFlickrUploader* _tmp25_;
	PublishingFlickrUploader* _tmp26_;
#line 356 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (PUBLISHING_FLICKR_IS_FLICKR_PUBLISHER (self));
#line 357 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_flickr_publisher_set_persistent_strip_metadata (self, strip_metadata);
#line 358 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_debug ("FlickrPublishing.vala:358: ACTION: uploading media items to remote ser" \
"ver.");
#line 360 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = self->priv->host;
#line 360 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	spit_publishing_plugin_host_set_service_locked (_tmp0_, TRUE);
#line 361 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp1_ = self->priv->host;
#line 361 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp2_ = self->priv->parameters;
#line 361 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp3_ = _tmp2_->photo_major_axis_size;
#line 361 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp6_ = spit_publishing_plugin_host_serialize_publishables (_tmp1_, _tmp3_, strip_metadata, &_tmp4_, &_tmp5_);
#line 361 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	(self->priv->progress_reporter_target_destroy_notify == NULL) ? NULL : (self->priv->progress_reporter_target_destroy_notify (self->priv->progress_reporter_target), NULL);
#line 361 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->progress_reporter = NULL;
#line 361 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->progress_reporter_target = NULL;
#line 361 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->progress_reporter_target_destroy_notify = NULL;
#line 361 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->progress_reporter = _tmp6_;
#line 361 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->progress_reporter_target = _tmp4_;
#line 361 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->progress_reporter_target_destroy_notify = _tmp5_;
#line 367 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (!spit_publishing_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_PUBLISHER, SpitPublishingPublisher))) {
#line 368 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		return;
#line 3039 "FlickrPublishing.c"
	}
#line 371 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp7_ = self->priv->host;
#line 371 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp9_ = spit_publishing_plugin_host_get_publishables (_tmp7_, &_tmp8_);
#line 371 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishables = _tmp9_;
#line 371 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishables_length1 = _tmp8_;
#line 371 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_publishables_size_ = publishables_length1;
#line 372 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp10_ = gee_array_list_new (SPIT_PUBLISHING_TYPE_PUBLISHABLE, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, NULL, NULL, NULL);
#line 372 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	sorted_list = _tmp10_;
#line 374 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp11_ = publishables;
#line 374 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp11__length1 = publishables_length1;
#line 3059 "FlickrPublishing.c"
	{
		SpitPublishingPublishable** p_collection = NULL;
		gint p_collection_length1 = 0;
		gint _p_collection_size_ = 0;
		gint p_it = 0;
#line 374 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		p_collection = _tmp11_;
#line 374 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		p_collection_length1 = _tmp11__length1;
#line 374 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		for (p_it = 0; p_it < _tmp11__length1; p_it = p_it + 1) {
#line 3071 "FlickrPublishing.c"
			SpitPublishingPublishable* _tmp12_;
			SpitPublishingPublishable* p = NULL;
#line 374 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_tmp12_ = _g_object_ref0 (p_collection[p_it]);
#line 374 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			p = _tmp12_;
#line 3078 "FlickrPublishing.c"
			{
				GeeArrayList* _tmp13_;
				SpitPublishingPublishable* _tmp14_;
#line 375 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_tmp13_ = sorted_list;
#line 375 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_tmp14_ = p;
#line 375 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				gee_abstract_collection_add (G_TYPE_CHECK_INSTANCE_CAST (_tmp13_, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection), _tmp14_);
#line 374 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_g_object_unref0 (p);
#line 3090 "FlickrPublishing.c"
			}
		}
	}
#line 377 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp15_ = sorted_list;
#line 377 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	gee_list_sort (G_TYPE_CHECK_INSTANCE_CAST (_tmp15_, GEE_TYPE_LIST, GeeList), _publishing_flickr_flickr_publisher_flickr_date_time_compare_func_gcompare_data_func, NULL, NULL);
#line 379 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp16_ = self->priv->session;
#line 379 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp17_ = sorted_list;
#line 379 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp19_ = gee_collection_to_array (G_TYPE_CHECK_INSTANCE_CAST (_tmp17_, GEE_TYPE_COLLECTION, GeeCollection), &_tmp18_);
#line 379 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp20_ = _tmp19_;
#line 379 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp20__length1 = _tmp18_;
#line 379 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp21_ = self->priv->parameters;
#line 379 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp22_ = publishing_flickr_uploader_new (_tmp16_, _tmp20_, _tmp18_, _tmp21_, strip_metadata);
#line 379 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp23_ = _tmp22_;
#line 379 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp20_ = (_vala_array_free (_tmp20_, _tmp20__length1, (GDestroyNotify) g_object_unref), NULL);
#line 379 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	uploader = _tmp23_;
#line 380 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp24_ = uploader;
#line 380 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp24_, PUBLISHING_REST_SUPPORT_TYPE_BATCH_UPLOADER, PublishingRESTSupportBatchUploader), "upload-complete", (GCallback) _publishing_flickr_flickr_publisher_on_upload_complete_publishing_rest_support_batch_uploader_upload_complete, self, 0);
#line 381 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp25_ = uploader;
#line 381 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp25_, PUBLISHING_REST_SUPPORT_TYPE_BATCH_UPLOADER, PublishingRESTSupportBatchUploader), "upload-error", (GCallback) _publishing_flickr_flickr_publisher_on_upload_error_publishing_rest_support_batch_uploader_upload_error, self, 0);
#line 382 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp26_ = uploader;
#line 382 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_rest_support_batch_uploader_upload (G_TYPE_CHECK_INSTANCE_CAST (_tmp26_, PUBLISHING_REST_SUPPORT_TYPE_BATCH_UPLOADER, PublishingRESTSupportBatchUploader), _publishing_flickr_flickr_publisher_on_upload_status_updated_spit_publishing_progress_callback, self);
#line 356 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_publishing_rest_support_batch_uploader_unref0 (uploader);
#line 356 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_object_unref0 (sorted_list);
#line 356 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishables = (_vala_array_free (publishables, publishables_length1, (GDestroyNotify) g_object_unref), NULL);
#line 3136 "FlickrPublishing.c"
}


static void
publishing_flickr_flickr_publisher_do_show_success_pane (PublishingFlickrFlickrPublisher* self)
{
	SpitPublishingPluginHost* _tmp0_;
	SpitPublishingPluginHost* _tmp1_;
#line 385 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (PUBLISHING_FLICKR_IS_FLICKR_PUBLISHER (self));
#line 386 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_debug ("FlickrPublishing.vala:386: ACTION: showing success pane.");
#line 388 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = self->priv->host;
#line 388 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	spit_publishing_plugin_host_set_service_locked (_tmp0_, FALSE);
#line 389 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp1_ = self->priv->host;
#line 389 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	spit_publishing_plugin_host_install_success_pane (_tmp1_);
#line 3157 "FlickrPublishing.c"
}


gint
publishing_flickr_flickr_publisher_get_persistent_visibility (PublishingFlickrFlickrPublisher* self)
{
	gint result = 0;
	SpitPublishingPluginHost* _tmp0_;
#line 392 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_val_if_fail (PUBLISHING_FLICKR_IS_FLICKR_PUBLISHER (self), 0);
#line 393 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = self->priv->host;
#line 393 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	result = spit_host_interface_get_config_int (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), "visibility", 0);
#line 393 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return result;
#line 3174 "FlickrPublishing.c"
}


void
publishing_flickr_flickr_publisher_set_persistent_visibility (PublishingFlickrFlickrPublisher* self,
                                                              gint vis)
{
	SpitPublishingPluginHost* _tmp0_;
#line 396 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (PUBLISHING_FLICKR_IS_FLICKR_PUBLISHER (self));
#line 397 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = self->priv->host;
#line 397 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	spit_host_interface_set_config_int (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), "visibility", vis);
#line 3189 "FlickrPublishing.c"
}


gint
publishing_flickr_flickr_publisher_get_persistent_default_size (PublishingFlickrFlickrPublisher* self)
{
	gint result = 0;
	SpitPublishingPluginHost* _tmp0_;
#line 400 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_val_if_fail (PUBLISHING_FLICKR_IS_FLICKR_PUBLISHER (self), 0);
#line 401 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = self->priv->host;
#line 401 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	result = spit_host_interface_get_config_int (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), "default_size", 1);
#line 401 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return result;
#line 3206 "FlickrPublishing.c"
}


void
publishing_flickr_flickr_publisher_set_persistent_default_size (PublishingFlickrFlickrPublisher* self,
                                                                gint size)
{
	SpitPublishingPluginHost* _tmp0_;
#line 404 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (PUBLISHING_FLICKR_IS_FLICKR_PUBLISHER (self));
#line 405 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = self->priv->host;
#line 405 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	spit_host_interface_set_config_int (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), "default_size", size);
#line 3221 "FlickrPublishing.c"
}


static SpitPublishingService*
publishing_flickr_flickr_publisher_real_get_service (SpitPublishingPublisher* base)
{
	PublishingFlickrFlickrPublisher * self;
	SpitPublishingService* result = NULL;
	SpitPublishingService* _tmp0_;
	SpitPublishingService* _tmp1_;
#line 408 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_FLICKR_TYPE_FLICKR_PUBLISHER, PublishingFlickrFlickrPublisher);
#line 409 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = self->priv->service;
#line 409 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 409 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	result = _tmp1_;
#line 409 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return result;
#line 3242 "FlickrPublishing.c"
}


static gboolean
publishing_flickr_flickr_publisher_real_is_running (SpitPublishingPublisher* base)
{
	PublishingFlickrFlickrPublisher * self;
	gboolean result = FALSE;
	gboolean _tmp0_;
#line 412 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_FLICKR_TYPE_FLICKR_PUBLISHER, PublishingFlickrFlickrPublisher);
#line 413 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = self->priv->running;
#line 413 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	result = _tmp0_;
#line 413 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return result;
#line 3260 "FlickrPublishing.c"
}


static void
publishing_flickr_flickr_publisher_attempt_start (PublishingFlickrFlickrPublisher* self)
{
	SpitPublishingAuthenticator* _tmp0_;
#line 418 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (PUBLISHING_FLICKR_IS_FLICKR_PUBLISHER (self));
#line 419 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->running = TRUE;
#line 420 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->was_started = TRUE;
#line 422 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = self->priv->authenticator;
#line 422 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	spit_publishing_authenticator_authenticate (_tmp0_);
#line 3278 "FlickrPublishing.c"
}


static void
publishing_flickr_flickr_publisher_real_start (SpitPublishingPublisher* base)
{
	PublishingFlickrFlickrPublisher * self;
	gboolean _tmp0_;
#line 425 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_FLICKR_TYPE_FLICKR_PUBLISHER, PublishingFlickrFlickrPublisher);
#line 426 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (spit_publishing_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_PUBLISHER, SpitPublishingPublisher))) {
#line 427 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		return;
#line 3293 "FlickrPublishing.c"
	}
#line 429 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = self->priv->was_started;
#line 429 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (_tmp0_) {
#line 430 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		g_error ("FlickrPublishing.vala:430: FlickrPublisher: start( ): can't start; thi" \
"s publisher is not restartable.");
#line 3301 "FlickrPublishing.c"
	}
#line 432 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_debug ("FlickrPublishing.vala:432: FlickrPublisher: starting interaction.");
#line 434 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_flickr_publisher_attempt_start (self);
#line 3307 "FlickrPublishing.c"
}


static void
publishing_flickr_flickr_publisher_real_stop (SpitPublishingPublisher* base)
{
	PublishingFlickrFlickrPublisher * self;
	PublishingRESTSupportOAuth1Session* _tmp0_;
#line 437 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_FLICKR_TYPE_FLICKR_PUBLISHER, PublishingFlickrFlickrPublisher);
#line 438 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_debug ("FlickrPublishing.vala:438: FlickrPublisher: stop( ) invoked.");
#line 440 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = self->priv->session;
#line 440 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (_tmp0_ != NULL) {
#line 3324 "FlickrPublishing.c"
		PublishingRESTSupportOAuth1Session* _tmp1_;
#line 441 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp1_ = self->priv->session;
#line 441 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		publishing_rest_support_session_stop_transactions (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, PUBLISHING_REST_SUPPORT_TYPE_SESSION, PublishingRESTSupportSession));
#line 3330 "FlickrPublishing.c"
	}
#line 443 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->running = FALSE;
#line 3334 "FlickrPublishing.c"
}


static void
publishing_flickr_flickr_publisher_class_init (PublishingFlickrFlickrPublisherClass * klass)
{
#line 92 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_flickr_publisher_parent_class = g_type_class_peek_parent (klass);
#line 92 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_type_class_add_private (klass, sizeof (PublishingFlickrFlickrPublisherPrivate));
#line 92 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	G_OBJECT_CLASS (klass)->finalize = publishing_flickr_flickr_publisher_finalize;
#line 3347 "FlickrPublishing.c"
}


static void
publishing_flickr_flickr_publisher_spit_publishing_publisher_interface_init (SpitPublishingPublisherIface * iface)
{
#line 92 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_flickr_publisher_spit_publishing_publisher_parent_iface = g_type_interface_peek_parent (iface);
#line 92 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	iface->get_service = (SpitPublishingService* (*) (SpitPublishingPublisher *)) publishing_flickr_flickr_publisher_real_get_service;
#line 92 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	iface->is_running = (gboolean (*) (SpitPublishingPublisher *)) publishing_flickr_flickr_publisher_real_is_running;
#line 92 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	iface->start = (void (*) (SpitPublishingPublisher *)) publishing_flickr_flickr_publisher_real_start;
#line 92 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	iface->stop = (void (*) (SpitPublishingPublisher *)) publishing_flickr_flickr_publisher_real_stop;
#line 3364 "FlickrPublishing.c"
}


static void
publishing_flickr_flickr_publisher_instance_init (PublishingFlickrFlickrPublisher * self)
{
#line 92 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv = PUBLISHING_FLICKR_FLICKR_PUBLISHER_GET_PRIVATE (self);
#line 95 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->progress_reporter = NULL;
#line 95 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->progress_reporter_target = self;
#line 95 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->progress_reporter_target_destroy_notify = NULL;
#line 96 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->running = FALSE;
#line 97 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->was_started = FALSE;
#line 98 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->session = NULL;
#line 99 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->publishing_options_pane = NULL;
#line 100 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->authenticator = NULL;
#line 102 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->parameters = NULL;
#line 3391 "FlickrPublishing.c"
}


static void
publishing_flickr_flickr_publisher_finalize (GObject * obj)
{
	PublishingFlickrFlickrPublisher * self;
	SpitPublishingAuthenticator* _tmp0_;
	guint _tmp1_;
#line 92 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_FLICKR_TYPE_FLICKR_PUBLISHER, PublishingFlickrFlickrPublisher);
#line 117 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = self->priv->authenticator;
#line 117 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_parse_name ("authenticated", SPIT_PUBLISHING_TYPE_AUTHENTICATOR, &_tmp1_, NULL, FALSE);
#line 117 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp0_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _publishing_flickr_flickr_publisher_on_session_authenticated_spit_publishing_authenticator_authenticated, self);
#line 93 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_object_unref0 (self->priv->service);
#line 94 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_object_unref0 (self->priv->host);
#line 95 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	(self->priv->progress_reporter_target_destroy_notify == NULL) ? NULL : (self->priv->progress_reporter_target_destroy_notify (self->priv->progress_reporter_target), NULL);
#line 95 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->progress_reporter = NULL;
#line 95 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->progress_reporter_target = NULL;
#line 95 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->progress_reporter_target_destroy_notify = NULL;
#line 98 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_publishing_rest_support_session_unref0 (self->priv->session);
#line 99 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_object_unref0 (self->priv->publishing_options_pane);
#line 100 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_object_unref0 (self->priv->authenticator);
#line 102 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_publishing_flickr_publishing_parameters_unref0 (self->priv->parameters);
#line 92 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	G_OBJECT_CLASS (publishing_flickr_flickr_publisher_parent_class)->finalize (obj);
#line 3431 "FlickrPublishing.c"
}


GType
publishing_flickr_flickr_publisher_get_type (void)
{
	static volatile gsize publishing_flickr_flickr_publisher_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_flickr_flickr_publisher_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingFlickrFlickrPublisherClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_flickr_flickr_publisher_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingFlickrFlickrPublisher), 0, (GInstanceInitFunc) publishing_flickr_flickr_publisher_instance_init, NULL };
		static const GInterfaceInfo spit_publishing_publisher_info = { (GInterfaceInitFunc) publishing_flickr_flickr_publisher_spit_publishing_publisher_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType publishing_flickr_flickr_publisher_type_id;
		publishing_flickr_flickr_publisher_type_id = g_type_register_static (G_TYPE_OBJECT, "PublishingFlickrFlickrPublisher", &g_define_type_info, 0);
		g_type_add_interface_static (publishing_flickr_flickr_publisher_type_id, SPIT_PUBLISHING_TYPE_PUBLISHER, &spit_publishing_publisher_info);
		g_once_init_leave (&publishing_flickr_flickr_publisher_type_id__volatile, publishing_flickr_flickr_publisher_type_id);
	}
	return publishing_flickr_flickr_publisher_type_id__volatile;
}


gchar*
publishing_flickr_transaction_validate_xml (PublishingRESTSupportXmlDocument* doc)
{
	gchar* result = NULL;
	xmlNode* root = NULL;
	xmlNode* _tmp0_;
	gchar* status = NULL;
	xmlNode* _tmp1_;
	gchar* _tmp2_;
	const gchar* _tmp3_;
	const gchar* _tmp5_;
	xmlNode* errcode = NULL;
	xmlNode* _tmp10_;
	gchar* _tmp11_;
	gchar* _tmp12_;
	xmlNode* _tmp13_;
	gchar* _tmp14_;
	gchar* _tmp15_;
	gchar* _tmp16_;
	gchar* _tmp17_;
	GError * _inner_error_ = NULL;
#line 448 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_val_if_fail (PUBLISHING_REST_SUPPORT_IS_XML_DOCUMENT (doc), NULL);
#line 449 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = publishing_rest_support_xml_document_get_root_node (doc);
#line 449 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	root = _tmp0_;
#line 450 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp1_ = root;
#line 450 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp2_ = (gchar*) xmlGetProp (_tmp1_, (xmlChar*) "stat");
#line 450 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	status = _tmp2_;
#line 453 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp3_ = status;
#line 453 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (_tmp3_ == NULL) {
#line 3488 "FlickrPublishing.c"
		gchar* _tmp4_;
#line 454 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp4_ = g_strdup ("No status property in root node");
#line 454 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		result = _tmp4_;
#line 454 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_g_free0 (status);
#line 454 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		return result;
#line 3498 "FlickrPublishing.c"
	}
#line 456 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp5_ = status;
#line 456 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (g_strcmp0 (_tmp5_, "ok") == 0) {
#line 457 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		result = NULL;
#line 457 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_g_free0 (status);
#line 457 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		return result;
#line 3510 "FlickrPublishing.c"
	}
	{
		xmlNode* _tmp6_ = NULL;
		xmlNode* _tmp7_;
		xmlNode* _tmp8_;
#line 461 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp7_ = root;
#line 461 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp8_ = publishing_rest_support_xml_document_get_named_child (doc, _tmp7_, "err", &_inner_error_);
#line 461 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp6_ = _tmp8_;
#line 461 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 461 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 3526 "FlickrPublishing.c"
				goto __catch16_spit_publishing_publishing_error;
			}
#line 461 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_g_free0 (status);
#line 461 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 461 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			g_clear_error (&_inner_error_);
#line 461 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			return NULL;
#line 3537 "FlickrPublishing.c"
		}
#line 461 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		errcode = _tmp6_;
#line 3541 "FlickrPublishing.c"
	}
	goto __finally16;
	__catch16_spit_publishing_publishing_error:
	{
		GError* err = NULL;
		gchar* _tmp9_;
#line 460 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		err = _inner_error_;
#line 460 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_inner_error_ = NULL;
#line 463 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp9_ = g_strdup ("No error code specified");
#line 463 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		result = _tmp9_;
#line 463 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_g_error_free0 (err);
#line 463 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_g_free0 (status);
#line 463 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		return result;
#line 3562 "FlickrPublishing.c"
	}
	__finally16:
#line 460 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 460 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_g_free0 (status);
#line 460 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 460 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		g_clear_error (&_inner_error_);
#line 460 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		return NULL;
#line 3575 "FlickrPublishing.c"
	}
#line 469 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp10_ = errcode;
#line 469 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp11_ = (gchar*) xmlGetProp (_tmp10_, (xmlChar*) "msg");
#line 469 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp12_ = _tmp11_;
#line 469 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp13_ = errcode;
#line 469 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp14_ = (gchar*) xmlGetProp (_tmp13_, (xmlChar*) "code");
#line 469 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp15_ = _tmp14_;
#line 469 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp16_ = g_strdup_printf ("%s (error code %s)", _tmp12_, _tmp15_);
#line 469 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp17_ = _tmp16_;
#line 469 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_free0 (_tmp15_);
#line 469 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_free0 (_tmp12_);
#line 469 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	result = _tmp17_;
#line 469 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_free0 (status);
#line 469 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return result;
#line 3603 "FlickrPublishing.c"
}


static gchar*
_publishing_flickr_transaction_validate_xml_publishing_rest_support_xml_document_check_for_error_response (PublishingRESTSupportXmlDocument* doc,
                                                                                                           gpointer self)
{
	gchar* result;
	result = publishing_flickr_transaction_validate_xml (doc);
#line 484 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return result;
#line 3615 "FlickrPublishing.c"
}


static gboolean
string_contains (const gchar* self,
                 const gchar* needle)
{
	gboolean result = FALSE;
	gchar* _tmp0_;
#line 1417 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, FALSE);
#line 1417 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	g_return_val_if_fail (needle != NULL, FALSE);
#line 1418 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	_tmp0_ = strstr ((gchar*) self, (gchar*) needle);
#line 1418 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	result = _tmp0_ != NULL;
#line 1418 "/usr/share/vala-0.40/vapi/glib-2.0.vapi"
	return result;
#line 3635 "FlickrPublishing.c"
}


static gpointer
_g_error_copy0 (gpointer self)
{
#line 489 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return self ? g_error_copy (self) : NULL;
#line 3644 "FlickrPublishing.c"
}


PublishingRESTSupportXmlDocument*
publishing_flickr_transaction_parse_flickr_response (const gchar* xml,
                                                     GError** error)
{
	PublishingRESTSupportXmlDocument* result = NULL;
	PublishingRESTSupportXmlDocument* _result_ = NULL;
	GError * _inner_error_ = NULL;
#line 479 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_val_if_fail (xml != NULL, NULL);
#line 481 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_result_ = NULL;
#line 3659 "FlickrPublishing.c"
	{
		PublishingRESTSupportXmlDocument* _tmp0_ = NULL;
		PublishingRESTSupportXmlDocument* _tmp1_;
		PublishingRESTSupportXmlDocument* _tmp2_;
#line 484 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp1_ = publishing_rest_support_xml_document_parse_string (xml, _publishing_flickr_transaction_validate_xml_publishing_rest_support_xml_document_check_for_error_response, NULL, &_inner_error_);
#line 484 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp0_ = _tmp1_;
#line 484 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 484 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 3672 "FlickrPublishing.c"
				goto __catch17_spit_publishing_publishing_error;
			}
#line 484 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_publishing_rest_support_xml_document_unref0 (_result_);
#line 484 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 484 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			g_clear_error (&_inner_error_);
#line 484 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			return NULL;
#line 3683 "FlickrPublishing.c"
		}
#line 484 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp2_ = _tmp0_;
#line 484 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp0_ = NULL;
#line 484 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_publishing_rest_support_xml_document_unref0 (_result_);
#line 484 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_result_ = _tmp2_;
#line 483 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_publishing_rest_support_xml_document_unref0 (_tmp0_);
#line 3695 "FlickrPublishing.c"
	}
	goto __finally17;
	__catch17_spit_publishing_publishing_error:
	{
		GError* e = NULL;
		GError* _tmp3_;
		const gchar* _tmp4_;
		gchar* _tmp5_;
		gchar* _tmp6_;
		gboolean _tmp7_;
#line 483 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		e = _inner_error_;
#line 483 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_inner_error_ = NULL;
#line 486 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp3_ = e;
#line 486 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp4_ = _tmp3_->message;
#line 486 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp5_ = g_strdup_printf ("(error code %s)", PUBLISHING_FLICKR_EXPIRED_SESSION_ERROR_CODE);
#line 486 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp6_ = _tmp5_;
#line 486 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp7_ = string_contains (_tmp4_, _tmp6_);
#line 486 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_g_free0 (_tmp6_);
#line 486 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		if (_tmp7_) {
#line 3724 "FlickrPublishing.c"
			GError* _tmp8_;
			const gchar* _tmp9_;
			GError* _tmp10_;
#line 487 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_tmp8_ = e;
#line 487 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_tmp9_ = _tmp8_->message;
#line 487 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_tmp10_ = g_error_new_literal (SPIT_PUBLISHING_PUBLISHING_ERROR, SPIT_PUBLISHING_PUBLISHING_ERROR_EXPIRED_SESSION, _tmp9_);
#line 487 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_inner_error_ = _tmp10_;
#line 487 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_g_error_free0 (e);
#line 3738 "FlickrPublishing.c"
			goto __finally17;
		} else {
			GError* _tmp11_;
			GError* _tmp12_;
#line 489 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_tmp11_ = e;
#line 489 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_tmp12_ = _g_error_copy0 (_tmp11_);
#line 489 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_inner_error_ = _tmp12_;
#line 489 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_g_error_free0 (e);
#line 3751 "FlickrPublishing.c"
			goto __finally17;
		}
#line 483 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_g_error_free0 (e);
#line 3756 "FlickrPublishing.c"
	}
	__finally17:
#line 483 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 483 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 483 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			g_propagate_error (error, _inner_error_);
#line 483 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_publishing_rest_support_xml_document_unref0 (_result_);
#line 483 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			return NULL;
#line 3769 "FlickrPublishing.c"
		} else {
#line 483 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_publishing_rest_support_xml_document_unref0 (_result_);
#line 483 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 483 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			g_clear_error (&_inner_error_);
#line 483 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			return NULL;
#line 3779 "FlickrPublishing.c"
		}
	}
#line 493 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	result = _result_;
#line 493 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return result;
#line 3786 "FlickrPublishing.c"
}


PublishingFlickrAccountInfoFetchTransaction*
publishing_flickr_account_info_fetch_transaction_construct (GType object_type,
                                                            PublishingRESTSupportOAuth1Session* session)
{
	PublishingFlickrAccountInfoFetchTransaction* self = NULL;
#line 498 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_val_if_fail (PUBLISHING_REST_SUPPORT_OAUTH1_IS_SESSION (session), NULL);
#line 499 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self = (PublishingFlickrAccountInfoFetchTransaction*) publishing_rest_support_oauth1_transaction_construct (object_type, session, PUBLISHING_REST_SUPPORT_HTTP_METHOD_GET);
#line 500 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_rest_support_transaction_add_argument (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "method", "flickr.people.getUploadStatus");
#line 498 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return self;
#line 3803 "FlickrPublishing.c"
}


PublishingFlickrAccountInfoFetchTransaction*
publishing_flickr_account_info_fetch_transaction_new (PublishingRESTSupportOAuth1Session* session)
{
#line 498 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return publishing_flickr_account_info_fetch_transaction_construct (PUBLISHING_FLICKR_TYPE_ACCOUNT_INFO_FETCH_TRANSACTION, session);
#line 3812 "FlickrPublishing.c"
}


static void
publishing_flickr_account_info_fetch_transaction_class_init (PublishingFlickrAccountInfoFetchTransactionClass * klass)
{
#line 497 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_account_info_fetch_transaction_parent_class = g_type_class_peek_parent (klass);
#line 3821 "FlickrPublishing.c"
}


static void
publishing_flickr_account_info_fetch_transaction_instance_init (PublishingFlickrAccountInfoFetchTransaction * self)
{
}


GType
publishing_flickr_account_info_fetch_transaction_get_type (void)
{
	static volatile gsize publishing_flickr_account_info_fetch_transaction_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_flickr_account_info_fetch_transaction_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingFlickrAccountInfoFetchTransactionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_flickr_account_info_fetch_transaction_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingFlickrAccountInfoFetchTransaction), 0, (GInstanceInitFunc) publishing_flickr_account_info_fetch_transaction_instance_init, NULL };
		GType publishing_flickr_account_info_fetch_transaction_type_id;
		publishing_flickr_account_info_fetch_transaction_type_id = g_type_register_static (PUBLISHING_REST_SUPPORT_OAUTH1_TYPE_TRANSACTION, "PublishingFlickrAccountInfoFetchTransaction", &g_define_type_info, 0);
		g_once_init_leave (&publishing_flickr_account_info_fetch_transaction_type_id__volatile, publishing_flickr_account_info_fetch_transaction_type_id);
	}
	return publishing_flickr_account_info_fetch_transaction_type_id__volatile;
}


static gpointer
_publishing_flickr_publishing_parameters_ref0 (gpointer self)
{
#line 511 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return self ? publishing_flickr_publishing_parameters_ref (self) : NULL;
#line 3850 "FlickrPublishing.c"
}


static void
_g_free0_ (gpointer var)
{
#line 517 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	var = (g_free (var), NULL);
#line 3859 "FlickrPublishing.c"
}


PublishingFlickrUploadTransaction*
publishing_flickr_upload_transaction_construct (GType object_type,
                                                PublishingRESTSupportOAuth1Session* session,
                                                PublishingFlickrPublishingParameters* parameters,
                                                SpitPublishingPublishable* publishable)
{
	PublishingFlickrUploadTransaction* self = NULL;
	PublishingFlickrPublishingParameters* _tmp0_;
	PublishingFlickrVisibilitySpecification* _tmp1_;
	gint _tmp2_;
	gchar* _tmp3_;
	gchar* _tmp4_;
	PublishingFlickrVisibilitySpecification* _tmp5_;
	gint _tmp6_;
	gchar* _tmp7_;
	gchar* _tmp8_;
	PublishingFlickrVisibilitySpecification* _tmp9_;
	gint _tmp10_;
	gchar* _tmp11_;
	gchar* _tmp12_;
	GHashTable* disposition_table = NULL;
	GHashFunc _tmp13_;
	GEqualFunc _tmp14_;
	GHashTable* _tmp15_;
	gchar* filename = NULL;
	gchar* _tmp16_;
	gboolean _tmp17_ = FALSE;
	const gchar* _tmp18_;
	GHashTable* _tmp21_;
	gchar* _tmp22_;
	gchar* _tmp23_;
	gchar* _tmp24_;
	gchar* _tmp25_;
	GHashTable* _tmp26_;
	gchar* _tmp27_;
	gchar* _tmp28_;
	GHashTable* _tmp29_;
#line 507 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_val_if_fail (PUBLISHING_REST_SUPPORT_OAUTH1_IS_SESSION (session), NULL);
#line 507 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_val_if_fail (PUBLISHING_FLICKR_IS_PUBLISHING_PARAMETERS (parameters), NULL);
#line 507 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_val_if_fail (SPIT_PUBLISHING_IS_PUBLISHABLE (publishable), NULL);
#line 509 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self = (PublishingFlickrUploadTransaction*) publishing_rest_support_oauth1_upload_transaction_construct (object_type, session, publishable, "https://api.flickr.com/services/upload");
#line 511 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = _publishing_flickr_publishing_parameters_ref0 (parameters);
#line 511 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_publishing_flickr_publishing_parameters_unref0 (self->priv->parameters);
#line 511 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->parameters = _tmp0_;
#line 513 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp1_ = parameters->visibility_specification;
#line 513 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp2_ = _tmp1_->everyone_level;
#line 513 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp3_ = g_strdup_printf ("%d", _tmp2_);
#line 513 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp4_ = _tmp3_;
#line 513 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_rest_support_transaction_add_argument (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "is_public", _tmp4_);
#line 513 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_free0 (_tmp4_);
#line 514 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp5_ = parameters->visibility_specification;
#line 514 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp6_ = _tmp5_->friends_level;
#line 514 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp7_ = g_strdup_printf ("%d", _tmp6_);
#line 514 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp8_ = _tmp7_;
#line 514 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_rest_support_transaction_add_argument (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "is_friend", _tmp8_);
#line 514 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_free0 (_tmp8_);
#line 515 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp9_ = parameters->visibility_specification;
#line 515 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp10_ = _tmp9_->family_level;
#line 515 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp11_ = g_strdup_printf ("%d", _tmp10_);
#line 515 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp12_ = _tmp11_;
#line 515 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_rest_support_transaction_add_argument (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "is_family", _tmp12_);
#line 515 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_free0 (_tmp12_);
#line 517 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp13_ = g_str_hash;
#line 517 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp14_ = g_str_equal;
#line 517 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp15_ = g_hash_table_new_full (_tmp13_, _tmp14_, _g_free0_, _g_free0_);
#line 517 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	disposition_table = _tmp15_;
#line 519 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp16_ = spit_publishing_publishable_get_publishing_name (publishable);
#line 519 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	filename = _tmp16_;
#line 520 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp18_ = filename;
#line 520 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (_tmp18_ == NULL) {
#line 520 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp17_ = TRUE;
#line 3968 "FlickrPublishing.c"
	} else {
		const gchar* _tmp19_;
#line 520 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp19_ = filename;
#line 520 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp17_ = g_strcmp0 (_tmp19_, "") == 0;
#line 3975 "FlickrPublishing.c"
	}
#line 520 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (_tmp17_) {
#line 3979 "FlickrPublishing.c"
		gchar* _tmp20_;
#line 521 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp20_ = spit_publishing_publishable_get_param_string (publishable, SPIT_PUBLISHING_PUBLISHABLE_PARAM_STRING_BASENAME);
#line 521 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_g_free0 (filename);
#line 521 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		filename = _tmp20_;
#line 3987 "FlickrPublishing.c"
	}
#line 525 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp21_ = disposition_table;
#line 525 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp22_ = g_strdup ("filename");
#line 525 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp23_ = spit_publishing_publishable_get_param_string (publishable, SPIT_PUBLISHING_PUBLISHABLE_PARAM_STRING_BASENAME);
#line 525 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp24_ = _tmp23_;
#line 525 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp25_ = soup_uri_encode (_tmp24_, NULL);
#line 525 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_hash_table_insert (_tmp21_, _tmp22_, _tmp25_);
#line 525 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_free0 (_tmp24_);
#line 528 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp26_ = disposition_table;
#line 528 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp27_ = g_strdup ("name");
#line 528 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp28_ = g_strdup ("photo");
#line 528 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_hash_table_insert (_tmp26_, _tmp27_, _tmp28_);
#line 530 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp29_ = disposition_table;
#line 530 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_rest_support_upload_transaction_set_binary_disposition_table (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_UPLOAD_TRANSACTION, PublishingRESTSupportUploadTransaction), _tmp29_);
#line 507 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_free0 (filename);
#line 507 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_hash_table_unref0 (disposition_table);
#line 507 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return self;
#line 4021 "FlickrPublishing.c"
}


PublishingFlickrUploadTransaction*
publishing_flickr_upload_transaction_new (PublishingRESTSupportOAuth1Session* session,
                                          PublishingFlickrPublishingParameters* parameters,
                                          SpitPublishingPublishable* publishable)
{
#line 507 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return publishing_flickr_upload_transaction_construct (PUBLISHING_FLICKR_TYPE_UPLOAD_TRANSACTION, session, parameters, publishable);
#line 4032 "FlickrPublishing.c"
}


static void
publishing_flickr_upload_transaction_real_execute (PublishingRESTSupportTransaction* base,
                                                   GError** error)
{
	PublishingFlickrUploadTransaction * self;
	GError * _inner_error_ = NULL;
#line 533 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_FLICKR_TYPE_UPLOAD_TRANSACTION, PublishingFlickrUploadTransaction);
#line 534 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_rest_support_oauth1_upload_transaction_authorize (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_OAUTH1_TYPE_UPLOAD_TRANSACTION, PublishingRESTSupportOAuth1UploadTransaction));
#line 535 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	PUBLISHING_REST_SUPPORT_TRANSACTION_CLASS (publishing_flickr_upload_transaction_parent_class)->execute (G_TYPE_CHECK_INSTANCE_CAST (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_OAUTH1_TYPE_UPLOAD_TRANSACTION, PublishingRESTSupportOAuth1UploadTransaction), PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), &_inner_error_);
#line 535 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 535 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 535 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			g_propagate_error (error, _inner_error_);
#line 535 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			return;
#line 4056 "FlickrPublishing.c"
		} else {
#line 535 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 535 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			g_clear_error (&_inner_error_);
#line 535 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			return;
#line 4064 "FlickrPublishing.c"
		}
	}
}


static void
publishing_flickr_upload_transaction_class_init (PublishingFlickrUploadTransactionClass * klass)
{
#line 504 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_upload_transaction_parent_class = g_type_class_peek_parent (klass);
#line 504 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	((PublishingRESTSupportTransactionClass *) klass)->finalize = publishing_flickr_upload_transaction_finalize;
#line 504 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_type_class_add_private (klass, sizeof (PublishingFlickrUploadTransactionPrivate));
#line 504 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	((PublishingRESTSupportTransactionClass *) klass)->execute = (void (*) (PublishingRESTSupportTransaction *, GError**)) publishing_flickr_upload_transaction_real_execute;
#line 4081 "FlickrPublishing.c"
}


static void
publishing_flickr_upload_transaction_instance_init (PublishingFlickrUploadTransaction * self)
{
#line 504 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv = PUBLISHING_FLICKR_UPLOAD_TRANSACTION_GET_PRIVATE (self);
#line 4090 "FlickrPublishing.c"
}


static void
publishing_flickr_upload_transaction_finalize (PublishingRESTSupportTransaction * obj)
{
	PublishingFlickrUploadTransaction * self;
#line 504 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_FLICKR_TYPE_UPLOAD_TRANSACTION, PublishingFlickrUploadTransaction);
#line 505 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_publishing_flickr_publishing_parameters_unref0 (self->priv->parameters);
#line 504 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	PUBLISHING_REST_SUPPORT_TRANSACTION_CLASS (publishing_flickr_upload_transaction_parent_class)->finalize (obj);
#line 4104 "FlickrPublishing.c"
}


GType
publishing_flickr_upload_transaction_get_type (void)
{
	static volatile gsize publishing_flickr_upload_transaction_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_flickr_upload_transaction_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingFlickrUploadTransactionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_flickr_upload_transaction_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingFlickrUploadTransaction), 0, (GInstanceInitFunc) publishing_flickr_upload_transaction_instance_init, NULL };
		GType publishing_flickr_upload_transaction_type_id;
		publishing_flickr_upload_transaction_type_id = g_type_register_static (PUBLISHING_REST_SUPPORT_OAUTH1_TYPE_UPLOAD_TRANSACTION, "PublishingFlickrUploadTransaction", &g_define_type_info, 0);
		g_once_init_leave (&publishing_flickr_upload_transaction_type_id__volatile, publishing_flickr_upload_transaction_type_id);
	}
	return publishing_flickr_upload_transaction_type_id__volatile;
}


static void
_publishing_flickr_publishing_options_pane_on_visibility_changed_gtk_combo_box_changed (GtkComboBox* _sender,
                                                                                        gpointer self)
{
#line 627 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_publishing_options_pane_on_visibility_changed ((PublishingFlickrPublishingOptionsPane*) self);
#line 4128 "FlickrPublishing.c"
}


static void
_publishing_flickr_publishing_options_pane_on_size_changed_gtk_combo_box_changed (GtkComboBox* _sender,
                                                                                  gpointer self)
{
#line 631 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_publishing_options_pane_on_size_changed ((PublishingFlickrPublishingOptionsPane*) self);
#line 4138 "FlickrPublishing.c"
}


static void
_publishing_flickr_publishing_options_pane_on_logout_clicked_gtk_button_clicked (GtkButton* _sender,
                                                                                 gpointer self)
{
#line 640 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_publishing_options_pane_on_logout_clicked ((PublishingFlickrPublishingOptionsPane*) self);
#line 4148 "FlickrPublishing.c"
}


static void
_publishing_flickr_publishing_options_pane_on_publish_clicked_gtk_button_clicked (GtkButton* _sender,
                                                                                  gpointer self)
{
#line 641 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_publishing_options_pane_on_publish_clicked ((PublishingFlickrPublishingOptionsPane*) self);
#line 4158 "FlickrPublishing.c"
}


PublishingFlickrPublishingOptionsPane*
publishing_flickr_publishing_options_pane_construct (GType object_type,
                                                     PublishingFlickrFlickrPublisher* publisher,
                                                     PublishingFlickrPublishingParameters* parameters,
                                                     SpitPublishingPublisherMediaType media_type,
                                                     GtkBuilder* builder,
                                                     gboolean strip_metadata)
{
	PublishingFlickrPublishingOptionsPane * self = NULL;
	GtkBuilder* _tmp0_;
	GSList* _tmp1_;
	GSList* _tmp2_;
	GtkBuilder* _tmp3_;
	GObject* _tmp4_;
	GtkBox* _tmp5_;
	GtkBuilder* _tmp6_;
	GObject* _tmp7_;
	GtkLabel* _tmp8_;
	GtkBuilder* _tmp9_;
	GObject* _tmp10_;
	GtkLabel* _tmp11_;
	GtkBuilder* _tmp12_;
	GObject* _tmp13_;
	GtkButton* _tmp14_;
	GtkBuilder* _tmp15_;
	GObject* _tmp16_;
	GtkButton* _tmp17_;
	GtkBuilder* _tmp18_;
	GObject* _tmp19_;
	GtkComboBoxText* _tmp20_;
	GtkBuilder* _tmp21_;
	GObject* _tmp22_;
	GtkComboBoxText* _tmp23_;
	GtkBuilder* _tmp24_;
	GObject* _tmp25_;
	GtkLabel* _tmp26_;
	GtkBuilder* _tmp27_;
	GObject* _tmp28_;
	GtkCheckButton* _tmp29_;
	SpitPublishingAuthenticator* _tmp30_;
	SpitPublishingAuthenticator* _tmp31_;
	gboolean _tmp32_;
	PublishingFlickrPublishingParameters* _tmp37_;
	PublishingFlickrFlickrPublisher* _tmp38_;
	gint _tmp39_;
	PublishingFlickrPublishingOptionsPaneVisibilityEntry** _tmp40_;
	gint _tmp41_;
	PublishingFlickrPublishingOptionsPaneSizeEntry** _tmp42_;
	gchar* upload_label_text = NULL;
	const gchar* _tmp43_;
	gchar* _tmp44_;
	PublishingFlickrUserKind _tmp45_;
	GtkLabel* _tmp55_;
	const gchar* _tmp56_;
	gchar* visibility_label_text = NULL;
	gchar* _tmp57_;
	GtkLabel* _tmp60_;
	const gchar* _tmp61_;
	GtkComboBoxText* _tmp62_;
	GtkCheckButton* _tmp66_;
	GtkButton* _tmp67_;
	GtkButton* _tmp68_;
#line 579 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_val_if_fail (PUBLISHING_FLICKR_IS_FLICKR_PUBLISHER (publisher), NULL);
#line 579 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_val_if_fail (PUBLISHING_FLICKR_IS_PUBLISHING_PARAMETERS (parameters), NULL);
#line 579 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_val_if_fail (GTK_IS_BUILDER (builder), NULL);
#line 579 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self = (PublishingFlickrPublishingOptionsPane*) g_object_new (object_type, NULL);
#line 581 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = _g_object_ref0 (builder);
#line 581 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_object_unref0 (self->priv->builder);
#line 581 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->builder = _tmp0_;
#line 582 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_vala_assert (builder != NULL, "builder != null");
#line 583 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp1_ = gtk_builder_get_objects (builder);
#line 583 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp2_ = _tmp1_;
#line 583 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_vala_assert (g_slist_length (_tmp2_) > ((guint) 0), "builder.get_objects().length() > 0");
#line 583 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_slist_free0 (_tmp2_);
#line 586 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp3_ = self->priv->builder;
#line 586 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp4_ = gtk_builder_get_object (_tmp3_, "flickr_pane");
#line 586 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp5_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp4_, gtk_box_get_type (), GtkBox));
#line 586 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_object_unref0 (self->priv->pane_widget);
#line 586 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->pane_widget = _tmp5_;
#line 587 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp6_ = self->priv->builder;
#line 587 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp7_ = gtk_builder_get_object (_tmp6_, "visibility_label");
#line 587 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp8_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp7_, gtk_label_get_type (), GtkLabel));
#line 587 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_object_unref0 (self->priv->visibility_label);
#line 587 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->visibility_label = _tmp8_;
#line 588 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp9_ = self->priv->builder;
#line 588 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp10_ = gtk_builder_get_object (_tmp9_, "upload_info_label");
#line 588 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp11_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp10_, gtk_label_get_type (), GtkLabel));
#line 588 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_object_unref0 (self->priv->upload_info_label);
#line 588 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->upload_info_label = _tmp11_;
#line 589 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp12_ = self->priv->builder;
#line 589 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp13_ = gtk_builder_get_object (_tmp12_, "logout_button");
#line 589 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp14_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp13_, gtk_button_get_type (), GtkButton));
#line 589 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_object_unref0 (self->priv->logout_button);
#line 589 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->logout_button = _tmp14_;
#line 590 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp15_ = self->priv->builder;
#line 590 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp16_ = gtk_builder_get_object (_tmp15_, "publish_button");
#line 590 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp17_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp16_, gtk_button_get_type (), GtkButton));
#line 590 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_object_unref0 (self->priv->publish_button);
#line 590 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->publish_button = _tmp17_;
#line 591 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp18_ = self->priv->builder;
#line 591 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp19_ = gtk_builder_get_object (_tmp18_, "visibility_combo");
#line 591 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp20_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp19_, gtk_combo_box_text_get_type (), GtkComboBoxText));
#line 591 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_object_unref0 (self->priv->visibility_combo);
#line 591 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->visibility_combo = _tmp20_;
#line 592 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp21_ = self->priv->builder;
#line 592 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp22_ = gtk_builder_get_object (_tmp21_, "size_combo");
#line 592 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp23_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp22_, gtk_combo_box_text_get_type (), GtkComboBoxText));
#line 592 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_object_unref0 (self->priv->size_combo);
#line 592 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->size_combo = _tmp23_;
#line 593 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp24_ = self->priv->builder;
#line 593 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp25_ = gtk_builder_get_object (_tmp24_, "size_label");
#line 593 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp26_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp25_, gtk_label_get_type (), GtkLabel));
#line 593 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_object_unref0 (self->priv->size_label);
#line 593 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->size_label = _tmp26_;
#line 594 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp27_ = self->priv->builder;
#line 594 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp28_ = gtk_builder_get_object (_tmp27_, "strip_metadata_check");
#line 594 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp29_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp28_, gtk_check_button_get_type (), GtkCheckButton));
#line 594 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_object_unref0 (self->priv->strip_metadata_check);
#line 594 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->strip_metadata_check = _tmp29_;
#line 596 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp30_ = publishing_flickr_flickr_publisher_get_authenticator (publisher);
#line 596 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp31_ = _tmp30_;
#line 596 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp32_ = !spit_publishing_authenticator_can_logout (_tmp31_);
#line 596 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_object_unref0 (_tmp31_);
#line 596 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (_tmp32_) {
#line 4348 "FlickrPublishing.c"
		GtkButton* _tmp33_;
		GtkContainer* _tmp34_;
		GtkContainer* _tmp35_;
		GtkButton* _tmp36_;
#line 597 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp33_ = self->priv->logout_button;
#line 597 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp34_ = gtk_widget_get_parent (G_TYPE_CHECK_INSTANCE_CAST (_tmp33_, gtk_widget_get_type (), GtkWidget));
#line 597 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp35_ = _tmp34_;
#line 597 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp36_ = self->priv->logout_button;
#line 597 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		gtk_container_remove (_tmp35_, G_TYPE_CHECK_INSTANCE_CAST (_tmp36_, gtk_widget_get_type (), GtkWidget));
#line 4363 "FlickrPublishing.c"
	}
#line 600 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp37_ = _publishing_flickr_publishing_parameters_ref0 (parameters);
#line 600 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_publishing_flickr_publishing_parameters_unref0 (self->priv->parameters);
#line 600 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->parameters = _tmp37_;
#line 601 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp38_ = _g_object_ref0 (publisher);
#line 601 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_object_unref0 (self->priv->publisher);
#line 601 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->publisher = _tmp38_;
#line 602 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->media_type = media_type;
#line 604 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp40_ = publishing_flickr_publishing_options_pane_create_visibilities (self, &_tmp39_);
#line 604 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->visibilities = (_vala_array_free (self->priv->visibilities, self->priv->visibilities_length1, (GDestroyNotify) publishing_flickr_publishing_options_pane_visibility_entry_unref), NULL);
#line 604 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->visibilities = _tmp40_;
#line 604 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->visibilities_length1 = _tmp39_;
#line 604 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->_visibilities_size_ = self->priv->visibilities_length1;
#line 605 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp42_ = publishing_flickr_publishing_options_pane_create_sizes (self, &_tmp41_);
#line 605 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->sizes = (_vala_array_free (self->priv->sizes, self->priv->sizes_length1, (GDestroyNotify) publishing_flickr_publishing_options_pane_size_entry_unref), NULL);
#line 605 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->sizes = _tmp42_;
#line 605 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->sizes_length1 = _tmp41_;
#line 605 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->_sizes_size_ = self->priv->sizes_length1;
#line 607 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp43_ = parameters->username;
#line 607 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp44_ = g_strdup_printf (_ ("You are logged into Flickr as %s.\n\n"), _tmp43_);
#line 607 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	upload_label_text = _tmp44_;
#line 608 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp45_ = parameters->user_kind;
#line 608 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (_tmp45_ == PUBLISHING_FLICKR_USER_KIND_FREE) {
#line 4409 "FlickrPublishing.c"
		const gchar* _tmp46_;
		gint64 _tmp47_;
		gchar* _tmp48_;
		gchar* _tmp49_;
		gchar* _tmp50_;
		gchar* _tmp51_;
		gchar* _tmp52_;
#line 609 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp46_ = upload_label_text;
#line 609 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp47_ = parameters->quota_free_bytes;
#line 609 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp48_ = g_format_size_full ((guint64) _tmp47_, G_FORMAT_SIZE_LONG_FORMAT | G_FORMAT_SIZE_IEC_UNITS);
#line 609 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp49_ = _tmp48_;
#line 609 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp50_ = g_strdup_printf (_ ("Your free Flickr account limits how much data you can upload per month" \
".\n" \
"This month you have %s remaining in your upload quota."), _tmp49_);
#line 609 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp51_ = _tmp50_;
#line 609 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp52_ = g_strconcat (_tmp46_, _tmp51_, NULL);
#line 609 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_g_free0 (upload_label_text);
#line 609 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		upload_label_text = _tmp52_;
#line 609 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_g_free0 (_tmp51_);
#line 609 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_g_free0 (_tmp49_);
#line 4439 "FlickrPublishing.c"
	} else {
		const gchar* _tmp53_;
		gchar* _tmp54_;
#line 611 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp53_ = upload_label_text;
#line 611 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp54_ = g_strconcat (_tmp53_, _ ("Your Flickr Pro account entitles you to unlimited uploads."), NULL);
#line 611 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_g_free0 (upload_label_text);
#line 611 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		upload_label_text = _tmp54_;
#line 4451 "FlickrPublishing.c"
	}
#line 614 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp55_ = self->priv->upload_info_label;
#line 614 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp56_ = upload_label_text;
#line 614 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	gtk_label_set_label (_tmp55_, _tmp56_);
#line 616 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp57_ = g_strdup (_ ("Photos _visible to:"));
#line 616 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	visibility_label_text = _tmp57_;
#line 617 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (media_type == SPIT_PUBLISHING_PUBLISHER_MEDIA_TYPE_VIDEO) {
#line 4465 "FlickrPublishing.c"
		gchar* _tmp58_;
#line 618 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp58_ = g_strdup (_ ("Videos _visible to:"));
#line 618 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_g_free0 (visibility_label_text);
#line 618 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		visibility_label_text = _tmp58_;
#line 4473 "FlickrPublishing.c"
	} else {
#line 619 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		if (media_type == (SPIT_PUBLISHING_PUBLISHER_MEDIA_TYPE_PHOTO | SPIT_PUBLISHING_PUBLISHER_MEDIA_TYPE_VIDEO)) {
#line 4477 "FlickrPublishing.c"
			gchar* _tmp59_;
#line 621 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_tmp59_ = g_strdup (_ ("Photos and videos _visible to:"));
#line 621 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_g_free0 (visibility_label_text);
#line 621 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			visibility_label_text = _tmp59_;
#line 4485 "FlickrPublishing.c"
		}
	}
#line 624 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp60_ = self->priv->visibility_label;
#line 624 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp61_ = visibility_label_text;
#line 624 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	gtk_label_set_label (_tmp60_, _tmp61_);
#line 626 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_publishing_options_pane_populate_visibility_combo (self);
#line 627 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp62_ = self->priv->visibility_combo;
#line 627 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp62_, gtk_combo_box_get_type (), GtkComboBox), "changed", (GCallback) _publishing_flickr_publishing_options_pane_on_visibility_changed_gtk_combo_box_changed, self, 0);
#line 629 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (media_type != SPIT_PUBLISHING_PUBLISHER_MEDIA_TYPE_VIDEO) {
#line 4502 "FlickrPublishing.c"
		GtkComboBoxText* _tmp63_;
#line 630 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		publishing_flickr_publishing_options_pane_populate_size_combo (self);
#line 631 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp63_ = self->priv->size_combo;
#line 631 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp63_, gtk_combo_box_get_type (), GtkComboBox), "changed", (GCallback) _publishing_flickr_publishing_options_pane_on_size_changed_gtk_combo_box_changed, self, 0);
#line 4510 "FlickrPublishing.c"
	} else {
		GtkComboBoxText* _tmp64_;
		GtkLabel* _tmp65_;
#line 634 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp64_ = self->priv->size_combo;
#line 634 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp64_, gtk_widget_get_type (), GtkWidget), FALSE);
#line 635 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp65_ = self->priv->size_label;
#line 635 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp65_, gtk_widget_get_type (), GtkWidget), FALSE);
#line 4522 "FlickrPublishing.c"
	}
#line 638 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp66_ = self->priv->strip_metadata_check;
#line 638 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	gtk_toggle_button_set_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp66_, gtk_toggle_button_get_type (), GtkToggleButton), strip_metadata);
#line 640 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp67_ = self->priv->logout_button;
#line 640 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_connect_object (_tmp67_, "clicked", (GCallback) _publishing_flickr_publishing_options_pane_on_logout_clicked_gtk_button_clicked, self, 0);
#line 641 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp68_ = self->priv->publish_button;
#line 641 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_connect_object (_tmp68_, "clicked", (GCallback) _publishing_flickr_publishing_options_pane_on_publish_clicked_gtk_button_clicked, self, 0);
#line 579 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_free0 (visibility_label_text);
#line 579 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_free0 (upload_label_text);
#line 579 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return self;
#line 4542 "FlickrPublishing.c"
}


PublishingFlickrPublishingOptionsPane*
publishing_flickr_publishing_options_pane_new (PublishingFlickrFlickrPublisher* publisher,
                                               PublishingFlickrPublishingParameters* parameters,
                                               SpitPublishingPublisherMediaType media_type,
                                               GtkBuilder* builder,
                                               gboolean strip_metadata)
{
#line 579 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return publishing_flickr_publishing_options_pane_construct (PUBLISHING_FLICKR_TYPE_PUBLISHING_OPTIONS_PANE, publisher, parameters, media_type, builder, strip_metadata);
#line 4555 "FlickrPublishing.c"
}


static void
publishing_flickr_publishing_options_pane_on_logout_clicked (PublishingFlickrPublishingOptionsPane* self)
{
#line 644 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (PUBLISHING_FLICKR_IS_PUBLISHING_OPTIONS_PANE (self));
#line 645 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_emit (self, publishing_flickr_publishing_options_pane_signals[PUBLISHING_FLICKR_PUBLISHING_OPTIONS_PANE_LOGOUT_SIGNAL], 0);
#line 4566 "FlickrPublishing.c"
}


static gpointer
_publishing_flickr_visibility_specification_ref0 (gpointer self)
{
#line 649 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return self ? publishing_flickr_visibility_specification_ref (self) : NULL;
#line 4575 "FlickrPublishing.c"
}


static void
publishing_flickr_publishing_options_pane_on_publish_clicked (PublishingFlickrPublishingOptionsPane* self)
{
	PublishingFlickrPublishingParameters* _tmp0_;
	PublishingFlickrPublishingOptionsPaneVisibilityEntry** _tmp1_;
	gint _tmp1__length1;
	GtkComboBoxText* _tmp2_;
	PublishingFlickrPublishingOptionsPaneVisibilityEntry* _tmp3_;
	PublishingFlickrVisibilitySpecification* _tmp4_;
	PublishingFlickrVisibilitySpecification* _tmp5_;
	SpitPublishingPublisherMediaType _tmp6_;
	GtkCheckButton* _tmp12_;
#line 648 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (PUBLISHING_FLICKR_IS_PUBLISHING_OPTIONS_PANE (self));
#line 649 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = self->priv->parameters;
#line 649 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp1_ = self->priv->visibilities;
#line 649 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp1__length1 = self->priv->visibilities_length1;
#line 649 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp2_ = self->priv->visibility_combo;
#line 649 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp3_ = _tmp1_[gtk_combo_box_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, gtk_combo_box_get_type (), GtkComboBox))];
#line 649 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp4_ = _tmp3_->specification;
#line 649 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp5_ = _publishing_flickr_visibility_specification_ref0 (_tmp4_);
#line 649 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_publishing_flickr_visibility_specification_unref0 (_tmp0_->visibility_specification);
#line 649 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_->visibility_specification = _tmp5_;
#line 652 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp6_ = self->priv->media_type;
#line 652 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if ((_tmp6_ & SPIT_PUBLISHING_PUBLISHER_MEDIA_TYPE_PHOTO) != 0) {
#line 4615 "FlickrPublishing.c"
		PublishingFlickrPublishingParameters* _tmp7_;
		PublishingFlickrPublishingOptionsPaneSizeEntry** _tmp8_;
		gint _tmp8__length1;
		GtkComboBoxText* _tmp9_;
		PublishingFlickrPublishingOptionsPaneSizeEntry* _tmp10_;
		gint _tmp11_;
#line 653 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp7_ = self->priv->parameters;
#line 653 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp8_ = self->priv->sizes;
#line 653 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp8__length1 = self->priv->sizes_length1;
#line 653 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp9_ = self->priv->size_combo;
#line 653 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp10_ = _tmp8_[gtk_combo_box_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, gtk_combo_box_get_type (), GtkComboBox))];
#line 653 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp11_ = _tmp10_->size;
#line 653 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp7_->photo_major_axis_size = _tmp11_;
#line 4636 "FlickrPublishing.c"
	}
#line 655 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp12_ = self->priv->strip_metadata_check;
#line 655 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_emit (self, publishing_flickr_publishing_options_pane_signals[PUBLISHING_FLICKR_PUBLISHING_OPTIONS_PANE_PUBLISH_SIGNAL], 0, gtk_toggle_button_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp12_, gtk_toggle_button_get_type (), GtkToggleButton)));
#line 4642 "FlickrPublishing.c"
}


static void
_vala_array_add20 (PublishingFlickrPublishingOptionsPaneVisibilityEntry** * array,
                   int* length,
                   int* size,
                   PublishingFlickrPublishingOptionsPaneVisibilityEntry* value)
{
#line 661 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if ((*length) == (*size)) {
#line 661 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 661 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		*array = g_renew (PublishingFlickrPublishingOptionsPaneVisibilityEntry*, *array, (*size) + 1);
#line 4658 "FlickrPublishing.c"
	}
#line 661 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	(*array)[(*length)++] = value;
#line 661 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	(*array)[*length] = NULL;
#line 4664 "FlickrPublishing.c"
}


static void
_vala_array_add21 (PublishingFlickrPublishingOptionsPaneVisibilityEntry** * array,
                   int* length,
                   int* size,
                   PublishingFlickrPublishingOptionsPaneVisibilityEntry* value)
{
#line 662 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if ((*length) == (*size)) {
#line 662 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 662 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		*array = g_renew (PublishingFlickrPublishingOptionsPaneVisibilityEntry*, *array, (*size) + 1);
#line 4680 "FlickrPublishing.c"
	}
#line 662 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	(*array)[(*length)++] = value;
#line 662 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	(*array)[*length] = NULL;
#line 4686 "FlickrPublishing.c"
}


static void
_vala_array_add22 (PublishingFlickrPublishingOptionsPaneVisibilityEntry** * array,
                   int* length,
                   int* size,
                   PublishingFlickrPublishingOptionsPaneVisibilityEntry* value)
{
#line 663 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if ((*length) == (*size)) {
#line 663 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 663 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		*array = g_renew (PublishingFlickrPublishingOptionsPaneVisibilityEntry*, *array, (*size) + 1);
#line 4702 "FlickrPublishing.c"
	}
#line 663 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	(*array)[(*length)++] = value;
#line 663 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	(*array)[*length] = NULL;
#line 4708 "FlickrPublishing.c"
}


static void
_vala_array_add23 (PublishingFlickrPublishingOptionsPaneVisibilityEntry** * array,
                   int* length,
                   int* size,
                   PublishingFlickrPublishingOptionsPaneVisibilityEntry* value)
{
#line 664 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if ((*length) == (*size)) {
#line 664 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 664 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		*array = g_renew (PublishingFlickrPublishingOptionsPaneVisibilityEntry*, *array, (*size) + 1);
#line 4724 "FlickrPublishing.c"
	}
#line 664 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	(*array)[(*length)++] = value;
#line 664 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	(*array)[*length] = NULL;
#line 4730 "FlickrPublishing.c"
}


static void
_vala_array_add24 (PublishingFlickrPublishingOptionsPaneVisibilityEntry** * array,
                   int* length,
                   int* size,
                   PublishingFlickrPublishingOptionsPaneVisibilityEntry* value)
{
#line 665 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if ((*length) == (*size)) {
#line 665 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 665 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		*array = g_renew (PublishingFlickrPublishingOptionsPaneVisibilityEntry*, *array, (*size) + 1);
#line 4746 "FlickrPublishing.c"
	}
#line 665 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	(*array)[(*length)++] = value;
#line 665 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	(*array)[*length] = NULL;
#line 4752 "FlickrPublishing.c"
}


static PublishingFlickrPublishingOptionsPaneVisibilityEntry**
publishing_flickr_publishing_options_pane_create_visibilities (PublishingFlickrPublishingOptionsPane* self,
                                                               int* result_length1)
{
	PublishingFlickrPublishingOptionsPaneVisibilityEntry** result = NULL;
	PublishingFlickrPublishingOptionsPaneVisibilityEntry** _result_ = NULL;
	PublishingFlickrPublishingOptionsPaneVisibilityEntry** _tmp0_;
	gint _result__length1;
	gint __result__size_;
	PublishingFlickrPublishingOptionsPaneVisibilityEntry** _tmp1_;
	gint _tmp1__length1;
	PublishingFlickrVisibilitySpecification* _tmp2_;
	PublishingFlickrVisibilitySpecification* _tmp3_;
	PublishingFlickrPublishingOptionsPaneVisibilityEntry* _tmp4_;
	PublishingFlickrPublishingOptionsPaneVisibilityEntry** _tmp5_;
	gint _tmp5__length1;
	PublishingFlickrVisibilitySpecification* _tmp6_;
	PublishingFlickrVisibilitySpecification* _tmp7_;
	PublishingFlickrPublishingOptionsPaneVisibilityEntry* _tmp8_;
	PublishingFlickrPublishingOptionsPaneVisibilityEntry** _tmp9_;
	gint _tmp9__length1;
	PublishingFlickrVisibilitySpecification* _tmp10_;
	PublishingFlickrVisibilitySpecification* _tmp11_;
	PublishingFlickrPublishingOptionsPaneVisibilityEntry* _tmp12_;
	PublishingFlickrPublishingOptionsPaneVisibilityEntry** _tmp13_;
	gint _tmp13__length1;
	PublishingFlickrVisibilitySpecification* _tmp14_;
	PublishingFlickrVisibilitySpecification* _tmp15_;
	PublishingFlickrPublishingOptionsPaneVisibilityEntry* _tmp16_;
	PublishingFlickrPublishingOptionsPaneVisibilityEntry** _tmp17_;
	gint _tmp17__length1;
	PublishingFlickrVisibilitySpecification* _tmp18_;
	PublishingFlickrVisibilitySpecification* _tmp19_;
	PublishingFlickrPublishingOptionsPaneVisibilityEntry* _tmp20_;
	PublishingFlickrPublishingOptionsPaneVisibilityEntry** _tmp21_;
	gint _tmp21__length1;
#line 658 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_val_if_fail (PUBLISHING_FLICKR_IS_PUBLISHING_OPTIONS_PANE (self), NULL);
#line 659 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = g_new0 (PublishingFlickrPublishingOptionsPaneVisibilityEntry*, 0 + 1);
#line 659 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_result_ = _tmp0_;
#line 659 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_result__length1 = 0;
#line 659 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	__result__size_ = _result__length1;
#line 661 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp1_ = _result_;
#line 661 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp1__length1 = _result__length1;
#line 661 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp2_ = publishing_flickr_visibility_specification_new (1, 1, 1);
#line 661 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp3_ = _tmp2_;
#line 661 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp4_ = publishing_flickr_publishing_options_pane_visibility_entry_new (_ ("Everyone"), _tmp3_);
#line 661 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_vala_array_add20 (&_result_, &_result__length1, &__result__size_, _tmp4_);
#line 661 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_publishing_flickr_visibility_specification_unref0 (_tmp3_);
#line 662 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp5_ = _result_;
#line 662 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp5__length1 = _result__length1;
#line 662 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp6_ = publishing_flickr_visibility_specification_new (1, 1, 0);
#line 662 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp7_ = _tmp6_;
#line 662 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp8_ = publishing_flickr_publishing_options_pane_visibility_entry_new (_ ("Friends & family only"), _tmp7_);
#line 662 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_vala_array_add21 (&_result_, &_result__length1, &__result__size_, _tmp8_);
#line 662 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_publishing_flickr_visibility_specification_unref0 (_tmp7_);
#line 663 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp9_ = _result_;
#line 663 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp9__length1 = _result__length1;
#line 663 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp10_ = publishing_flickr_visibility_specification_new (0, 1, 0);
#line 663 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp11_ = _tmp10_;
#line 663 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp12_ = publishing_flickr_publishing_options_pane_visibility_entry_new (_ ("Family only"), _tmp11_);
#line 663 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_vala_array_add22 (&_result_, &_result__length1, &__result__size_, _tmp12_);
#line 663 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_publishing_flickr_visibility_specification_unref0 (_tmp11_);
#line 664 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp13_ = _result_;
#line 664 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp13__length1 = _result__length1;
#line 664 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp14_ = publishing_flickr_visibility_specification_new (1, 0, 0);
#line 664 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp15_ = _tmp14_;
#line 664 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp16_ = publishing_flickr_publishing_options_pane_visibility_entry_new (_ ("Friends only"), _tmp15_);
#line 664 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_vala_array_add23 (&_result_, &_result__length1, &__result__size_, _tmp16_);
#line 664 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_publishing_flickr_visibility_specification_unref0 (_tmp15_);
#line 665 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp17_ = _result_;
#line 665 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp17__length1 = _result__length1;
#line 665 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp18_ = publishing_flickr_visibility_specification_new (0, 0, 0);
#line 665 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp19_ = _tmp18_;
#line 665 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp20_ = publishing_flickr_publishing_options_pane_visibility_entry_new (_ ("Just me"), _tmp19_);
#line 665 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_vala_array_add24 (&_result_, &_result__length1, &__result__size_, _tmp20_);
#line 665 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_publishing_flickr_visibility_specification_unref0 (_tmp19_);
#line 667 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp21_ = _result_;
#line 667 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp21__length1 = _result__length1;
#line 667 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (result_length1) {
#line 667 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		*result_length1 = _tmp21__length1;
#line 4880 "FlickrPublishing.c"
	}
#line 667 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	result = _tmp21_;
#line 667 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return result;
#line 4886 "FlickrPublishing.c"
}


static gpointer
_publishing_flickr_publishing_options_pane_visibility_entry_ref0 (gpointer self)
{
#line 674 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return self ? publishing_flickr_publishing_options_pane_visibility_entry_ref (self) : NULL;
#line 4895 "FlickrPublishing.c"
}


static void
publishing_flickr_publishing_options_pane_populate_visibility_combo (PublishingFlickrPublishingOptionsPane* self)
{
	PublishingFlickrPublishingOptionsPaneVisibilityEntry** _tmp0_;
	gint _tmp0__length1;
	PublishingFlickrPublishingOptionsPaneVisibilityEntry** _tmp3_;
	gint _tmp3__length1;
	GtkComboBoxText* _tmp8_;
	PublishingFlickrFlickrPublisher* _tmp9_;
#line 670 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (PUBLISHING_FLICKR_IS_PUBLISHING_OPTIONS_PANE (self));
#line 671 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = self->priv->visibilities;
#line 671 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0__length1 = self->priv->visibilities_length1;
#line 671 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (_tmp0_ == NULL) {
#line 4916 "FlickrPublishing.c"
		gint _tmp1_;
		PublishingFlickrPublishingOptionsPaneVisibilityEntry** _tmp2_;
#line 672 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp2_ = publishing_flickr_publishing_options_pane_create_visibilities (self, &_tmp1_);
#line 672 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		self->priv->visibilities = (_vala_array_free (self->priv->visibilities, self->priv->visibilities_length1, (GDestroyNotify) publishing_flickr_publishing_options_pane_visibility_entry_unref), NULL);
#line 672 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		self->priv->visibilities = _tmp2_;
#line 672 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		self->priv->visibilities_length1 = _tmp1_;
#line 672 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		self->priv->_visibilities_size_ = self->priv->visibilities_length1;
#line 4929 "FlickrPublishing.c"
	}
#line 674 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp3_ = self->priv->visibilities;
#line 674 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp3__length1 = self->priv->visibilities_length1;
#line 4935 "FlickrPublishing.c"
	{
		PublishingFlickrPublishingOptionsPaneVisibilityEntry** v_collection = NULL;
		gint v_collection_length1 = 0;
		gint _v_collection_size_ = 0;
		gint v_it = 0;
#line 674 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		v_collection = _tmp3_;
#line 674 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		v_collection_length1 = _tmp3__length1;
#line 674 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		for (v_it = 0; v_it < _tmp3__length1; v_it = v_it + 1) {
#line 4947 "FlickrPublishing.c"
			PublishingFlickrPublishingOptionsPaneVisibilityEntry* _tmp4_;
			PublishingFlickrPublishingOptionsPaneVisibilityEntry* v = NULL;
#line 674 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_tmp4_ = _publishing_flickr_publishing_options_pane_visibility_entry_ref0 (v_collection[v_it]);
#line 674 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			v = _tmp4_;
#line 4954 "FlickrPublishing.c"
			{
				GtkComboBoxText* _tmp5_;
				PublishingFlickrPublishingOptionsPaneVisibilityEntry* _tmp6_;
				const gchar* _tmp7_;
#line 675 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_tmp5_ = self->priv->visibility_combo;
#line 675 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_tmp6_ = v;
#line 675 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_tmp7_ = _tmp6_->title;
#line 675 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				gtk_combo_box_text_append_text (_tmp5_, _tmp7_);
#line 674 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_publishing_flickr_publishing_options_pane_visibility_entry_unref0 (v);
#line 4969 "FlickrPublishing.c"
			}
		}
	}
#line 677 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp8_ = self->priv->visibility_combo;
#line 677 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp9_ = self->priv->publisher;
#line 677 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	gtk_combo_box_set_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp8_, gtk_combo_box_get_type (), GtkComboBox), publishing_flickr_flickr_publisher_get_persistent_visibility (_tmp9_));
#line 4979 "FlickrPublishing.c"
}


static void
_vala_array_add25 (PublishingFlickrPublishingOptionsPaneSizeEntry** * array,
                   int* length,
                   int* size,
                   PublishingFlickrPublishingOptionsPaneSizeEntry* value)
{
#line 683 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if ((*length) == (*size)) {
#line 683 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 683 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		*array = g_renew (PublishingFlickrPublishingOptionsPaneSizeEntry*, *array, (*size) + 1);
#line 4995 "FlickrPublishing.c"
	}
#line 683 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	(*array)[(*length)++] = value;
#line 683 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	(*array)[*length] = NULL;
#line 5001 "FlickrPublishing.c"
}


static void
_vala_array_add26 (PublishingFlickrPublishingOptionsPaneSizeEntry** * array,
                   int* length,
                   int* size,
                   PublishingFlickrPublishingOptionsPaneSizeEntry* value)
{
#line 684 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if ((*length) == (*size)) {
#line 684 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 684 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		*array = g_renew (PublishingFlickrPublishingOptionsPaneSizeEntry*, *array, (*size) + 1);
#line 5017 "FlickrPublishing.c"
	}
#line 684 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	(*array)[(*length)++] = value;
#line 684 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	(*array)[*length] = NULL;
#line 5023 "FlickrPublishing.c"
}


static void
_vala_array_add27 (PublishingFlickrPublishingOptionsPaneSizeEntry** * array,
                   int* length,
                   int* size,
                   PublishingFlickrPublishingOptionsPaneSizeEntry* value)
{
#line 685 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if ((*length) == (*size)) {
#line 685 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 685 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		*array = g_renew (PublishingFlickrPublishingOptionsPaneSizeEntry*, *array, (*size) + 1);
#line 5039 "FlickrPublishing.c"
	}
#line 685 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	(*array)[(*length)++] = value;
#line 685 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	(*array)[*length] = NULL;
#line 5045 "FlickrPublishing.c"
}


static void
_vala_array_add28 (PublishingFlickrPublishingOptionsPaneSizeEntry** * array,
                   int* length,
                   int* size,
                   PublishingFlickrPublishingOptionsPaneSizeEntry* value)
{
#line 686 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if ((*length) == (*size)) {
#line 686 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 686 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		*array = g_renew (PublishingFlickrPublishingOptionsPaneSizeEntry*, *array, (*size) + 1);
#line 5061 "FlickrPublishing.c"
	}
#line 686 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	(*array)[(*length)++] = value;
#line 686 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	(*array)[*length] = NULL;
#line 5067 "FlickrPublishing.c"
}


static void
_vala_array_add29 (PublishingFlickrPublishingOptionsPaneSizeEntry** * array,
                   int* length,
                   int* size,
                   PublishingFlickrPublishingOptionsPaneSizeEntry* value)
{
#line 687 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if ((*length) == (*size)) {
#line 687 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 687 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		*array = g_renew (PublishingFlickrPublishingOptionsPaneSizeEntry*, *array, (*size) + 1);
#line 5083 "FlickrPublishing.c"
	}
#line 687 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	(*array)[(*length)++] = value;
#line 687 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	(*array)[*length] = NULL;
#line 5089 "FlickrPublishing.c"
}


static PublishingFlickrPublishingOptionsPaneSizeEntry**
publishing_flickr_publishing_options_pane_create_sizes (PublishingFlickrPublishingOptionsPane* self,
                                                        int* result_length1)
{
	PublishingFlickrPublishingOptionsPaneSizeEntry** result = NULL;
	PublishingFlickrPublishingOptionsPaneSizeEntry** _result_ = NULL;
	PublishingFlickrPublishingOptionsPaneSizeEntry** _tmp0_;
	gint _result__length1;
	gint __result__size_;
	PublishingFlickrPublishingOptionsPaneSizeEntry** _tmp1_;
	gint _tmp1__length1;
	PublishingFlickrPublishingOptionsPaneSizeEntry* _tmp2_;
	PublishingFlickrPublishingOptionsPaneSizeEntry** _tmp3_;
	gint _tmp3__length1;
	PublishingFlickrPublishingOptionsPaneSizeEntry* _tmp4_;
	PublishingFlickrPublishingOptionsPaneSizeEntry** _tmp5_;
	gint _tmp5__length1;
	PublishingFlickrPublishingOptionsPaneSizeEntry* _tmp6_;
	PublishingFlickrPublishingOptionsPaneSizeEntry** _tmp7_;
	gint _tmp7__length1;
	PublishingFlickrPublishingOptionsPaneSizeEntry* _tmp8_;
	PublishingFlickrPublishingOptionsPaneSizeEntry** _tmp9_;
	gint _tmp9__length1;
	PublishingFlickrPublishingOptionsPaneSizeEntry* _tmp10_;
	PublishingFlickrPublishingOptionsPaneSizeEntry** _tmp11_;
	gint _tmp11__length1;
#line 680 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_val_if_fail (PUBLISHING_FLICKR_IS_PUBLISHING_OPTIONS_PANE (self), NULL);
#line 681 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = g_new0 (PublishingFlickrPublishingOptionsPaneSizeEntry*, 0 + 1);
#line 681 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_result_ = _tmp0_;
#line 681 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_result__length1 = 0;
#line 681 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	__result__size_ = _result__length1;
#line 683 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp1_ = _result_;
#line 683 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp1__length1 = _result__length1;
#line 683 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp2_ = publishing_flickr_publishing_options_pane_size_entry_new (_ ("500 × 375 pixels"), 500);
#line 683 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_vala_array_add25 (&_result_, &_result__length1, &__result__size_, _tmp2_);
#line 684 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp3_ = _result_;
#line 684 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp3__length1 = _result__length1;
#line 684 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp4_ = publishing_flickr_publishing_options_pane_size_entry_new (_ ("1024 × 768 pixels"), 1024);
#line 684 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_vala_array_add26 (&_result_, &_result__length1, &__result__size_, _tmp4_);
#line 685 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp5_ = _result_;
#line 685 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp5__length1 = _result__length1;
#line 685 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp6_ = publishing_flickr_publishing_options_pane_size_entry_new (_ ("2048 × 1536 pixels"), 2048);
#line 685 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_vala_array_add27 (&_result_, &_result__length1, &__result__size_, _tmp6_);
#line 686 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp7_ = _result_;
#line 686 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp7__length1 = _result__length1;
#line 686 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp8_ = publishing_flickr_publishing_options_pane_size_entry_new (_ ("4096 × 3072 pixels"), 4096);
#line 686 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_vala_array_add28 (&_result_, &_result__length1, &__result__size_, _tmp8_);
#line 687 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp9_ = _result_;
#line 687 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp9__length1 = _result__length1;
#line 687 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp10_ = publishing_flickr_publishing_options_pane_size_entry_new (_ ("Original size"), PUBLISHING_FLICKR_ORIGINAL_SIZE);
#line 687 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_vala_array_add29 (&_result_, &_result__length1, &__result__size_, _tmp10_);
#line 689 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp11_ = _result_;
#line 689 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp11__length1 = _result__length1;
#line 689 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (result_length1) {
#line 689 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		*result_length1 = _tmp11__length1;
#line 5177 "FlickrPublishing.c"
	}
#line 689 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	result = _tmp11_;
#line 689 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return result;
#line 5183 "FlickrPublishing.c"
}


static gpointer
_publishing_flickr_publishing_options_pane_size_entry_ref0 (gpointer self)
{
#line 696 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return self ? publishing_flickr_publishing_options_pane_size_entry_ref (self) : NULL;
#line 5192 "FlickrPublishing.c"
}


static void
publishing_flickr_publishing_options_pane_populate_size_combo (PublishingFlickrPublishingOptionsPane* self)
{
	PublishingFlickrPublishingOptionsPaneSizeEntry** _tmp0_;
	gint _tmp0__length1;
	PublishingFlickrPublishingOptionsPaneSizeEntry** _tmp3_;
	gint _tmp3__length1;
	GtkComboBoxText* _tmp8_;
	PublishingFlickrFlickrPublisher* _tmp9_;
#line 692 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (PUBLISHING_FLICKR_IS_PUBLISHING_OPTIONS_PANE (self));
#line 693 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = self->priv->sizes;
#line 693 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0__length1 = self->priv->sizes_length1;
#line 693 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (_tmp0_ == NULL) {
#line 5213 "FlickrPublishing.c"
		gint _tmp1_;
		PublishingFlickrPublishingOptionsPaneSizeEntry** _tmp2_;
#line 694 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp2_ = publishing_flickr_publishing_options_pane_create_sizes (self, &_tmp1_);
#line 694 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		self->priv->sizes = (_vala_array_free (self->priv->sizes, self->priv->sizes_length1, (GDestroyNotify) publishing_flickr_publishing_options_pane_size_entry_unref), NULL);
#line 694 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		self->priv->sizes = _tmp2_;
#line 694 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		self->priv->sizes_length1 = _tmp1_;
#line 694 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		self->priv->_sizes_size_ = self->priv->sizes_length1;
#line 5226 "FlickrPublishing.c"
	}
#line 696 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp3_ = self->priv->sizes;
#line 696 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp3__length1 = self->priv->sizes_length1;
#line 5232 "FlickrPublishing.c"
	{
		PublishingFlickrPublishingOptionsPaneSizeEntry** e_collection = NULL;
		gint e_collection_length1 = 0;
		gint _e_collection_size_ = 0;
		gint e_it = 0;
#line 696 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		e_collection = _tmp3_;
#line 696 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		e_collection_length1 = _tmp3__length1;
#line 696 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		for (e_it = 0; e_it < _tmp3__length1; e_it = e_it + 1) {
#line 5244 "FlickrPublishing.c"
			PublishingFlickrPublishingOptionsPaneSizeEntry* _tmp4_;
			PublishingFlickrPublishingOptionsPaneSizeEntry* e = NULL;
#line 696 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_tmp4_ = _publishing_flickr_publishing_options_pane_size_entry_ref0 (e_collection[e_it]);
#line 696 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			e = _tmp4_;
#line 5251 "FlickrPublishing.c"
			{
				GtkComboBoxText* _tmp5_;
				PublishingFlickrPublishingOptionsPaneSizeEntry* _tmp6_;
				const gchar* _tmp7_;
#line 697 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_tmp5_ = self->priv->size_combo;
#line 697 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_tmp6_ = e;
#line 697 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_tmp7_ = _tmp6_->title;
#line 697 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				gtk_combo_box_text_append_text (_tmp5_, _tmp7_);
#line 696 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				_publishing_flickr_publishing_options_pane_size_entry_unref0 (e);
#line 5266 "FlickrPublishing.c"
			}
		}
	}
#line 699 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp8_ = self->priv->size_combo;
#line 699 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp9_ = self->priv->publisher;
#line 699 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	gtk_combo_box_set_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp8_, gtk_combo_box_get_type (), GtkComboBox), publishing_flickr_flickr_publisher_get_persistent_default_size (_tmp9_));
#line 5276 "FlickrPublishing.c"
}


static void
publishing_flickr_publishing_options_pane_on_size_changed (PublishingFlickrPublishingOptionsPane* self)
{
	PublishingFlickrFlickrPublisher* _tmp0_;
	GtkComboBoxText* _tmp1_;
#line 702 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (PUBLISHING_FLICKR_IS_PUBLISHING_OPTIONS_PANE (self));
#line 703 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = self->priv->publisher;
#line 703 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp1_ = self->priv->size_combo;
#line 703 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_flickr_publisher_set_persistent_default_size (_tmp0_, gtk_combo_box_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, gtk_combo_box_get_type (), GtkComboBox)));
#line 5293 "FlickrPublishing.c"
}


static void
publishing_flickr_publishing_options_pane_on_visibility_changed (PublishingFlickrPublishingOptionsPane* self)
{
	PublishingFlickrFlickrPublisher* _tmp0_;
	GtkComboBoxText* _tmp1_;
#line 706 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (PUBLISHING_FLICKR_IS_PUBLISHING_OPTIONS_PANE (self));
#line 707 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = self->priv->publisher;
#line 707 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp1_ = self->priv->visibility_combo;
#line 707 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_flickr_publisher_set_persistent_visibility (_tmp0_, gtk_combo_box_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, gtk_combo_box_get_type (), GtkComboBox)));
#line 5310 "FlickrPublishing.c"
}


void
publishing_flickr_publishing_options_pane_notify_publish (PublishingFlickrPublishingOptionsPane* self)
{
	GtkCheckButton* _tmp0_;
#line 710 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (PUBLISHING_FLICKR_IS_PUBLISHING_OPTIONS_PANE (self));
#line 711 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = self->priv->strip_metadata_check;
#line 711 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_emit (self, publishing_flickr_publishing_options_pane_signals[PUBLISHING_FLICKR_PUBLISHING_OPTIONS_PANE_PUBLISH_SIGNAL], 0, gtk_toggle_button_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, gtk_toggle_button_get_type (), GtkToggleButton)));
#line 5324 "FlickrPublishing.c"
}


void
publishing_flickr_publishing_options_pane_notify_logout (PublishingFlickrPublishingOptionsPane* self)
{
#line 714 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (PUBLISHING_FLICKR_IS_PUBLISHING_OPTIONS_PANE (self));
#line 715 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_emit (self, publishing_flickr_publishing_options_pane_signals[PUBLISHING_FLICKR_PUBLISHING_OPTIONS_PANE_LOGOUT_SIGNAL], 0);
#line 5335 "FlickrPublishing.c"
}


static GtkWidget*
publishing_flickr_publishing_options_pane_real_get_widget (SpitPublishingDialogPane* base)
{
	PublishingFlickrPublishingOptionsPane * self;
	GtkWidget* result = NULL;
	GtkBox* _tmp0_;
	GtkWidget* _tmp1_;
#line 718 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_FLICKR_TYPE_PUBLISHING_OPTIONS_PANE, PublishingFlickrPublishingOptionsPane);
#line 719 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = self->priv->pane_widget;
#line 719 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp1_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, gtk_widget_get_type (), GtkWidget));
#line 719 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	result = _tmp1_;
#line 719 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return result;
#line 5356 "FlickrPublishing.c"
}


static SpitPublishingDialogPaneGeometryOptions
publishing_flickr_publishing_options_pane_real_get_preferred_geometry (SpitPublishingDialogPane* base)
{
	PublishingFlickrPublishingOptionsPane * self;
	SpitPublishingDialogPaneGeometryOptions result = 0;
#line 722 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_FLICKR_TYPE_PUBLISHING_OPTIONS_PANE, PublishingFlickrPublishingOptionsPane);
#line 723 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	result = SPIT_PUBLISHING_DIALOG_PANE_GEOMETRY_OPTIONS_NONE;
#line 723 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return result;
#line 5371 "FlickrPublishing.c"
}


static void
_publishing_flickr_publishing_options_pane_notify_publish_publishing_flickr_publishing_options_pane_publish (PublishingFlickrPublishingOptionsPane* _sender,
                                                                                                             gboolean strip_metadata,
                                                                                                             gpointer self)
{
#line 727 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_publishing_options_pane_notify_publish ((PublishingFlickrPublishingOptionsPane*) self);
#line 5382 "FlickrPublishing.c"
}


static void
_publishing_flickr_publishing_options_pane_notify_logout_publishing_flickr_publishing_options_pane_logout (PublishingFlickrPublishingOptionsPane* _sender,
                                                                                                           gpointer self)
{
#line 728 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_publishing_options_pane_notify_logout ((PublishingFlickrPublishingOptionsPane*) self);
#line 5392 "FlickrPublishing.c"
}


static void
publishing_flickr_publishing_options_pane_real_on_pane_installed (SpitPublishingDialogPane* base)
{
	PublishingFlickrPublishingOptionsPane * self;
#line 726 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_FLICKR_TYPE_PUBLISHING_OPTIONS_PANE, PublishingFlickrPublishingOptionsPane);
#line 727 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_connect_object (self, "publish", (GCallback) _publishing_flickr_publishing_options_pane_notify_publish_publishing_flickr_publishing_options_pane_publish, self, 0);
#line 728 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_connect_object (self, "logout", (GCallback) _publishing_flickr_publishing_options_pane_notify_logout_publishing_flickr_publishing_options_pane_logout, self, 0);
#line 5406 "FlickrPublishing.c"
}


static void
publishing_flickr_publishing_options_pane_real_on_pane_uninstalled (SpitPublishingDialogPane* base)
{
	PublishingFlickrPublishingOptionsPane * self;
	guint _tmp0_;
	guint _tmp1_;
#line 731 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_FLICKR_TYPE_PUBLISHING_OPTIONS_PANE, PublishingFlickrPublishingOptionsPane);
#line 732 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_parse_name ("publish", PUBLISHING_FLICKR_TYPE_PUBLISHING_OPTIONS_PANE, &_tmp0_, NULL, FALSE);
#line 732 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_handlers_disconnect_matched (self, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp0_, 0, NULL, (GCallback) _publishing_flickr_publishing_options_pane_notify_publish_publishing_flickr_publishing_options_pane_publish, self);
#line 733 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_parse_name ("logout", PUBLISHING_FLICKR_TYPE_PUBLISHING_OPTIONS_PANE, &_tmp1_, NULL, FALSE);
#line 733 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_handlers_disconnect_matched (self, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _publishing_flickr_publishing_options_pane_notify_logout_publishing_flickr_publishing_options_pane_logout, self);
#line 5426 "FlickrPublishing.c"
}


static PublishingFlickrPublishingOptionsPaneSizeEntry*
publishing_flickr_publishing_options_pane_size_entry_construct (GType object_type,
                                                                const gchar* creator_title,
                                                                gint creator_size)
{
	PublishingFlickrPublishingOptionsPaneSizeEntry* self = NULL;
	gchar* _tmp0_;
#line 544 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_val_if_fail (creator_title != NULL, NULL);
#line 544 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self = (PublishingFlickrPublishingOptionsPaneSizeEntry*) g_type_create_instance (object_type);
#line 545 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = g_strdup (creator_title);
#line 545 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_free0 (self->title);
#line 545 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->title = _tmp0_;
#line 546 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->size = creator_size;
#line 544 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return self;
#line 5451 "FlickrPublishing.c"
}


static PublishingFlickrPublishingOptionsPaneSizeEntry*
publishing_flickr_publishing_options_pane_size_entry_new (const gchar* creator_title,
                                                          gint creator_size)
{
#line 544 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return publishing_flickr_publishing_options_pane_size_entry_construct (PUBLISHING_FLICKR_PUBLISHING_OPTIONS_PANE_TYPE_SIZE_ENTRY, creator_title, creator_size);
#line 5461 "FlickrPublishing.c"
}


static void
publishing_flickr_publishing_options_pane_value_size_entry_init (GValue* value)
{
#line 540 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	value->data[0].v_pointer = NULL;
#line 5470 "FlickrPublishing.c"
}


static void
publishing_flickr_publishing_options_pane_value_size_entry_free_value (GValue* value)
{
#line 540 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (value->data[0].v_pointer) {
#line 540 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		publishing_flickr_publishing_options_pane_size_entry_unref (value->data[0].v_pointer);
#line 5481 "FlickrPublishing.c"
	}
}


static void
publishing_flickr_publishing_options_pane_value_size_entry_copy_value (const GValue* src_value,
                                                                       GValue* dest_value)
{
#line 540 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (src_value->data[0].v_pointer) {
#line 540 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		dest_value->data[0].v_pointer = publishing_flickr_publishing_options_pane_size_entry_ref (src_value->data[0].v_pointer);
#line 5494 "FlickrPublishing.c"
	} else {
#line 540 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		dest_value->data[0].v_pointer = NULL;
#line 5498 "FlickrPublishing.c"
	}
}


static gpointer
publishing_flickr_publishing_options_pane_value_size_entry_peek_pointer (const GValue* value)
{
#line 540 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return value->data[0].v_pointer;
#line 5508 "FlickrPublishing.c"
}


static gchar*
publishing_flickr_publishing_options_pane_value_size_entry_collect_value (GValue* value,
                                                                          guint n_collect_values,
                                                                          GTypeCValue* collect_values,
                                                                          guint collect_flags)
{
#line 540 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (collect_values[0].v_pointer) {
#line 5520 "FlickrPublishing.c"
		PublishingFlickrPublishingOptionsPaneSizeEntry * object;
		object = collect_values[0].v_pointer;
#line 540 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		if (object->parent_instance.g_class == NULL) {
#line 540 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 5527 "FlickrPublishing.c"
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
#line 540 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 5531 "FlickrPublishing.c"
		}
#line 540 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		value->data[0].v_pointer = publishing_flickr_publishing_options_pane_size_entry_ref (object);
#line 5535 "FlickrPublishing.c"
	} else {
#line 540 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		value->data[0].v_pointer = NULL;
#line 5539 "FlickrPublishing.c"
	}
#line 540 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return NULL;
#line 5543 "FlickrPublishing.c"
}


static gchar*
publishing_flickr_publishing_options_pane_value_size_entry_lcopy_value (const GValue* value,
                                                                        guint n_collect_values,
                                                                        GTypeCValue* collect_values,
                                                                        guint collect_flags)
{
	PublishingFlickrPublishingOptionsPaneSizeEntry ** object_p;
	object_p = collect_values[0].v_pointer;
#line 540 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (!object_p) {
#line 540 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
#line 5559 "FlickrPublishing.c"
	}
#line 540 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (!value->data[0].v_pointer) {
#line 540 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		*object_p = NULL;
#line 5565 "FlickrPublishing.c"
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
#line 540 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		*object_p = value->data[0].v_pointer;
#line 5569 "FlickrPublishing.c"
	} else {
#line 540 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		*object_p = publishing_flickr_publishing_options_pane_size_entry_ref (value->data[0].v_pointer);
#line 5573 "FlickrPublishing.c"
	}
#line 540 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return NULL;
#line 5577 "FlickrPublishing.c"
}


static GParamSpec*
publishing_flickr_publishing_options_pane_param_spec_size_entry (const gchar* name,
                                                                 const gchar* nick,
                                                                 const gchar* blurb,
                                                                 GType object_type,
                                                                 GParamFlags flags)
{
	PublishingFlickrPublishingOptionsPaneParamSpecSizeEntry* spec;
#line 540 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_val_if_fail (g_type_is_a (object_type, PUBLISHING_FLICKR_PUBLISHING_OPTIONS_PANE_TYPE_SIZE_ENTRY), NULL);
#line 540 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
#line 540 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	G_PARAM_SPEC (spec)->value_type = object_type;
#line 540 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return G_PARAM_SPEC (spec);
#line 5597 "FlickrPublishing.c"
}


static gpointer
publishing_flickr_publishing_options_pane_value_get_size_entry (const GValue* value)
{
#line 540 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_FLICKR_PUBLISHING_OPTIONS_PANE_TYPE_SIZE_ENTRY), NULL);
#line 540 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return value->data[0].v_pointer;
#line 5608 "FlickrPublishing.c"
}


static void
publishing_flickr_publishing_options_pane_value_set_size_entry (GValue* value,
                                                                gpointer v_object)
{
	PublishingFlickrPublishingOptionsPaneSizeEntry * old;
#line 540 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_FLICKR_PUBLISHING_OPTIONS_PANE_TYPE_SIZE_ENTRY));
#line 540 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	old = value->data[0].v_pointer;
#line 540 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (v_object) {
#line 540 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, PUBLISHING_FLICKR_PUBLISHING_OPTIONS_PANE_TYPE_SIZE_ENTRY));
#line 540 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 540 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		value->data[0].v_pointer = v_object;
#line 540 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		publishing_flickr_publishing_options_pane_size_entry_ref (value->data[0].v_pointer);
#line 5631 "FlickrPublishing.c"
	} else {
#line 540 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		value->data[0].v_pointer = NULL;
#line 5635 "FlickrPublishing.c"
	}
#line 540 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (old) {
#line 540 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		publishing_flickr_publishing_options_pane_size_entry_unref (old);
#line 5641 "FlickrPublishing.c"
	}
}


static void
publishing_flickr_publishing_options_pane_value_take_size_entry (GValue* value,
                                                                 gpointer v_object)
{
	PublishingFlickrPublishingOptionsPaneSizeEntry * old;
#line 540 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_FLICKR_PUBLISHING_OPTIONS_PANE_TYPE_SIZE_ENTRY));
#line 540 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	old = value->data[0].v_pointer;
#line 540 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (v_object) {
#line 540 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, PUBLISHING_FLICKR_PUBLISHING_OPTIONS_PANE_TYPE_SIZE_ENTRY));
#line 540 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 540 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		value->data[0].v_pointer = v_object;
#line 5663 "FlickrPublishing.c"
	} else {
#line 540 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		value->data[0].v_pointer = NULL;
#line 5667 "FlickrPublishing.c"
	}
#line 540 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (old) {
#line 540 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		publishing_flickr_publishing_options_pane_size_entry_unref (old);
#line 5673 "FlickrPublishing.c"
	}
}


static void
publishing_flickr_publishing_options_pane_size_entry_class_init (PublishingFlickrPublishingOptionsPaneSizeEntryClass * klass)
{
#line 540 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_publishing_options_pane_size_entry_parent_class = g_type_class_peek_parent (klass);
#line 540 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	((PublishingFlickrPublishingOptionsPaneSizeEntryClass *) klass)->finalize = publishing_flickr_publishing_options_pane_size_entry_finalize;
#line 5685 "FlickrPublishing.c"
}


static void
publishing_flickr_publishing_options_pane_size_entry_instance_init (PublishingFlickrPublishingOptionsPaneSizeEntry * self)
{
#line 540 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->ref_count = 1;
#line 5694 "FlickrPublishing.c"
}


static void
publishing_flickr_publishing_options_pane_size_entry_finalize (PublishingFlickrPublishingOptionsPaneSizeEntry * obj)
{
	PublishingFlickrPublishingOptionsPaneSizeEntry * self;
#line 540 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_FLICKR_PUBLISHING_OPTIONS_PANE_TYPE_SIZE_ENTRY, PublishingFlickrPublishingOptionsPaneSizeEntry);
#line 540 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_handlers_destroy (self);
#line 541 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_free0 (self->title);
#line 5708 "FlickrPublishing.c"
}


static GType
publishing_flickr_publishing_options_pane_size_entry_get_type (void)
{
	static volatile gsize publishing_flickr_publishing_options_pane_size_entry_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_flickr_publishing_options_pane_size_entry_type_id__volatile)) {
		static const GTypeValueTable g_define_type_value_table = { publishing_flickr_publishing_options_pane_value_size_entry_init, publishing_flickr_publishing_options_pane_value_size_entry_free_value, publishing_flickr_publishing_options_pane_value_size_entry_copy_value, publishing_flickr_publishing_options_pane_value_size_entry_peek_pointer, "p", publishing_flickr_publishing_options_pane_value_size_entry_collect_value, "p", publishing_flickr_publishing_options_pane_value_size_entry_lcopy_value };
		static const GTypeInfo g_define_type_info = { sizeof (PublishingFlickrPublishingOptionsPaneSizeEntryClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_flickr_publishing_options_pane_size_entry_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingFlickrPublishingOptionsPaneSizeEntry), 0, (GInstanceInitFunc) publishing_flickr_publishing_options_pane_size_entry_instance_init, &g_define_type_value_table };
		static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
		GType publishing_flickr_publishing_options_pane_size_entry_type_id;
		publishing_flickr_publishing_options_pane_size_entry_type_id = g_type_register_fundamental (g_type_fundamental_next (), "PublishingFlickrPublishingOptionsPaneSizeEntry", &g_define_type_info, &g_define_type_fundamental_info, 0);
		g_once_init_leave (&publishing_flickr_publishing_options_pane_size_entry_type_id__volatile, publishing_flickr_publishing_options_pane_size_entry_type_id);
	}
	return publishing_flickr_publishing_options_pane_size_entry_type_id__volatile;
}


static gpointer
publishing_flickr_publishing_options_pane_size_entry_ref (gpointer instance)
{
	PublishingFlickrPublishingOptionsPaneSizeEntry * self;
	self = instance;
#line 540 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_atomic_int_inc (&self->ref_count);
#line 540 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return instance;
#line 5737 "FlickrPublishing.c"
}


static void
publishing_flickr_publishing_options_pane_size_entry_unref (gpointer instance)
{
	PublishingFlickrPublishingOptionsPaneSizeEntry * self;
	self = instance;
#line 540 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
#line 540 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		PUBLISHING_FLICKR_PUBLISHING_OPTIONS_PANE_SIZE_ENTRY_GET_CLASS (self)->finalize (self);
#line 540 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		g_type_free_instance ((GTypeInstance *) self);
#line 5752 "FlickrPublishing.c"
	}
}


static PublishingFlickrPublishingOptionsPaneVisibilityEntry*
publishing_flickr_publishing_options_pane_visibility_entry_construct (GType object_type,
                                                                      const gchar* creator_title,
                                                                      PublishingFlickrVisibilitySpecification* creator_specification)
{
	PublishingFlickrPublishingOptionsPaneVisibilityEntry* self = NULL;
	PublishingFlickrVisibilitySpecification* _tmp0_;
	gchar* _tmp1_;
#line 554 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_val_if_fail (creator_title != NULL, NULL);
#line 554 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_val_if_fail (PUBLISHING_FLICKR_IS_VISIBILITY_SPECIFICATION (creator_specification), NULL);
#line 554 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self = (PublishingFlickrPublishingOptionsPaneVisibilityEntry*) g_type_create_instance (object_type);
#line 555 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = _publishing_flickr_visibility_specification_ref0 (creator_specification);
#line 555 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_publishing_flickr_visibility_specification_unref0 (self->specification);
#line 555 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->specification = _tmp0_;
#line 556 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp1_ = g_strdup (creator_title);
#line 556 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_free0 (self->title);
#line 556 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->title = _tmp1_;
#line 554 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return self;
#line 5785 "FlickrPublishing.c"
}


static PublishingFlickrPublishingOptionsPaneVisibilityEntry*
publishing_flickr_publishing_options_pane_visibility_entry_new (const gchar* creator_title,
                                                                PublishingFlickrVisibilitySpecification* creator_specification)
{
#line 554 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return publishing_flickr_publishing_options_pane_visibility_entry_construct (PUBLISHING_FLICKR_PUBLISHING_OPTIONS_PANE_TYPE_VISIBILITY_ENTRY, creator_title, creator_specification);
#line 5795 "FlickrPublishing.c"
}


static void
publishing_flickr_publishing_options_pane_value_visibility_entry_init (GValue* value)
{
#line 550 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	value->data[0].v_pointer = NULL;
#line 5804 "FlickrPublishing.c"
}


static void
publishing_flickr_publishing_options_pane_value_visibility_entry_free_value (GValue* value)
{
#line 550 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (value->data[0].v_pointer) {
#line 550 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		publishing_flickr_publishing_options_pane_visibility_entry_unref (value->data[0].v_pointer);
#line 5815 "FlickrPublishing.c"
	}
}


static void
publishing_flickr_publishing_options_pane_value_visibility_entry_copy_value (const GValue* src_value,
                                                                             GValue* dest_value)
{
#line 550 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (src_value->data[0].v_pointer) {
#line 550 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		dest_value->data[0].v_pointer = publishing_flickr_publishing_options_pane_visibility_entry_ref (src_value->data[0].v_pointer);
#line 5828 "FlickrPublishing.c"
	} else {
#line 550 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		dest_value->data[0].v_pointer = NULL;
#line 5832 "FlickrPublishing.c"
	}
}


static gpointer
publishing_flickr_publishing_options_pane_value_visibility_entry_peek_pointer (const GValue* value)
{
#line 550 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return value->data[0].v_pointer;
#line 5842 "FlickrPublishing.c"
}


static gchar*
publishing_flickr_publishing_options_pane_value_visibility_entry_collect_value (GValue* value,
                                                                                guint n_collect_values,
                                                                                GTypeCValue* collect_values,
                                                                                guint collect_flags)
{
#line 550 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (collect_values[0].v_pointer) {
#line 5854 "FlickrPublishing.c"
		PublishingFlickrPublishingOptionsPaneVisibilityEntry * object;
		object = collect_values[0].v_pointer;
#line 550 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		if (object->parent_instance.g_class == NULL) {
#line 550 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 5861 "FlickrPublishing.c"
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
#line 550 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 5865 "FlickrPublishing.c"
		}
#line 550 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		value->data[0].v_pointer = publishing_flickr_publishing_options_pane_visibility_entry_ref (object);
#line 5869 "FlickrPublishing.c"
	} else {
#line 550 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		value->data[0].v_pointer = NULL;
#line 5873 "FlickrPublishing.c"
	}
#line 550 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return NULL;
#line 5877 "FlickrPublishing.c"
}


static gchar*
publishing_flickr_publishing_options_pane_value_visibility_entry_lcopy_value (const GValue* value,
                                                                              guint n_collect_values,
                                                                              GTypeCValue* collect_values,
                                                                              guint collect_flags)
{
	PublishingFlickrPublishingOptionsPaneVisibilityEntry ** object_p;
	object_p = collect_values[0].v_pointer;
#line 550 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (!object_p) {
#line 550 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
#line 5893 "FlickrPublishing.c"
	}
#line 550 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (!value->data[0].v_pointer) {
#line 550 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		*object_p = NULL;
#line 5899 "FlickrPublishing.c"
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
#line 550 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		*object_p = value->data[0].v_pointer;
#line 5903 "FlickrPublishing.c"
	} else {
#line 550 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		*object_p = publishing_flickr_publishing_options_pane_visibility_entry_ref (value->data[0].v_pointer);
#line 5907 "FlickrPublishing.c"
	}
#line 550 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return NULL;
#line 5911 "FlickrPublishing.c"
}


static GParamSpec*
publishing_flickr_publishing_options_pane_param_spec_visibility_entry (const gchar* name,
                                                                       const gchar* nick,
                                                                       const gchar* blurb,
                                                                       GType object_type,
                                                                       GParamFlags flags)
{
	PublishingFlickrPublishingOptionsPaneParamSpecVisibilityEntry* spec;
#line 550 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_val_if_fail (g_type_is_a (object_type, PUBLISHING_FLICKR_PUBLISHING_OPTIONS_PANE_TYPE_VISIBILITY_ENTRY), NULL);
#line 550 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
#line 550 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	G_PARAM_SPEC (spec)->value_type = object_type;
#line 550 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return G_PARAM_SPEC (spec);
#line 5931 "FlickrPublishing.c"
}


static gpointer
publishing_flickr_publishing_options_pane_value_get_visibility_entry (const GValue* value)
{
#line 550 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_FLICKR_PUBLISHING_OPTIONS_PANE_TYPE_VISIBILITY_ENTRY), NULL);
#line 550 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return value->data[0].v_pointer;
#line 5942 "FlickrPublishing.c"
}


static void
publishing_flickr_publishing_options_pane_value_set_visibility_entry (GValue* value,
                                                                      gpointer v_object)
{
	PublishingFlickrPublishingOptionsPaneVisibilityEntry * old;
#line 550 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_FLICKR_PUBLISHING_OPTIONS_PANE_TYPE_VISIBILITY_ENTRY));
#line 550 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	old = value->data[0].v_pointer;
#line 550 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (v_object) {
#line 550 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, PUBLISHING_FLICKR_PUBLISHING_OPTIONS_PANE_TYPE_VISIBILITY_ENTRY));
#line 550 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 550 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		value->data[0].v_pointer = v_object;
#line 550 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		publishing_flickr_publishing_options_pane_visibility_entry_ref (value->data[0].v_pointer);
#line 5965 "FlickrPublishing.c"
	} else {
#line 550 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		value->data[0].v_pointer = NULL;
#line 5969 "FlickrPublishing.c"
	}
#line 550 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (old) {
#line 550 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		publishing_flickr_publishing_options_pane_visibility_entry_unref (old);
#line 5975 "FlickrPublishing.c"
	}
}


static void
publishing_flickr_publishing_options_pane_value_take_visibility_entry (GValue* value,
                                                                       gpointer v_object)
{
	PublishingFlickrPublishingOptionsPaneVisibilityEntry * old;
#line 550 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_FLICKR_PUBLISHING_OPTIONS_PANE_TYPE_VISIBILITY_ENTRY));
#line 550 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	old = value->data[0].v_pointer;
#line 550 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (v_object) {
#line 550 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, PUBLISHING_FLICKR_PUBLISHING_OPTIONS_PANE_TYPE_VISIBILITY_ENTRY));
#line 550 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 550 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		value->data[0].v_pointer = v_object;
#line 5997 "FlickrPublishing.c"
	} else {
#line 550 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		value->data[0].v_pointer = NULL;
#line 6001 "FlickrPublishing.c"
	}
#line 550 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (old) {
#line 550 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		publishing_flickr_publishing_options_pane_visibility_entry_unref (old);
#line 6007 "FlickrPublishing.c"
	}
}


static void
publishing_flickr_publishing_options_pane_visibility_entry_class_init (PublishingFlickrPublishingOptionsPaneVisibilityEntryClass * klass)
{
#line 550 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_publishing_options_pane_visibility_entry_parent_class = g_type_class_peek_parent (klass);
#line 550 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	((PublishingFlickrPublishingOptionsPaneVisibilityEntryClass *) klass)->finalize = publishing_flickr_publishing_options_pane_visibility_entry_finalize;
#line 6019 "FlickrPublishing.c"
}


static void
publishing_flickr_publishing_options_pane_visibility_entry_instance_init (PublishingFlickrPublishingOptionsPaneVisibilityEntry * self)
{
#line 550 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->ref_count = 1;
#line 6028 "FlickrPublishing.c"
}


static void
publishing_flickr_publishing_options_pane_visibility_entry_finalize (PublishingFlickrPublishingOptionsPaneVisibilityEntry * obj)
{
	PublishingFlickrPublishingOptionsPaneVisibilityEntry * self;
#line 550 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_FLICKR_PUBLISHING_OPTIONS_PANE_TYPE_VISIBILITY_ENTRY, PublishingFlickrPublishingOptionsPaneVisibilityEntry);
#line 550 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_signal_handlers_destroy (self);
#line 551 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_publishing_flickr_visibility_specification_unref0 (self->specification);
#line 552 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_free0 (self->title);
#line 6044 "FlickrPublishing.c"
}


static GType
publishing_flickr_publishing_options_pane_visibility_entry_get_type (void)
{
	static volatile gsize publishing_flickr_publishing_options_pane_visibility_entry_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_flickr_publishing_options_pane_visibility_entry_type_id__volatile)) {
		static const GTypeValueTable g_define_type_value_table = { publishing_flickr_publishing_options_pane_value_visibility_entry_init, publishing_flickr_publishing_options_pane_value_visibility_entry_free_value, publishing_flickr_publishing_options_pane_value_visibility_entry_copy_value, publishing_flickr_publishing_options_pane_value_visibility_entry_peek_pointer, "p", publishing_flickr_publishing_options_pane_value_visibility_entry_collect_value, "p", publishing_flickr_publishing_options_pane_value_visibility_entry_lcopy_value };
		static const GTypeInfo g_define_type_info = { sizeof (PublishingFlickrPublishingOptionsPaneVisibilityEntryClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_flickr_publishing_options_pane_visibility_entry_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingFlickrPublishingOptionsPaneVisibilityEntry), 0, (GInstanceInitFunc) publishing_flickr_publishing_options_pane_visibility_entry_instance_init, &g_define_type_value_table };
		static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
		GType publishing_flickr_publishing_options_pane_visibility_entry_type_id;
		publishing_flickr_publishing_options_pane_visibility_entry_type_id = g_type_register_fundamental (g_type_fundamental_next (), "PublishingFlickrPublishingOptionsPaneVisibilityEntry", &g_define_type_info, &g_define_type_fundamental_info, 0);
		g_once_init_leave (&publishing_flickr_publishing_options_pane_visibility_entry_type_id__volatile, publishing_flickr_publishing_options_pane_visibility_entry_type_id);
	}
	return publishing_flickr_publishing_options_pane_visibility_entry_type_id__volatile;
}


static gpointer
publishing_flickr_publishing_options_pane_visibility_entry_ref (gpointer instance)
{
	PublishingFlickrPublishingOptionsPaneVisibilityEntry * self;
	self = instance;
#line 550 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_atomic_int_inc (&self->ref_count);
#line 550 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return instance;
#line 6073 "FlickrPublishing.c"
}


static void
publishing_flickr_publishing_options_pane_visibility_entry_unref (gpointer instance)
{
	PublishingFlickrPublishingOptionsPaneVisibilityEntry * self;
	self = instance;
#line 550 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
#line 550 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		PUBLISHING_FLICKR_PUBLISHING_OPTIONS_PANE_VISIBILITY_ENTRY_GET_CLASS (self)->finalize (self);
#line 550 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		g_type_free_instance ((GTypeInstance *) self);
#line 6088 "FlickrPublishing.c"
	}
}


static void
publishing_flickr_publishing_options_pane_class_init (PublishingFlickrPublishingOptionsPaneClass * klass)
{
#line 539 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_publishing_options_pane_parent_class = g_type_class_peek_parent (klass);
#line 539 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_type_class_add_private (klass, sizeof (PublishingFlickrPublishingOptionsPanePrivate));
#line 539 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	G_OBJECT_CLASS (klass)->finalize = publishing_flickr_publishing_options_pane_finalize;
#line 539 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_publishing_options_pane_signals[PUBLISHING_FLICKR_PUBLISHING_OPTIONS_PANE_PUBLISH_SIGNAL] = g_signal_new ("publish", PUBLISHING_FLICKR_TYPE_PUBLISHING_OPTIONS_PANE, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__BOOLEAN, G_TYPE_NONE, 1, G_TYPE_BOOLEAN);
#line 539 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_publishing_options_pane_signals[PUBLISHING_FLICKR_PUBLISHING_OPTIONS_PANE_LOGOUT_SIGNAL] = g_signal_new ("logout", PUBLISHING_FLICKR_TYPE_PUBLISHING_OPTIONS_PANE, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
#line 6106 "FlickrPublishing.c"
}


static void
publishing_flickr_publishing_options_pane_spit_publishing_dialog_pane_interface_init (SpitPublishingDialogPaneIface * iface)
{
#line 539 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_publishing_options_pane_spit_publishing_dialog_pane_parent_iface = g_type_interface_peek_parent (iface);
#line 539 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	iface->get_widget = (GtkWidget* (*) (SpitPublishingDialogPane *)) publishing_flickr_publishing_options_pane_real_get_widget;
#line 539 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	iface->get_preferred_geometry = (SpitPublishingDialogPaneGeometryOptions (*) (SpitPublishingDialogPane *)) publishing_flickr_publishing_options_pane_real_get_preferred_geometry;
#line 539 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	iface->on_pane_installed = (void (*) (SpitPublishingDialogPane *)) publishing_flickr_publishing_options_pane_real_on_pane_installed;
#line 539 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	iface->on_pane_uninstalled = (void (*) (SpitPublishingDialogPane *)) publishing_flickr_publishing_options_pane_real_on_pane_uninstalled;
#line 6123 "FlickrPublishing.c"
}


static void
publishing_flickr_publishing_options_pane_instance_init (PublishingFlickrPublishingOptionsPane * self)
{
#line 539 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv = PUBLISHING_FLICKR_PUBLISHING_OPTIONS_PANE_GET_PRIVATE (self);
#line 561 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->pane_widget = NULL;
#line 562 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->visibility_label = NULL;
#line 563 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->upload_info_label = NULL;
#line 564 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->size_label = NULL;
#line 565 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->logout_button = NULL;
#line 566 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->publish_button = NULL;
#line 567 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->visibility_combo = NULL;
#line 568 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->size_combo = NULL;
#line 569 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->strip_metadata_check = NULL;
#line 570 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->visibilities = NULL;
#line 570 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->visibilities_length1 = 0;
#line 570 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->_visibilities_size_ = self->priv->visibilities_length1;
#line 571 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->sizes = NULL;
#line 571 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->sizes_length1 = 0;
#line 571 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->_sizes_size_ = self->priv->sizes_length1;
#line 572 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->parameters = NULL;
#line 573 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->publisher = NULL;
#line 6166 "FlickrPublishing.c"
}


static void
publishing_flickr_publishing_options_pane_finalize (GObject * obj)
{
	PublishingFlickrPublishingOptionsPane * self;
#line 539 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_FLICKR_TYPE_PUBLISHING_OPTIONS_PANE, PublishingFlickrPublishingOptionsPane);
#line 560 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_object_unref0 (self->priv->builder);
#line 561 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_object_unref0 (self->priv->pane_widget);
#line 562 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_object_unref0 (self->priv->visibility_label);
#line 563 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_object_unref0 (self->priv->upload_info_label);
#line 564 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_object_unref0 (self->priv->size_label);
#line 565 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_object_unref0 (self->priv->logout_button);
#line 566 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_object_unref0 (self->priv->publish_button);
#line 567 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_object_unref0 (self->priv->visibility_combo);
#line 568 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_object_unref0 (self->priv->size_combo);
#line 569 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_object_unref0 (self->priv->strip_metadata_check);
#line 570 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->visibilities = (_vala_array_free (self->priv->visibilities, self->priv->visibilities_length1, (GDestroyNotify) publishing_flickr_publishing_options_pane_visibility_entry_unref), NULL);
#line 571 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->sizes = (_vala_array_free (self->priv->sizes, self->priv->sizes_length1, (GDestroyNotify) publishing_flickr_publishing_options_pane_size_entry_unref), NULL);
#line 572 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_publishing_flickr_publishing_parameters_unref0 (self->priv->parameters);
#line 573 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_object_unref0 (self->priv->publisher);
#line 539 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	G_OBJECT_CLASS (publishing_flickr_publishing_options_pane_parent_class)->finalize (obj);
#line 6206 "FlickrPublishing.c"
}


GType
publishing_flickr_publishing_options_pane_get_type (void)
{
	static volatile gsize publishing_flickr_publishing_options_pane_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_flickr_publishing_options_pane_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingFlickrPublishingOptionsPaneClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_flickr_publishing_options_pane_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingFlickrPublishingOptionsPane), 0, (GInstanceInitFunc) publishing_flickr_publishing_options_pane_instance_init, NULL };
		static const GInterfaceInfo spit_publishing_dialog_pane_info = { (GInterfaceInitFunc) publishing_flickr_publishing_options_pane_spit_publishing_dialog_pane_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType publishing_flickr_publishing_options_pane_type_id;
		publishing_flickr_publishing_options_pane_type_id = g_type_register_static (G_TYPE_OBJECT, "PublishingFlickrPublishingOptionsPane", &g_define_type_info, 0);
		g_type_add_interface_static (publishing_flickr_publishing_options_pane_type_id, SPIT_PUBLISHING_TYPE_DIALOG_PANE, &spit_publishing_dialog_pane_info);
		g_once_init_leave (&publishing_flickr_publishing_options_pane_type_id__volatile, publishing_flickr_publishing_options_pane_type_id);
	}
	return publishing_flickr_publishing_options_pane_type_id__volatile;
}


PublishingFlickrUploader*
publishing_flickr_uploader_construct (GType object_type,
                                      PublishingRESTSupportOAuth1Session* session,
                                      SpitPublishingPublishable** publishables,
                                      int publishables_length1,
                                      PublishingFlickrPublishingParameters* parameters,
                                      gboolean strip_metadata)
{
	PublishingFlickrUploader* self = NULL;
	PublishingFlickrPublishingParameters* _tmp0_;
#line 741 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_val_if_fail (PUBLISHING_REST_SUPPORT_OAUTH1_IS_SESSION (session), NULL);
#line 741 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_val_if_fail (PUBLISHING_FLICKR_IS_PUBLISHING_PARAMETERS (parameters), NULL);
#line 743 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self = (PublishingFlickrUploader*) publishing_rest_support_batch_uploader_construct (object_type, G_TYPE_CHECK_INSTANCE_CAST (session, PUBLISHING_REST_SUPPORT_TYPE_SESSION, PublishingRESTSupportSession), publishables, publishables_length1);
#line 745 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = _publishing_flickr_publishing_parameters_ref0 (parameters);
#line 745 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_publishing_flickr_publishing_parameters_unref0 (self->priv->parameters);
#line 745 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->parameters = _tmp0_;
#line 746 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv->strip_metadata = strip_metadata;
#line 741 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return self;
#line 6252 "FlickrPublishing.c"
}


PublishingFlickrUploader*
publishing_flickr_uploader_new (PublishingRESTSupportOAuth1Session* session,
                                SpitPublishingPublishable** publishables,
                                int publishables_length1,
                                PublishingFlickrPublishingParameters* parameters,
                                gboolean strip_metadata)
{
#line 741 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return publishing_flickr_uploader_construct (PUBLISHING_FLICKR_TYPE_UPLOADER, session, publishables, publishables_length1, parameters, strip_metadata);
#line 6265 "FlickrPublishing.c"
}


static void
_vala_array_add30 (gchar** * array,
                   int* length,
                   int* size,
                   gchar* value)
{
#line 795 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if ((*length) == (*size)) {
#line 795 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 795 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		*array = g_renew (gchar*, *array, (*size) + 1);
#line 6281 "FlickrPublishing.c"
	}
#line 795 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	(*array)[(*length)++] = value;
#line 795 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	(*array)[*length] = NULL;
#line 6287 "FlickrPublishing.c"
}


static void
publishing_flickr_uploader_preprocess_publishable (PublishingFlickrUploader* self,
                                                   SpitPublishingPublishable* publishable)
{
	GExiv2Metadata* publishable_metadata = NULL;
	GExiv2Metadata* _tmp0_;
	GExiv2Metadata* _tmp10_;
	GExiv2Metadata* _tmp11_;
	GExiv2Metadata* _tmp18_;
	GExiv2Metadata* _tmp25_;
	GError * _inner_error_ = NULL;
#line 749 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (PUBLISHING_FLICKR_IS_UPLOADER (self));
#line 749 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_if_fail (SPIT_PUBLISHING_IS_PUBLISHABLE (publishable));
#line 750 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (spit_publishing_publishable_get_media_type (publishable) != SPIT_PUBLISHING_PUBLISHER_MEDIA_TYPE_PHOTO) {
#line 751 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		return;
#line 6310 "FlickrPublishing.c"
	}
#line 753 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = gexiv2_metadata_new ();
#line 753 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishable_metadata = _tmp0_;
#line 6316 "FlickrPublishing.c"
	{
		GExiv2Metadata* _tmp1_;
		GFile* _tmp2_;
		GFile* _tmp3_;
		gchar* _tmp4_;
		gchar* _tmp5_;
#line 755 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp1_ = publishable_metadata;
#line 755 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp2_ = spit_publishing_publishable_get_serialized_file (publishable);
#line 755 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp3_ = _tmp2_;
#line 755 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp4_ = g_file_get_path (_tmp3_);
#line 755 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp5_ = _tmp4_;
#line 755 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		gexiv2_metadata_open_path (_tmp1_, _tmp5_, &_inner_error_);
#line 755 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_g_free0 (_tmp5_);
#line 755 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_g_object_unref0 (_tmp3_);
#line 755 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 6341 "FlickrPublishing.c"
			goto __catch18_g_error;
		}
	}
	goto __finally18;
	__catch18_g_error:
	{
		GError* err = NULL;
		GFile* _tmp6_;
		GFile* _tmp7_;
		gchar* _tmp8_;
		gchar* _tmp9_;
#line 754 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		err = _inner_error_;
#line 754 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_inner_error_ = NULL;
#line 757 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp6_ = spit_publishing_publishable_get_serialized_file (publishable);
#line 757 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp7_ = _tmp6_;
#line 757 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp8_ = g_file_get_path (_tmp7_);
#line 757 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp9_ = _tmp8_;
#line 757 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		g_warning ("FlickrPublishing.vala:757: couldn't read metadata from file '%s' for u" \
"pload preprocessing.", _tmp9_);
#line 757 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_g_free0 (_tmp9_);
#line 757 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_g_object_unref0 (_tmp7_);
#line 754 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_g_error_free0 (err);
#line 6373 "FlickrPublishing.c"
	}
	__finally18:
#line 754 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 754 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_g_object_unref0 (publishable_metadata);
#line 754 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 754 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		g_clear_error (&_inner_error_);
#line 754 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		return;
#line 6386 "FlickrPublishing.c"
	}
#line 765 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp10_ = publishable_metadata;
#line 765 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (!gexiv2_metadata_has_iptc (_tmp10_)) {
#line 766 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_g_object_unref0 (publishable_metadata);
#line 766 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		return;
#line 6396 "FlickrPublishing.c"
	}
#line 768 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp11_ = publishable_metadata;
#line 768 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (gexiv2_metadata_has_tag (_tmp11_, "Iptc.Application2.Caption")) {
#line 6402 "FlickrPublishing.c"
		GExiv2Metadata* _tmp12_;
		GExiv2Metadata* _tmp13_;
		gchar* _tmp14_;
		gchar* _tmp15_;
		gchar* _tmp16_;
		gchar* _tmp17_;
#line 769 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp12_ = publishable_metadata;
#line 769 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp13_ = publishable_metadata;
#line 769 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp14_ = gexiv2_metadata_get_tag_string (_tmp13_, "Iptc.Application2.Caption");
#line 769 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp15_ = _tmp14_;
#line 769 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp16_ = publishing_rest_support_asciify_string (_tmp15_);
#line 769 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp17_ = _tmp16_;
#line 769 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		gexiv2_metadata_set_tag_string (_tmp12_, "Iptc.Application2.Caption", _tmp17_);
#line 769 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_g_free0 (_tmp17_);
#line 769 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_g_free0 (_tmp15_);
#line 6427 "FlickrPublishing.c"
	}
#line 773 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp18_ = publishable_metadata;
#line 773 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (gexiv2_metadata_has_tag (_tmp18_, "Iptc.Application2.Headline")) {
#line 6433 "FlickrPublishing.c"
		GExiv2Metadata* _tmp19_;
		GExiv2Metadata* _tmp20_;
		gchar* _tmp21_;
		gchar* _tmp22_;
		gchar* _tmp23_;
		gchar* _tmp24_;
#line 774 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp19_ = publishable_metadata;
#line 774 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp20_ = publishable_metadata;
#line 774 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp21_ = gexiv2_metadata_get_tag_string (_tmp20_, "Iptc.Application2.Headline");
#line 774 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp22_ = _tmp21_;
#line 774 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp23_ = publishing_rest_support_asciify_string (_tmp22_);
#line 774 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp24_ = _tmp23_;
#line 774 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		gexiv2_metadata_set_tag_string (_tmp19_, "Iptc.Application2.Headline", _tmp24_);
#line 774 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_g_free0 (_tmp24_);
#line 774 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_g_free0 (_tmp22_);
#line 6458 "FlickrPublishing.c"
	}
#line 778 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp25_ = publishable_metadata;
#line 778 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	if (gexiv2_metadata_has_tag (_tmp25_, "Iptc.Application2.Keywords")) {
#line 6464 "FlickrPublishing.c"
		GeeSet* keyword_set = NULL;
		GeeHashSet* _tmp26_;
		gchar** iptc_keywords = NULL;
		GExiv2Metadata* _tmp27_;
		gchar** _tmp28_;
		gchar** _tmp29_;
		gint iptc_keywords_length1;
		gint _iptc_keywords_size_;
		gchar** _tmp30_;
		gint _tmp30__length1;
		gchar** xmp_keywords = NULL;
		GExiv2Metadata* _tmp35_;
		gchar** _tmp36_;
		gchar** _tmp37_;
		gint xmp_keywords_length1;
		gint _xmp_keywords_size_;
		gchar** _tmp38_;
		gint _tmp38__length1;
		gchar** all_keywords = NULL;
		GeeSet* _tmp43_;
		gint _tmp44_;
		gpointer* _tmp45_;
		gint all_keywords_length1;
		gint _all_keywords_size_;
		gchar** _tmp46_;
		gint _tmp46__length1;
		gchar** no_keywords = NULL;
		gchar** _tmp47_;
		gint no_keywords_length1;
		gint _no_keywords_size_;
		gchar** _tmp48_;
		gint _tmp48__length1;
		gchar* _tmp49_;
		GExiv2Metadata* _tmp50_;
		gchar** _tmp51_;
		gint _tmp51__length1;
		GExiv2Metadata* _tmp52_;
		gchar** _tmp53_;
		gint _tmp53__length1;
#line 779 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp26_ = gee_hash_set_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, (GDestroyNotify) g_free, NULL, NULL, NULL, NULL, NULL, NULL);
#line 779 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		keyword_set = G_TYPE_CHECK_INSTANCE_CAST (_tmp26_, GEE_TYPE_SET, GeeSet);
#line 780 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp27_ = publishable_metadata;
#line 780 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp29_ = _tmp28_ = gexiv2_metadata_get_tag_multiple (_tmp27_, "Iptc.Application2.Keywords");
#line 780 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		iptc_keywords = _tmp29_;
#line 780 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		iptc_keywords_length1 = _vala_array_length (_tmp28_);
#line 780 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_iptc_keywords_size_ = iptc_keywords_length1;
#line 781 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp30_ = iptc_keywords;
#line 781 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp30__length1 = iptc_keywords_length1;
#line 781 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		if (_tmp30_ != NULL) {
#line 6524 "FlickrPublishing.c"
			gchar** _tmp31_;
			gint _tmp31__length1;
#line 782 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_tmp31_ = iptc_keywords;
#line 782 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_tmp31__length1 = iptc_keywords_length1;
#line 6531 "FlickrPublishing.c"
			{
				gchar** keyword_collection = NULL;
				gint keyword_collection_length1 = 0;
				gint _keyword_collection_size_ = 0;
				gint keyword_it = 0;
#line 782 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				keyword_collection = _tmp31_;
#line 782 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				keyword_collection_length1 = _tmp31__length1;
#line 782 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				for (keyword_it = 0; keyword_it < _tmp31__length1; keyword_it = keyword_it + 1) {
#line 6543 "FlickrPublishing.c"
					gchar* _tmp32_;
					gchar* keyword = NULL;
#line 782 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
					_tmp32_ = g_strdup (keyword_collection[keyword_it]);
#line 782 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
					keyword = _tmp32_;
#line 6550 "FlickrPublishing.c"
					{
						GeeSet* _tmp33_;
						const gchar* _tmp34_;
#line 783 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
						_tmp33_ = keyword_set;
#line 783 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
						_tmp34_ = keyword;
#line 783 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
						gee_collection_add (G_TYPE_CHECK_INSTANCE_CAST (_tmp33_, GEE_TYPE_COLLECTION, GeeCollection), _tmp34_);
#line 782 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
						_g_free0 (keyword);
#line 6562 "FlickrPublishing.c"
					}
				}
			}
		}
#line 785 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp35_ = publishable_metadata;
#line 785 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp37_ = _tmp36_ = gexiv2_metadata_get_tag_multiple (_tmp35_, "Xmp.dc.subject");
#line 785 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		xmp_keywords = _tmp37_;
#line 785 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		xmp_keywords_length1 = _vala_array_length (_tmp36_);
#line 785 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_xmp_keywords_size_ = xmp_keywords_length1;
#line 786 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp38_ = xmp_keywords;
#line 786 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp38__length1 = xmp_keywords_length1;
#line 786 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		if (_tmp38_ != NULL) {
#line 6583 "FlickrPublishing.c"
			gchar** _tmp39_;
			gint _tmp39__length1;
#line 787 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_tmp39_ = xmp_keywords;
#line 787 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_tmp39__length1 = xmp_keywords_length1;
#line 6590 "FlickrPublishing.c"
			{
				gchar** keyword_collection = NULL;
				gint keyword_collection_length1 = 0;
				gint _keyword_collection_size_ = 0;
				gint keyword_it = 0;
#line 787 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				keyword_collection = _tmp39_;
#line 787 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				keyword_collection_length1 = _tmp39__length1;
#line 787 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
				for (keyword_it = 0; keyword_it < _tmp39__length1; keyword_it = keyword_it + 1) {
#line 6602 "FlickrPublishing.c"
					gchar* _tmp40_;
					gchar* keyword = NULL;
#line 787 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
					_tmp40_ = g_strdup (keyword_collection[keyword_it]);
#line 787 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
					keyword = _tmp40_;
#line 6609 "FlickrPublishing.c"
					{
						GeeSet* _tmp41_;
						const gchar* _tmp42_;
#line 788 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
						_tmp41_ = keyword_set;
#line 788 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
						_tmp42_ = keyword;
#line 788 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
						gee_collection_add (G_TYPE_CHECK_INSTANCE_CAST (_tmp41_, GEE_TYPE_COLLECTION, GeeCollection), _tmp42_);
#line 787 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
						_g_free0 (keyword);
#line 6621 "FlickrPublishing.c"
					}
				}
			}
		}
#line 790 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp43_ = keyword_set;
#line 790 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp45_ = gee_collection_to_array (G_TYPE_CHECK_INSTANCE_CAST (_tmp43_, GEE_TYPE_COLLECTION, GeeCollection), &_tmp44_);
#line 790 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		all_keywords = _tmp45_;
#line 790 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		all_keywords_length1 = _tmp44_;
#line 790 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_all_keywords_size_ = all_keywords_length1;
#line 795 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp46_ = all_keywords;
#line 795 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp46__length1 = all_keywords_length1;
#line 795 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_vala_array_add30 (&all_keywords, &all_keywords_length1, &_all_keywords_size_, NULL);
#line 797 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp47_ = g_new0 (gchar*, 1 + 1);
#line 797 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		no_keywords = _tmp47_;
#line 797 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		no_keywords_length1 = 1;
#line 797 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_no_keywords_size_ = no_keywords_length1;
#line 802 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp48_ = no_keywords;
#line 802 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp48__length1 = no_keywords_length1;
#line 802 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_g_free0 (_tmp48_[0]);
#line 802 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp48_[0] = NULL;
#line 802 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp49_ = _tmp48_[0];
#line 804 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp50_ = publishable_metadata;
#line 804 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp51_ = all_keywords;
#line 804 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp51__length1 = all_keywords_length1;
#line 804 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		gexiv2_metadata_set_tag_multiple (_tmp50_, "Xmp.dc.subject", _tmp51_);
#line 805 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp52_ = publishable_metadata;
#line 805 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp53_ = no_keywords;
#line 805 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_tmp53__length1 = no_keywords_length1;
#line 805 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		gexiv2_metadata_set_tag_multiple (_tmp52_, "Iptc.Application2.Keywords", _tmp53_);
#line 6676 "FlickrPublishing.c"
		{
			GExiv2Metadata* _tmp54_;
			GFile* _tmp55_;
			GFile* _tmp56_;
			gchar* _tmp57_;
			gchar* _tmp58_;
#line 808 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_tmp54_ = publishable_metadata;
#line 808 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_tmp55_ = spit_publishing_publishable_get_serialized_file (publishable);
#line 808 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_tmp56_ = _tmp55_;
#line 808 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_tmp57_ = g_file_get_path (_tmp56_);
#line 808 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_tmp58_ = _tmp57_;
#line 808 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			gexiv2_metadata_save_file (_tmp54_, _tmp58_, &_inner_error_);
#line 808 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_g_free0 (_tmp58_);
#line 808 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_g_object_unref0 (_tmp56_);
#line 808 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 6701 "FlickrPublishing.c"
				goto __catch19_g_error;
			}
		}
		goto __finally19;
		__catch19_g_error:
		{
			GError* err = NULL;
			GFile* _tmp59_;
			GFile* _tmp60_;
			gchar* _tmp61_;
			gchar* _tmp62_;
#line 807 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			err = _inner_error_;
#line 807 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_inner_error_ = NULL;
#line 810 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_tmp59_ = spit_publishing_publishable_get_serialized_file (publishable);
#line 810 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_tmp60_ = _tmp59_;
#line 810 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_tmp61_ = g_file_get_path (_tmp60_);
#line 810 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_tmp62_ = _tmp61_;
#line 810 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			g_warning ("FlickrPublishing.vala:810: couldn't write metadata to file '%s' for up" \
"load preprocessing.", _tmp62_);
#line 810 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_g_free0 (_tmp62_);
#line 810 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_g_object_unref0 (_tmp60_);
#line 807 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_g_error_free0 (err);
#line 6733 "FlickrPublishing.c"
		}
		__finally19:
#line 807 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 807 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			no_keywords = (_vala_array_free (no_keywords, no_keywords_length1, (GDestroyNotify) g_free), NULL);
#line 807 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			all_keywords = (_vala_array_free (all_keywords, all_keywords_length1, (GDestroyNotify) g_free), NULL);
#line 807 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			xmp_keywords = (_vala_array_free (xmp_keywords, xmp_keywords_length1, (GDestroyNotify) g_free), NULL);
#line 807 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			iptc_keywords = (_vala_array_free (iptc_keywords, iptc_keywords_length1, (GDestroyNotify) g_free), NULL);
#line 807 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_g_object_unref0 (keyword_set);
#line 807 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			_g_object_unref0 (publishable_metadata);
#line 807 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 807 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			g_clear_error (&_inner_error_);
#line 807 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
			return;
#line 6756 "FlickrPublishing.c"
		}
#line 778 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		no_keywords = (_vala_array_free (no_keywords, no_keywords_length1, (GDestroyNotify) g_free), NULL);
#line 778 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		all_keywords = (_vala_array_free (all_keywords, all_keywords_length1, (GDestroyNotify) g_free), NULL);
#line 778 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		xmp_keywords = (_vala_array_free (xmp_keywords, xmp_keywords_length1, (GDestroyNotify) g_free), NULL);
#line 778 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		iptc_keywords = (_vala_array_free (iptc_keywords, iptc_keywords_length1, (GDestroyNotify) g_free), NULL);
#line 778 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
		_g_object_unref0 (keyword_set);
#line 6768 "FlickrPublishing.c"
	}
#line 749 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_object_unref0 (publishable_metadata);
#line 6772 "FlickrPublishing.c"
}


static PublishingRESTSupportTransaction*
publishing_flickr_uploader_real_create_transaction (PublishingRESTSupportBatchUploader* base,
                                                    SpitPublishingPublishable* publishable)
{
	PublishingFlickrUploader * self;
	PublishingRESTSupportTransaction* result = NULL;
	SpitPublishingPublishable* _tmp0_;
	SpitPublishingPublishable* _tmp1_;
	PublishingRESTSupportSession* _tmp2_;
	PublishingRESTSupportOAuth1Session* _tmp3_;
	PublishingFlickrPublishingParameters* _tmp4_;
	SpitPublishingPublishable* _tmp5_;
	SpitPublishingPublishable* _tmp6_;
	PublishingFlickrUploadTransaction* _tmp7_;
	PublishingRESTSupportTransaction* _tmp8_;
#line 816 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_FLICKR_TYPE_UPLOADER, PublishingFlickrUploader);
#line 816 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_return_val_if_fail (SPIT_PUBLISHING_IS_PUBLISHABLE (publishable), NULL);
#line 818 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp0_ = publishing_rest_support_batch_uploader_get_current_publishable (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_BATCH_UPLOADER, PublishingRESTSupportBatchUploader));
#line 818 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp1_ = _tmp0_;
#line 818 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_uploader_preprocess_publishable (self, _tmp1_);
#line 818 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_object_unref0 (_tmp1_);
#line 819 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp2_ = publishing_rest_support_batch_uploader_get_session (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_BATCH_UPLOADER, PublishingRESTSupportBatchUploader));
#line 819 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp3_ = G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, PUBLISHING_REST_SUPPORT_OAUTH1_TYPE_SESSION, PublishingRESTSupportOAuth1Session);
#line 819 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp4_ = self->priv->parameters;
#line 819 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp5_ = publishing_rest_support_batch_uploader_get_current_publishable (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_BATCH_UPLOADER, PublishingRESTSupportBatchUploader));
#line 819 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp6_ = _tmp5_;
#line 819 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp7_ = publishing_flickr_upload_transaction_new (_tmp3_, _tmp4_, _tmp6_);
#line 819 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_tmp8_ = G_TYPE_CHECK_INSTANCE_CAST (_tmp7_, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction);
#line 819 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_g_object_unref0 (_tmp6_);
#line 819 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_publishing_rest_support_session_unref0 (_tmp3_);
#line 819 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	result = _tmp8_;
#line 819 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	return result;
#line 6825 "FlickrPublishing.c"
}


static void
publishing_flickr_uploader_class_init (PublishingFlickrUploaderClass * klass)
{
#line 737 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	publishing_flickr_uploader_parent_class = g_type_class_peek_parent (klass);
#line 737 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	((PublishingRESTSupportBatchUploaderClass *) klass)->finalize = publishing_flickr_uploader_finalize;
#line 737 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	g_type_class_add_private (klass, sizeof (PublishingFlickrUploaderPrivate));
#line 737 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	((PublishingRESTSupportBatchUploaderClass *) klass)->create_transaction = (PublishingRESTSupportTransaction* (*) (PublishingRESTSupportBatchUploader *, SpitPublishingPublishable*)) publishing_flickr_uploader_real_create_transaction;
#line 6840 "FlickrPublishing.c"
}


static void
publishing_flickr_uploader_instance_init (PublishingFlickrUploader * self)
{
#line 737 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self->priv = PUBLISHING_FLICKR_UPLOADER_GET_PRIVATE (self);
#line 6849 "FlickrPublishing.c"
}


static void
publishing_flickr_uploader_finalize (PublishingRESTSupportBatchUploader * obj)
{
	PublishingFlickrUploader * self;
#line 737 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_FLICKR_TYPE_UPLOADER, PublishingFlickrUploader);
#line 738 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	_publishing_flickr_publishing_parameters_unref0 (self->priv->parameters);
#line 737 "/home/jens/Source/shotwell/plugins/shotwell-publishing/FlickrPublishing.vala"
	PUBLISHING_REST_SUPPORT_BATCH_UPLOADER_CLASS (publishing_flickr_uploader_parent_class)->finalize (obj);
#line 6863 "FlickrPublishing.c"
}


GType
publishing_flickr_uploader_get_type (void)
{
	static volatile gsize publishing_flickr_uploader_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_flickr_uploader_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingFlickrUploaderClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_flickr_uploader_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingFlickrUploader), 0, (GInstanceInitFunc) publishing_flickr_uploader_instance_init, NULL };
		GType publishing_flickr_uploader_type_id;
		publishing_flickr_uploader_type_id = g_type_register_static (PUBLISHING_REST_SUPPORT_TYPE_BATCH_UPLOADER, "PublishingFlickrUploader", &g_define_type_info, 0);
		g_once_init_leave (&publishing_flickr_uploader_type_id__volatile, publishing_flickr_uploader_type_id);
	}
	return publishing_flickr_uploader_type_id__volatile;
}


static void
_vala_array_destroy (gpointer array,
                     gint array_length,
                     GDestroyNotify destroy_func)
{
	if ((array != NULL) && (destroy_func != NULL)) {
		int i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}


static void
_vala_array_free (gpointer array,
                  gint array_length,
                  GDestroyNotify destroy_func)
{
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}


static gint
_vala_array_length (gpointer array)
{
	int length;
	length = 0;
	if (array) {
		while (((gpointer*) array)[length]) {
			length++;
		}
	}
	return length;
}



